# frozen_string_literal: true

# Collection of pseudo-legal move tablebases.
module PseudoLegalMoveTablebase
  # Shogi chess variant.
  module Shogi
    # Computerized database that contains precalculated exhaustive pseudo-legal
    # moves of Shogi positions.
    #
    # @see https://developer.sashite.com/specs/general-actor-notation
    DB = {"S:+B"=>{0=>[[{1=>:enemy}, 1, "S:+B", true], [{9=>:enemy}, 9, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{1=>nil}, 1, "S:+B", false], [{9=>nil}, 9, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 20=>:enemy}, 20, "S:+B", true], [{10=>nil, 20=>nil}, 20, "S:+B", false], [{10=>nil, 20=>nil, 30=>:enemy}, 30, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil}, 30, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>:enemy}, 40, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil}, 40, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 1=>[[{0=>:enemy}, 0, "S:+B", true], [{2=>:enemy}, 2, "S:+B", true], [{9=>:enemy}, 9, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{0=>nil}, 0, "S:+B", false], [{2=>nil}, 2, "S:+B", false], [{9=>nil}, 9, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 21=>:enemy}, 21, "S:+B", true], [{11=>nil, 21=>nil}, 21, "S:+B", false], [{11=>nil, 21=>nil, 31=>:enemy}, 31, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil}, 31, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>:enemy}, 41, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil}, 41, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 2=>[[{1=>:enemy}, 1, "S:+B", true], [{3=>:enemy}, 3, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{1=>nil}, 1, "S:+B", false], [{3=>nil}, 3, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 18=>:enemy}, 18, "S:+B", true], [{10=>nil, 18=>nil}, 18, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 22=>:enemy}, 22, "S:+B", true], [{12=>nil, 22=>nil}, 22, "S:+B", false], [{12=>nil, 22=>nil, 32=>:enemy}, 32, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil}, 32, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>:enemy}, 42, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil}, 42, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 3=>[[{2=>:enemy}, 2, "S:+B", true], [{4=>:enemy}, 4, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{2=>nil}, 2, "S:+B", false], [{4=>nil}, 4, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 19=>:enemy}, 19, "S:+B", true], [{11=>nil, 19=>nil}, 19, "S:+B", false], [{11=>nil, 19=>nil, 27=>:enemy}, 27, "S:+B", true], [{11=>nil, 19=>nil, 27=>nil}, 27, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 23=>:enemy}, 23, "S:+B", true], [{13=>nil, 23=>nil}, 23, "S:+B", false], [{13=>nil, 23=>nil, 33=>:enemy}, 33, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil}, 33, "S:+B", false], [{13=>nil, 23=>nil, 33=>nil, 43=>:enemy}, 43, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil}, 43, "S:+B", false], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 4=>[[{3=>:enemy}, 3, "S:+B", true], [{5=>:enemy}, 5, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{3=>nil}, 3, "S:+B", false], [{5=>nil}, 5, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 20=>:enemy}, 20, "S:+B", true], [{12=>nil, 20=>nil}, 20, "S:+B", false], [{12=>nil, 20=>nil, 28=>:enemy}, 28, "S:+B", true], [{12=>nil, 20=>nil, 28=>nil}, 28, "S:+B", false], [{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, 36, "S:+B", true], [{12=>nil, 20=>nil, 28=>nil, 36=>nil}, 36, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 24=>:enemy}, 24, "S:+B", true], [{14=>nil, 24=>nil}, 24, "S:+B", false], [{14=>nil, 24=>nil, 34=>:enemy}, 34, "S:+B", true], [{14=>nil, 24=>nil, 34=>nil}, 34, "S:+B", false], [{14=>nil, 24=>nil, 34=>nil, 44=>:enemy}, 44, "S:+B", true], [{14=>nil, 24=>nil, 34=>nil, 44=>nil}, 44, "S:+B", false]], 5=>[[{4=>:enemy}, 4, "S:+B", true], [{6=>:enemy}, 6, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{4=>nil}, 4, "S:+B", false], [{6=>nil}, 6, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 21=>:enemy}, 21, "S:+B", true], [{13=>nil, 21=>nil}, 21, "S:+B", false], [{13=>nil, 21=>nil, 29=>:enemy}, 29, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil}, 29, "S:+B", false], [{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, 37, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil}, 37, "S:+B", false], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 25=>:enemy}, 25, "S:+B", true], [{15=>nil, 25=>nil}, 25, "S:+B", false], [{15=>nil, 25=>nil, 35=>:enemy}, 35, "S:+B", true], [{15=>nil, 25=>nil, 35=>nil}, 35, "S:+B", false]], 6=>[[{5=>:enemy}, 5, "S:+B", true], [{7=>:enemy}, 7, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{5=>nil}, 5, "S:+B", false], [{7=>nil}, 7, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 22=>:enemy}, 22, "S:+B", true], [{14=>nil, 22=>nil}, 22, "S:+B", false], [{14=>nil, 22=>nil, 30=>:enemy}, 30, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil}, 30, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, 38, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil}, 38, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 26=>:enemy}, 26, "S:+B", true], [{16=>nil, 26=>nil}, 26, "S:+B", false]], 7=>[[{6=>:enemy}, 6, "S:+B", true], [{8=>:enemy}, 8, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{6=>nil}, 6, "S:+B", false], [{8=>nil}, 8, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 23=>:enemy}, 23, "S:+B", true], [{15=>nil, 23=>nil}, 23, "S:+B", false], [{15=>nil, 23=>nil, 31=>:enemy}, 31, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil}, 31, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, 39, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil}, 39, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{17=>nil}, 17, "S:+B", false]], 8=>[[{7=>:enemy}, 7, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{7=>nil}, 7, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 24=>:enemy}, 24, "S:+B", true], [{16=>nil, 24=>nil}, 24, "S:+B", false], [{16=>nil, 24=>nil, 32=>:enemy}, 32, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil}, 32, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, 40, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil}, 40, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{17=>nil}, 17, "S:+B", false]], 9=>[[{0=>:enemy}, 0, "S:+B", true], [{1=>:enemy}, 1, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{18=>:enemy}, 18, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{0=>nil}, 0, "S:+B", false], [{1=>nil}, 1, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{18=>nil}, 18, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 29=>:enemy}, 29, "S:+B", true], [{19=>nil, 29=>nil}, 29, "S:+B", false], [{19=>nil, 29=>nil, 39=>:enemy}, 39, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil}, 39, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>:enemy}, 49, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil}, 49, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 10=>[[{0=>:enemy}, 0, "S:+B", true], [{1=>:enemy}, 1, "S:+B", true], [{2=>:enemy}, 2, "S:+B", true], [{9=>:enemy}, 9, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{18=>:enemy}, 18, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{0=>nil}, 0, "S:+B", false], [{1=>nil}, 1, "S:+B", false], [{2=>nil}, 2, "S:+B", false], [{9=>nil}, 9, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{18=>nil}, 18, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 30=>:enemy}, 30, "S:+B", true], [{20=>nil, 30=>nil}, 30, "S:+B", false], [{20=>nil, 30=>nil, 40=>:enemy}, 40, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil}, 40, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 11=>[[{1=>:enemy}, 1, "S:+B", true], [{2=>:enemy}, 2, "S:+B", true], [{3=>:enemy}, 3, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{1=>nil}, 1, "S:+B", false], [{2=>nil}, 2, "S:+B", false], [{3=>nil}, 3, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 27=>:enemy}, 27, "S:+B", true], [{19=>nil, 27=>nil}, 27, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 31=>:enemy}, 31, "S:+B", true], [{21=>nil, 31=>nil}, 31, "S:+B", false], [{21=>nil, 31=>nil, 41=>:enemy}, 41, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil}, 41, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 12=>[[{2=>:enemy}, 2, "S:+B", true], [{3=>:enemy}, 3, "S:+B", true], [{4=>:enemy}, 4, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{2=>nil}, 2, "S:+B", false], [{3=>nil}, 3, "S:+B", false], [{4=>nil}, 4, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 28=>:enemy}, 28, "S:+B", true], [{20=>nil, 28=>nil}, 28, "S:+B", false], [{20=>nil, 28=>nil, 36=>:enemy}, 36, "S:+B", true], [{20=>nil, 28=>nil, 36=>nil}, 36, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 32=>:enemy}, 32, "S:+B", true], [{22=>nil, 32=>nil}, 32, "S:+B", false], [{22=>nil, 32=>nil, 42=>:enemy}, 42, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil}, 42, "S:+B", false], [{22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 13=>[[{3=>:enemy}, 3, "S:+B", true], [{4=>:enemy}, 4, "S:+B", true], [{5=>:enemy}, 5, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{3=>nil}, 3, "S:+B", false], [{4=>nil}, 4, "S:+B", false], [{5=>nil}, 5, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 29=>:enemy}, 29, "S:+B", true], [{21=>nil, 29=>nil}, 29, "S:+B", false], [{21=>nil, 29=>nil, 37=>:enemy}, 37, "S:+B", true], [{21=>nil, 29=>nil, 37=>nil}, 37, "S:+B", false], [{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 33=>:enemy}, 33, "S:+B", true], [{23=>nil, 33=>nil}, 33, "S:+B", false], [{23=>nil, 33=>nil, 43=>:enemy}, 43, "S:+B", true], [{23=>nil, 33=>nil, 43=>nil}, 43, "S:+B", false], [{23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 14=>[[{4=>:enemy}, 4, "S:+B", true], [{5=>:enemy}, 5, "S:+B", true], [{6=>:enemy}, 6, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{4=>nil}, 4, "S:+B", false], [{5=>nil}, 5, "S:+B", false], [{6=>nil}, 6, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 30=>:enemy}, 30, "S:+B", true], [{22=>nil, 30=>nil}, 30, "S:+B", false], [{22=>nil, 30=>nil, 38=>:enemy}, 38, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil}, 38, "S:+B", false], [{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 34=>:enemy}, 34, "S:+B", true], [{24=>nil, 34=>nil}, 34, "S:+B", false], [{24=>nil, 34=>nil, 44=>:enemy}, 44, "S:+B", true], [{24=>nil, 34=>nil, 44=>nil}, 44, "S:+B", false]], 15=>[[{5=>:enemy}, 5, "S:+B", true], [{6=>:enemy}, 6, "S:+B", true], [{7=>:enemy}, 7, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{5=>nil}, 5, "S:+B", false], [{6=>nil}, 6, "S:+B", false], [{7=>nil}, 7, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 31=>:enemy}, 31, "S:+B", true], [{23=>nil, 31=>nil}, 31, "S:+B", false], [{23=>nil, 31=>nil, 39=>:enemy}, 39, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil}, 39, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 35=>:enemy}, 35, "S:+B", true], [{25=>nil, 35=>nil}, 35, "S:+B", false]], 16=>[[{6=>:enemy}, 6, "S:+B", true], [{7=>:enemy}, 7, "S:+B", true], [{8=>:enemy}, 8, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{6=>nil}, 6, "S:+B", false], [{7=>nil}, 7, "S:+B", false], [{8=>nil}, 8, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{17=>nil}, 17, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 32=>:enemy}, 32, "S:+B", true], [{24=>nil, 32=>nil}, 32, "S:+B", false], [{24=>nil, 32=>nil, 40=>:enemy}, 40, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil}, 40, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{26=>nil}, 26, "S:+B", false]], 17=>[[{7=>:enemy}, 7, "S:+B", true], [{8=>:enemy}, 8, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{7=>nil}, 7, "S:+B", false], [{8=>nil}, 8, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 33=>:enemy}, 33, "S:+B", true], [{25=>nil, 33=>nil}, 33, "S:+B", false], [{25=>nil, 33=>nil, 41=>:enemy}, 41, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil}, 41, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, 49, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil}, 49, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{26=>nil}, 26, "S:+B", false]], 18=>[[{9=>:enemy}, 9, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{27=>:enemy}, 27, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{9=>nil}, 9, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 2=>:enemy}, 2, "S:+B", true], [{10=>nil, 2=>nil}, 2, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{27=>nil}, 27, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 38=>:enemy}, 38, "S:+B", true], [{28=>nil, 38=>nil}, 38, "S:+B", false], [{28=>nil, 38=>nil, 48=>:enemy}, 48, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil}, 48, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>:enemy}, 58, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil}, 58, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:+B", false]], 19=>[[{9=>:enemy}, 9, "S:+B", true], [{10=>:enemy}, 10, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{18=>:enemy}, 18, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{27=>:enemy}, 27, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{9=>nil}, 9, "S:+B", false], [{10=>nil}, 10, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 3=>:enemy}, 3, "S:+B", true], [{11=>nil, 3=>nil}, 3, "S:+B", false], [{18=>nil}, 18, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{27=>nil}, 27, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 39=>:enemy}, 39, "S:+B", true], [{29=>nil, 39=>nil}, 39, "S:+B", false], [{29=>nil, 39=>nil, 49=>:enemy}, 49, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil}, 49, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 20=>[[{10=>:enemy}, 10, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 0=>:enemy}, 0, "S:+B", true], [{10=>nil, 0=>nil}, 0, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 4=>:enemy}, 4, "S:+B", true], [{12=>nil, 4=>nil}, 4, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 36=>:enemy}, 36, "S:+B", true], [{28=>nil, 36=>nil}, 36, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 40=>:enemy}, 40, "S:+B", true], [{30=>nil, 40=>nil}, 40, "S:+B", false], [{30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 21=>[[{11=>:enemy}, 11, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 1=>:enemy}, 1, "S:+B", true], [{11=>nil, 1=>nil}, 1, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 5=>:enemy}, 5, "S:+B", true], [{13=>nil, 5=>nil}, 5, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 37=>:enemy}, 37, "S:+B", true], [{29=>nil, 37=>nil}, 37, "S:+B", false], [{29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 41=>:enemy}, 41, "S:+B", true], [{31=>nil, 41=>nil}, 41, "S:+B", false], [{31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 22=>[[{12=>:enemy}, 12, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 2=>:enemy}, 2, "S:+B", true], [{12=>nil, 2=>nil}, 2, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 6=>:enemy}, 6, "S:+B", true], [{14=>nil, 6=>nil}, 6, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 38=>:enemy}, 38, "S:+B", true], [{30=>nil, 38=>nil}, 38, "S:+B", false], [{30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 42=>:enemy}, 42, "S:+B", true], [{32=>nil, 42=>nil}, 42, "S:+B", false], [{32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 23=>[[{13=>:enemy}, 13, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 3=>:enemy}, 3, "S:+B", true], [{13=>nil, 3=>nil}, 3, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 7=>:enemy}, 7, "S:+B", true], [{15=>nil, 7=>nil}, 7, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 39=>:enemy}, 39, "S:+B", true], [{31=>nil, 39=>nil}, 39, "S:+B", false], [{31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 43=>:enemy}, 43, "S:+B", true], [{33=>nil, 43=>nil}, 43, "S:+B", false], [{33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 24=>[[{14=>:enemy}, 14, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 4=>:enemy}, 4, "S:+B", true], [{14=>nil, 4=>nil}, 4, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 8=>:enemy}, 8, "S:+B", true], [{16=>nil, 8=>nil}, 8, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 40=>:enemy}, 40, "S:+B", true], [{32=>nil, 40=>nil}, 40, "S:+B", false], [{32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 44=>:enemy}, 44, "S:+B", true], [{34=>nil, 44=>nil}, 44, "S:+B", false]], 25=>[[{15=>:enemy}, 15, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 5=>:enemy}, 5, "S:+B", true], [{15=>nil, 5=>nil}, 5, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{17=>nil}, 17, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{26=>nil}, 26, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 41=>:enemy}, 41, "S:+B", true], [{33=>nil, 41=>nil}, 41, "S:+B", false], [{33=>nil, 41=>nil, 49=>:enemy}, 49, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil}, 49, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{35=>nil}, 35, "S:+B", false]], 26=>[[{16=>:enemy}, 16, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 6=>:enemy}, 6, "S:+B", true], [{16=>nil, 6=>nil}, 6, "S:+B", false], [{17=>nil}, 17, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 42=>:enemy}, 42, "S:+B", true], [{34=>nil, 42=>nil}, 42, "S:+B", false], [{34=>nil, 42=>nil, 50=>:enemy}, 50, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil}, 50, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, 58, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil}, 58, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:+B", false], [{35=>nil}, 35, "S:+B", false]], 27=>[[{18=>:enemy}, 18, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{36=>:enemy}, 36, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{18=>nil}, 18, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 11=>:enemy}, 11, "S:+B", true], [{19=>nil, 11=>nil}, 11, "S:+B", false], [{19=>nil, 11=>nil, 3=>:enemy}, 3, "S:+B", true], [{19=>nil, 11=>nil, 3=>nil}, 3, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{36=>nil}, 36, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{37=>nil, 47=>:enemy}, 47, "S:+B", true], [{37=>nil, 47=>nil}, 47, "S:+B", false], [{37=>nil, 47=>nil, 57=>:enemy}, 57, "S:+B", true], [{37=>nil, 47=>nil, 57=>nil}, 57, "S:+B", false], [{37=>nil, 47=>nil, 57=>nil, 67=>:enemy}, 67, "S:+B", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil}, 67, "S:+B", false], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "S:+B", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "S:+B", false]], 28=>[[{18=>:enemy}, 18, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{27=>:enemy}, 27, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{36=>:enemy}, 36, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{18=>nil}, 18, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 12=>:enemy}, 12, "S:+B", true], [{20=>nil, 12=>nil}, 12, "S:+B", false], [{20=>nil, 12=>nil, 4=>:enemy}, 4, "S:+B", true], [{20=>nil, 12=>nil, 4=>nil}, 4, "S:+B", false], [{27=>nil}, 27, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{36=>nil}, 36, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{38=>nil, 48=>:enemy}, 48, "S:+B", true], [{38=>nil, 48=>nil}, 48, "S:+B", false], [{38=>nil, 48=>nil, 58=>:enemy}, 58, "S:+B", true], [{38=>nil, 48=>nil, 58=>nil}, 58, "S:+B", false], [{38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "S:+B", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "S:+B", false], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:+B", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:+B", false]], 29=>[[{19=>:enemy}, 19, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 9=>:enemy}, 9, "S:+B", true], [{19=>nil, 9=>nil}, 9, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 13=>:enemy}, 13, "S:+B", true], [{21=>nil, 13=>nil}, 13, "S:+B", false], [{21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{37=>nil, 45=>:enemy}, 45, "S:+B", true], [{37=>nil, 45=>nil}, 45, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{39=>nil, 49=>:enemy}, 49, "S:+B", true], [{39=>nil, 49=>nil}, 49, "S:+B", false], [{39=>nil, 49=>nil, 59=>:enemy}, 59, "S:+B", true], [{39=>nil, 49=>nil, 59=>nil}, 59, "S:+B", false], [{39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 30=>[[{20=>:enemy}, 20, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 10=>:enemy}, 10, "S:+B", true], [{20=>nil, 10=>nil}, 10, "S:+B", false], [{20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 14=>:enemy}, 14, "S:+B", true], [{22=>nil, 14=>nil}, 14, "S:+B", false], [{22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{38=>nil, 46=>:enemy}, 46, "S:+B", true], [{38=>nil, 46=>nil}, 46, "S:+B", false], [{38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{40=>nil, 50=>:enemy}, 50, "S:+B", true], [{40=>nil, 50=>nil}, 50, "S:+B", false], [{40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 31=>[[{21=>:enemy}, 21, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 11=>:enemy}, 11, "S:+B", true], [{21=>nil, 11=>nil}, 11, "S:+B", false], [{21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 15=>:enemy}, 15, "S:+B", true], [{23=>nil, 15=>nil}, 15, "S:+B", false], [{23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{39=>nil, 47=>:enemy}, 47, "S:+B", true], [{39=>nil, 47=>nil}, 47, "S:+B", false], [{39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{41=>nil, 51=>:enemy}, 51, "S:+B", true], [{41=>nil, 51=>nil}, 51, "S:+B", false], [{41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 32=>[[{22=>:enemy}, 22, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 12=>:enemy}, 12, "S:+B", true], [{22=>nil, 12=>nil}, 12, "S:+B", false], [{22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 16=>:enemy}, 16, "S:+B", true], [{24=>nil, 16=>nil}, 16, "S:+B", false], [{24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{40=>nil, 48=>:enemy}, 48, "S:+B", true], [{40=>nil, 48=>nil}, 48, "S:+B", false], [{40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{42=>nil, 52=>:enemy}, 52, "S:+B", true], [{42=>nil, 52=>nil}, 52, "S:+B", false], [{42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 33=>[[{23=>:enemy}, 23, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 13=>:enemy}, 13, "S:+B", true], [{23=>nil, 13=>nil}, 13, "S:+B", false], [{23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 17=>:enemy}, 17, "S:+B", true], [{25=>nil, 17=>nil}, 17, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{41=>nil, 49=>:enemy}, 49, "S:+B", true], [{41=>nil, 49=>nil}, 49, "S:+B", false], [{41=>nil, 49=>nil, 57=>:enemy}, 57, "S:+B", true], [{41=>nil, 49=>nil, 57=>nil}, 57, "S:+B", false], [{41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{43=>nil, 53=>:enemy}, 53, "S:+B", true], [{43=>nil, 53=>nil}, 53, "S:+B", false]], 34=>[[{24=>:enemy}, 24, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{44=>:enemy}, 44, "S:+B", true], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 14=>:enemy}, 14, "S:+B", true], [{24=>nil, 14=>nil}, 14, "S:+B", false], [{24=>nil, 14=>nil, 4=>:enemy}, 4, "S:+B", true], [{24=>nil, 14=>nil, 4=>nil}, 4, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{26=>nil}, 26, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{35=>nil}, 35, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{42=>nil, 50=>:enemy}, 50, "S:+B", true], [{42=>nil, 50=>nil}, 50, "S:+B", false], [{42=>nil, 50=>nil, 58=>:enemy}, 58, "S:+B", true], [{42=>nil, 50=>nil, 58=>nil}, 58, "S:+B", false], [{42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "S:+B", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "S:+B", false], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:+B", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{44=>nil}, 44, "S:+B", false]], 35=>[[{25=>:enemy}, 25, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{44=>:enemy}, 44, "S:+B", true], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 15=>:enemy}, 15, "S:+B", true], [{25=>nil, 15=>nil}, 15, "S:+B", false], [{25=>nil, 15=>nil, 5=>:enemy}, 5, "S:+B", true], [{25=>nil, 15=>nil, 5=>nil}, 5, "S:+B", false], [{26=>nil}, 26, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{43=>nil, 51=>:enemy}, 51, "S:+B", true], [{43=>nil, 51=>nil}, 51, "S:+B", false], [{43=>nil, 51=>nil, 59=>:enemy}, 59, "S:+B", true], [{43=>nil, 51=>nil, 59=>nil}, 59, "S:+B", false], [{43=>nil, 51=>nil, 59=>nil, 67=>:enemy}, 67, "S:+B", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil}, 67, "S:+B", false], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "S:+B", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "S:+B", false], [{44=>nil}, 44, "S:+B", false]], 36=>[[{27=>:enemy}, 27, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{45=>:enemy}, 45, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{27=>nil}, 27, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 20=>:enemy}, 20, "S:+B", true], [{28=>nil, 20=>nil}, 20, "S:+B", false], [{28=>nil, 20=>nil, 12=>:enemy}, 12, "S:+B", true], [{28=>nil, 20=>nil, 12=>nil}, 12, "S:+B", false], [{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, 4, "S:+B", true], [{28=>nil, 20=>nil, 12=>nil, 4=>nil}, 4, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{45=>nil}, 45, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{46=>nil, 56=>:enemy}, 56, "S:+B", true], [{46=>nil, 56=>nil}, 56, "S:+B", false], [{46=>nil, 56=>nil, 66=>:enemy}, 66, "S:+B", true], [{46=>nil, 56=>nil, 66=>nil}, 66, "S:+B", false], [{46=>nil, 56=>nil, 66=>nil, 76=>:enemy}, 76, "S:+B", true], [{46=>nil, 56=>nil, 66=>nil, 76=>nil}, 76, "S:+B", false]], 37=>[[{27=>:enemy}, 27, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{36=>:enemy}, 36, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{45=>:enemy}, 45, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{27=>nil}, 27, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 21=>:enemy}, 21, "S:+B", true], [{29=>nil, 21=>nil}, 21, "S:+B", false], [{29=>nil, 21=>nil, 13=>:enemy}, 13, "S:+B", true], [{29=>nil, 21=>nil, 13=>nil}, 13, "S:+B", false], [{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{36=>nil}, 36, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{45=>nil}, 45, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{47=>nil, 57=>:enemy}, 57, "S:+B", true], [{47=>nil, 57=>nil}, 57, "S:+B", false], [{47=>nil, 57=>nil, 67=>:enemy}, 67, "S:+B", true], [{47=>nil, 57=>nil, 67=>nil}, 67, "S:+B", false], [{47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "S:+B", true], [{47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "S:+B", false]], 38=>[[{28=>:enemy}, 28, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 18=>:enemy}, 18, "S:+B", true], [{28=>nil, 18=>nil}, 18, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 22=>:enemy}, 22, "S:+B", true], [{30=>nil, 22=>nil}, 22, "S:+B", false], [{30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{46=>nil, 54=>:enemy}, 54, "S:+B", true], [{46=>nil, 54=>nil}, 54, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{48=>nil, 58=>:enemy}, 58, "S:+B", true], [{48=>nil, 58=>nil}, 58, "S:+B", false], [{48=>nil, 58=>nil, 68=>:enemy}, 68, "S:+B", true], [{48=>nil, 58=>nil, 68=>nil}, 68, "S:+B", false], [{48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:+B", true], [{48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:+B", false]], 39=>[[{29=>:enemy}, 29, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 19=>:enemy}, 19, "S:+B", true], [{29=>nil, 19=>nil}, 19, "S:+B", false], [{29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 23=>:enemy}, 23, "S:+B", true], [{31=>nil, 23=>nil}, 23, "S:+B", false], [{31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{47=>nil, 55=>:enemy}, 55, "S:+B", true], [{47=>nil, 55=>nil}, 55, "S:+B", false], [{47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{49=>nil, 59=>:enemy}, 59, "S:+B", true], [{49=>nil, 59=>nil}, 59, "S:+B", false], [{49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 40=>[[{30=>:enemy}, 30, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 20=>:enemy}, 20, "S:+B", true], [{30=>nil, 20=>nil}, 20, "S:+B", false], [{30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 24=>:enemy}, 24, "S:+B", true], [{32=>nil, 24=>nil}, 24, "S:+B", false], [{32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{48=>nil, 56=>:enemy}, 56, "S:+B", true], [{48=>nil, 56=>nil}, 56, "S:+B", false], [{48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{50=>nil, 60=>:enemy}, 60, "S:+B", true], [{50=>nil, 60=>nil}, 60, "S:+B", false], [{50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 41=>[[{31=>:enemy}, 31, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 21=>:enemy}, 21, "S:+B", true], [{31=>nil, 21=>nil}, 21, "S:+B", false], [{31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 25=>:enemy}, 25, "S:+B", true], [{33=>nil, 25=>nil}, 25, "S:+B", false], [{33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{49=>nil, 57=>:enemy}, 57, "S:+B", true], [{49=>nil, 57=>nil}, 57, "S:+B", false], [{49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{51=>nil, 61=>:enemy}, 61, "S:+B", true], [{51=>nil, 61=>nil}, 61, "S:+B", false], [{51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 42=>[[{32=>:enemy}, 32, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 22=>:enemy}, 22, "S:+B", true], [{32=>nil, 22=>nil}, 22, "S:+B", false], [{32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 26=>:enemy}, 26, "S:+B", true], [{34=>nil, 26=>nil}, 26, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{50=>nil, 58=>:enemy}, 58, "S:+B", true], [{50=>nil, 58=>nil}, 58, "S:+B", false], [{50=>nil, 58=>nil, 66=>:enemy}, 66, "S:+B", true], [{50=>nil, 58=>nil, 66=>nil}, 66, "S:+B", false], [{50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:+B", true], [{50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{52=>nil, 62=>:enemy}, 62, "S:+B", true], [{52=>nil, 62=>nil}, 62, "S:+B", false]], 43=>[[{33=>:enemy}, 33, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{44=>:enemy}, 44, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{53=>:enemy}, 53, "S:+B", true], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 23=>:enemy}, 23, "S:+B", true], [{33=>nil, 23=>nil}, 23, "S:+B", false], [{33=>nil, 23=>nil, 13=>:enemy}, 13, "S:+B", true], [{33=>nil, 23=>nil, 13=>nil}, 13, "S:+B", false], [{33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{35=>nil}, 35, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{44=>nil}, 44, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{51=>nil, 59=>:enemy}, 59, "S:+B", true], [{51=>nil, 59=>nil}, 59, "S:+B", false], [{51=>nil, 59=>nil, 67=>:enemy}, 67, "S:+B", true], [{51=>nil, 59=>nil, 67=>nil}, 67, "S:+B", false], [{51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "S:+B", true], [{51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{53=>nil}, 53, "S:+B", false]], 44=>[[{34=>:enemy}, 34, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{53=>:enemy}, 53, "S:+B", true], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 24=>:enemy}, 24, "S:+B", true], [{34=>nil, 24=>nil}, 24, "S:+B", false], [{34=>nil, 24=>nil, 14=>:enemy}, 14, "S:+B", true], [{34=>nil, 24=>nil, 14=>nil}, 14, "S:+B", false], [{34=>nil, 24=>nil, 14=>nil, 4=>:enemy}, 4, "S:+B", true], [{34=>nil, 24=>nil, 14=>nil, 4=>nil}, 4, "S:+B", false], [{35=>nil}, 35, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{52=>nil, 60=>:enemy}, 60, "S:+B", true], [{52=>nil, 60=>nil}, 60, "S:+B", false], [{52=>nil, 60=>nil, 68=>:enemy}, 68, "S:+B", true], [{52=>nil, 60=>nil, 68=>nil}, 68, "S:+B", false], [{52=>nil, 60=>nil, 68=>nil, 76=>:enemy}, 76, "S:+B", true], [{52=>nil, 60=>nil, 68=>nil, 76=>nil}, 76, "S:+B", false], [{53=>nil}, 53, "S:+B", false]], 45=>[[{36=>:enemy}, 36, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{54=>:enemy}, 54, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{36=>nil}, 36, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{37=>nil, 29=>:enemy}, 29, "S:+B", true], [{37=>nil, 29=>nil}, 29, "S:+B", false], [{37=>nil, 29=>nil, 21=>:enemy}, 21, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil}, 21, "S:+B", false], [{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, 13, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil}, 13, "S:+B", false], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{54=>nil}, 54, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{55=>nil, 65=>:enemy}, 65, "S:+B", true], [{55=>nil, 65=>nil}, 65, "S:+B", false], [{55=>nil, 65=>nil, 75=>:enemy}, 75, "S:+B", true], [{55=>nil, 65=>nil, 75=>nil}, 75, "S:+B", false]], 46=>[[{36=>:enemy}, 36, "S:+B", true], [{37=>:enemy}, 37, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{45=>:enemy}, 45, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{54=>:enemy}, 54, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{36=>nil}, 36, "S:+B", false], [{37=>nil}, 37, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{38=>nil, 30=>:enemy}, 30, "S:+B", true], [{38=>nil, 30=>nil}, 30, "S:+B", false], [{38=>nil, 30=>nil, 22=>:enemy}, 22, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil}, 22, "S:+B", false], [{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{45=>nil}, 45, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{54=>nil}, 54, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{56=>nil, 66=>:enemy}, 66, "S:+B", true], [{56=>nil, 66=>nil}, 66, "S:+B", false], [{56=>nil, 66=>nil, 76=>:enemy}, 76, "S:+B", true], [{56=>nil, 66=>nil, 76=>nil}, 76, "S:+B", false]], 47=>[[{37=>:enemy}, 37, "S:+B", true], [{38=>:enemy}, 38, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{37=>nil}, 37, "S:+B", false], [{37=>nil, 27=>:enemy}, 27, "S:+B", true], [{37=>nil, 27=>nil}, 27, "S:+B", false], [{38=>nil}, 38, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{39=>nil, 31=>:enemy}, 31, "S:+B", true], [{39=>nil, 31=>nil}, 31, "S:+B", false], [{39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{55=>nil, 63=>:enemy}, 63, "S:+B", true], [{55=>nil, 63=>nil}, 63, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{57=>nil, 67=>:enemy}, 67, "S:+B", true], [{57=>nil, 67=>nil}, 67, "S:+B", false], [{57=>nil, 67=>nil, 77=>:enemy}, 77, "S:+B", true], [{57=>nil, 67=>nil, 77=>nil}, 77, "S:+B", false]], 48=>[[{38=>:enemy}, 38, "S:+B", true], [{39=>:enemy}, 39, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{38=>nil}, 38, "S:+B", false], [{38=>nil, 28=>:enemy}, 28, "S:+B", true], [{38=>nil, 28=>nil}, 28, "S:+B", false], [{38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{39=>nil}, 39, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{40=>nil, 32=>:enemy}, 32, "S:+B", true], [{40=>nil, 32=>nil}, 32, "S:+B", false], [{40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{56=>nil, 64=>:enemy}, 64, "S:+B", true], [{56=>nil, 64=>nil}, 64, "S:+B", false], [{56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{58=>nil, 68=>:enemy}, 68, "S:+B", true], [{58=>nil, 68=>nil}, 68, "S:+B", false], [{58=>nil, 68=>nil, 78=>:enemy}, 78, "S:+B", true], [{58=>nil, 68=>nil, 78=>nil}, 78, "S:+B", false]], 49=>[[{39=>:enemy}, 39, "S:+B", true], [{40=>:enemy}, 40, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{39=>nil}, 39, "S:+B", false], [{39=>nil, 29=>:enemy}, 29, "S:+B", true], [{39=>nil, 29=>nil}, 29, "S:+B", false], [{39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{40=>nil}, 40, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{41=>nil, 33=>:enemy}, 33, "S:+B", true], [{41=>nil, 33=>nil}, 33, "S:+B", false], [{41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{57=>nil, 65=>:enemy}, 65, "S:+B", true], [{57=>nil, 65=>nil}, 65, "S:+B", false], [{57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{59=>nil, 69=>:enemy}, 69, "S:+B", true], [{59=>nil, 69=>nil}, 69, "S:+B", false], [{59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 50=>[[{40=>:enemy}, 40, "S:+B", true], [{41=>:enemy}, 41, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{40=>nil}, 40, "S:+B", false], [{40=>nil, 30=>:enemy}, 30, "S:+B", true], [{40=>nil, 30=>nil}, 30, "S:+B", false], [{40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{41=>nil}, 41, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{42=>nil, 34=>:enemy}, 34, "S:+B", true], [{42=>nil, 34=>nil}, 34, "S:+B", false], [{42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{58=>nil, 66=>:enemy}, 66, "S:+B", true], [{58=>nil, 66=>nil}, 66, "S:+B", false], [{58=>nil, 66=>nil, 74=>:enemy}, 74, "S:+B", true], [{58=>nil, 66=>nil, 74=>nil}, 74, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{60=>nil, 70=>:enemy}, 70, "S:+B", true], [{60=>nil, 70=>nil}, 70, "S:+B", false], [{60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 51=>[[{41=>:enemy}, 41, "S:+B", true], [{42=>:enemy}, 42, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{41=>nil}, 41, "S:+B", false], [{41=>nil, 31=>:enemy}, 31, "S:+B", true], [{41=>nil, 31=>nil}, 31, "S:+B", false], [{41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{42=>nil}, 42, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{43=>nil, 35=>:enemy}, 35, "S:+B", true], [{43=>nil, 35=>nil}, 35, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{59=>nil, 67=>:enemy}, 67, "S:+B", true], [{59=>nil, 67=>nil}, 67, "S:+B", false], [{59=>nil, 67=>nil, 75=>:enemy}, 75, "S:+B", true], [{59=>nil, 67=>nil, 75=>nil}, 75, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{61=>nil, 71=>:enemy}, 71, "S:+B", true], [{61=>nil, 71=>nil}, 71, "S:+B", false]], 52=>[[{42=>:enemy}, 42, "S:+B", true], [{43=>:enemy}, 43, "S:+B", true], [{44=>:enemy}, 44, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{53=>:enemy}, 53, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{62=>:enemy}, 62, "S:+B", true], [{42=>nil}, 42, "S:+B", false], [{42=>nil, 32=>:enemy}, 32, "S:+B", true], [{42=>nil, 32=>nil}, 32, "S:+B", false], [{42=>nil, 32=>nil, 22=>:enemy}, 22, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil}, 22, "S:+B", false], [{42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{43=>nil}, 43, "S:+B", false], [{44=>nil}, 44, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{53=>nil}, 53, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{60=>nil, 68=>:enemy}, 68, "S:+B", true], [{60=>nil, 68=>nil}, 68, "S:+B", false], [{60=>nil, 68=>nil, 76=>:enemy}, 76, "S:+B", true], [{60=>nil, 68=>nil, 76=>nil}, 76, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{62=>nil}, 62, "S:+B", false]], 53=>[[{43=>:enemy}, 43, "S:+B", true], [{44=>:enemy}, 44, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{62=>:enemy}, 62, "S:+B", true], [{43=>nil}, 43, "S:+B", false], [{43=>nil, 33=>:enemy}, 33, "S:+B", true], [{43=>nil, 33=>nil}, 33, "S:+B", false], [{43=>nil, 33=>nil, 23=>:enemy}, 23, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil}, 23, "S:+B", false], [{43=>nil, 33=>nil, 23=>nil, 13=>:enemy}, 13, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil}, 13, "S:+B", false], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{44=>nil}, 44, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{61=>nil, 69=>:enemy}, 69, "S:+B", true], [{61=>nil, 69=>nil}, 69, "S:+B", false], [{61=>nil, 69=>nil, 77=>:enemy}, 77, "S:+B", true], [{61=>nil, 69=>nil, 77=>nil}, 77, "S:+B", false], [{62=>nil}, 62, "S:+B", false]], 54=>[[{45=>:enemy}, 45, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{63=>:enemy}, 63, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{45=>nil}, 45, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{46=>nil, 38=>:enemy}, 38, "S:+B", true], [{46=>nil, 38=>nil}, 38, "S:+B", false], [{46=>nil, 38=>nil, 30=>:enemy}, 30, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil}, 30, "S:+B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, 22, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil}, 22, "S:+B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{63=>nil}, 63, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{64=>nil, 74=>:enemy}, 74, "S:+B", true], [{64=>nil, 74=>nil}, 74, "S:+B", false]], 55=>[[{45=>:enemy}, 45, "S:+B", true], [{46=>:enemy}, 46, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{54=>:enemy}, 54, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{63=>:enemy}, 63, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{45=>nil}, 45, "S:+B", false], [{46=>nil}, 46, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{47=>nil, 39=>:enemy}, 39, "S:+B", true], [{47=>nil, 39=>nil}, 39, "S:+B", false], [{47=>nil, 39=>nil, 31=>:enemy}, 31, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil}, 31, "S:+B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{54=>nil}, 54, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{63=>nil}, 63, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{65=>nil, 75=>:enemy}, 75, "S:+B", true], [{65=>nil, 75=>nil}, 75, "S:+B", false]], 56=>[[{46=>:enemy}, 46, "S:+B", true], [{47=>:enemy}, 47, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{46=>nil}, 46, "S:+B", false], [{46=>nil, 36=>:enemy}, 36, "S:+B", true], [{46=>nil, 36=>nil}, 36, "S:+B", false], [{47=>nil}, 47, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{48=>nil, 40=>:enemy}, 40, "S:+B", true], [{48=>nil, 40=>nil}, 40, "S:+B", false], [{48=>nil, 40=>nil, 32=>:enemy}, 32, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil}, 32, "S:+B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{64=>nil, 72=>:enemy}, 72, "S:+B", true], [{64=>nil, 72=>nil}, 72, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{66=>nil, 76=>:enemy}, 76, "S:+B", true], [{66=>nil, 76=>nil}, 76, "S:+B", false]], 57=>[[{47=>:enemy}, 47, "S:+B", true], [{48=>:enemy}, 48, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{47=>nil}, 47, "S:+B", false], [{47=>nil, 37=>:enemy}, 37, "S:+B", true], [{47=>nil, 37=>nil}, 37, "S:+B", false], [{47=>nil, 37=>nil, 27=>:enemy}, 27, "S:+B", true], [{47=>nil, 37=>nil, 27=>nil}, 27, "S:+B", false], [{48=>nil}, 48, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{49=>nil, 41=>:enemy}, 41, "S:+B", true], [{49=>nil, 41=>nil}, 41, "S:+B", false], [{49=>nil, 41=>nil, 33=>:enemy}, 33, "S:+B", true], [{49=>nil, 41=>nil, 33=>nil}, 33, "S:+B", false], [{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{65=>nil, 73=>:enemy}, 73, "S:+B", true], [{65=>nil, 73=>nil}, 73, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{67=>nil, 77=>:enemy}, 77, "S:+B", true], [{67=>nil, 77=>nil}, 77, "S:+B", false]], 58=>[[{48=>:enemy}, 48, "S:+B", true], [{49=>:enemy}, 49, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{48=>nil}, 48, "S:+B", false], [{48=>nil, 38=>:enemy}, 38, "S:+B", true], [{48=>nil, 38=>nil}, 38, "S:+B", false], [{48=>nil, 38=>nil, 28=>:enemy}, 28, "S:+B", true], [{48=>nil, 38=>nil, 28=>nil}, 28, "S:+B", false], [{48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{49=>nil}, 49, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{50=>nil, 42=>:enemy}, 42, "S:+B", true], [{50=>nil, 42=>nil}, 42, "S:+B", false], [{50=>nil, 42=>nil, 34=>:enemy}, 34, "S:+B", true], [{50=>nil, 42=>nil, 34=>nil}, 34, "S:+B", false], [{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{66=>nil, 74=>:enemy}, 74, "S:+B", true], [{66=>nil, 74=>nil}, 74, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{68=>nil, 78=>:enemy}, 78, "S:+B", true], [{68=>nil, 78=>nil}, 78, "S:+B", false]], 59=>[[{49=>:enemy}, 49, "S:+B", true], [{50=>:enemy}, 50, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{49=>nil}, 49, "S:+B", false], [{49=>nil, 39=>:enemy}, 39, "S:+B", true], [{49=>nil, 39=>nil}, 39, "S:+B", false], [{49=>nil, 39=>nil, 29=>:enemy}, 29, "S:+B", true], [{49=>nil, 39=>nil, 29=>nil}, 29, "S:+B", false], [{49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{50=>nil}, 50, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{51=>nil, 43=>:enemy}, 43, "S:+B", true], [{51=>nil, 43=>nil}, 43, "S:+B", false], [{51=>nil, 43=>nil, 35=>:enemy}, 35, "S:+B", true], [{51=>nil, 43=>nil, 35=>nil}, 35, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{67=>nil, 75=>:enemy}, 75, "S:+B", true], [{67=>nil, 75=>nil}, 75, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{69=>nil, 79=>:enemy}, 79, "S:+B", true], [{69=>nil, 79=>nil}, 79, "S:+B", false]], 60=>[[{50=>:enemy}, 50, "S:+B", true], [{51=>:enemy}, 51, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{50=>nil}, 50, "S:+B", false], [{50=>nil, 40=>:enemy}, 40, "S:+B", true], [{50=>nil, 40=>nil}, 40, "S:+B", false], [{50=>nil, 40=>nil, 30=>:enemy}, 30, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil}, 30, "S:+B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{51=>nil}, 51, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{52=>nil, 44=>:enemy}, 44, "S:+B", true], [{52=>nil, 44=>nil}, 44, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{68=>nil, 76=>:enemy}, 76, "S:+B", true], [{68=>nil, 76=>nil}, 76, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{70=>nil, 80=>:enemy}, 80, "S:+B", true], [{70=>nil, 80=>nil}, 80, "S:+B", false]], 61=>[[{51=>:enemy}, 51, "S:+B", true], [{52=>:enemy}, 52, "S:+B", true], [{53=>:enemy}, 53, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{62=>:enemy}, 62, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{71=>:enemy}, 71, "S:+B", true], [{51=>nil}, 51, "S:+B", false], [{51=>nil, 41=>:enemy}, 41, "S:+B", true], [{51=>nil, 41=>nil}, 41, "S:+B", false], [{51=>nil, 41=>nil, 31=>:enemy}, 31, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil}, 31, "S:+B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{52=>nil}, 52, "S:+B", false], [{53=>nil}, 53, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{62=>nil}, 62, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{69=>nil, 77=>:enemy}, 77, "S:+B", true], [{69=>nil, 77=>nil}, 77, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{71=>nil}, 71, "S:+B", false]], 62=>[[{52=>:enemy}, 52, "S:+B", true], [{53=>:enemy}, 53, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{71=>:enemy}, 71, "S:+B", true], [{52=>nil}, 52, "S:+B", false], [{52=>nil, 42=>:enemy}, 42, "S:+B", true], [{52=>nil, 42=>nil}, 42, "S:+B", false], [{52=>nil, 42=>nil, 32=>:enemy}, 32, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil}, 32, "S:+B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>:enemy}, 22, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil}, 22, "S:+B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{53=>nil}, 53, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{70=>nil, 78=>:enemy}, 78, "S:+B", true], [{70=>nil, 78=>nil}, 78, "S:+B", false], [{71=>nil}, 71, "S:+B", false]], 63=>[[{54=>:enemy}, 54, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{72=>:enemy}, 72, "S:+B", true], [{73=>:enemy}, 73, "S:+B", true], [{54=>nil}, 54, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{55=>nil, 47=>:enemy}, 47, "S:+B", true], [{55=>nil, 47=>nil}, 47, "S:+B", false], [{55=>nil, 47=>nil, 39=>:enemy}, 39, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil}, 39, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, 31, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil}, 31, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{72=>nil}, 72, "S:+B", false], [{73=>nil}, 73, "S:+B", false]], 64=>[[{54=>:enemy}, 54, "S:+B", true], [{55=>:enemy}, 55, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{63=>:enemy}, 63, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{72=>:enemy}, 72, "S:+B", true], [{73=>:enemy}, 73, "S:+B", true], [{74=>:enemy}, 74, "S:+B", true], [{54=>nil}, 54, "S:+B", false], [{55=>nil}, 55, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{56=>nil, 48=>:enemy}, 48, "S:+B", true], [{56=>nil, 48=>nil}, 48, "S:+B", false], [{56=>nil, 48=>nil, 40=>:enemy}, 40, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil}, 40, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{63=>nil}, 63, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{72=>nil}, 72, "S:+B", false], [{73=>nil}, 73, "S:+B", false], [{74=>nil}, 74, "S:+B", false]], 65=>[[{55=>:enemy}, 55, "S:+B", true], [{56=>:enemy}, 56, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{73=>:enemy}, 73, "S:+B", true], [{74=>:enemy}, 74, "S:+B", true], [{75=>:enemy}, 75, "S:+B", true], [{55=>nil}, 55, "S:+B", false], [{55=>nil, 45=>:enemy}, 45, "S:+B", true], [{55=>nil, 45=>nil}, 45, "S:+B", false], [{56=>nil}, 56, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{57=>nil, 49=>:enemy}, 49, "S:+B", true], [{57=>nil, 49=>nil}, 49, "S:+B", false], [{57=>nil, 49=>nil, 41=>:enemy}, 41, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil}, 41, "S:+B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "S:+B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{73=>nil}, 73, "S:+B", false], [{74=>nil}, 74, "S:+B", false], [{75=>nil}, 75, "S:+B", false]], 66=>[[{56=>:enemy}, 56, "S:+B", true], [{57=>:enemy}, 57, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{74=>:enemy}, 74, "S:+B", true], [{75=>:enemy}, 75, "S:+B", true], [{76=>:enemy}, 76, "S:+B", true], [{56=>nil}, 56, "S:+B", false], [{56=>nil, 46=>:enemy}, 46, "S:+B", true], [{56=>nil, 46=>nil}, 46, "S:+B", false], [{56=>nil, 46=>nil, 36=>:enemy}, 36, "S:+B", true], [{56=>nil, 46=>nil, 36=>nil}, 36, "S:+B", false], [{57=>nil}, 57, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{58=>nil, 50=>:enemy}, 50, "S:+B", true], [{58=>nil, 50=>nil}, 50, "S:+B", false], [{58=>nil, 50=>nil, 42=>:enemy}, 42, "S:+B", true], [{58=>nil, 50=>nil, 42=>nil}, 42, "S:+B", false], [{58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "S:+B", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "S:+B", false], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{74=>nil}, 74, "S:+B", false], [{75=>nil}, 75, "S:+B", false], [{76=>nil}, 76, "S:+B", false]], 67=>[[{57=>:enemy}, 57, "S:+B", true], [{58=>:enemy}, 58, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{75=>:enemy}, 75, "S:+B", true], [{76=>:enemy}, 76, "S:+B", true], [{77=>:enemy}, 77, "S:+B", true], [{57=>nil}, 57, "S:+B", false], [{57=>nil, 47=>:enemy}, 47, "S:+B", true], [{57=>nil, 47=>nil}, 47, "S:+B", false], [{57=>nil, 47=>nil, 37=>:enemy}, 37, "S:+B", true], [{57=>nil, 47=>nil, 37=>nil}, 37, "S:+B", false], [{57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "S:+B", true], [{57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "S:+B", false], [{58=>nil}, 58, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{59=>nil, 51=>:enemy}, 51, "S:+B", true], [{59=>nil, 51=>nil}, 51, "S:+B", false], [{59=>nil, 51=>nil, 43=>:enemy}, 43, "S:+B", true], [{59=>nil, 51=>nil, 43=>nil}, 43, "S:+B", false], [{59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "S:+B", true], [{59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{75=>nil}, 75, "S:+B", false], [{76=>nil}, 76, "S:+B", false], [{77=>nil}, 77, "S:+B", false]], 68=>[[{58=>:enemy}, 58, "S:+B", true], [{59=>:enemy}, 59, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{76=>:enemy}, 76, "S:+B", true], [{77=>:enemy}, 77, "S:+B", true], [{78=>:enemy}, 78, "S:+B", true], [{58=>nil}, 58, "S:+B", false], [{58=>nil, 48=>:enemy}, 48, "S:+B", true], [{58=>nil, 48=>nil}, 48, "S:+B", false], [{58=>nil, 48=>nil, 38=>:enemy}, 38, "S:+B", true], [{58=>nil, 48=>nil, 38=>nil}, 38, "S:+B", false], [{58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "S:+B", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "S:+B", false], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{59=>nil}, 59, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{60=>nil, 52=>:enemy}, 52, "S:+B", true], [{60=>nil, 52=>nil}, 52, "S:+B", false], [{60=>nil, 52=>nil, 44=>:enemy}, 44, "S:+B", true], [{60=>nil, 52=>nil, 44=>nil}, 44, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{76=>nil}, 76, "S:+B", false], [{77=>nil}, 77, "S:+B", false], [{78=>nil}, 78, "S:+B", false]], 69=>[[{59=>:enemy}, 59, "S:+B", true], [{60=>:enemy}, 60, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{77=>:enemy}, 77, "S:+B", true], [{78=>:enemy}, 78, "S:+B", true], [{79=>:enemy}, 79, "S:+B", true], [{59=>nil}, 59, "S:+B", false], [{59=>nil, 49=>:enemy}, 49, "S:+B", true], [{59=>nil, 49=>nil}, 49, "S:+B", false], [{59=>nil, 49=>nil, 39=>:enemy}, 39, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil}, 39, "S:+B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "S:+B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{60=>nil}, 60, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{61=>nil, 53=>:enemy}, 53, "S:+B", true], [{61=>nil, 53=>nil}, 53, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{77=>nil}, 77, "S:+B", false], [{78=>nil}, 78, "S:+B", false], [{79=>nil}, 79, "S:+B", false]], 70=>[[{60=>:enemy}, 60, "S:+B", true], [{61=>:enemy}, 61, "S:+B", true], [{62=>:enemy}, 62, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{71=>:enemy}, 71, "S:+B", true], [{78=>:enemy}, 78, "S:+B", true], [{79=>:enemy}, 79, "S:+B", true], [{80=>:enemy}, 80, "S:+B", true], [{60=>nil}, 60, "S:+B", false], [{60=>nil, 50=>:enemy}, 50, "S:+B", true], [{60=>nil, 50=>nil}, 50, "S:+B", false], [{60=>nil, 50=>nil, 40=>:enemy}, 40, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil}, 40, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{61=>nil}, 61, "S:+B", false], [{62=>nil}, 62, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{71=>nil}, 71, "S:+B", false], [{78=>nil}, 78, "S:+B", false], [{79=>nil}, 79, "S:+B", false], [{80=>nil}, 80, "S:+B", false]], 71=>[[{61=>:enemy}, 61, "S:+B", true], [{62=>:enemy}, 62, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{79=>:enemy}, 79, "S:+B", true], [{80=>:enemy}, 80, "S:+B", true], [{61=>nil}, 61, "S:+B", false], [{61=>nil, 51=>:enemy}, 51, "S:+B", true], [{61=>nil, 51=>nil}, 51, "S:+B", false], [{61=>nil, 51=>nil, 41=>:enemy}, 41, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil}, 41, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>:enemy}, 31, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil}, 31, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{62=>nil}, 62, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{79=>nil}, 79, "S:+B", false], [{80=>nil}, 80, "S:+B", false]], 72=>[[{63=>:enemy}, 63, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{73=>:enemy}, 73, "S:+B", true], [{63=>nil}, 63, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{64=>nil, 56=>:enemy}, 56, "S:+B", true], [{64=>nil, 56=>nil}, 56, "S:+B", false], [{64=>nil, 56=>nil, 48=>:enemy}, 48, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil}, 48, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>:enemy}, 40, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil}, 40, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{73=>nil}, 73, "S:+B", false]], 73=>[[{63=>:enemy}, 63, "S:+B", true], [{64=>:enemy}, 64, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{72=>:enemy}, 72, "S:+B", true], [{74=>:enemy}, 74, "S:+B", true], [{63=>nil}, 63, "S:+B", false], [{64=>nil}, 64, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{65=>nil, 57=>:enemy}, 57, "S:+B", true], [{65=>nil, 57=>nil}, 57, "S:+B", false], [{65=>nil, 57=>nil, 49=>:enemy}, 49, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil}, 49, "S:+B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>:enemy}, 41, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil}, 41, "S:+B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "S:+B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{72=>nil}, 72, "S:+B", false], [{74=>nil}, 74, "S:+B", false]], 74=>[[{64=>:enemy}, 64, "S:+B", true], [{65=>:enemy}, 65, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{73=>:enemy}, 73, "S:+B", true], [{75=>:enemy}, 75, "S:+B", true], [{64=>nil}, 64, "S:+B", false], [{64=>nil, 54=>:enemy}, 54, "S:+B", true], [{64=>nil, 54=>nil}, 54, "S:+B", false], [{65=>nil}, 65, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{66=>nil, 58=>:enemy}, 58, "S:+B", true], [{66=>nil, 58=>nil}, 58, "S:+B", false], [{66=>nil, 58=>nil, 50=>:enemy}, 50, "S:+B", true], [{66=>nil, 58=>nil, 50=>nil}, 50, "S:+B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>:enemy}, 42, "S:+B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil}, 42, "S:+B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "S:+B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "S:+B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{73=>nil}, 73, "S:+B", false], [{75=>nil}, 75, "S:+B", false]], 75=>[[{65=>:enemy}, 65, "S:+B", true], [{66=>:enemy}, 66, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{74=>:enemy}, 74, "S:+B", true], [{76=>:enemy}, 76, "S:+B", true], [{65=>nil}, 65, "S:+B", false], [{65=>nil, 55=>:enemy}, 55, "S:+B", true], [{65=>nil, 55=>nil}, 55, "S:+B", false], [{65=>nil, 55=>nil, 45=>:enemy}, 45, "S:+B", true], [{65=>nil, 55=>nil, 45=>nil}, 45, "S:+B", false], [{66=>nil}, 66, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{67=>nil, 59=>:enemy}, 59, "S:+B", true], [{67=>nil, 59=>nil}, 59, "S:+B", false], [{67=>nil, 59=>nil, 51=>:enemy}, 51, "S:+B", true], [{67=>nil, 59=>nil, 51=>nil}, 51, "S:+B", false], [{67=>nil, 59=>nil, 51=>nil, 43=>:enemy}, 43, "S:+B", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil}, 43, "S:+B", false], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "S:+B", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "S:+B", false], [{74=>nil}, 74, "S:+B", false], [{76=>nil}, 76, "S:+B", false]], 76=>[[{66=>:enemy}, 66, "S:+B", true], [{67=>:enemy}, 67, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{75=>:enemy}, 75, "S:+B", true], [{77=>:enemy}, 77, "S:+B", true], [{66=>nil}, 66, "S:+B", false], [{66=>nil, 56=>:enemy}, 56, "S:+B", true], [{66=>nil, 56=>nil}, 56, "S:+B", false], [{66=>nil, 56=>nil, 46=>:enemy}, 46, "S:+B", true], [{66=>nil, 56=>nil, 46=>nil}, 46, "S:+B", false], [{66=>nil, 56=>nil, 46=>nil, 36=>:enemy}, 36, "S:+B", true], [{66=>nil, 56=>nil, 46=>nil, 36=>nil}, 36, "S:+B", false], [{67=>nil}, 67, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{68=>nil, 60=>:enemy}, 60, "S:+B", true], [{68=>nil, 60=>nil}, 60, "S:+B", false], [{68=>nil, 60=>nil, 52=>:enemy}, 52, "S:+B", true], [{68=>nil, 60=>nil, 52=>nil}, 52, "S:+B", false], [{68=>nil, 60=>nil, 52=>nil, 44=>:enemy}, 44, "S:+B", true], [{68=>nil, 60=>nil, 52=>nil, 44=>nil}, 44, "S:+B", false], [{75=>nil}, 75, "S:+B", false], [{77=>nil}, 77, "S:+B", false]], 77=>[[{67=>:enemy}, 67, "S:+B", true], [{68=>:enemy}, 68, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{76=>:enemy}, 76, "S:+B", true], [{78=>:enemy}, 78, "S:+B", true], [{67=>nil}, 67, "S:+B", false], [{67=>nil, 57=>:enemy}, 57, "S:+B", true], [{67=>nil, 57=>nil}, 57, "S:+B", false], [{67=>nil, 57=>nil, 47=>:enemy}, 47, "S:+B", true], [{67=>nil, 57=>nil, 47=>nil}, 47, "S:+B", false], [{67=>nil, 57=>nil, 47=>nil, 37=>:enemy}, 37, "S:+B", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil}, 37, "S:+B", false], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "S:+B", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "S:+B", false], [{68=>nil}, 68, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{69=>nil, 61=>:enemy}, 61, "S:+B", true], [{69=>nil, 61=>nil}, 61, "S:+B", false], [{69=>nil, 61=>nil, 53=>:enemy}, 53, "S:+B", true], [{69=>nil, 61=>nil, 53=>nil}, 53, "S:+B", false], [{76=>nil}, 76, "S:+B", false], [{78=>nil}, 78, "S:+B", false]], 78=>[[{68=>:enemy}, 68, "S:+B", true], [{69=>:enemy}, 69, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{77=>:enemy}, 77, "S:+B", true], [{79=>:enemy}, 79, "S:+B", true], [{68=>nil}, 68, "S:+B", false], [{68=>nil, 58=>:enemy}, 58, "S:+B", true], [{68=>nil, 58=>nil}, 58, "S:+B", false], [{68=>nil, 58=>nil, 48=>:enemy}, 48, "S:+B", true], [{68=>nil, 58=>nil, 48=>nil}, 48, "S:+B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>:enemy}, 38, "S:+B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil}, 38, "S:+B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "S:+B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "S:+B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{69=>nil}, 69, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{70=>nil, 62=>:enemy}, 62, "S:+B", true], [{70=>nil, 62=>nil}, 62, "S:+B", false], [{77=>nil}, 77, "S:+B", false], [{79=>nil}, 79, "S:+B", false]], 79=>[[{69=>:enemy}, 69, "S:+B", true], [{70=>:enemy}, 70, "S:+B", true], [{71=>:enemy}, 71, "S:+B", true], [{78=>:enemy}, 78, "S:+B", true], [{80=>:enemy}, 80, "S:+B", true], [{69=>nil}, 69, "S:+B", false], [{69=>nil, 59=>:enemy}, 59, "S:+B", true], [{69=>nil, 59=>nil}, 59, "S:+B", false], [{69=>nil, 59=>nil, 49=>:enemy}, 49, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil}, 49, "S:+B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>:enemy}, 39, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil}, 39, "S:+B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "S:+B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{70=>nil}, 70, "S:+B", false], [{71=>nil}, 71, "S:+B", false], [{78=>nil}, 78, "S:+B", false], [{80=>nil}, 80, "S:+B", false]], 80=>[[{70=>:enemy}, 70, "S:+B", true], [{71=>:enemy}, 71, "S:+B", true], [{79=>:enemy}, 79, "S:+B", true], [{70=>nil}, 70, "S:+B", false], [{70=>nil, 60=>:enemy}, 60, "S:+B", true], [{70=>nil, 60=>nil}, 60, "S:+B", false], [{70=>nil, 60=>nil, 50=>:enemy}, 50, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil}, 50, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>:enemy}, 40, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil}, 40, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{71=>nil}, 71, "S:+B", false], [{79=>nil}, 79, "S:+B", false]], nil=>[]}, "S:+L"=>{0=>[[{1=>:enemy}, 1, "S:+L", true], [{9=>:enemy}, 9, "S:+L", true], [{1=>nil}, 1, "S:+L", false], [{9=>nil}, 9, "S:+L", false]], 1=>[[{0=>:enemy}, 0, "S:+L", true], [{2=>:enemy}, 2, "S:+L", true], [{10=>:enemy}, 10, "S:+L", true], [{0=>nil}, 0, "S:+L", false], [{2=>nil}, 2, "S:+L", false], [{10=>nil}, 10, "S:+L", false]], 2=>[[{1=>:enemy}, 1, "S:+L", true], [{3=>:enemy}, 3, "S:+L", true], [{11=>:enemy}, 11, "S:+L", true], [{1=>nil}, 1, "S:+L", false], [{3=>nil}, 3, "S:+L", false], [{11=>nil}, 11, "S:+L", false]], 3=>[[{2=>:enemy}, 2, "S:+L", true], [{4=>:enemy}, 4, "S:+L", true], [{12=>:enemy}, 12, "S:+L", true], [{2=>nil}, 2, "S:+L", false], [{4=>nil}, 4, "S:+L", false], [{12=>nil}, 12, "S:+L", false]], 4=>[[{3=>:enemy}, 3, "S:+L", true], [{5=>:enemy}, 5, "S:+L", true], [{13=>:enemy}, 13, "S:+L", true], [{3=>nil}, 3, "S:+L", false], [{5=>nil}, 5, "S:+L", false], [{13=>nil}, 13, "S:+L", false]], 5=>[[{4=>:enemy}, 4, "S:+L", true], [{6=>:enemy}, 6, "S:+L", true], [{14=>:enemy}, 14, "S:+L", true], [{4=>nil}, 4, "S:+L", false], [{6=>nil}, 6, "S:+L", false], [{14=>nil}, 14, "S:+L", false]], 6=>[[{5=>:enemy}, 5, "S:+L", true], [{7=>:enemy}, 7, "S:+L", true], [{15=>:enemy}, 15, "S:+L", true], [{5=>nil}, 5, "S:+L", false], [{7=>nil}, 7, "S:+L", false], [{15=>nil}, 15, "S:+L", false]], 7=>[[{6=>:enemy}, 6, "S:+L", true], [{8=>:enemy}, 8, "S:+L", true], [{16=>:enemy}, 16, "S:+L", true], [{6=>nil}, 6, "S:+L", false], [{8=>nil}, 8, "S:+L", false], [{16=>nil}, 16, "S:+L", false]], 8=>[[{7=>:enemy}, 7, "S:+L", true], [{17=>:enemy}, 17, "S:+L", true], [{7=>nil}, 7, "S:+L", false], [{17=>nil}, 17, "S:+L", false]], 9=>[[{0=>:enemy}, 0, "S:+L", true], [{1=>:enemy}, 1, "S:+L", true], [{10=>:enemy}, 10, "S:+L", true], [{18=>:enemy}, 18, "S:+L", true], [{0=>nil}, 0, "S:+L", false], [{1=>nil}, 1, "S:+L", false], [{10=>nil}, 10, "S:+L", false], [{18=>nil}, 18, "S:+L", false]], 10=>[[{0=>:enemy}, 0, "S:+L", true], [{1=>:enemy}, 1, "S:+L", true], [{2=>:enemy}, 2, "S:+L", true], [{9=>:enemy}, 9, "S:+L", true], [{11=>:enemy}, 11, "S:+L", true], [{19=>:enemy}, 19, "S:+L", true], [{0=>nil}, 0, "S:+L", false], [{1=>nil}, 1, "S:+L", false], [{2=>nil}, 2, "S:+L", false], [{9=>nil}, 9, "S:+L", false], [{11=>nil}, 11, "S:+L", false], [{19=>nil}, 19, "S:+L", false]], 11=>[[{1=>:enemy}, 1, "S:+L", true], [{2=>:enemy}, 2, "S:+L", true], [{3=>:enemy}, 3, "S:+L", true], [{10=>:enemy}, 10, "S:+L", true], [{12=>:enemy}, 12, "S:+L", true], [{20=>:enemy}, 20, "S:+L", true], [{1=>nil}, 1, "S:+L", false], [{2=>nil}, 2, "S:+L", false], [{3=>nil}, 3, "S:+L", false], [{10=>nil}, 10, "S:+L", false], [{12=>nil}, 12, "S:+L", false], [{20=>nil}, 20, "S:+L", false]], 12=>[[{2=>:enemy}, 2, "S:+L", true], [{3=>:enemy}, 3, "S:+L", true], [{4=>:enemy}, 4, "S:+L", true], [{11=>:enemy}, 11, "S:+L", true], [{13=>:enemy}, 13, "S:+L", true], [{21=>:enemy}, 21, "S:+L", true], [{2=>nil}, 2, "S:+L", false], [{3=>nil}, 3, "S:+L", false], [{4=>nil}, 4, "S:+L", false], [{11=>nil}, 11, "S:+L", false], [{13=>nil}, 13, "S:+L", false], [{21=>nil}, 21, "S:+L", false]], 13=>[[{3=>:enemy}, 3, "S:+L", true], [{4=>:enemy}, 4, "S:+L", true], [{5=>:enemy}, 5, "S:+L", true], [{12=>:enemy}, 12, "S:+L", true], [{14=>:enemy}, 14, "S:+L", true], [{22=>:enemy}, 22, "S:+L", true], [{3=>nil}, 3, "S:+L", false], [{4=>nil}, 4, "S:+L", false], [{5=>nil}, 5, "S:+L", false], [{12=>nil}, 12, "S:+L", false], [{14=>nil}, 14, "S:+L", false], [{22=>nil}, 22, "S:+L", false]], 14=>[[{4=>:enemy}, 4, "S:+L", true], [{5=>:enemy}, 5, "S:+L", true], [{6=>:enemy}, 6, "S:+L", true], [{13=>:enemy}, 13, "S:+L", true], [{15=>:enemy}, 15, "S:+L", true], [{23=>:enemy}, 23, "S:+L", true], [{4=>nil}, 4, "S:+L", false], [{5=>nil}, 5, "S:+L", false], [{6=>nil}, 6, "S:+L", false], [{13=>nil}, 13, "S:+L", false], [{15=>nil}, 15, "S:+L", false], [{23=>nil}, 23, "S:+L", false]], 15=>[[{5=>:enemy}, 5, "S:+L", true], [{6=>:enemy}, 6, "S:+L", true], [{7=>:enemy}, 7, "S:+L", true], [{14=>:enemy}, 14, "S:+L", true], [{16=>:enemy}, 16, "S:+L", true], [{24=>:enemy}, 24, "S:+L", true], [{5=>nil}, 5, "S:+L", false], [{6=>nil}, 6, "S:+L", false], [{7=>nil}, 7, "S:+L", false], [{14=>nil}, 14, "S:+L", false], [{16=>nil}, 16, "S:+L", false], [{24=>nil}, 24, "S:+L", false]], 16=>[[{6=>:enemy}, 6, "S:+L", true], [{7=>:enemy}, 7, "S:+L", true], [{8=>:enemy}, 8, "S:+L", true], [{15=>:enemy}, 15, "S:+L", true], [{17=>:enemy}, 17, "S:+L", true], [{25=>:enemy}, 25, "S:+L", true], [{6=>nil}, 6, "S:+L", false], [{7=>nil}, 7, "S:+L", false], [{8=>nil}, 8, "S:+L", false], [{15=>nil}, 15, "S:+L", false], [{17=>nil}, 17, "S:+L", false], [{25=>nil}, 25, "S:+L", false]], 17=>[[{7=>:enemy}, 7, "S:+L", true], [{8=>:enemy}, 8, "S:+L", true], [{16=>:enemy}, 16, "S:+L", true], [{26=>:enemy}, 26, "S:+L", true], [{7=>nil}, 7, "S:+L", false], [{8=>nil}, 8, "S:+L", false], [{16=>nil}, 16, "S:+L", false], [{26=>nil}, 26, "S:+L", false]], 18=>[[{9=>:enemy}, 9, "S:+L", true], [{10=>:enemy}, 10, "S:+L", true], [{19=>:enemy}, 19, "S:+L", true], [{27=>:enemy}, 27, "S:+L", true], [{9=>nil}, 9, "S:+L", false], [{9=>nil, 0=>:enemy}, 0, "S:+L", true], [{9=>nil, 0=>nil}, 0, "S:+L", false], [{10=>nil}, 10, "S:+L", false], [{19=>nil}, 19, "S:+L", false], [{27=>nil}, 27, "S:+L", false]], 19=>[[{9=>:enemy}, 9, "S:+L", true], [{10=>:enemy}, 10, "S:+L", true], [{11=>:enemy}, 11, "S:+L", true], [{18=>:enemy}, 18, "S:+L", true], [{20=>:enemy}, 20, "S:+L", true], [{28=>:enemy}, 28, "S:+L", true], [{9=>nil}, 9, "S:+L", false], [{10=>nil}, 10, "S:+L", false], [{10=>nil, 1=>:enemy}, 1, "S:+L", true], [{10=>nil, 1=>nil}, 1, "S:+L", false], [{11=>nil}, 11, "S:+L", false], [{18=>nil}, 18, "S:+L", false], [{20=>nil}, 20, "S:+L", false], [{28=>nil}, 28, "S:+L", false]], 20=>[[{10=>:enemy}, 10, "S:+L", true], [{11=>:enemy}, 11, "S:+L", true], [{12=>:enemy}, 12, "S:+L", true], [{19=>:enemy}, 19, "S:+L", true], [{21=>:enemy}, 21, "S:+L", true], [{29=>:enemy}, 29, "S:+L", true], [{10=>nil}, 10, "S:+L", false], [{11=>nil}, 11, "S:+L", false], [{11=>nil, 2=>:enemy}, 2, "S:+L", true], [{11=>nil, 2=>nil}, 2, "S:+L", false], [{12=>nil}, 12, "S:+L", false], [{19=>nil}, 19, "S:+L", false], [{21=>nil}, 21, "S:+L", false], [{29=>nil}, 29, "S:+L", false]], 21=>[[{11=>:enemy}, 11, "S:+L", true], [{12=>:enemy}, 12, "S:+L", true], [{13=>:enemy}, 13, "S:+L", true], [{20=>:enemy}, 20, "S:+L", true], [{22=>:enemy}, 22, "S:+L", true], [{30=>:enemy}, 30, "S:+L", true], [{11=>nil}, 11, "S:+L", false], [{12=>nil}, 12, "S:+L", false], [{12=>nil, 3=>:enemy}, 3, "S:+L", true], [{12=>nil, 3=>nil}, 3, "S:+L", false], [{13=>nil}, 13, "S:+L", false], [{20=>nil}, 20, "S:+L", false], [{22=>nil}, 22, "S:+L", false], [{30=>nil}, 30, "S:+L", false]], 22=>[[{12=>:enemy}, 12, "S:+L", true], [{13=>:enemy}, 13, "S:+L", true], [{14=>:enemy}, 14, "S:+L", true], [{21=>:enemy}, 21, "S:+L", true], [{23=>:enemy}, 23, "S:+L", true], [{31=>:enemy}, 31, "S:+L", true], [{12=>nil}, 12, "S:+L", false], [{13=>nil}, 13, "S:+L", false], [{13=>nil, 4=>:enemy}, 4, "S:+L", true], [{13=>nil, 4=>nil}, 4, "S:+L", false], [{14=>nil}, 14, "S:+L", false], [{21=>nil}, 21, "S:+L", false], [{23=>nil}, 23, "S:+L", false], [{31=>nil}, 31, "S:+L", false]], 23=>[[{13=>:enemy}, 13, "S:+L", true], [{14=>:enemy}, 14, "S:+L", true], [{15=>:enemy}, 15, "S:+L", true], [{22=>:enemy}, 22, "S:+L", true], [{24=>:enemy}, 24, "S:+L", true], [{32=>:enemy}, 32, "S:+L", true], [{13=>nil}, 13, "S:+L", false], [{14=>nil}, 14, "S:+L", false], [{14=>nil, 5=>:enemy}, 5, "S:+L", true], [{14=>nil, 5=>nil}, 5, "S:+L", false], [{15=>nil}, 15, "S:+L", false], [{22=>nil}, 22, "S:+L", false], [{24=>nil}, 24, "S:+L", false], [{32=>nil}, 32, "S:+L", false]], 24=>[[{14=>:enemy}, 14, "S:+L", true], [{15=>:enemy}, 15, "S:+L", true], [{16=>:enemy}, 16, "S:+L", true], [{23=>:enemy}, 23, "S:+L", true], [{25=>:enemy}, 25, "S:+L", true], [{33=>:enemy}, 33, "S:+L", true], [{14=>nil}, 14, "S:+L", false], [{15=>nil}, 15, "S:+L", false], [{15=>nil, 6=>:enemy}, 6, "S:+L", true], [{15=>nil, 6=>nil}, 6, "S:+L", false], [{16=>nil}, 16, "S:+L", false], [{23=>nil}, 23, "S:+L", false], [{25=>nil}, 25, "S:+L", false], [{33=>nil}, 33, "S:+L", false]], 25=>[[{15=>:enemy}, 15, "S:+L", true], [{16=>:enemy}, 16, "S:+L", true], [{17=>:enemy}, 17, "S:+L", true], [{24=>:enemy}, 24, "S:+L", true], [{26=>:enemy}, 26, "S:+L", true], [{34=>:enemy}, 34, "S:+L", true], [{15=>nil}, 15, "S:+L", false], [{16=>nil}, 16, "S:+L", false], [{16=>nil, 7=>:enemy}, 7, "S:+L", true], [{16=>nil, 7=>nil}, 7, "S:+L", false], [{17=>nil}, 17, "S:+L", false], [{24=>nil}, 24, "S:+L", false], [{26=>nil}, 26, "S:+L", false], [{34=>nil}, 34, "S:+L", false]], 26=>[[{16=>:enemy}, 16, "S:+L", true], [{17=>:enemy}, 17, "S:+L", true], [{25=>:enemy}, 25, "S:+L", true], [{35=>:enemy}, 35, "S:+L", true], [{16=>nil}, 16, "S:+L", false], [{17=>nil}, 17, "S:+L", false], [{17=>nil, 8=>:enemy}, 8, "S:+L", true], [{17=>nil, 8=>nil}, 8, "S:+L", false], [{25=>nil}, 25, "S:+L", false], [{35=>nil}, 35, "S:+L", false]], 27=>[[{18=>:enemy}, 18, "S:+L", true], [{19=>:enemy}, 19, "S:+L", true], [{28=>:enemy}, 28, "S:+L", true], [{36=>:enemy}, 36, "S:+L", true], [{18=>nil}, 18, "S:+L", false], [{18=>nil, 9=>:enemy}, 9, "S:+L", true], [{18=>nil, 9=>nil}, 9, "S:+L", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{19=>nil}, 19, "S:+L", false], [{28=>nil}, 28, "S:+L", false], [{36=>nil}, 36, "S:+L", false]], 28=>[[{18=>:enemy}, 18, "S:+L", true], [{19=>:enemy}, 19, "S:+L", true], [{20=>:enemy}, 20, "S:+L", true], [{27=>:enemy}, 27, "S:+L", true], [{29=>:enemy}, 29, "S:+L", true], [{37=>:enemy}, 37, "S:+L", true], [{18=>nil}, 18, "S:+L", false], [{19=>nil}, 19, "S:+L", false], [{19=>nil, 10=>:enemy}, 10, "S:+L", true], [{19=>nil, 10=>nil}, 10, "S:+L", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{20=>nil}, 20, "S:+L", false], [{27=>nil}, 27, "S:+L", false], [{29=>nil}, 29, "S:+L", false], [{37=>nil}, 37, "S:+L", false]], 29=>[[{19=>:enemy}, 19, "S:+L", true], [{20=>:enemy}, 20, "S:+L", true], [{21=>:enemy}, 21, "S:+L", true], [{28=>:enemy}, 28, "S:+L", true], [{30=>:enemy}, 30, "S:+L", true], [{38=>:enemy}, 38, "S:+L", true], [{19=>nil}, 19, "S:+L", false], [{20=>nil}, 20, "S:+L", false], [{20=>nil, 11=>:enemy}, 11, "S:+L", true], [{20=>nil, 11=>nil}, 11, "S:+L", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{21=>nil}, 21, "S:+L", false], [{28=>nil}, 28, "S:+L", false], [{30=>nil}, 30, "S:+L", false], [{38=>nil}, 38, "S:+L", false]], 30=>[[{20=>:enemy}, 20, "S:+L", true], [{21=>:enemy}, 21, "S:+L", true], [{22=>:enemy}, 22, "S:+L", true], [{29=>:enemy}, 29, "S:+L", true], [{31=>:enemy}, 31, "S:+L", true], [{39=>:enemy}, 39, "S:+L", true], [{20=>nil}, 20, "S:+L", false], [{21=>nil}, 21, "S:+L", false], [{21=>nil, 12=>:enemy}, 12, "S:+L", true], [{21=>nil, 12=>nil}, 12, "S:+L", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{22=>nil}, 22, "S:+L", false], [{29=>nil}, 29, "S:+L", false], [{31=>nil}, 31, "S:+L", false], [{39=>nil}, 39, "S:+L", false]], 31=>[[{21=>:enemy}, 21, "S:+L", true], [{22=>:enemy}, 22, "S:+L", true], [{23=>:enemy}, 23, "S:+L", true], [{30=>:enemy}, 30, "S:+L", true], [{32=>:enemy}, 32, "S:+L", true], [{40=>:enemy}, 40, "S:+L", true], [{21=>nil}, 21, "S:+L", false], [{22=>nil}, 22, "S:+L", false], [{22=>nil, 13=>:enemy}, 13, "S:+L", true], [{22=>nil, 13=>nil}, 13, "S:+L", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{23=>nil}, 23, "S:+L", false], [{30=>nil}, 30, "S:+L", false], [{32=>nil}, 32, "S:+L", false], [{40=>nil}, 40, "S:+L", false]], 32=>[[{22=>:enemy}, 22, "S:+L", true], [{23=>:enemy}, 23, "S:+L", true], [{24=>:enemy}, 24, "S:+L", true], [{31=>:enemy}, 31, "S:+L", true], [{33=>:enemy}, 33, "S:+L", true], [{41=>:enemy}, 41, "S:+L", true], [{22=>nil}, 22, "S:+L", false], [{23=>nil}, 23, "S:+L", false], [{23=>nil, 14=>:enemy}, 14, "S:+L", true], [{23=>nil, 14=>nil}, 14, "S:+L", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{24=>nil}, 24, "S:+L", false], [{31=>nil}, 31, "S:+L", false], [{33=>nil}, 33, "S:+L", false], [{41=>nil}, 41, "S:+L", false]], 33=>[[{23=>:enemy}, 23, "S:+L", true], [{24=>:enemy}, 24, "S:+L", true], [{25=>:enemy}, 25, "S:+L", true], [{32=>:enemy}, 32, "S:+L", true], [{34=>:enemy}, 34, "S:+L", true], [{42=>:enemy}, 42, "S:+L", true], [{23=>nil}, 23, "S:+L", false], [{24=>nil}, 24, "S:+L", false], [{24=>nil, 15=>:enemy}, 15, "S:+L", true], [{24=>nil, 15=>nil}, 15, "S:+L", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{25=>nil}, 25, "S:+L", false], [{32=>nil}, 32, "S:+L", false], [{34=>nil}, 34, "S:+L", false], [{42=>nil}, 42, "S:+L", false]], 34=>[[{24=>:enemy}, 24, "S:+L", true], [{25=>:enemy}, 25, "S:+L", true], [{26=>:enemy}, 26, "S:+L", true], [{33=>:enemy}, 33, "S:+L", true], [{35=>:enemy}, 35, "S:+L", true], [{43=>:enemy}, 43, "S:+L", true], [{24=>nil}, 24, "S:+L", false], [{25=>nil}, 25, "S:+L", false], [{25=>nil, 16=>:enemy}, 16, "S:+L", true], [{25=>nil, 16=>nil}, 16, "S:+L", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{26=>nil}, 26, "S:+L", false], [{33=>nil}, 33, "S:+L", false], [{35=>nil}, 35, "S:+L", false], [{43=>nil}, 43, "S:+L", false]], 35=>[[{25=>:enemy}, 25, "S:+L", true], [{26=>:enemy}, 26, "S:+L", true], [{34=>:enemy}, 34, "S:+L", true], [{44=>:enemy}, 44, "S:+L", true], [{25=>nil}, 25, "S:+L", false], [{26=>nil}, 26, "S:+L", false], [{26=>nil, 17=>:enemy}, 17, "S:+L", true], [{26=>nil, 17=>nil}, 17, "S:+L", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{34=>nil}, 34, "S:+L", false], [{44=>nil}, 44, "S:+L", false]], 36=>[[{27=>:enemy}, 27, "S:+L", true], [{28=>:enemy}, 28, "S:+L", true], [{37=>:enemy}, 37, "S:+L", true], [{45=>:enemy}, 45, "S:+L", true], [{27=>nil}, 27, "S:+L", false], [{27=>nil, 18=>:enemy}, 18, "S:+L", true], [{27=>nil, 18=>nil}, 18, "S:+L", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{28=>nil}, 28, "S:+L", false], [{37=>nil}, 37, "S:+L", false], [{45=>nil}, 45, "S:+L", false]], 37=>[[{27=>:enemy}, 27, "S:+L", true], [{28=>:enemy}, 28, "S:+L", true], [{29=>:enemy}, 29, "S:+L", true], [{36=>:enemy}, 36, "S:+L", true], [{38=>:enemy}, 38, "S:+L", true], [{46=>:enemy}, 46, "S:+L", true], [{27=>nil}, 27, "S:+L", false], [{28=>nil}, 28, "S:+L", false], [{28=>nil, 19=>:enemy}, 19, "S:+L", true], [{28=>nil, 19=>nil}, 19, "S:+L", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{29=>nil}, 29, "S:+L", false], [{36=>nil}, 36, "S:+L", false], [{38=>nil}, 38, "S:+L", false], [{46=>nil}, 46, "S:+L", false]], 38=>[[{28=>:enemy}, 28, "S:+L", true], [{29=>:enemy}, 29, "S:+L", true], [{30=>:enemy}, 30, "S:+L", true], [{37=>:enemy}, 37, "S:+L", true], [{39=>:enemy}, 39, "S:+L", true], [{47=>:enemy}, 47, "S:+L", true], [{28=>nil}, 28, "S:+L", false], [{29=>nil}, 29, "S:+L", false], [{29=>nil, 20=>:enemy}, 20, "S:+L", true], [{29=>nil, 20=>nil}, 20, "S:+L", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{30=>nil}, 30, "S:+L", false], [{37=>nil}, 37, "S:+L", false], [{39=>nil}, 39, "S:+L", false], [{47=>nil}, 47, "S:+L", false]], 39=>[[{29=>:enemy}, 29, "S:+L", true], [{30=>:enemy}, 30, "S:+L", true], [{31=>:enemy}, 31, "S:+L", true], [{38=>:enemy}, 38, "S:+L", true], [{40=>:enemy}, 40, "S:+L", true], [{48=>:enemy}, 48, "S:+L", true], [{29=>nil}, 29, "S:+L", false], [{30=>nil}, 30, "S:+L", false], [{30=>nil, 21=>:enemy}, 21, "S:+L", true], [{30=>nil, 21=>nil}, 21, "S:+L", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{31=>nil}, 31, "S:+L", false], [{38=>nil}, 38, "S:+L", false], [{40=>nil}, 40, "S:+L", false], [{48=>nil}, 48, "S:+L", false]], 40=>[[{30=>:enemy}, 30, "S:+L", true], [{31=>:enemy}, 31, "S:+L", true], [{32=>:enemy}, 32, "S:+L", true], [{39=>:enemy}, 39, "S:+L", true], [{41=>:enemy}, 41, "S:+L", true], [{49=>:enemy}, 49, "S:+L", true], [{30=>nil}, 30, "S:+L", false], [{31=>nil}, 31, "S:+L", false], [{31=>nil, 22=>:enemy}, 22, "S:+L", true], [{31=>nil, 22=>nil}, 22, "S:+L", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{32=>nil}, 32, "S:+L", false], [{39=>nil}, 39, "S:+L", false], [{41=>nil}, 41, "S:+L", false], [{49=>nil}, 49, "S:+L", false]], 41=>[[{31=>:enemy}, 31, "S:+L", true], [{32=>:enemy}, 32, "S:+L", true], [{33=>:enemy}, 33, "S:+L", true], [{40=>:enemy}, 40, "S:+L", true], [{42=>:enemy}, 42, "S:+L", true], [{50=>:enemy}, 50, "S:+L", true], [{31=>nil}, 31, "S:+L", false], [{32=>nil}, 32, "S:+L", false], [{32=>nil, 23=>:enemy}, 23, "S:+L", true], [{32=>nil, 23=>nil}, 23, "S:+L", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{33=>nil}, 33, "S:+L", false], [{40=>nil}, 40, "S:+L", false], [{42=>nil}, 42, "S:+L", false], [{50=>nil}, 50, "S:+L", false]], 42=>[[{32=>:enemy}, 32, "S:+L", true], [{33=>:enemy}, 33, "S:+L", true], [{34=>:enemy}, 34, "S:+L", true], [{41=>:enemy}, 41, "S:+L", true], [{43=>:enemy}, 43, "S:+L", true], [{51=>:enemy}, 51, "S:+L", true], [{32=>nil}, 32, "S:+L", false], [{33=>nil}, 33, "S:+L", false], [{33=>nil, 24=>:enemy}, 24, "S:+L", true], [{33=>nil, 24=>nil}, 24, "S:+L", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{34=>nil}, 34, "S:+L", false], [{41=>nil}, 41, "S:+L", false], [{43=>nil}, 43, "S:+L", false], [{51=>nil}, 51, "S:+L", false]], 43=>[[{33=>:enemy}, 33, "S:+L", true], [{34=>:enemy}, 34, "S:+L", true], [{35=>:enemy}, 35, "S:+L", true], [{42=>:enemy}, 42, "S:+L", true], [{44=>:enemy}, 44, "S:+L", true], [{52=>:enemy}, 52, "S:+L", true], [{33=>nil}, 33, "S:+L", false], [{34=>nil}, 34, "S:+L", false], [{34=>nil, 25=>:enemy}, 25, "S:+L", true], [{34=>nil, 25=>nil}, 25, "S:+L", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{35=>nil}, 35, "S:+L", false], [{42=>nil}, 42, "S:+L", false], [{44=>nil}, 44, "S:+L", false], [{52=>nil}, 52, "S:+L", false]], 44=>[[{34=>:enemy}, 34, "S:+L", true], [{35=>:enemy}, 35, "S:+L", true], [{43=>:enemy}, 43, "S:+L", true], [{53=>:enemy}, 53, "S:+L", true], [{34=>nil}, 34, "S:+L", false], [{35=>nil}, 35, "S:+L", false], [{35=>nil, 26=>:enemy}, 26, "S:+L", true], [{35=>nil, 26=>nil}, 26, "S:+L", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{43=>nil}, 43, "S:+L", false], [{53=>nil}, 53, "S:+L", false]], 45=>[[{36=>:enemy}, 36, "S:+L", true], [{37=>:enemy}, 37, "S:+L", true], [{46=>:enemy}, 46, "S:+L", true], [{54=>:enemy}, 54, "S:+L", true], [{36=>nil}, 36, "S:+L", false], [{36=>nil, 27=>:enemy}, 27, "S:+L", true], [{36=>nil, 27=>nil}, 27, "S:+L", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{37=>nil}, 37, "S:+L", false], [{46=>nil}, 46, "S:+L", false], [{54=>nil}, 54, "S:+L", false]], 46=>[[{36=>:enemy}, 36, "S:+L", true], [{37=>:enemy}, 37, "S:+L", true], [{38=>:enemy}, 38, "S:+L", true], [{45=>:enemy}, 45, "S:+L", true], [{47=>:enemy}, 47, "S:+L", true], [{55=>:enemy}, 55, "S:+L", true], [{36=>nil}, 36, "S:+L", false], [{37=>nil}, 37, "S:+L", false], [{37=>nil, 28=>:enemy}, 28, "S:+L", true], [{37=>nil, 28=>nil}, 28, "S:+L", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{38=>nil}, 38, "S:+L", false], [{45=>nil}, 45, "S:+L", false], [{47=>nil}, 47, "S:+L", false], [{55=>nil}, 55, "S:+L", false]], 47=>[[{37=>:enemy}, 37, "S:+L", true], [{38=>:enemy}, 38, "S:+L", true], [{39=>:enemy}, 39, "S:+L", true], [{46=>:enemy}, 46, "S:+L", true], [{48=>:enemy}, 48, "S:+L", true], [{56=>:enemy}, 56, "S:+L", true], [{37=>nil}, 37, "S:+L", false], [{38=>nil}, 38, "S:+L", false], [{38=>nil, 29=>:enemy}, 29, "S:+L", true], [{38=>nil, 29=>nil}, 29, "S:+L", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{39=>nil}, 39, "S:+L", false], [{46=>nil}, 46, "S:+L", false], [{48=>nil}, 48, "S:+L", false], [{56=>nil}, 56, "S:+L", false]], 48=>[[{38=>:enemy}, 38, "S:+L", true], [{39=>:enemy}, 39, "S:+L", true], [{40=>:enemy}, 40, "S:+L", true], [{47=>:enemy}, 47, "S:+L", true], [{49=>:enemy}, 49, "S:+L", true], [{57=>:enemy}, 57, "S:+L", true], [{38=>nil}, 38, "S:+L", false], [{39=>nil}, 39, "S:+L", false], [{39=>nil, 30=>:enemy}, 30, "S:+L", true], [{39=>nil, 30=>nil}, 30, "S:+L", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{40=>nil}, 40, "S:+L", false], [{47=>nil}, 47, "S:+L", false], [{49=>nil}, 49, "S:+L", false], [{57=>nil}, 57, "S:+L", false]], 49=>[[{39=>:enemy}, 39, "S:+L", true], [{40=>:enemy}, 40, "S:+L", true], [{41=>:enemy}, 41, "S:+L", true], [{48=>:enemy}, 48, "S:+L", true], [{50=>:enemy}, 50, "S:+L", true], [{58=>:enemy}, 58, "S:+L", true], [{39=>nil}, 39, "S:+L", false], [{40=>nil}, 40, "S:+L", false], [{40=>nil, 31=>:enemy}, 31, "S:+L", true], [{40=>nil, 31=>nil}, 31, "S:+L", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{41=>nil}, 41, "S:+L", false], [{48=>nil}, 48, "S:+L", false], [{50=>nil}, 50, "S:+L", false], [{58=>nil}, 58, "S:+L", false]], 50=>[[{40=>:enemy}, 40, "S:+L", true], [{41=>:enemy}, 41, "S:+L", true], [{42=>:enemy}, 42, "S:+L", true], [{49=>:enemy}, 49, "S:+L", true], [{51=>:enemy}, 51, "S:+L", true], [{59=>:enemy}, 59, "S:+L", true], [{40=>nil}, 40, "S:+L", false], [{41=>nil}, 41, "S:+L", false], [{41=>nil, 32=>:enemy}, 32, "S:+L", true], [{41=>nil, 32=>nil}, 32, "S:+L", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{42=>nil}, 42, "S:+L", false], [{49=>nil}, 49, "S:+L", false], [{51=>nil}, 51, "S:+L", false], [{59=>nil}, 59, "S:+L", false]], 51=>[[{41=>:enemy}, 41, "S:+L", true], [{42=>:enemy}, 42, "S:+L", true], [{43=>:enemy}, 43, "S:+L", true], [{50=>:enemy}, 50, "S:+L", true], [{52=>:enemy}, 52, "S:+L", true], [{60=>:enemy}, 60, "S:+L", true], [{41=>nil}, 41, "S:+L", false], [{42=>nil}, 42, "S:+L", false], [{42=>nil, 33=>:enemy}, 33, "S:+L", true], [{42=>nil, 33=>nil}, 33, "S:+L", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{43=>nil}, 43, "S:+L", false], [{50=>nil}, 50, "S:+L", false], [{52=>nil}, 52, "S:+L", false], [{60=>nil}, 60, "S:+L", false]], 52=>[[{42=>:enemy}, 42, "S:+L", true], [{43=>:enemy}, 43, "S:+L", true], [{44=>:enemy}, 44, "S:+L", true], [{51=>:enemy}, 51, "S:+L", true], [{53=>:enemy}, 53, "S:+L", true], [{61=>:enemy}, 61, "S:+L", true], [{42=>nil}, 42, "S:+L", false], [{43=>nil}, 43, "S:+L", false], [{43=>nil, 34=>:enemy}, 34, "S:+L", true], [{43=>nil, 34=>nil}, 34, "S:+L", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{44=>nil}, 44, "S:+L", false], [{51=>nil}, 51, "S:+L", false], [{53=>nil}, 53, "S:+L", false], [{61=>nil}, 61, "S:+L", false]], 53=>[[{43=>:enemy}, 43, "S:+L", true], [{44=>:enemy}, 44, "S:+L", true], [{52=>:enemy}, 52, "S:+L", true], [{62=>:enemy}, 62, "S:+L", true], [{43=>nil}, 43, "S:+L", false], [{44=>nil}, 44, "S:+L", false], [{44=>nil, 35=>:enemy}, 35, "S:+L", true], [{44=>nil, 35=>nil}, 35, "S:+L", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{52=>nil}, 52, "S:+L", false], [{62=>nil}, 62, "S:+L", false]], 54=>[[{45=>:enemy}, 45, "S:+L", true], [{46=>:enemy}, 46, "S:+L", true], [{55=>:enemy}, 55, "S:+L", true], [{63=>:enemy}, 63, "S:+L", true], [{45=>nil}, 45, "S:+L", false], [{45=>nil, 36=>:enemy}, 36, "S:+L", true], [{45=>nil, 36=>nil}, 36, "S:+L", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "S:+L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{46=>nil}, 46, "S:+L", false], [{55=>nil}, 55, "S:+L", false], [{63=>nil}, 63, "S:+L", false]], 55=>[[{45=>:enemy}, 45, "S:+L", true], [{46=>:enemy}, 46, "S:+L", true], [{47=>:enemy}, 47, "S:+L", true], [{54=>:enemy}, 54, "S:+L", true], [{56=>:enemy}, 56, "S:+L", true], [{64=>:enemy}, 64, "S:+L", true], [{45=>nil}, 45, "S:+L", false], [{46=>nil}, 46, "S:+L", false], [{46=>nil, 37=>:enemy}, 37, "S:+L", true], [{46=>nil, 37=>nil}, 37, "S:+L", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "S:+L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{47=>nil}, 47, "S:+L", false], [{54=>nil}, 54, "S:+L", false], [{56=>nil}, 56, "S:+L", false], [{64=>nil}, 64, "S:+L", false]], 56=>[[{46=>:enemy}, 46, "S:+L", true], [{47=>:enemy}, 47, "S:+L", true], [{48=>:enemy}, 48, "S:+L", true], [{55=>:enemy}, 55, "S:+L", true], [{57=>:enemy}, 57, "S:+L", true], [{65=>:enemy}, 65, "S:+L", true], [{46=>nil}, 46, "S:+L", false], [{47=>nil}, 47, "S:+L", false], [{47=>nil, 38=>:enemy}, 38, "S:+L", true], [{47=>nil, 38=>nil}, 38, "S:+L", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "S:+L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{48=>nil}, 48, "S:+L", false], [{55=>nil}, 55, "S:+L", false], [{57=>nil}, 57, "S:+L", false], [{65=>nil}, 65, "S:+L", false]], 57=>[[{47=>:enemy}, 47, "S:+L", true], [{48=>:enemy}, 48, "S:+L", true], [{49=>:enemy}, 49, "S:+L", true], [{56=>:enemy}, 56, "S:+L", true], [{58=>:enemy}, 58, "S:+L", true], [{66=>:enemy}, 66, "S:+L", true], [{47=>nil}, 47, "S:+L", false], [{48=>nil}, 48, "S:+L", false], [{48=>nil, 39=>:enemy}, 39, "S:+L", true], [{48=>nil, 39=>nil}, 39, "S:+L", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "S:+L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{49=>nil}, 49, "S:+L", false], [{56=>nil}, 56, "S:+L", false], [{58=>nil}, 58, "S:+L", false], [{66=>nil}, 66, "S:+L", false]], 58=>[[{48=>:enemy}, 48, "S:+L", true], [{49=>:enemy}, 49, "S:+L", true], [{50=>:enemy}, 50, "S:+L", true], [{57=>:enemy}, 57, "S:+L", true], [{59=>:enemy}, 59, "S:+L", true], [{67=>:enemy}, 67, "S:+L", true], [{48=>nil}, 48, "S:+L", false], [{49=>nil}, 49, "S:+L", false], [{49=>nil, 40=>:enemy}, 40, "S:+L", true], [{49=>nil, 40=>nil}, 40, "S:+L", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "S:+L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{50=>nil}, 50, "S:+L", false], [{57=>nil}, 57, "S:+L", false], [{59=>nil}, 59, "S:+L", false], [{67=>nil}, 67, "S:+L", false]], 59=>[[{49=>:enemy}, 49, "S:+L", true], [{50=>:enemy}, 50, "S:+L", true], [{51=>:enemy}, 51, "S:+L", true], [{58=>:enemy}, 58, "S:+L", true], [{60=>:enemy}, 60, "S:+L", true], [{68=>:enemy}, 68, "S:+L", true], [{49=>nil}, 49, "S:+L", false], [{50=>nil}, 50, "S:+L", false], [{50=>nil, 41=>:enemy}, 41, "S:+L", true], [{50=>nil, 41=>nil}, 41, "S:+L", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "S:+L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{51=>nil}, 51, "S:+L", false], [{58=>nil}, 58, "S:+L", false], [{60=>nil}, 60, "S:+L", false], [{68=>nil}, 68, "S:+L", false]], 60=>[[{50=>:enemy}, 50, "S:+L", true], [{51=>:enemy}, 51, "S:+L", true], [{52=>:enemy}, 52, "S:+L", true], [{59=>:enemy}, 59, "S:+L", true], [{61=>:enemy}, 61, "S:+L", true], [{69=>:enemy}, 69, "S:+L", true], [{50=>nil}, 50, "S:+L", false], [{51=>nil}, 51, "S:+L", false], [{51=>nil, 42=>:enemy}, 42, "S:+L", true], [{51=>nil, 42=>nil}, 42, "S:+L", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "S:+L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{52=>nil}, 52, "S:+L", false], [{59=>nil}, 59, "S:+L", false], [{61=>nil}, 61, "S:+L", false], [{69=>nil}, 69, "S:+L", false]], 61=>[[{51=>:enemy}, 51, "S:+L", true], [{52=>:enemy}, 52, "S:+L", true], [{53=>:enemy}, 53, "S:+L", true], [{60=>:enemy}, 60, "S:+L", true], [{62=>:enemy}, 62, "S:+L", true], [{70=>:enemy}, 70, "S:+L", true], [{51=>nil}, 51, "S:+L", false], [{52=>nil}, 52, "S:+L", false], [{52=>nil, 43=>:enemy}, 43, "S:+L", true], [{52=>nil, 43=>nil}, 43, "S:+L", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "S:+L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{53=>nil}, 53, "S:+L", false], [{60=>nil}, 60, "S:+L", false], [{62=>nil}, 62, "S:+L", false], [{70=>nil}, 70, "S:+L", false]], 62=>[[{52=>:enemy}, 52, "S:+L", true], [{53=>:enemy}, 53, "S:+L", true], [{61=>:enemy}, 61, "S:+L", true], [{71=>:enemy}, 71, "S:+L", true], [{52=>nil}, 52, "S:+L", false], [{53=>nil}, 53, "S:+L", false], [{53=>nil, 44=>:enemy}, 44, "S:+L", true], [{53=>nil, 44=>nil}, 44, "S:+L", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "S:+L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{61=>nil}, 61, "S:+L", false], [{71=>nil}, 71, "S:+L", false]], 63=>[[{54=>:enemy}, 54, "S:+L", true], [{55=>:enemy}, 55, "S:+L", true], [{64=>:enemy}, 64, "S:+L", true], [{72=>:enemy}, 72, "S:+L", true], [{54=>nil}, 54, "S:+L", false], [{54=>nil, 45=>:enemy}, 45, "S:+L", true], [{54=>nil, 45=>nil}, 45, "S:+L", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{55=>nil}, 55, "S:+L", false], [{64=>nil}, 64, "S:+L", false], [{72=>nil}, 72, "S:+L", false]], 64=>[[{54=>:enemy}, 54, "S:+L", true], [{55=>:enemy}, 55, "S:+L", true], [{56=>:enemy}, 56, "S:+L", true], [{63=>:enemy}, 63, "S:+L", true], [{65=>:enemy}, 65, "S:+L", true], [{73=>:enemy}, 73, "S:+L", true], [{54=>nil}, 54, "S:+L", false], [{55=>nil}, 55, "S:+L", false], [{55=>nil, 46=>:enemy}, 46, "S:+L", true], [{55=>nil, 46=>nil}, 46, "S:+L", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{56=>nil}, 56, "S:+L", false], [{63=>nil}, 63, "S:+L", false], [{65=>nil}, 65, "S:+L", false], [{73=>nil}, 73, "S:+L", false]], 65=>[[{55=>:enemy}, 55, "S:+L", true], [{56=>:enemy}, 56, "S:+L", true], [{57=>:enemy}, 57, "S:+L", true], [{64=>:enemy}, 64, "S:+L", true], [{66=>:enemy}, 66, "S:+L", true], [{74=>:enemy}, 74, "S:+L", true], [{55=>nil}, 55, "S:+L", false], [{56=>nil}, 56, "S:+L", false], [{56=>nil, 47=>:enemy}, 47, "S:+L", true], [{56=>nil, 47=>nil}, 47, "S:+L", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{57=>nil}, 57, "S:+L", false], [{64=>nil}, 64, "S:+L", false], [{66=>nil}, 66, "S:+L", false], [{74=>nil}, 74, "S:+L", false]], 66=>[[{56=>:enemy}, 56, "S:+L", true], [{57=>:enemy}, 57, "S:+L", true], [{58=>:enemy}, 58, "S:+L", true], [{65=>:enemy}, 65, "S:+L", true], [{67=>:enemy}, 67, "S:+L", true], [{75=>:enemy}, 75, "S:+L", true], [{56=>nil}, 56, "S:+L", false], [{57=>nil}, 57, "S:+L", false], [{57=>nil, 48=>:enemy}, 48, "S:+L", true], [{57=>nil, 48=>nil}, 48, "S:+L", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{58=>nil}, 58, "S:+L", false], [{65=>nil}, 65, "S:+L", false], [{67=>nil}, 67, "S:+L", false], [{75=>nil}, 75, "S:+L", false]], 67=>[[{57=>:enemy}, 57, "S:+L", true], [{58=>:enemy}, 58, "S:+L", true], [{59=>:enemy}, 59, "S:+L", true], [{66=>:enemy}, 66, "S:+L", true], [{68=>:enemy}, 68, "S:+L", true], [{76=>:enemy}, 76, "S:+L", true], [{57=>nil}, 57, "S:+L", false], [{58=>nil}, 58, "S:+L", false], [{58=>nil, 49=>:enemy}, 49, "S:+L", true], [{58=>nil, 49=>nil}, 49, "S:+L", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{59=>nil}, 59, "S:+L", false], [{66=>nil}, 66, "S:+L", false], [{68=>nil}, 68, "S:+L", false], [{76=>nil}, 76, "S:+L", false]], 68=>[[{58=>:enemy}, 58, "S:+L", true], [{59=>:enemy}, 59, "S:+L", true], [{60=>:enemy}, 60, "S:+L", true], [{67=>:enemy}, 67, "S:+L", true], [{69=>:enemy}, 69, "S:+L", true], [{77=>:enemy}, 77, "S:+L", true], [{58=>nil}, 58, "S:+L", false], [{59=>nil}, 59, "S:+L", false], [{59=>nil, 50=>:enemy}, 50, "S:+L", true], [{59=>nil, 50=>nil}, 50, "S:+L", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{60=>nil}, 60, "S:+L", false], [{67=>nil}, 67, "S:+L", false], [{69=>nil}, 69, "S:+L", false], [{77=>nil}, 77, "S:+L", false]], 69=>[[{59=>:enemy}, 59, "S:+L", true], [{60=>:enemy}, 60, "S:+L", true], [{61=>:enemy}, 61, "S:+L", true], [{68=>:enemy}, 68, "S:+L", true], [{70=>:enemy}, 70, "S:+L", true], [{78=>:enemy}, 78, "S:+L", true], [{59=>nil}, 59, "S:+L", false], [{60=>nil}, 60, "S:+L", false], [{60=>nil, 51=>:enemy}, 51, "S:+L", true], [{60=>nil, 51=>nil}, 51, "S:+L", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{61=>nil}, 61, "S:+L", false], [{68=>nil}, 68, "S:+L", false], [{70=>nil}, 70, "S:+L", false], [{78=>nil}, 78, "S:+L", false]], 70=>[[{60=>:enemy}, 60, "S:+L", true], [{61=>:enemy}, 61, "S:+L", true], [{62=>:enemy}, 62, "S:+L", true], [{69=>:enemy}, 69, "S:+L", true], [{71=>:enemy}, 71, "S:+L", true], [{79=>:enemy}, 79, "S:+L", true], [{60=>nil}, 60, "S:+L", false], [{61=>nil}, 61, "S:+L", false], [{61=>nil, 52=>:enemy}, 52, "S:+L", true], [{61=>nil, 52=>nil}, 52, "S:+L", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{62=>nil}, 62, "S:+L", false], [{69=>nil}, 69, "S:+L", false], [{71=>nil}, 71, "S:+L", false], [{79=>nil}, 79, "S:+L", false]], 71=>[[{61=>:enemy}, 61, "S:+L", true], [{62=>:enemy}, 62, "S:+L", true], [{70=>:enemy}, 70, "S:+L", true], [{80=>:enemy}, 80, "S:+L", true], [{61=>nil}, 61, "S:+L", false], [{62=>nil}, 62, "S:+L", false], [{62=>nil, 53=>:enemy}, 53, "S:+L", true], [{62=>nil, 53=>nil}, 53, "S:+L", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{70=>nil}, 70, "S:+L", false], [{80=>nil}, 80, "S:+L", false]], 72=>[[{63=>:enemy}, 63, "S:+L", true], [{64=>:enemy}, 64, "S:+L", true], [{73=>:enemy}, 73, "S:+L", true], [{63=>nil}, 63, "S:+L", false], [{63=>nil, 54=>:enemy}, 54, "S:+L", true], [{63=>nil, 54=>nil}, 54, "S:+L", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false], [{64=>nil}, 64, "S:+L", false], [{73=>nil}, 73, "S:+L", false]], 73=>[[{63=>:enemy}, 63, "S:+L", true], [{64=>:enemy}, 64, "S:+L", true], [{65=>:enemy}, 65, "S:+L", true], [{72=>:enemy}, 72, "S:+L", true], [{74=>:enemy}, 74, "S:+L", true], [{63=>nil}, 63, "S:+L", false], [{64=>nil}, 64, "S:+L", false], [{64=>nil, 55=>:enemy}, 55, "S:+L", true], [{64=>nil, 55=>nil}, 55, "S:+L", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false], [{65=>nil}, 65, "S:+L", false], [{72=>nil}, 72, "S:+L", false], [{74=>nil}, 74, "S:+L", false]], 74=>[[{64=>:enemy}, 64, "S:+L", true], [{65=>:enemy}, 65, "S:+L", true], [{66=>:enemy}, 66, "S:+L", true], [{73=>:enemy}, 73, "S:+L", true], [{75=>:enemy}, 75, "S:+L", true], [{64=>nil}, 64, "S:+L", false], [{65=>nil}, 65, "S:+L", false], [{65=>nil, 56=>:enemy}, 56, "S:+L", true], [{65=>nil, 56=>nil}, 56, "S:+L", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false], [{66=>nil}, 66, "S:+L", false], [{73=>nil}, 73, "S:+L", false], [{75=>nil}, 75, "S:+L", false]], 75=>[[{65=>:enemy}, 65, "S:+L", true], [{66=>:enemy}, 66, "S:+L", true], [{67=>:enemy}, 67, "S:+L", true], [{74=>:enemy}, 74, "S:+L", true], [{76=>:enemy}, 76, "S:+L", true], [{65=>nil}, 65, "S:+L", false], [{66=>nil}, 66, "S:+L", false], [{66=>nil, 57=>:enemy}, 57, "S:+L", true], [{66=>nil, 57=>nil}, 57, "S:+L", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false], [{67=>nil}, 67, "S:+L", false], [{74=>nil}, 74, "S:+L", false], [{76=>nil}, 76, "S:+L", false]], 76=>[[{66=>:enemy}, 66, "S:+L", true], [{67=>:enemy}, 67, "S:+L", true], [{68=>:enemy}, 68, "S:+L", true], [{75=>:enemy}, 75, "S:+L", true], [{77=>:enemy}, 77, "S:+L", true], [{66=>nil}, 66, "S:+L", false], [{67=>nil}, 67, "S:+L", false], [{67=>nil, 58=>:enemy}, 58, "S:+L", true], [{67=>nil, 58=>nil}, 58, "S:+L", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false], [{68=>nil}, 68, "S:+L", false], [{75=>nil}, 75, "S:+L", false], [{77=>nil}, 77, "S:+L", false]], 77=>[[{67=>:enemy}, 67, "S:+L", true], [{68=>:enemy}, 68, "S:+L", true], [{69=>:enemy}, 69, "S:+L", true], [{76=>:enemy}, 76, "S:+L", true], [{78=>:enemy}, 78, "S:+L", true], [{67=>nil}, 67, "S:+L", false], [{68=>nil}, 68, "S:+L", false], [{68=>nil, 59=>:enemy}, 59, "S:+L", true], [{68=>nil, 59=>nil}, 59, "S:+L", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false], [{69=>nil}, 69, "S:+L", false], [{76=>nil}, 76, "S:+L", false], [{78=>nil}, 78, "S:+L", false]], 78=>[[{68=>:enemy}, 68, "S:+L", true], [{69=>:enemy}, 69, "S:+L", true], [{70=>:enemy}, 70, "S:+L", true], [{77=>:enemy}, 77, "S:+L", true], [{79=>:enemy}, 79, "S:+L", true], [{68=>nil}, 68, "S:+L", false], [{69=>nil}, 69, "S:+L", false], [{69=>nil, 60=>:enemy}, 60, "S:+L", true], [{69=>nil, 60=>nil}, 60, "S:+L", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false], [{70=>nil}, 70, "S:+L", false], [{77=>nil}, 77, "S:+L", false], [{79=>nil}, 79, "S:+L", false]], 79=>[[{69=>:enemy}, 69, "S:+L", true], [{70=>:enemy}, 70, "S:+L", true], [{71=>:enemy}, 71, "S:+L", true], [{78=>:enemy}, 78, "S:+L", true], [{80=>:enemy}, 80, "S:+L", true], [{69=>nil}, 69, "S:+L", false], [{70=>nil}, 70, "S:+L", false], [{70=>nil, 61=>:enemy}, 61, "S:+L", true], [{70=>nil, 61=>nil}, 61, "S:+L", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false], [{71=>nil}, 71, "S:+L", false], [{78=>nil}, 78, "S:+L", false], [{80=>nil}, 80, "S:+L", false]], 80=>[[{70=>:enemy}, 70, "S:+L", true], [{71=>:enemy}, 71, "S:+L", true], [{79=>:enemy}, 79, "S:+L", true], [{70=>nil}, 70, "S:+L", false], [{71=>nil}, 71, "S:+L", false], [{71=>nil, 62=>:enemy}, 62, "S:+L", true], [{71=>nil, 62=>nil}, 62, "S:+L", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false], [{79=>nil}, 79, "S:+L", false]], nil=>[]}, "S:+N"=>{0=>[[{1=>:enemy}, 1, "S:+N", true], [{9=>:enemy}, 9, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{9=>nil}, 9, "S:+N", false]], 1=>[[{0=>:enemy}, 0, "S:+N", true], [{2=>:enemy}, 2, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{0=>nil}, 0, "S:+N", false], [{2=>nil}, 2, "S:+N", false], [{10=>nil}, 10, "S:+N", false]], 2=>[[{1=>:enemy}, 1, "S:+N", true], [{3=>:enemy}, 3, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{3=>nil}, 3, "S:+N", false], [{11=>nil}, 11, "S:+N", false]], 3=>[[{2=>:enemy}, 2, "S:+N", true], [{4=>:enemy}, 4, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{2=>nil}, 2, "S:+N", false], [{4=>nil}, 4, "S:+N", false], [{12=>nil}, 12, "S:+N", false]], 4=>[[{3=>:enemy}, 3, "S:+N", true], [{5=>:enemy}, 5, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{3=>nil}, 3, "S:+N", false], [{5=>nil}, 5, "S:+N", false], [{13=>nil}, 13, "S:+N", false]], 5=>[[{4=>:enemy}, 4, "S:+N", true], [{6=>:enemy}, 6, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{4=>nil}, 4, "S:+N", false], [{6=>nil}, 6, "S:+N", false], [{14=>nil}, 14, "S:+N", false]], 6=>[[{5=>:enemy}, 5, "S:+N", true], [{7=>:enemy}, 7, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{5=>nil}, 5, "S:+N", false], [{7=>nil}, 7, "S:+N", false], [{15=>nil}, 15, "S:+N", false]], 7=>[[{6=>:enemy}, 6, "S:+N", true], [{8=>:enemy}, 8, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{6=>nil}, 6, "S:+N", false], [{8=>nil}, 8, "S:+N", false], [{16=>nil}, 16, "S:+N", false]], 8=>[[{7=>:enemy}, 7, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{7=>nil}, 7, "S:+N", false], [{17=>nil}, 17, "S:+N", false]], 9=>[[{0=>:enemy}, 0, "S:+N", true], [{1=>:enemy}, 1, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{18=>:enemy}, 18, "S:+N", true], [{0=>nil}, 0, "S:+N", false], [{1=>nil}, 1, "S:+N", false], [{10=>nil}, 10, "S:+N", false], [{18=>nil}, 18, "S:+N", false]], 10=>[[{0=>:enemy}, 0, "S:+N", true], [{1=>:enemy}, 1, "S:+N", true], [{2=>:enemy}, 2, "S:+N", true], [{9=>:enemy}, 9, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{0=>nil}, 0, "S:+N", false], [{1=>nil}, 1, "S:+N", false], [{2=>nil}, 2, "S:+N", false], [{9=>nil}, 9, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{19=>nil}, 19, "S:+N", false]], 11=>[[{1=>:enemy}, 1, "S:+N", true], [{2=>:enemy}, 2, "S:+N", true], [{3=>:enemy}, 3, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{2=>nil}, 2, "S:+N", false], [{3=>nil}, 3, "S:+N", false], [{10=>nil}, 10, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{20=>nil}, 20, "S:+N", false]], 12=>[[{2=>:enemy}, 2, "S:+N", true], [{3=>:enemy}, 3, "S:+N", true], [{4=>:enemy}, 4, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{2=>nil}, 2, "S:+N", false], [{3=>nil}, 3, "S:+N", false], [{4=>nil}, 4, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{21=>nil}, 21, "S:+N", false]], 13=>[[{3=>:enemy}, 3, "S:+N", true], [{4=>:enemy}, 4, "S:+N", true], [{5=>:enemy}, 5, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{3=>nil}, 3, "S:+N", false], [{4=>nil}, 4, "S:+N", false], [{5=>nil}, 5, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{22=>nil}, 22, "S:+N", false]], 14=>[[{4=>:enemy}, 4, "S:+N", true], [{5=>:enemy}, 5, "S:+N", true], [{6=>:enemy}, 6, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{4=>nil}, 4, "S:+N", false], [{5=>nil}, 5, "S:+N", false], [{6=>nil}, 6, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{23=>nil}, 23, "S:+N", false]], 15=>[[{5=>:enemy}, 5, "S:+N", true], [{6=>:enemy}, 6, "S:+N", true], [{7=>:enemy}, 7, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{5=>nil}, 5, "S:+N", false], [{6=>nil}, 6, "S:+N", false], [{7=>nil}, 7, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{24=>nil}, 24, "S:+N", false]], 16=>[[{6=>:enemy}, 6, "S:+N", true], [{7=>:enemy}, 7, "S:+N", true], [{8=>:enemy}, 8, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{6=>nil}, 6, "S:+N", false], [{7=>nil}, 7, "S:+N", false], [{8=>nil}, 8, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{17=>nil}, 17, "S:+N", false], [{25=>nil}, 25, "S:+N", false]], 17=>[[{7=>:enemy}, 7, "S:+N", true], [{8=>:enemy}, 8, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{7=>nil}, 7, "S:+N", false], [{8=>nil}, 8, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{26=>nil}, 26, "S:+N", false]], 18=>[[{1=>:enemy}, 1, "S:+N", true], [{9=>:enemy}, 9, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{27=>:enemy}, 27, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{9=>nil}, 9, "S:+N", false], [{10=>nil}, 10, "S:+N", false], [{19=>nil}, 19, "S:+N", false], [{27=>nil}, 27, "S:+N", false]], 19=>[[{0=>:enemy}, 0, "S:+N", true], [{2=>:enemy}, 2, "S:+N", true], [{9=>:enemy}, 9, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{18=>:enemy}, 18, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{0=>nil}, 0, "S:+N", false], [{2=>nil}, 2, "S:+N", false], [{9=>nil}, 9, "S:+N", false], [{10=>nil}, 10, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{18=>nil}, 18, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{28=>nil}, 28, "S:+N", false]], 20=>[[{1=>:enemy}, 1, "S:+N", true], [{3=>:enemy}, 3, "S:+N", true], [{10=>:enemy}, 10, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{3=>nil}, 3, "S:+N", false], [{10=>nil}, 10, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{19=>nil}, 19, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{29=>nil}, 29, "S:+N", false]], 21=>[[{2=>:enemy}, 2, "S:+N", true], [{4=>:enemy}, 4, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{2=>nil}, 2, "S:+N", false], [{4=>nil}, 4, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{30=>nil}, 30, "S:+N", false]], 22=>[[{3=>:enemy}, 3, "S:+N", true], [{5=>:enemy}, 5, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{3=>nil}, 3, "S:+N", false], [{5=>nil}, 5, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{31=>nil}, 31, "S:+N", false]], 23=>[[{4=>:enemy}, 4, "S:+N", true], [{6=>:enemy}, 6, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{4=>nil}, 4, "S:+N", false], [{6=>nil}, 6, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{32=>nil}, 32, "S:+N", false]], 24=>[[{5=>:enemy}, 5, "S:+N", true], [{7=>:enemy}, 7, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{5=>nil}, 5, "S:+N", false], [{7=>nil}, 7, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{33=>nil}, 33, "S:+N", false]], 25=>[[{6=>:enemy}, 6, "S:+N", true], [{8=>:enemy}, 8, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{6=>nil}, 6, "S:+N", false], [{8=>nil}, 8, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{17=>nil}, 17, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{26=>nil}, 26, "S:+N", false], [{34=>nil}, 34, "S:+N", false]], 26=>[[{7=>:enemy}, 7, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{35=>:enemy}, 35, "S:+N", true], [{7=>nil}, 7, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{17=>nil}, 17, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{35=>nil}, 35, "S:+N", false]], 27=>[[{10=>:enemy}, 10, "S:+N", true], [{18=>:enemy}, 18, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{36=>:enemy}, 36, "S:+N", true], [{10=>nil}, 10, "S:+N", false], [{18=>nil}, 18, "S:+N", false], [{19=>nil}, 19, "S:+N", false], [{28=>nil}, 28, "S:+N", false], [{36=>nil}, 36, "S:+N", false]], 28=>[[{9=>:enemy}, 9, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{18=>:enemy}, 18, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{27=>:enemy}, 27, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{9=>nil}, 9, "S:+N", false], [{11=>nil}, 11, "S:+N", false], [{18=>nil}, 18, "S:+N", false], [{19=>nil}, 19, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{27=>nil}, 27, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{37=>nil}, 37, "S:+N", false]], 29=>[[{10=>:enemy}, 10, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{19=>:enemy}, 19, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{10=>nil}, 10, "S:+N", false], [{12=>nil}, 12, "S:+N", false], [{19=>nil}, 19, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{28=>nil}, 28, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{38=>nil}, 38, "S:+N", false]], 30=>[[{11=>:enemy}, 11, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{11=>nil}, 11, "S:+N", false], [{13=>nil}, 13, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{39=>nil}, 39, "S:+N", false]], 31=>[[{12=>:enemy}, 12, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{12=>nil}, 12, "S:+N", false], [{14=>nil}, 14, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{40=>nil}, 40, "S:+N", false]], 32=>[[{13=>:enemy}, 13, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{13=>nil}, 13, "S:+N", false], [{15=>nil}, 15, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{41=>nil}, 41, "S:+N", false]], 33=>[[{14=>:enemy}, 14, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{14=>nil}, 14, "S:+N", false], [{16=>nil}, 16, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{42=>nil}, 42, "S:+N", false]], 34=>[[{15=>:enemy}, 15, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{35=>:enemy}, 35, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{15=>nil}, 15, "S:+N", false], [{17=>nil}, 17, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{26=>nil}, 26, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{35=>nil}, 35, "S:+N", false], [{43=>nil}, 43, "S:+N", false]], 35=>[[{16=>:enemy}, 16, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{44=>:enemy}, 44, "S:+N", true], [{16=>nil}, 16, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{26=>nil}, 26, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{44=>nil}, 44, "S:+N", false]], 36=>[[{19=>:enemy}, 19, "S:+N", true], [{27=>:enemy}, 27, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{45=>:enemy}, 45, "S:+N", true], [{19=>nil}, 19, "S:+N", false], [{27=>nil}, 27, "S:+N", false], [{28=>nil}, 28, "S:+N", false], [{37=>nil}, 37, "S:+N", false], [{45=>nil}, 45, "S:+N", false]], 37=>[[{18=>:enemy}, 18, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{27=>:enemy}, 27, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{36=>:enemy}, 36, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{18=>nil}, 18, "S:+N", false], [{20=>nil}, 20, "S:+N", false], [{27=>nil}, 27, "S:+N", false], [{28=>nil}, 28, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{36=>nil}, 36, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{46=>nil}, 46, "S:+N", false]], 38=>[[{19=>:enemy}, 19, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{28=>:enemy}, 28, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{19=>nil}, 19, "S:+N", false], [{21=>nil}, 21, "S:+N", false], [{28=>nil}, 28, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{37=>nil}, 37, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{47=>nil}, 47, "S:+N", false]], 39=>[[{20=>:enemy}, 20, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{20=>nil}, 20, "S:+N", false], [{22=>nil}, 22, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{48=>nil}, 48, "S:+N", false]], 40=>[[{21=>:enemy}, 21, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{21=>nil}, 21, "S:+N", false], [{23=>nil}, 23, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{49=>nil}, 49, "S:+N", false]], 41=>[[{22=>:enemy}, 22, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{22=>nil}, 22, "S:+N", false], [{24=>nil}, 24, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{50=>nil}, 50, "S:+N", false]], 42=>[[{23=>:enemy}, 23, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{23=>nil}, 23, "S:+N", false], [{25=>nil}, 25, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{51=>nil}, 51, "S:+N", false]], 43=>[[{24=>:enemy}, 24, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{35=>:enemy}, 35, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{44=>:enemy}, 44, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{24=>nil}, 24, "S:+N", false], [{26=>nil}, 26, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{35=>nil}, 35, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{44=>nil}, 44, "S:+N", false], [{52=>nil}, 52, "S:+N", false]], 44=>[[{25=>:enemy}, 25, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{35=>:enemy}, 35, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{53=>:enemy}, 53, "S:+N", true], [{25=>nil}, 25, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{35=>nil}, 35, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{53=>nil}, 53, "S:+N", false]], 45=>[[{28=>:enemy}, 28, "S:+N", true], [{36=>:enemy}, 36, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{54=>:enemy}, 54, "S:+N", true], [{28=>nil}, 28, "S:+N", false], [{36=>nil}, 36, "S:+N", false], [{37=>nil}, 37, "S:+N", false], [{46=>nil}, 46, "S:+N", false], [{54=>nil}, 54, "S:+N", false]], 46=>[[{27=>:enemy}, 27, "S:+N", true], [{29=>:enemy}, 29, "S:+N", true], [{36=>:enemy}, 36, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{45=>:enemy}, 45, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{27=>nil}, 27, "S:+N", false], [{29=>nil}, 29, "S:+N", false], [{36=>nil}, 36, "S:+N", false], [{37=>nil}, 37, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{45=>nil}, 45, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{55=>nil}, 55, "S:+N", false]], 47=>[[{28=>:enemy}, 28, "S:+N", true], [{30=>:enemy}, 30, "S:+N", true], [{37=>:enemy}, 37, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{28=>nil}, 28, "S:+N", false], [{30=>nil}, 30, "S:+N", false], [{37=>nil}, 37, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{46=>nil}, 46, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{56=>nil}, 56, "S:+N", false]], 48=>[[{29=>:enemy}, 29, "S:+N", true], [{31=>:enemy}, 31, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{29=>nil}, 29, "S:+N", false], [{31=>nil}, 31, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{57=>nil}, 57, "S:+N", false]], 49=>[[{30=>:enemy}, 30, "S:+N", true], [{32=>:enemy}, 32, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{30=>nil}, 30, "S:+N", false], [{32=>nil}, 32, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{58=>nil}, 58, "S:+N", false]], 50=>[[{31=>:enemy}, 31, "S:+N", true], [{33=>:enemy}, 33, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{31=>nil}, 31, "S:+N", false], [{33=>nil}, 33, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{59=>nil}, 59, "S:+N", false]], 51=>[[{32=>:enemy}, 32, "S:+N", true], [{34=>:enemy}, 34, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{32=>nil}, 32, "S:+N", false], [{34=>nil}, 34, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{60=>nil}, 60, "S:+N", false]], 52=>[[{33=>:enemy}, 33, "S:+N", true], [{35=>:enemy}, 35, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{44=>:enemy}, 44, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{53=>:enemy}, 53, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{33=>nil}, 33, "S:+N", false], [{35=>nil}, 35, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{44=>nil}, 44, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{53=>nil}, 53, "S:+N", false], [{61=>nil}, 61, "S:+N", false]], 53=>[[{34=>:enemy}, 34, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{44=>:enemy}, 44, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{62=>:enemy}, 62, "S:+N", true], [{34=>nil}, 34, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{44=>nil}, 44, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{62=>nil}, 62, "S:+N", false]], 54=>[[{37=>:enemy}, 37, "S:+N", true], [{45=>:enemy}, 45, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{63=>:enemy}, 63, "S:+N", true], [{37=>nil}, 37, "S:+N", false], [{45=>nil}, 45, "S:+N", false], [{46=>nil}, 46, "S:+N", false], [{55=>nil}, 55, "S:+N", false], [{63=>nil}, 63, "S:+N", false]], 55=>[[{36=>:enemy}, 36, "S:+N", true], [{38=>:enemy}, 38, "S:+N", true], [{45=>:enemy}, 45, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{54=>:enemy}, 54, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{36=>nil}, 36, "S:+N", false], [{38=>nil}, 38, "S:+N", false], [{45=>nil}, 45, "S:+N", false], [{46=>nil}, 46, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{54=>nil}, 54, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{64=>nil}, 64, "S:+N", false]], 56=>[[{37=>:enemy}, 37, "S:+N", true], [{39=>:enemy}, 39, "S:+N", true], [{46=>:enemy}, 46, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{37=>nil}, 37, "S:+N", false], [{39=>nil}, 39, "S:+N", false], [{46=>nil}, 46, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{55=>nil}, 55, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{65=>nil}, 65, "S:+N", false]], 57=>[[{38=>:enemy}, 38, "S:+N", true], [{40=>:enemy}, 40, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{38=>nil}, 38, "S:+N", false], [{40=>nil}, 40, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{66=>nil}, 66, "S:+N", false]], 58=>[[{39=>:enemy}, 39, "S:+N", true], [{41=>:enemy}, 41, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{39=>nil}, 39, "S:+N", false], [{41=>nil}, 41, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{67=>nil}, 67, "S:+N", false]], 59=>[[{40=>:enemy}, 40, "S:+N", true], [{42=>:enemy}, 42, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{40=>nil}, 40, "S:+N", false], [{42=>nil}, 42, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{68=>nil}, 68, "S:+N", false]], 60=>[[{41=>:enemy}, 41, "S:+N", true], [{43=>:enemy}, 43, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{41=>nil}, 41, "S:+N", false], [{43=>nil}, 43, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{69=>nil}, 69, "S:+N", false]], 61=>[[{42=>:enemy}, 42, "S:+N", true], [{44=>:enemy}, 44, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{53=>:enemy}, 53, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{62=>:enemy}, 62, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{42=>nil}, 42, "S:+N", false], [{44=>nil}, 44, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{53=>nil}, 53, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{62=>nil}, 62, "S:+N", false], [{70=>nil}, 70, "S:+N", false]], 62=>[[{43=>:enemy}, 43, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{53=>:enemy}, 53, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{71=>:enemy}, 71, "S:+N", true], [{43=>nil}, 43, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{53=>nil}, 53, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{71=>nil}, 71, "S:+N", false]], 63=>[[{46=>:enemy}, 46, "S:+N", true], [{54=>:enemy}, 54, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{72=>:enemy}, 72, "S:+N", true], [{46=>nil}, 46, "S:+N", false], [{54=>nil}, 54, "S:+N", false], [{55=>nil}, 55, "S:+N", false], [{64=>nil}, 64, "S:+N", false], [{72=>nil}, 72, "S:+N", false]], 64=>[[{45=>:enemy}, 45, "S:+N", true], [{47=>:enemy}, 47, "S:+N", true], [{54=>:enemy}, 54, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{63=>:enemy}, 63, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{73=>:enemy}, 73, "S:+N", true], [{45=>nil}, 45, "S:+N", false], [{47=>nil}, 47, "S:+N", false], [{54=>nil}, 54, "S:+N", false], [{55=>nil}, 55, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{63=>nil}, 63, "S:+N", false], [{65=>nil}, 65, "S:+N", false], [{73=>nil}, 73, "S:+N", false]], 65=>[[{46=>:enemy}, 46, "S:+N", true], [{48=>:enemy}, 48, "S:+N", true], [{55=>:enemy}, 55, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{74=>:enemy}, 74, "S:+N", true], [{46=>nil}, 46, "S:+N", false], [{48=>nil}, 48, "S:+N", false], [{55=>nil}, 55, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{64=>nil}, 64, "S:+N", false], [{66=>nil}, 66, "S:+N", false], [{74=>nil}, 74, "S:+N", false]], 66=>[[{47=>:enemy}, 47, "S:+N", true], [{49=>:enemy}, 49, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{75=>:enemy}, 75, "S:+N", true], [{47=>nil}, 47, "S:+N", false], [{49=>nil}, 49, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{65=>nil}, 65, "S:+N", false], [{67=>nil}, 67, "S:+N", false], [{75=>nil}, 75, "S:+N", false]], 67=>[[{48=>:enemy}, 48, "S:+N", true], [{50=>:enemy}, 50, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{76=>:enemy}, 76, "S:+N", true], [{48=>nil}, 48, "S:+N", false], [{50=>nil}, 50, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{66=>nil}, 66, "S:+N", false], [{68=>nil}, 68, "S:+N", false], [{76=>nil}, 76, "S:+N", false]], 68=>[[{49=>:enemy}, 49, "S:+N", true], [{51=>:enemy}, 51, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{77=>:enemy}, 77, "S:+N", true], [{49=>nil}, 49, "S:+N", false], [{51=>nil}, 51, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{67=>nil}, 67, "S:+N", false], [{69=>nil}, 69, "S:+N", false], [{77=>nil}, 77, "S:+N", false]], 69=>[[{50=>:enemy}, 50, "S:+N", true], [{52=>:enemy}, 52, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{78=>:enemy}, 78, "S:+N", true], [{50=>nil}, 50, "S:+N", false], [{52=>nil}, 52, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{68=>nil}, 68, "S:+N", false], [{70=>nil}, 70, "S:+N", false], [{78=>nil}, 78, "S:+N", false]], 70=>[[{51=>:enemy}, 51, "S:+N", true], [{53=>:enemy}, 53, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{62=>:enemy}, 62, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{71=>:enemy}, 71, "S:+N", true], [{79=>:enemy}, 79, "S:+N", true], [{51=>nil}, 51, "S:+N", false], [{53=>nil}, 53, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{62=>nil}, 62, "S:+N", false], [{69=>nil}, 69, "S:+N", false], [{71=>nil}, 71, "S:+N", false], [{79=>nil}, 79, "S:+N", false]], 71=>[[{52=>:enemy}, 52, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{62=>:enemy}, 62, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{80=>:enemy}, 80, "S:+N", true], [{52=>nil}, 52, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{62=>nil}, 62, "S:+N", false], [{70=>nil}, 70, "S:+N", false], [{80=>nil}, 80, "S:+N", false]], 72=>[[{55=>:enemy}, 55, "S:+N", true], [{63=>:enemy}, 63, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{73=>:enemy}, 73, "S:+N", true], [{55=>nil}, 55, "S:+N", false], [{63=>nil}, 63, "S:+N", false], [{64=>nil}, 64, "S:+N", false], [{73=>nil}, 73, "S:+N", false]], 73=>[[{54=>:enemy}, 54, "S:+N", true], [{56=>:enemy}, 56, "S:+N", true], [{63=>:enemy}, 63, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{72=>:enemy}, 72, "S:+N", true], [{74=>:enemy}, 74, "S:+N", true], [{54=>nil}, 54, "S:+N", false], [{56=>nil}, 56, "S:+N", false], [{63=>nil}, 63, "S:+N", false], [{64=>nil}, 64, "S:+N", false], [{65=>nil}, 65, "S:+N", false], [{72=>nil}, 72, "S:+N", false], [{74=>nil}, 74, "S:+N", false]], 74=>[[{55=>:enemy}, 55, "S:+N", true], [{57=>:enemy}, 57, "S:+N", true], [{64=>:enemy}, 64, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{73=>:enemy}, 73, "S:+N", true], [{75=>:enemy}, 75, "S:+N", true], [{55=>nil}, 55, "S:+N", false], [{57=>nil}, 57, "S:+N", false], [{64=>nil}, 64, "S:+N", false], [{65=>nil}, 65, "S:+N", false], [{66=>nil}, 66, "S:+N", false], [{73=>nil}, 73, "S:+N", false], [{75=>nil}, 75, "S:+N", false]], 75=>[[{56=>:enemy}, 56, "S:+N", true], [{58=>:enemy}, 58, "S:+N", true], [{65=>:enemy}, 65, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{74=>:enemy}, 74, "S:+N", true], [{76=>:enemy}, 76, "S:+N", true], [{56=>nil}, 56, "S:+N", false], [{58=>nil}, 58, "S:+N", false], [{65=>nil}, 65, "S:+N", false], [{66=>nil}, 66, "S:+N", false], [{67=>nil}, 67, "S:+N", false], [{74=>nil}, 74, "S:+N", false], [{76=>nil}, 76, "S:+N", false]], 76=>[[{57=>:enemy}, 57, "S:+N", true], [{59=>:enemy}, 59, "S:+N", true], [{66=>:enemy}, 66, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{75=>:enemy}, 75, "S:+N", true], [{77=>:enemy}, 77, "S:+N", true], [{57=>nil}, 57, "S:+N", false], [{59=>nil}, 59, "S:+N", false], [{66=>nil}, 66, "S:+N", false], [{67=>nil}, 67, "S:+N", false], [{68=>nil}, 68, "S:+N", false], [{75=>nil}, 75, "S:+N", false], [{77=>nil}, 77, "S:+N", false]], 77=>[[{58=>:enemy}, 58, "S:+N", true], [{60=>:enemy}, 60, "S:+N", true], [{67=>:enemy}, 67, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{76=>:enemy}, 76, "S:+N", true], [{78=>:enemy}, 78, "S:+N", true], [{58=>nil}, 58, "S:+N", false], [{60=>nil}, 60, "S:+N", false], [{67=>nil}, 67, "S:+N", false], [{68=>nil}, 68, "S:+N", false], [{69=>nil}, 69, "S:+N", false], [{76=>nil}, 76, "S:+N", false], [{78=>nil}, 78, "S:+N", false]], 78=>[[{59=>:enemy}, 59, "S:+N", true], [{61=>:enemy}, 61, "S:+N", true], [{68=>:enemy}, 68, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{77=>:enemy}, 77, "S:+N", true], [{79=>:enemy}, 79, "S:+N", true], [{59=>nil}, 59, "S:+N", false], [{61=>nil}, 61, "S:+N", false], [{68=>nil}, 68, "S:+N", false], [{69=>nil}, 69, "S:+N", false], [{70=>nil}, 70, "S:+N", false], [{77=>nil}, 77, "S:+N", false], [{79=>nil}, 79, "S:+N", false]], 79=>[[{60=>:enemy}, 60, "S:+N", true], [{62=>:enemy}, 62, "S:+N", true], [{69=>:enemy}, 69, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{71=>:enemy}, 71, "S:+N", true], [{78=>:enemy}, 78, "S:+N", true], [{80=>:enemy}, 80, "S:+N", true], [{60=>nil}, 60, "S:+N", false], [{62=>nil}, 62, "S:+N", false], [{69=>nil}, 69, "S:+N", false], [{70=>nil}, 70, "S:+N", false], [{71=>nil}, 71, "S:+N", false], [{78=>nil}, 78, "S:+N", false], [{80=>nil}, 80, "S:+N", false]], 80=>[[{61=>:enemy}, 61, "S:+N", true], [{70=>:enemy}, 70, "S:+N", true], [{71=>:enemy}, 71, "S:+N", true], [{79=>:enemy}, 79, "S:+N", true], [{61=>nil}, 61, "S:+N", false], [{70=>nil}, 70, "S:+N", false], [{71=>nil}, 71, "S:+N", false], [{79=>nil}, 79, "S:+N", false]], nil=>[]}, "S:+P"=>{0=>[[{1=>:enemy}, 1, "S:+P", true], [{9=>:enemy}, 9, "S:+P", true], [{1=>nil}, 1, "S:+P", false], [{9=>nil}, 9, "S:+P", false]], 1=>[[{0=>:enemy}, 0, "S:+P", true], [{2=>:enemy}, 2, "S:+P", true], [{10=>:enemy}, 10, "S:+P", true], [{0=>nil}, 0, "S:+P", false], [{2=>nil}, 2, "S:+P", false], [{10=>nil}, 10, "S:+P", false]], 2=>[[{1=>:enemy}, 1, "S:+P", true], [{3=>:enemy}, 3, "S:+P", true], [{11=>:enemy}, 11, "S:+P", true], [{1=>nil}, 1, "S:+P", false], [{3=>nil}, 3, "S:+P", false], [{11=>nil}, 11, "S:+P", false]], 3=>[[{2=>:enemy}, 2, "S:+P", true], [{4=>:enemy}, 4, "S:+P", true], [{12=>:enemy}, 12, "S:+P", true], [{2=>nil}, 2, "S:+P", false], [{4=>nil}, 4, "S:+P", false], [{12=>nil}, 12, "S:+P", false]], 4=>[[{3=>:enemy}, 3, "S:+P", true], [{5=>:enemy}, 5, "S:+P", true], [{13=>:enemy}, 13, "S:+P", true], [{3=>nil}, 3, "S:+P", false], [{5=>nil}, 5, "S:+P", false], [{13=>nil}, 13, "S:+P", false]], 5=>[[{4=>:enemy}, 4, "S:+P", true], [{6=>:enemy}, 6, "S:+P", true], [{14=>:enemy}, 14, "S:+P", true], [{4=>nil}, 4, "S:+P", false], [{6=>nil}, 6, "S:+P", false], [{14=>nil}, 14, "S:+P", false]], 6=>[[{5=>:enemy}, 5, "S:+P", true], [{7=>:enemy}, 7, "S:+P", true], [{15=>:enemy}, 15, "S:+P", true], [{5=>nil}, 5, "S:+P", false], [{7=>nil}, 7, "S:+P", false], [{15=>nil}, 15, "S:+P", false]], 7=>[[{6=>:enemy}, 6, "S:+P", true], [{8=>:enemy}, 8, "S:+P", true], [{16=>:enemy}, 16, "S:+P", true], [{6=>nil}, 6, "S:+P", false], [{8=>nil}, 8, "S:+P", false], [{16=>nil}, 16, "S:+P", false]], 8=>[[{7=>:enemy}, 7, "S:+P", true], [{17=>:enemy}, 17, "S:+P", true], [{7=>nil}, 7, "S:+P", false], [{17=>nil}, 17, "S:+P", false]], 9=>[[{0=>:enemy}, 0, "S:+P", true], [{1=>:enemy}, 1, "S:+P", true], [{10=>:enemy}, 10, "S:+P", true], [{18=>:enemy}, 18, "S:+P", true], [{0=>nil}, 0, "S:+P", false], [{1=>nil}, 1, "S:+P", false], [{10=>nil}, 10, "S:+P", false], [{18=>nil}, 18, "S:+P", false]], 10=>[[{0=>:enemy}, 0, "S:+P", true], [{1=>:enemy}, 1, "S:+P", true], [{2=>:enemy}, 2, "S:+P", true], [{9=>:enemy}, 9, "S:+P", true], [{11=>:enemy}, 11, "S:+P", true], [{19=>:enemy}, 19, "S:+P", true], [{0=>nil}, 0, "S:+P", false], [{1=>nil}, 1, "S:+P", false], [{2=>nil}, 2, "S:+P", false], [{9=>nil}, 9, "S:+P", false], [{11=>nil}, 11, "S:+P", false], [{19=>nil}, 19, "S:+P", false]], 11=>[[{1=>:enemy}, 1, "S:+P", true], [{2=>:enemy}, 2, "S:+P", true], [{3=>:enemy}, 3, "S:+P", true], [{10=>:enemy}, 10, "S:+P", true], [{12=>:enemy}, 12, "S:+P", true], [{20=>:enemy}, 20, "S:+P", true], [{1=>nil}, 1, "S:+P", false], [{2=>nil}, 2, "S:+P", false], [{3=>nil}, 3, "S:+P", false], [{10=>nil}, 10, "S:+P", false], [{12=>nil}, 12, "S:+P", false], [{20=>nil}, 20, "S:+P", false]], 12=>[[{2=>:enemy}, 2, "S:+P", true], [{3=>:enemy}, 3, "S:+P", true], [{4=>:enemy}, 4, "S:+P", true], [{11=>:enemy}, 11, "S:+P", true], [{13=>:enemy}, 13, "S:+P", true], [{21=>:enemy}, 21, "S:+P", true], [{2=>nil}, 2, "S:+P", false], [{3=>nil}, 3, "S:+P", false], [{4=>nil}, 4, "S:+P", false], [{11=>nil}, 11, "S:+P", false], [{13=>nil}, 13, "S:+P", false], [{21=>nil}, 21, "S:+P", false]], 13=>[[{3=>:enemy}, 3, "S:+P", true], [{4=>:enemy}, 4, "S:+P", true], [{5=>:enemy}, 5, "S:+P", true], [{12=>:enemy}, 12, "S:+P", true], [{14=>:enemy}, 14, "S:+P", true], [{22=>:enemy}, 22, "S:+P", true], [{3=>nil}, 3, "S:+P", false], [{4=>nil}, 4, "S:+P", false], [{5=>nil}, 5, "S:+P", false], [{12=>nil}, 12, "S:+P", false], [{14=>nil}, 14, "S:+P", false], [{22=>nil}, 22, "S:+P", false]], 14=>[[{4=>:enemy}, 4, "S:+P", true], [{5=>:enemy}, 5, "S:+P", true], [{6=>:enemy}, 6, "S:+P", true], [{13=>:enemy}, 13, "S:+P", true], [{15=>:enemy}, 15, "S:+P", true], [{23=>:enemy}, 23, "S:+P", true], [{4=>nil}, 4, "S:+P", false], [{5=>nil}, 5, "S:+P", false], [{6=>nil}, 6, "S:+P", false], [{13=>nil}, 13, "S:+P", false], [{15=>nil}, 15, "S:+P", false], [{23=>nil}, 23, "S:+P", false]], 15=>[[{5=>:enemy}, 5, "S:+P", true], [{6=>:enemy}, 6, "S:+P", true], [{7=>:enemy}, 7, "S:+P", true], [{14=>:enemy}, 14, "S:+P", true], [{16=>:enemy}, 16, "S:+P", true], [{24=>:enemy}, 24, "S:+P", true], [{5=>nil}, 5, "S:+P", false], [{6=>nil}, 6, "S:+P", false], [{7=>nil}, 7, "S:+P", false], [{14=>nil}, 14, "S:+P", false], [{16=>nil}, 16, "S:+P", false], [{24=>nil}, 24, "S:+P", false]], 16=>[[{6=>:enemy}, 6, "S:+P", true], [{7=>:enemy}, 7, "S:+P", true], [{8=>:enemy}, 8, "S:+P", true], [{15=>:enemy}, 15, "S:+P", true], [{17=>:enemy}, 17, "S:+P", true], [{25=>:enemy}, 25, "S:+P", true], [{6=>nil}, 6, "S:+P", false], [{7=>nil}, 7, "S:+P", false], [{8=>nil}, 8, "S:+P", false], [{15=>nil}, 15, "S:+P", false], [{17=>nil}, 17, "S:+P", false], [{25=>nil}, 25, "S:+P", false]], 17=>[[{7=>:enemy}, 7, "S:+P", true], [{8=>:enemy}, 8, "S:+P", true], [{16=>:enemy}, 16, "S:+P", true], [{26=>:enemy}, 26, "S:+P", true], [{7=>nil}, 7, "S:+P", false], [{8=>nil}, 8, "S:+P", false], [{16=>nil}, 16, "S:+P", false], [{26=>nil}, 26, "S:+P", false]], 18=>[[{9=>:enemy}, 9, "S:+P", true], [{10=>:enemy}, 10, "S:+P", true], [{19=>:enemy}, 19, "S:+P", true], [{27=>:enemy}, 27, "S:+P", true], [{9=>nil}, 9, "S:+P", false], [{10=>nil}, 10, "S:+P", false], [{19=>nil}, 19, "S:+P", false], [{27=>nil}, 27, "S:+P", false]], 19=>[[{9=>:enemy}, 9, "S:+P", true], [{10=>:enemy}, 10, "S:+P", true], [{11=>:enemy}, 11, "S:+P", true], [{18=>:enemy}, 18, "S:+P", true], [{20=>:enemy}, 20, "S:+P", true], [{28=>:enemy}, 28, "S:+P", true], [{9=>nil}, 9, "S:+P", false], [{10=>nil}, 10, "S:+P", false], [{11=>nil}, 11, "S:+P", false], [{18=>nil}, 18, "S:+P", false], [{20=>nil}, 20, "S:+P", false], [{28=>nil}, 28, "S:+P", false]], 20=>[[{10=>:enemy}, 10, "S:+P", true], [{11=>:enemy}, 11, "S:+P", true], [{12=>:enemy}, 12, "S:+P", true], [{19=>:enemy}, 19, "S:+P", true], [{21=>:enemy}, 21, "S:+P", true], [{29=>:enemy}, 29, "S:+P", true], [{10=>nil}, 10, "S:+P", false], [{11=>nil}, 11, "S:+P", false], [{12=>nil}, 12, "S:+P", false], [{19=>nil}, 19, "S:+P", false], [{21=>nil}, 21, "S:+P", false], [{29=>nil}, 29, "S:+P", false]], 21=>[[{11=>:enemy}, 11, "S:+P", true], [{12=>:enemy}, 12, "S:+P", true], [{13=>:enemy}, 13, "S:+P", true], [{20=>:enemy}, 20, "S:+P", true], [{22=>:enemy}, 22, "S:+P", true], [{30=>:enemy}, 30, "S:+P", true], [{11=>nil}, 11, "S:+P", false], [{12=>nil}, 12, "S:+P", false], [{13=>nil}, 13, "S:+P", false], [{20=>nil}, 20, "S:+P", false], [{22=>nil}, 22, "S:+P", false], [{30=>nil}, 30, "S:+P", false]], 22=>[[{12=>:enemy}, 12, "S:+P", true], [{13=>:enemy}, 13, "S:+P", true], [{14=>:enemy}, 14, "S:+P", true], [{21=>:enemy}, 21, "S:+P", true], [{23=>:enemy}, 23, "S:+P", true], [{31=>:enemy}, 31, "S:+P", true], [{12=>nil}, 12, "S:+P", false], [{13=>nil}, 13, "S:+P", false], [{14=>nil}, 14, "S:+P", false], [{21=>nil}, 21, "S:+P", false], [{23=>nil}, 23, "S:+P", false], [{31=>nil}, 31, "S:+P", false]], 23=>[[{13=>:enemy}, 13, "S:+P", true], [{14=>:enemy}, 14, "S:+P", true], [{15=>:enemy}, 15, "S:+P", true], [{22=>:enemy}, 22, "S:+P", true], [{24=>:enemy}, 24, "S:+P", true], [{32=>:enemy}, 32, "S:+P", true], [{13=>nil}, 13, "S:+P", false], [{14=>nil}, 14, "S:+P", false], [{15=>nil}, 15, "S:+P", false], [{22=>nil}, 22, "S:+P", false], [{24=>nil}, 24, "S:+P", false], [{32=>nil}, 32, "S:+P", false]], 24=>[[{14=>:enemy}, 14, "S:+P", true], [{15=>:enemy}, 15, "S:+P", true], [{16=>:enemy}, 16, "S:+P", true], [{23=>:enemy}, 23, "S:+P", true], [{25=>:enemy}, 25, "S:+P", true], [{33=>:enemy}, 33, "S:+P", true], [{14=>nil}, 14, "S:+P", false], [{15=>nil}, 15, "S:+P", false], [{16=>nil}, 16, "S:+P", false], [{23=>nil}, 23, "S:+P", false], [{25=>nil}, 25, "S:+P", false], [{33=>nil}, 33, "S:+P", false]], 25=>[[{15=>:enemy}, 15, "S:+P", true], [{16=>:enemy}, 16, "S:+P", true], [{17=>:enemy}, 17, "S:+P", true], [{24=>:enemy}, 24, "S:+P", true], [{26=>:enemy}, 26, "S:+P", true], [{34=>:enemy}, 34, "S:+P", true], [{15=>nil}, 15, "S:+P", false], [{16=>nil}, 16, "S:+P", false], [{17=>nil}, 17, "S:+P", false], [{24=>nil}, 24, "S:+P", false], [{26=>nil}, 26, "S:+P", false], [{34=>nil}, 34, "S:+P", false]], 26=>[[{16=>:enemy}, 16, "S:+P", true], [{17=>:enemy}, 17, "S:+P", true], [{25=>:enemy}, 25, "S:+P", true], [{35=>:enemy}, 35, "S:+P", true], [{16=>nil}, 16, "S:+P", false], [{17=>nil}, 17, "S:+P", false], [{25=>nil}, 25, "S:+P", false], [{35=>nil}, 35, "S:+P", false]], 27=>[[{18=>:enemy}, 18, "S:+P", true], [{19=>:enemy}, 19, "S:+P", true], [{28=>:enemy}, 28, "S:+P", true], [{36=>:enemy}, 36, "S:+P", true], [{18=>nil}, 18, "S:+P", false], [{19=>nil}, 19, "S:+P", false], [{28=>nil}, 28, "S:+P", false], [{36=>nil}, 36, "S:+P", false]], 28=>[[{18=>:enemy}, 18, "S:+P", true], [{19=>:enemy}, 19, "S:+P", true], [{20=>:enemy}, 20, "S:+P", true], [{27=>:enemy}, 27, "S:+P", true], [{29=>:enemy}, 29, "S:+P", true], [{37=>:enemy}, 37, "S:+P", true], [{18=>nil}, 18, "S:+P", false], [{19=>nil}, 19, "S:+P", false], [{20=>nil}, 20, "S:+P", false], [{27=>nil}, 27, "S:+P", false], [{29=>nil}, 29, "S:+P", false], [{37=>nil}, 37, "S:+P", false]], 29=>[[{19=>:enemy}, 19, "S:+P", true], [{20=>:enemy}, 20, "S:+P", true], [{21=>:enemy}, 21, "S:+P", true], [{28=>:enemy}, 28, "S:+P", true], [{30=>:enemy}, 30, "S:+P", true], [{38=>:enemy}, 38, "S:+P", true], [{19=>nil}, 19, "S:+P", false], [{20=>nil}, 20, "S:+P", false], [{21=>nil}, 21, "S:+P", false], [{28=>nil}, 28, "S:+P", false], [{30=>nil}, 30, "S:+P", false], [{38=>nil}, 38, "S:+P", false]], 30=>[[{20=>:enemy}, 20, "S:+P", true], [{21=>:enemy}, 21, "S:+P", true], [{22=>:enemy}, 22, "S:+P", true], [{29=>:enemy}, 29, "S:+P", true], [{31=>:enemy}, 31, "S:+P", true], [{39=>:enemy}, 39, "S:+P", true], [{20=>nil}, 20, "S:+P", false], [{21=>nil}, 21, "S:+P", false], [{22=>nil}, 22, "S:+P", false], [{29=>nil}, 29, "S:+P", false], [{31=>nil}, 31, "S:+P", false], [{39=>nil}, 39, "S:+P", false]], 31=>[[{21=>:enemy}, 21, "S:+P", true], [{22=>:enemy}, 22, "S:+P", true], [{23=>:enemy}, 23, "S:+P", true], [{30=>:enemy}, 30, "S:+P", true], [{32=>:enemy}, 32, "S:+P", true], [{40=>:enemy}, 40, "S:+P", true], [{21=>nil}, 21, "S:+P", false], [{22=>nil}, 22, "S:+P", false], [{23=>nil}, 23, "S:+P", false], [{30=>nil}, 30, "S:+P", false], [{32=>nil}, 32, "S:+P", false], [{40=>nil}, 40, "S:+P", false]], 32=>[[{22=>:enemy}, 22, "S:+P", true], [{23=>:enemy}, 23, "S:+P", true], [{24=>:enemy}, 24, "S:+P", true], [{31=>:enemy}, 31, "S:+P", true], [{33=>:enemy}, 33, "S:+P", true], [{41=>:enemy}, 41, "S:+P", true], [{22=>nil}, 22, "S:+P", false], [{23=>nil}, 23, "S:+P", false], [{24=>nil}, 24, "S:+P", false], [{31=>nil}, 31, "S:+P", false], [{33=>nil}, 33, "S:+P", false], [{41=>nil}, 41, "S:+P", false]], 33=>[[{23=>:enemy}, 23, "S:+P", true], [{24=>:enemy}, 24, "S:+P", true], [{25=>:enemy}, 25, "S:+P", true], [{32=>:enemy}, 32, "S:+P", true], [{34=>:enemy}, 34, "S:+P", true], [{42=>:enemy}, 42, "S:+P", true], [{23=>nil}, 23, "S:+P", false], [{24=>nil}, 24, "S:+P", false], [{25=>nil}, 25, "S:+P", false], [{32=>nil}, 32, "S:+P", false], [{34=>nil}, 34, "S:+P", false], [{42=>nil}, 42, "S:+P", false]], 34=>[[{24=>:enemy}, 24, "S:+P", true], [{25=>:enemy}, 25, "S:+P", true], [{26=>:enemy}, 26, "S:+P", true], [{33=>:enemy}, 33, "S:+P", true], [{35=>:enemy}, 35, "S:+P", true], [{43=>:enemy}, 43, "S:+P", true], [{24=>nil}, 24, "S:+P", false], [{25=>nil}, 25, "S:+P", false], [{26=>nil}, 26, "S:+P", false], [{33=>nil}, 33, "S:+P", false], [{35=>nil}, 35, "S:+P", false], [{43=>nil}, 43, "S:+P", false]], 35=>[[{25=>:enemy}, 25, "S:+P", true], [{26=>:enemy}, 26, "S:+P", true], [{34=>:enemy}, 34, "S:+P", true], [{44=>:enemy}, 44, "S:+P", true], [{25=>nil}, 25, "S:+P", false], [{26=>nil}, 26, "S:+P", false], [{34=>nil}, 34, "S:+P", false], [{44=>nil}, 44, "S:+P", false]], 36=>[[{27=>:enemy}, 27, "S:+P", true], [{28=>:enemy}, 28, "S:+P", true], [{37=>:enemy}, 37, "S:+P", true], [{45=>:enemy}, 45, "S:+P", true], [{27=>nil}, 27, "S:+P", false], [{28=>nil}, 28, "S:+P", false], [{37=>nil}, 37, "S:+P", false], [{45=>nil}, 45, "S:+P", false]], 37=>[[{27=>:enemy}, 27, "S:+P", true], [{28=>:enemy}, 28, "S:+P", true], [{29=>:enemy}, 29, "S:+P", true], [{36=>:enemy}, 36, "S:+P", true], [{38=>:enemy}, 38, "S:+P", true], [{46=>:enemy}, 46, "S:+P", true], [{27=>nil}, 27, "S:+P", false], [{28=>nil}, 28, "S:+P", false], [{29=>nil}, 29, "S:+P", false], [{36=>nil}, 36, "S:+P", false], [{38=>nil}, 38, "S:+P", false], [{46=>nil}, 46, "S:+P", false]], 38=>[[{28=>:enemy}, 28, "S:+P", true], [{29=>:enemy}, 29, "S:+P", true], [{30=>:enemy}, 30, "S:+P", true], [{37=>:enemy}, 37, "S:+P", true], [{39=>:enemy}, 39, "S:+P", true], [{47=>:enemy}, 47, "S:+P", true], [{28=>nil}, 28, "S:+P", false], [{29=>nil}, 29, "S:+P", false], [{30=>nil}, 30, "S:+P", false], [{37=>nil}, 37, "S:+P", false], [{39=>nil}, 39, "S:+P", false], [{47=>nil}, 47, "S:+P", false]], 39=>[[{29=>:enemy}, 29, "S:+P", true], [{30=>:enemy}, 30, "S:+P", true], [{31=>:enemy}, 31, "S:+P", true], [{38=>:enemy}, 38, "S:+P", true], [{40=>:enemy}, 40, "S:+P", true], [{48=>:enemy}, 48, "S:+P", true], [{29=>nil}, 29, "S:+P", false], [{30=>nil}, 30, "S:+P", false], [{31=>nil}, 31, "S:+P", false], [{38=>nil}, 38, "S:+P", false], [{40=>nil}, 40, "S:+P", false], [{48=>nil}, 48, "S:+P", false]], 40=>[[{30=>:enemy}, 30, "S:+P", true], [{31=>:enemy}, 31, "S:+P", true], [{32=>:enemy}, 32, "S:+P", true], [{39=>:enemy}, 39, "S:+P", true], [{41=>:enemy}, 41, "S:+P", true], [{49=>:enemy}, 49, "S:+P", true], [{30=>nil}, 30, "S:+P", false], [{31=>nil}, 31, "S:+P", false], [{32=>nil}, 32, "S:+P", false], [{39=>nil}, 39, "S:+P", false], [{41=>nil}, 41, "S:+P", false], [{49=>nil}, 49, "S:+P", false]], 41=>[[{31=>:enemy}, 31, "S:+P", true], [{32=>:enemy}, 32, "S:+P", true], [{33=>:enemy}, 33, "S:+P", true], [{40=>:enemy}, 40, "S:+P", true], [{42=>:enemy}, 42, "S:+P", true], [{50=>:enemy}, 50, "S:+P", true], [{31=>nil}, 31, "S:+P", false], [{32=>nil}, 32, "S:+P", false], [{33=>nil}, 33, "S:+P", false], [{40=>nil}, 40, "S:+P", false], [{42=>nil}, 42, "S:+P", false], [{50=>nil}, 50, "S:+P", false]], 42=>[[{32=>:enemy}, 32, "S:+P", true], [{33=>:enemy}, 33, "S:+P", true], [{34=>:enemy}, 34, "S:+P", true], [{41=>:enemy}, 41, "S:+P", true], [{43=>:enemy}, 43, "S:+P", true], [{51=>:enemy}, 51, "S:+P", true], [{32=>nil}, 32, "S:+P", false], [{33=>nil}, 33, "S:+P", false], [{34=>nil}, 34, "S:+P", false], [{41=>nil}, 41, "S:+P", false], [{43=>nil}, 43, "S:+P", false], [{51=>nil}, 51, "S:+P", false]], 43=>[[{33=>:enemy}, 33, "S:+P", true], [{34=>:enemy}, 34, "S:+P", true], [{35=>:enemy}, 35, "S:+P", true], [{42=>:enemy}, 42, "S:+P", true], [{44=>:enemy}, 44, "S:+P", true], [{52=>:enemy}, 52, "S:+P", true], [{33=>nil}, 33, "S:+P", false], [{34=>nil}, 34, "S:+P", false], [{35=>nil}, 35, "S:+P", false], [{42=>nil}, 42, "S:+P", false], [{44=>nil}, 44, "S:+P", false], [{52=>nil}, 52, "S:+P", false]], 44=>[[{34=>:enemy}, 34, "S:+P", true], [{35=>:enemy}, 35, "S:+P", true], [{43=>:enemy}, 43, "S:+P", true], [{53=>:enemy}, 53, "S:+P", true], [{34=>nil}, 34, "S:+P", false], [{35=>nil}, 35, "S:+P", false], [{43=>nil}, 43, "S:+P", false], [{53=>nil}, 53, "S:+P", false]], 45=>[[{36=>:enemy}, 36, "S:+P", true], [{37=>:enemy}, 37, "S:+P", true], [{46=>:enemy}, 46, "S:+P", true], [{54=>:enemy}, 54, "S:+P", true], [{36=>nil}, 36, "S:+P", false], [{37=>nil}, 37, "S:+P", false], [{46=>nil}, 46, "S:+P", false], [{54=>nil}, 54, "S:+P", false]], 46=>[[{36=>:enemy}, 36, "S:+P", true], [{37=>:enemy}, 37, "S:+P", true], [{38=>:enemy}, 38, "S:+P", true], [{45=>:enemy}, 45, "S:+P", true], [{47=>:enemy}, 47, "S:+P", true], [{55=>:enemy}, 55, "S:+P", true], [{36=>nil}, 36, "S:+P", false], [{37=>nil}, 37, "S:+P", false], [{38=>nil}, 38, "S:+P", false], [{45=>nil}, 45, "S:+P", false], [{47=>nil}, 47, "S:+P", false], [{55=>nil}, 55, "S:+P", false]], 47=>[[{37=>:enemy}, 37, "S:+P", true], [{38=>:enemy}, 38, "S:+P", true], [{39=>:enemy}, 39, "S:+P", true], [{46=>:enemy}, 46, "S:+P", true], [{48=>:enemy}, 48, "S:+P", true], [{56=>:enemy}, 56, "S:+P", true], [{37=>nil}, 37, "S:+P", false], [{38=>nil}, 38, "S:+P", false], [{39=>nil}, 39, "S:+P", false], [{46=>nil}, 46, "S:+P", false], [{48=>nil}, 48, "S:+P", false], [{56=>nil}, 56, "S:+P", false]], 48=>[[{38=>:enemy}, 38, "S:+P", true], [{39=>:enemy}, 39, "S:+P", true], [{40=>:enemy}, 40, "S:+P", true], [{47=>:enemy}, 47, "S:+P", true], [{49=>:enemy}, 49, "S:+P", true], [{57=>:enemy}, 57, "S:+P", true], [{38=>nil}, 38, "S:+P", false], [{39=>nil}, 39, "S:+P", false], [{40=>nil}, 40, "S:+P", false], [{47=>nil}, 47, "S:+P", false], [{49=>nil}, 49, "S:+P", false], [{57=>nil}, 57, "S:+P", false]], 49=>[[{39=>:enemy}, 39, "S:+P", true], [{40=>:enemy}, 40, "S:+P", true], [{41=>:enemy}, 41, "S:+P", true], [{48=>:enemy}, 48, "S:+P", true], [{50=>:enemy}, 50, "S:+P", true], [{58=>:enemy}, 58, "S:+P", true], [{39=>nil}, 39, "S:+P", false], [{40=>nil}, 40, "S:+P", false], [{41=>nil}, 41, "S:+P", false], [{48=>nil}, 48, "S:+P", false], [{50=>nil}, 50, "S:+P", false], [{58=>nil}, 58, "S:+P", false]], 50=>[[{40=>:enemy}, 40, "S:+P", true], [{41=>:enemy}, 41, "S:+P", true], [{42=>:enemy}, 42, "S:+P", true], [{49=>:enemy}, 49, "S:+P", true], [{51=>:enemy}, 51, "S:+P", true], [{59=>:enemy}, 59, "S:+P", true], [{40=>nil}, 40, "S:+P", false], [{41=>nil}, 41, "S:+P", false], [{42=>nil}, 42, "S:+P", false], [{49=>nil}, 49, "S:+P", false], [{51=>nil}, 51, "S:+P", false], [{59=>nil}, 59, "S:+P", false]], 51=>[[{41=>:enemy}, 41, "S:+P", true], [{42=>:enemy}, 42, "S:+P", true], [{43=>:enemy}, 43, "S:+P", true], [{50=>:enemy}, 50, "S:+P", true], [{52=>:enemy}, 52, "S:+P", true], [{60=>:enemy}, 60, "S:+P", true], [{41=>nil}, 41, "S:+P", false], [{42=>nil}, 42, "S:+P", false], [{43=>nil}, 43, "S:+P", false], [{50=>nil}, 50, "S:+P", false], [{52=>nil}, 52, "S:+P", false], [{60=>nil}, 60, "S:+P", false]], 52=>[[{42=>:enemy}, 42, "S:+P", true], [{43=>:enemy}, 43, "S:+P", true], [{44=>:enemy}, 44, "S:+P", true], [{51=>:enemy}, 51, "S:+P", true], [{53=>:enemy}, 53, "S:+P", true], [{61=>:enemy}, 61, "S:+P", true], [{42=>nil}, 42, "S:+P", false], [{43=>nil}, 43, "S:+P", false], [{44=>nil}, 44, "S:+P", false], [{51=>nil}, 51, "S:+P", false], [{53=>nil}, 53, "S:+P", false], [{61=>nil}, 61, "S:+P", false]], 53=>[[{43=>:enemy}, 43, "S:+P", true], [{44=>:enemy}, 44, "S:+P", true], [{52=>:enemy}, 52, "S:+P", true], [{62=>:enemy}, 62, "S:+P", true], [{43=>nil}, 43, "S:+P", false], [{44=>nil}, 44, "S:+P", false], [{52=>nil}, 52, "S:+P", false], [{62=>nil}, 62, "S:+P", false]], 54=>[[{45=>:enemy}, 45, "S:+P", true], [{46=>:enemy}, 46, "S:+P", true], [{55=>:enemy}, 55, "S:+P", true], [{63=>:enemy}, 63, "S:+P", true], [{45=>nil}, 45, "S:+P", false], [{46=>nil}, 46, "S:+P", false], [{55=>nil}, 55, "S:+P", false], [{63=>nil}, 63, "S:+P", false]], 55=>[[{45=>:enemy}, 45, "S:+P", true], [{46=>:enemy}, 46, "S:+P", true], [{47=>:enemy}, 47, "S:+P", true], [{54=>:enemy}, 54, "S:+P", true], [{56=>:enemy}, 56, "S:+P", true], [{64=>:enemy}, 64, "S:+P", true], [{45=>nil}, 45, "S:+P", false], [{46=>nil}, 46, "S:+P", false], [{47=>nil}, 47, "S:+P", false], [{54=>nil}, 54, "S:+P", false], [{56=>nil}, 56, "S:+P", false], [{64=>nil}, 64, "S:+P", false]], 56=>[[{46=>:enemy}, 46, "S:+P", true], [{47=>:enemy}, 47, "S:+P", true], [{48=>:enemy}, 48, "S:+P", true], [{55=>:enemy}, 55, "S:+P", true], [{57=>:enemy}, 57, "S:+P", true], [{65=>:enemy}, 65, "S:+P", true], [{46=>nil}, 46, "S:+P", false], [{47=>nil}, 47, "S:+P", false], [{48=>nil}, 48, "S:+P", false], [{55=>nil}, 55, "S:+P", false], [{57=>nil}, 57, "S:+P", false], [{65=>nil}, 65, "S:+P", false]], 57=>[[{47=>:enemy}, 47, "S:+P", true], [{48=>:enemy}, 48, "S:+P", true], [{49=>:enemy}, 49, "S:+P", true], [{56=>:enemy}, 56, "S:+P", true], [{58=>:enemy}, 58, "S:+P", true], [{66=>:enemy}, 66, "S:+P", true], [{47=>nil}, 47, "S:+P", false], [{48=>nil}, 48, "S:+P", false], [{49=>nil}, 49, "S:+P", false], [{56=>nil}, 56, "S:+P", false], [{58=>nil}, 58, "S:+P", false], [{66=>nil}, 66, "S:+P", false]], 58=>[[{48=>:enemy}, 48, "S:+P", true], [{49=>:enemy}, 49, "S:+P", true], [{50=>:enemy}, 50, "S:+P", true], [{57=>:enemy}, 57, "S:+P", true], [{59=>:enemy}, 59, "S:+P", true], [{67=>:enemy}, 67, "S:+P", true], [{48=>nil}, 48, "S:+P", false], [{49=>nil}, 49, "S:+P", false], [{50=>nil}, 50, "S:+P", false], [{57=>nil}, 57, "S:+P", false], [{59=>nil}, 59, "S:+P", false], [{67=>nil}, 67, "S:+P", false]], 59=>[[{49=>:enemy}, 49, "S:+P", true], [{50=>:enemy}, 50, "S:+P", true], [{51=>:enemy}, 51, "S:+P", true], [{58=>:enemy}, 58, "S:+P", true], [{60=>:enemy}, 60, "S:+P", true], [{68=>:enemy}, 68, "S:+P", true], [{49=>nil}, 49, "S:+P", false], [{50=>nil}, 50, "S:+P", false], [{51=>nil}, 51, "S:+P", false], [{58=>nil}, 58, "S:+P", false], [{60=>nil}, 60, "S:+P", false], [{68=>nil}, 68, "S:+P", false]], 60=>[[{50=>:enemy}, 50, "S:+P", true], [{51=>:enemy}, 51, "S:+P", true], [{52=>:enemy}, 52, "S:+P", true], [{59=>:enemy}, 59, "S:+P", true], [{61=>:enemy}, 61, "S:+P", true], [{69=>:enemy}, 69, "S:+P", true], [{50=>nil}, 50, "S:+P", false], [{51=>nil}, 51, "S:+P", false], [{52=>nil}, 52, "S:+P", false], [{59=>nil}, 59, "S:+P", false], [{61=>nil}, 61, "S:+P", false], [{69=>nil}, 69, "S:+P", false]], 61=>[[{51=>:enemy}, 51, "S:+P", true], [{52=>:enemy}, 52, "S:+P", true], [{53=>:enemy}, 53, "S:+P", true], [{60=>:enemy}, 60, "S:+P", true], [{62=>:enemy}, 62, "S:+P", true], [{70=>:enemy}, 70, "S:+P", true], [{51=>nil}, 51, "S:+P", false], [{52=>nil}, 52, "S:+P", false], [{53=>nil}, 53, "S:+P", false], [{60=>nil}, 60, "S:+P", false], [{62=>nil}, 62, "S:+P", false], [{70=>nil}, 70, "S:+P", false]], 62=>[[{52=>:enemy}, 52, "S:+P", true], [{53=>:enemy}, 53, "S:+P", true], [{61=>:enemy}, 61, "S:+P", true], [{71=>:enemy}, 71, "S:+P", true], [{52=>nil}, 52, "S:+P", false], [{53=>nil}, 53, "S:+P", false], [{61=>nil}, 61, "S:+P", false], [{71=>nil}, 71, "S:+P", false]], 63=>[[{54=>:enemy}, 54, "S:+P", true], [{55=>:enemy}, 55, "S:+P", true], [{64=>:enemy}, 64, "S:+P", true], [{72=>:enemy}, 72, "S:+P", true], [{54=>nil}, 54, "S:+P", false], [{55=>nil}, 55, "S:+P", false], [{64=>nil}, 64, "S:+P", false], [{72=>nil}, 72, "S:+P", false]], 64=>[[{54=>:enemy}, 54, "S:+P", true], [{55=>:enemy}, 55, "S:+P", true], [{56=>:enemy}, 56, "S:+P", true], [{63=>:enemy}, 63, "S:+P", true], [{65=>:enemy}, 65, "S:+P", true], [{73=>:enemy}, 73, "S:+P", true], [{54=>nil}, 54, "S:+P", false], [{55=>nil}, 55, "S:+P", false], [{56=>nil}, 56, "S:+P", false], [{63=>nil}, 63, "S:+P", false], [{65=>nil}, 65, "S:+P", false], [{73=>nil}, 73, "S:+P", false]], 65=>[[{55=>:enemy}, 55, "S:+P", true], [{56=>:enemy}, 56, "S:+P", true], [{57=>:enemy}, 57, "S:+P", true], [{64=>:enemy}, 64, "S:+P", true], [{66=>:enemy}, 66, "S:+P", true], [{74=>:enemy}, 74, "S:+P", true], [{55=>nil}, 55, "S:+P", false], [{56=>nil}, 56, "S:+P", false], [{57=>nil}, 57, "S:+P", false], [{64=>nil}, 64, "S:+P", false], [{66=>nil}, 66, "S:+P", false], [{74=>nil}, 74, "S:+P", false]], 66=>[[{56=>:enemy}, 56, "S:+P", true], [{57=>:enemy}, 57, "S:+P", true], [{58=>:enemy}, 58, "S:+P", true], [{65=>:enemy}, 65, "S:+P", true], [{67=>:enemy}, 67, "S:+P", true], [{75=>:enemy}, 75, "S:+P", true], [{56=>nil}, 56, "S:+P", false], [{57=>nil}, 57, "S:+P", false], [{58=>nil}, 58, "S:+P", false], [{65=>nil}, 65, "S:+P", false], [{67=>nil}, 67, "S:+P", false], [{75=>nil}, 75, "S:+P", false]], 67=>[[{57=>:enemy}, 57, "S:+P", true], [{58=>:enemy}, 58, "S:+P", true], [{59=>:enemy}, 59, "S:+P", true], [{66=>:enemy}, 66, "S:+P", true], [{68=>:enemy}, 68, "S:+P", true], [{76=>:enemy}, 76, "S:+P", true], [{57=>nil}, 57, "S:+P", false], [{58=>nil}, 58, "S:+P", false], [{59=>nil}, 59, "S:+P", false], [{66=>nil}, 66, "S:+P", false], [{68=>nil}, 68, "S:+P", false], [{76=>nil}, 76, "S:+P", false]], 68=>[[{58=>:enemy}, 58, "S:+P", true], [{59=>:enemy}, 59, "S:+P", true], [{60=>:enemy}, 60, "S:+P", true], [{67=>:enemy}, 67, "S:+P", true], [{69=>:enemy}, 69, "S:+P", true], [{77=>:enemy}, 77, "S:+P", true], [{58=>nil}, 58, "S:+P", false], [{59=>nil}, 59, "S:+P", false], [{60=>nil}, 60, "S:+P", false], [{67=>nil}, 67, "S:+P", false], [{69=>nil}, 69, "S:+P", false], [{77=>nil}, 77, "S:+P", false]], 69=>[[{59=>:enemy}, 59, "S:+P", true], [{60=>:enemy}, 60, "S:+P", true], [{61=>:enemy}, 61, "S:+P", true], [{68=>:enemy}, 68, "S:+P", true], [{70=>:enemy}, 70, "S:+P", true], [{78=>:enemy}, 78, "S:+P", true], [{59=>nil}, 59, "S:+P", false], [{60=>nil}, 60, "S:+P", false], [{61=>nil}, 61, "S:+P", false], [{68=>nil}, 68, "S:+P", false], [{70=>nil}, 70, "S:+P", false], [{78=>nil}, 78, "S:+P", false]], 70=>[[{60=>:enemy}, 60, "S:+P", true], [{61=>:enemy}, 61, "S:+P", true], [{62=>:enemy}, 62, "S:+P", true], [{69=>:enemy}, 69, "S:+P", true], [{71=>:enemy}, 71, "S:+P", true], [{79=>:enemy}, 79, "S:+P", true], [{60=>nil}, 60, "S:+P", false], [{61=>nil}, 61, "S:+P", false], [{62=>nil}, 62, "S:+P", false], [{69=>nil}, 69, "S:+P", false], [{71=>nil}, 71, "S:+P", false], [{79=>nil}, 79, "S:+P", false]], 71=>[[{61=>:enemy}, 61, "S:+P", true], [{62=>:enemy}, 62, "S:+P", true], [{70=>:enemy}, 70, "S:+P", true], [{80=>:enemy}, 80, "S:+P", true], [{61=>nil}, 61, "S:+P", false], [{62=>nil}, 62, "S:+P", false], [{70=>nil}, 70, "S:+P", false], [{80=>nil}, 80, "S:+P", false]], 72=>[[{63=>:enemy}, 63, "S:+P", true], [{64=>:enemy}, 64, "S:+P", true], [{73=>:enemy}, 73, "S:+P", true], [{63=>nil}, 63, "S:+P", false], [{64=>nil}, 64, "S:+P", false], [{73=>nil}, 73, "S:+P", false]], 73=>[[{63=>:enemy}, 63, "S:+P", true], [{64=>:enemy}, 64, "S:+P", true], [{65=>:enemy}, 65, "S:+P", true], [{72=>:enemy}, 72, "S:+P", true], [{74=>:enemy}, 74, "S:+P", true], [{63=>nil}, 63, "S:+P", false], [{64=>nil}, 64, "S:+P", false], [{65=>nil}, 65, "S:+P", false], [{72=>nil}, 72, "S:+P", false], [{74=>nil}, 74, "S:+P", false]], 74=>[[{64=>:enemy}, 64, "S:+P", true], [{65=>:enemy}, 65, "S:+P", true], [{66=>:enemy}, 66, "S:+P", true], [{73=>:enemy}, 73, "S:+P", true], [{75=>:enemy}, 75, "S:+P", true], [{64=>nil}, 64, "S:+P", false], [{65=>nil}, 65, "S:+P", false], [{66=>nil}, 66, "S:+P", false], [{73=>nil}, 73, "S:+P", false], [{75=>nil}, 75, "S:+P", false]], 75=>[[{65=>:enemy}, 65, "S:+P", true], [{66=>:enemy}, 66, "S:+P", true], [{67=>:enemy}, 67, "S:+P", true], [{74=>:enemy}, 74, "S:+P", true], [{76=>:enemy}, 76, "S:+P", true], [{65=>nil}, 65, "S:+P", false], [{66=>nil}, 66, "S:+P", false], [{67=>nil}, 67, "S:+P", false], [{74=>nil}, 74, "S:+P", false], [{76=>nil}, 76, "S:+P", false]], 76=>[[{66=>:enemy}, 66, "S:+P", true], [{67=>:enemy}, 67, "S:+P", true], [{68=>:enemy}, 68, "S:+P", true], [{75=>:enemy}, 75, "S:+P", true], [{77=>:enemy}, 77, "S:+P", true], [{66=>nil}, 66, "S:+P", false], [{67=>nil}, 67, "S:+P", false], [{68=>nil}, 68, "S:+P", false], [{75=>nil}, 75, "S:+P", false], [{77=>nil}, 77, "S:+P", false]], 77=>[[{67=>:enemy}, 67, "S:+P", true], [{68=>:enemy}, 68, "S:+P", true], [{69=>:enemy}, 69, "S:+P", true], [{76=>:enemy}, 76, "S:+P", true], [{78=>:enemy}, 78, "S:+P", true], [{67=>nil}, 67, "S:+P", false], [{68=>nil}, 68, "S:+P", false], [{69=>nil}, 69, "S:+P", false], [{76=>nil}, 76, "S:+P", false], [{78=>nil}, 78, "S:+P", false]], 78=>[[{68=>:enemy}, 68, "S:+P", true], [{69=>:enemy}, 69, "S:+P", true], [{70=>:enemy}, 70, "S:+P", true], [{77=>:enemy}, 77, "S:+P", true], [{79=>:enemy}, 79, "S:+P", true], [{68=>nil}, 68, "S:+P", false], [{69=>nil}, 69, "S:+P", false], [{70=>nil}, 70, "S:+P", false], [{77=>nil}, 77, "S:+P", false], [{79=>nil}, 79, "S:+P", false]], 79=>[[{69=>:enemy}, 69, "S:+P", true], [{70=>:enemy}, 70, "S:+P", true], [{71=>:enemy}, 71, "S:+P", true], [{78=>:enemy}, 78, "S:+P", true], [{80=>:enemy}, 80, "S:+P", true], [{69=>nil}, 69, "S:+P", false], [{70=>nil}, 70, "S:+P", false], [{71=>nil}, 71, "S:+P", false], [{78=>nil}, 78, "S:+P", false], [{80=>nil}, 80, "S:+P", false]], 80=>[[{70=>:enemy}, 70, "S:+P", true], [{71=>:enemy}, 71, "S:+P", true], [{79=>:enemy}, 79, "S:+P", true], [{70=>nil}, 70, "S:+P", false], [{71=>nil}, 71, "S:+P", false], [{79=>nil}, 79, "S:+P", false]], nil=>[]}, "S:+R"=>{0=>[[{1=>:enemy}, 1, "S:+R", true], [{9=>:enemy}, 9, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{1=>nil, 2=>:enemy}, 2, "S:+R", true], [{1=>nil, 2=>nil}, 2, "S:+R", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{9=>nil}, 9, "S:+R", false], [{9=>nil, 18=>:enemy}, 18, "S:+R", true], [{9=>nil, 18=>nil}, 18, "S:+R", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{10=>nil}, 10, "S:+R", false]], 1=>[[{0=>:enemy}, 0, "S:+R", true], [{2=>:enemy}, 2, "S:+R", true], [{9=>:enemy}, 9, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{0=>nil}, 0, "S:+R", false], [{2=>nil}, 2, "S:+R", false], [{2=>nil, 3=>:enemy}, 3, "S:+R", true], [{2=>nil, 3=>nil}, 3, "S:+R", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{9=>nil}, 9, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 19=>:enemy}, 19, "S:+R", true], [{10=>nil, 19=>nil}, 19, "S:+R", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{11=>nil}, 11, "S:+R", false]], 2=>[[{1=>:enemy}, 1, "S:+R", true], [{3=>:enemy}, 3, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{1=>nil, 0=>:enemy}, 0, "S:+R", true], [{1=>nil, 0=>nil}, 0, "S:+R", false], [{3=>nil}, 3, "S:+R", false], [{3=>nil, 4=>:enemy}, 4, "S:+R", true], [{3=>nil, 4=>nil}, 4, "S:+R", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 20=>:enemy}, 20, "S:+R", true], [{11=>nil, 20=>nil}, 20, "S:+R", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{12=>nil}, 12, "S:+R", false]], 3=>[[{2=>:enemy}, 2, "S:+R", true], [{4=>:enemy}, 4, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{2=>nil}, 2, "S:+R", false], [{2=>nil, 1=>:enemy}, 1, "S:+R", true], [{2=>nil, 1=>nil}, 1, "S:+R", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{4=>nil}, 4, "S:+R", false], [{4=>nil, 5=>:enemy}, 5, "S:+R", true], [{4=>nil, 5=>nil}, 5, "S:+R", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 21=>:enemy}, 21, "S:+R", true], [{12=>nil, 21=>nil}, 21, "S:+R", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{13=>nil}, 13, "S:+R", false]], 4=>[[{3=>:enemy}, 3, "S:+R", true], [{5=>:enemy}, 5, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{3=>nil}, 3, "S:+R", false], [{3=>nil, 2=>:enemy}, 2, "S:+R", true], [{3=>nil, 2=>nil}, 2, "S:+R", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{5=>nil}, 5, "S:+R", false], [{5=>nil, 6=>:enemy}, 6, "S:+R", true], [{5=>nil, 6=>nil}, 6, "S:+R", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 22=>:enemy}, 22, "S:+R", true], [{13=>nil, 22=>nil}, 22, "S:+R", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{14=>nil}, 14, "S:+R", false]], 5=>[[{4=>:enemy}, 4, "S:+R", true], [{6=>:enemy}, 6, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{4=>nil}, 4, "S:+R", false], [{4=>nil, 3=>:enemy}, 3, "S:+R", true], [{4=>nil, 3=>nil}, 3, "S:+R", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{6=>nil}, 6, "S:+R", false], [{6=>nil, 7=>:enemy}, 7, "S:+R", true], [{6=>nil, 7=>nil}, 7, "S:+R", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 23=>:enemy}, 23, "S:+R", true], [{14=>nil, 23=>nil}, 23, "S:+R", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{15=>nil}, 15, "S:+R", false]], 6=>[[{5=>:enemy}, 5, "S:+R", true], [{7=>:enemy}, 7, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{5=>nil}, 5, "S:+R", false], [{5=>nil, 4=>:enemy}, 4, "S:+R", true], [{5=>nil, 4=>nil}, 4, "S:+R", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{7=>nil}, 7, "S:+R", false], [{7=>nil, 8=>:enemy}, 8, "S:+R", true], [{7=>nil, 8=>nil}, 8, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 24=>:enemy}, 24, "S:+R", true], [{15=>nil, 24=>nil}, 24, "S:+R", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{16=>nil}, 16, "S:+R", false]], 7=>[[{6=>:enemy}, 6, "S:+R", true], [{8=>:enemy}, 8, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{6=>nil}, 6, "S:+R", false], [{6=>nil, 5=>:enemy}, 5, "S:+R", true], [{6=>nil, 5=>nil}, 5, "S:+R", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{8=>nil}, 8, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 25=>:enemy}, 25, "S:+R", true], [{16=>nil, 25=>nil}, 25, "S:+R", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{17=>nil}, 17, "S:+R", false]], 8=>[[{7=>:enemy}, 7, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{7=>nil}, 7, "S:+R", false], [{7=>nil, 6=>:enemy}, 6, "S:+R", true], [{7=>nil, 6=>nil}, 6, "S:+R", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{17=>nil, 26=>:enemy}, 26, "S:+R", true], [{17=>nil, 26=>nil}, 26, "S:+R", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 9=>[[{0=>:enemy}, 0, "S:+R", true], [{1=>:enemy}, 1, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{18=>:enemy}, 18, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{0=>nil}, 0, "S:+R", false], [{1=>nil}, 1, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 11=>:enemy}, 11, "S:+R", true], [{10=>nil, 11=>nil}, 11, "S:+R", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{18=>nil}, 18, "S:+R", false], [{18=>nil, 27=>:enemy}, 27, "S:+R", true], [{18=>nil, 27=>nil}, 27, "S:+R", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{19=>nil}, 19, "S:+R", false]], 10=>[[{0=>:enemy}, 0, "S:+R", true], [{1=>:enemy}, 1, "S:+R", true], [{2=>:enemy}, 2, "S:+R", true], [{9=>:enemy}, 9, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{18=>:enemy}, 18, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{0=>nil}, 0, "S:+R", false], [{1=>nil}, 1, "S:+R", false], [{2=>nil}, 2, "S:+R", false], [{9=>nil}, 9, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 12=>:enemy}, 12, "S:+R", true], [{11=>nil, 12=>nil}, 12, "S:+R", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{18=>nil}, 18, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 28=>:enemy}, 28, "S:+R", true], [{19=>nil, 28=>nil}, 28, "S:+R", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{20=>nil}, 20, "S:+R", false]], 11=>[[{1=>:enemy}, 1, "S:+R", true], [{2=>:enemy}, 2, "S:+R", true], [{3=>:enemy}, 3, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{2=>nil}, 2, "S:+R", false], [{3=>nil}, 3, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 9=>:enemy}, 9, "S:+R", true], [{10=>nil, 9=>nil}, 9, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 13=>:enemy}, 13, "S:+R", true], [{12=>nil, 13=>nil}, 13, "S:+R", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 29=>:enemy}, 29, "S:+R", true], [{20=>nil, 29=>nil}, 29, "S:+R", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{21=>nil}, 21, "S:+R", false]], 12=>[[{2=>:enemy}, 2, "S:+R", true], [{3=>:enemy}, 3, "S:+R", true], [{4=>:enemy}, 4, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{2=>nil}, 2, "S:+R", false], [{3=>nil}, 3, "S:+R", false], [{4=>nil}, 4, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 10=>:enemy}, 10, "S:+R", true], [{11=>nil, 10=>nil}, 10, "S:+R", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 14=>:enemy}, 14, "S:+R", true], [{13=>nil, 14=>nil}, 14, "S:+R", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 30=>:enemy}, 30, "S:+R", true], [{21=>nil, 30=>nil}, 30, "S:+R", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{22=>nil}, 22, "S:+R", false]], 13=>[[{3=>:enemy}, 3, "S:+R", true], [{4=>:enemy}, 4, "S:+R", true], [{5=>:enemy}, 5, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{3=>nil}, 3, "S:+R", false], [{4=>nil}, 4, "S:+R", false], [{5=>nil}, 5, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 11=>:enemy}, 11, "S:+R", true], [{12=>nil, 11=>nil}, 11, "S:+R", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 15=>:enemy}, 15, "S:+R", true], [{14=>nil, 15=>nil}, 15, "S:+R", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 31=>:enemy}, 31, "S:+R", true], [{22=>nil, 31=>nil}, 31, "S:+R", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{23=>nil}, 23, "S:+R", false]], 14=>[[{4=>:enemy}, 4, "S:+R", true], [{5=>:enemy}, 5, "S:+R", true], [{6=>:enemy}, 6, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{4=>nil}, 4, "S:+R", false], [{5=>nil}, 5, "S:+R", false], [{6=>nil}, 6, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 12=>:enemy}, 12, "S:+R", true], [{13=>nil, 12=>nil}, 12, "S:+R", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 16=>:enemy}, 16, "S:+R", true], [{15=>nil, 16=>nil}, 16, "S:+R", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 32=>:enemy}, 32, "S:+R", true], [{23=>nil, 32=>nil}, 32, "S:+R", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{24=>nil}, 24, "S:+R", false]], 15=>[[{5=>:enemy}, 5, "S:+R", true], [{6=>:enemy}, 6, "S:+R", true], [{7=>:enemy}, 7, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{5=>nil}, 5, "S:+R", false], [{6=>nil}, 6, "S:+R", false], [{7=>nil}, 7, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 13=>:enemy}, 13, "S:+R", true], [{14=>nil, 13=>nil}, 13, "S:+R", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 17=>:enemy}, 17, "S:+R", true], [{16=>nil, 17=>nil}, 17, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 33=>:enemy}, 33, "S:+R", true], [{24=>nil, 33=>nil}, 33, "S:+R", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{25=>nil}, 25, "S:+R", false]], 16=>[[{6=>:enemy}, 6, "S:+R", true], [{7=>:enemy}, 7, "S:+R", true], [{8=>:enemy}, 8, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{6=>nil}, 6, "S:+R", false], [{7=>nil}, 7, "S:+R", false], [{8=>nil}, 8, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 14=>:enemy}, 14, "S:+R", true], [{15=>nil, 14=>nil}, 14, "S:+R", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 34=>:enemy}, 34, "S:+R", true], [{25=>nil, 34=>nil}, 34, "S:+R", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{26=>nil}, 26, "S:+R", false]], 17=>[[{7=>:enemy}, 7, "S:+R", true], [{8=>:enemy}, 8, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{7=>nil}, 7, "S:+R", false], [{8=>nil}, 8, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 15=>:enemy}, 15, "S:+R", true], [{16=>nil, 15=>nil}, 15, "S:+R", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{26=>nil, 35=>:enemy}, 35, "S:+R", true], [{26=>nil, 35=>nil}, 35, "S:+R", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 18=>[[{9=>:enemy}, 9, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{27=>:enemy}, 27, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{9=>nil}, 9, "S:+R", false], [{9=>nil, 0=>:enemy}, 0, "S:+R", true], [{9=>nil, 0=>nil}, 0, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 20=>:enemy}, 20, "S:+R", true], [{19=>nil, 20=>nil}, 20, "S:+R", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{27=>nil}, 27, "S:+R", false], [{27=>nil, 36=>:enemy}, 36, "S:+R", true], [{27=>nil, 36=>nil}, 36, "S:+R", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{28=>nil}, 28, "S:+R", false]], 19=>[[{9=>:enemy}, 9, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{18=>:enemy}, 18, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{27=>:enemy}, 27, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{9=>nil}, 9, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 1=>:enemy}, 1, "S:+R", true], [{10=>nil, 1=>nil}, 1, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{18=>nil}, 18, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 21=>:enemy}, 21, "S:+R", true], [{20=>nil, 21=>nil}, 21, "S:+R", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{27=>nil}, 27, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{28=>nil, 37=>:enemy}, 37, "S:+R", true], [{28=>nil, 37=>nil}, 37, "S:+R", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{29=>nil}, 29, "S:+R", false]], 20=>[[{10=>:enemy}, 10, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{10=>nil}, 10, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 2=>:enemy}, 2, "S:+R", true], [{11=>nil, 2=>nil}, 2, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 18=>:enemy}, 18, "S:+R", true], [{19=>nil, 18=>nil}, 18, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 22=>:enemy}, 22, "S:+R", true], [{21=>nil, 22=>nil}, 22, "S:+R", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{29=>nil, 38=>:enemy}, 38, "S:+R", true], [{29=>nil, 38=>nil}, 38, "S:+R", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{30=>nil}, 30, "S:+R", false]], 21=>[[{11=>:enemy}, 11, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{11=>nil}, 11, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 3=>:enemy}, 3, "S:+R", true], [{12=>nil, 3=>nil}, 3, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 19=>:enemy}, 19, "S:+R", true], [{20=>nil, 19=>nil}, 19, "S:+R", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 23=>:enemy}, 23, "S:+R", true], [{22=>nil, 23=>nil}, 23, "S:+R", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{30=>nil, 39=>:enemy}, 39, "S:+R", true], [{30=>nil, 39=>nil}, 39, "S:+R", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{31=>nil}, 31, "S:+R", false]], 22=>[[{12=>:enemy}, 12, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{12=>nil}, 12, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 4=>:enemy}, 4, "S:+R", true], [{13=>nil, 4=>nil}, 4, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 20=>:enemy}, 20, "S:+R", true], [{21=>nil, 20=>nil}, 20, "S:+R", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 24=>:enemy}, 24, "S:+R", true], [{23=>nil, 24=>nil}, 24, "S:+R", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{31=>nil, 40=>:enemy}, 40, "S:+R", true], [{31=>nil, 40=>nil}, 40, "S:+R", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{32=>nil}, 32, "S:+R", false]], 23=>[[{13=>:enemy}, 13, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{13=>nil}, 13, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 5=>:enemy}, 5, "S:+R", true], [{14=>nil, 5=>nil}, 5, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 21=>:enemy}, 21, "S:+R", true], [{22=>nil, 21=>nil}, 21, "S:+R", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 25=>:enemy}, 25, "S:+R", true], [{24=>nil, 25=>nil}, 25, "S:+R", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{32=>nil, 41=>:enemy}, 41, "S:+R", true], [{32=>nil, 41=>nil}, 41, "S:+R", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{33=>nil}, 33, "S:+R", false]], 24=>[[{14=>:enemy}, 14, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{14=>nil}, 14, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 6=>:enemy}, 6, "S:+R", true], [{15=>nil, 6=>nil}, 6, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 22=>:enemy}, 22, "S:+R", true], [{23=>nil, 22=>nil}, 22, "S:+R", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 26=>:enemy}, 26, "S:+R", true], [{25=>nil, 26=>nil}, 26, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{33=>nil, 42=>:enemy}, 42, "S:+R", true], [{33=>nil, 42=>nil}, 42, "S:+R", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{34=>nil}, 34, "S:+R", false]], 25=>[[{15=>:enemy}, 15, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{15=>nil}, 15, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 7=>:enemy}, 7, "S:+R", true], [{16=>nil, 7=>nil}, 7, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 23=>:enemy}, 23, "S:+R", true], [{24=>nil, 23=>nil}, 23, "S:+R", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{34=>nil, 43=>:enemy}, 43, "S:+R", true], [{34=>nil, 43=>nil}, 43, "S:+R", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{35=>nil}, 35, "S:+R", false]], 26=>[[{16=>:enemy}, 16, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{16=>nil}, 16, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{17=>nil, 8=>:enemy}, 8, "S:+R", true], [{17=>nil, 8=>nil}, 8, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 24=>:enemy}, 24, "S:+R", true], [{25=>nil, 24=>nil}, 24, "S:+R", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{35=>nil}, 35, "S:+R", false], [{35=>nil, 44=>:enemy}, 44, "S:+R", true], [{35=>nil, 44=>nil}, 44, "S:+R", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 27=>[[{18=>:enemy}, 18, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{36=>:enemy}, 36, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{18=>nil}, 18, "S:+R", false], [{18=>nil, 9=>:enemy}, 9, "S:+R", true], [{18=>nil, 9=>nil}, 9, "S:+R", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{28=>nil, 29=>:enemy}, 29, "S:+R", true], [{28=>nil, 29=>nil}, 29, "S:+R", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "S:+R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "S:+R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "S:+R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:+R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:+R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{36=>nil}, 36, "S:+R", false], [{36=>nil, 45=>:enemy}, 45, "S:+R", true], [{36=>nil, 45=>nil}, 45, "S:+R", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{37=>nil}, 37, "S:+R", false]], 28=>[[{18=>:enemy}, 18, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{27=>:enemy}, 27, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{36=>:enemy}, 36, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{18=>nil}, 18, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 10=>:enemy}, 10, "S:+R", true], [{19=>nil, 10=>nil}, 10, "S:+R", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{27=>nil}, 27, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{29=>nil, 30=>:enemy}, 30, "S:+R", true], [{29=>nil, 30=>nil}, 30, "S:+R", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "S:+R", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "S:+R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "S:+R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "S:+R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:+R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:+R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:+R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:+R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{36=>nil}, 36, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{37=>nil, 46=>:enemy}, 46, "S:+R", true], [{37=>nil, 46=>nil}, 46, "S:+R", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{38=>nil}, 38, "S:+R", false]], 29=>[[{19=>:enemy}, 19, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{19=>nil}, 19, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 11=>:enemy}, 11, "S:+R", true], [{20=>nil, 11=>nil}, 11, "S:+R", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{28=>nil, 27=>:enemy}, 27, "S:+R", true], [{28=>nil, 27=>nil}, 27, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{30=>nil, 31=>:enemy}, 31, "S:+R", true], [{30=>nil, 31=>nil}, 31, "S:+R", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "S:+R", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "S:+R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:+R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:+R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:+R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:+R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{38=>nil, 47=>:enemy}, 47, "S:+R", true], [{38=>nil, 47=>nil}, 47, "S:+R", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{39=>nil}, 39, "S:+R", false]], 30=>[[{20=>:enemy}, 20, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{20=>nil}, 20, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 12=>:enemy}, 12, "S:+R", true], [{21=>nil, 12=>nil}, 12, "S:+R", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{29=>nil, 28=>:enemy}, 28, "S:+R", true], [{29=>nil, 28=>nil}, 28, "S:+R", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{31=>nil, 32=>:enemy}, 32, "S:+R", true], [{31=>nil, 32=>nil}, 32, "S:+R", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "S:+R", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "S:+R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:+R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:+R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{39=>nil, 48=>:enemy}, 48, "S:+R", true], [{39=>nil, 48=>nil}, 48, "S:+R", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{40=>nil}, 40, "S:+R", false]], 31=>[[{21=>:enemy}, 21, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{21=>nil}, 21, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 13=>:enemy}, 13, "S:+R", true], [{22=>nil, 13=>nil}, 13, "S:+R", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{30=>nil, 29=>:enemy}, 29, "S:+R", true], [{30=>nil, 29=>nil}, 29, "S:+R", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "S:+R", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "S:+R", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{32=>nil, 33=>:enemy}, 33, "S:+R", true], [{32=>nil, 33=>nil}, 33, "S:+R", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "S:+R", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "S:+R", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{40=>nil, 49=>:enemy}, 49, "S:+R", true], [{40=>nil, 49=>nil}, 49, "S:+R", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{41=>nil}, 41, "S:+R", false]], 32=>[[{22=>:enemy}, 22, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{22=>nil}, 22, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 14=>:enemy}, 14, "S:+R", true], [{23=>nil, 14=>nil}, 14, "S:+R", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{31=>nil, 30=>:enemy}, 30, "S:+R", true], [{31=>nil, 30=>nil}, 30, "S:+R", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "S:+R", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "S:+R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:+R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:+R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{33=>nil, 34=>:enemy}, 34, "S:+R", true], [{33=>nil, 34=>nil}, 34, "S:+R", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "S:+R", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{41=>nil, 50=>:enemy}, 50, "S:+R", true], [{41=>nil, 50=>nil}, 50, "S:+R", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{42=>nil}, 42, "S:+R", false]], 33=>[[{23=>:enemy}, 23, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{23=>nil}, 23, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 15=>:enemy}, 15, "S:+R", true], [{24=>nil, 15=>nil}, 15, "S:+R", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{32=>nil, 31=>:enemy}, 31, "S:+R", true], [{32=>nil, 31=>nil}, 31, "S:+R", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "S:+R", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "S:+R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:+R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:+R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:+R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:+R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{34=>nil, 35=>:enemy}, 35, "S:+R", true], [{34=>nil, 35=>nil}, 35, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{42=>nil, 51=>:enemy}, 51, "S:+R", true], [{42=>nil, 51=>nil}, 51, "S:+R", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{43=>nil}, 43, "S:+R", false]], 34=>[[{24=>:enemy}, 24, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{44=>:enemy}, 44, "S:+R", true], [{24=>nil}, 24, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 16=>:enemy}, 16, "S:+R", true], [{25=>nil, 16=>nil}, 16, "S:+R", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{33=>nil, 32=>:enemy}, 32, "S:+R", true], [{33=>nil, 32=>nil}, 32, "S:+R", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "S:+R", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "S:+R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "S:+R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "S:+R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:+R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:+R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:+R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:+R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{35=>nil}, 35, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{43=>nil, 52=>:enemy}, 52, "S:+R", true], [{43=>nil, 52=>nil}, 52, "S:+R", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{44=>nil}, 44, "S:+R", false]], 35=>[[{25=>:enemy}, 25, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{44=>:enemy}, 44, "S:+R", true], [{25=>nil}, 25, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{26=>nil, 17=>:enemy}, 17, "S:+R", true], [{26=>nil, 17=>nil}, 17, "S:+R", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{34=>nil, 33=>:enemy}, 33, "S:+R", true], [{34=>nil, 33=>nil}, 33, "S:+R", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "S:+R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "S:+R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "S:+R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:+R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:+R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:+R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{44=>nil}, 44, "S:+R", false], [{44=>nil, 53=>:enemy}, 53, "S:+R", true], [{44=>nil, 53=>nil}, 53, "S:+R", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 36=>[[{27=>:enemy}, 27, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{45=>:enemy}, 45, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{27=>nil}, 27, "S:+R", false], [{27=>nil, 18=>:enemy}, 18, "S:+R", true], [{27=>nil, 18=>nil}, 18, "S:+R", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{37=>nil, 38=>:enemy}, 38, "S:+R", true], [{37=>nil, 38=>nil}, 38, "S:+R", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "S:+R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "S:+R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "S:+R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:+R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:+R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{45=>nil}, 45, "S:+R", false], [{45=>nil, 54=>:enemy}, 54, "S:+R", true], [{45=>nil, 54=>nil}, 54, "S:+R", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{46=>nil}, 46, "S:+R", false]], 37=>[[{27=>:enemy}, 27, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{36=>:enemy}, 36, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{45=>:enemy}, 45, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{27=>nil}, 27, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{28=>nil, 19=>:enemy}, 19, "S:+R", true], [{28=>nil, 19=>nil}, 19, "S:+R", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{36=>nil}, 36, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{38=>nil, 39=>:enemy}, 39, "S:+R", true], [{38=>nil, 39=>nil}, 39, "S:+R", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "S:+R", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "S:+R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "S:+R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "S:+R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:+R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:+R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:+R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:+R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{45=>nil}, 45, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{46=>nil, 55=>:enemy}, 55, "S:+R", true], [{46=>nil, 55=>nil}, 55, "S:+R", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{47=>nil}, 47, "S:+R", false]], 38=>[[{28=>:enemy}, 28, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{28=>nil}, 28, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{29=>nil, 20=>:enemy}, 20, "S:+R", true], [{29=>nil, 20=>nil}, 20, "S:+R", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{37=>nil, 36=>:enemy}, 36, "S:+R", true], [{37=>nil, 36=>nil}, 36, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{39=>nil, 40=>:enemy}, 40, "S:+R", true], [{39=>nil, 40=>nil}, 40, "S:+R", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "S:+R", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "S:+R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:+R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:+R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:+R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:+R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{47=>nil, 56=>:enemy}, 56, "S:+R", true], [{47=>nil, 56=>nil}, 56, "S:+R", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{48=>nil}, 48, "S:+R", false]], 39=>[[{29=>:enemy}, 29, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{29=>nil}, 29, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{30=>nil, 21=>:enemy}, 21, "S:+R", true], [{30=>nil, 21=>nil}, 21, "S:+R", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{38=>nil, 37=>:enemy}, 37, "S:+R", true], [{38=>nil, 37=>nil}, 37, "S:+R", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{40=>nil, 41=>:enemy}, 41, "S:+R", true], [{40=>nil, 41=>nil}, 41, "S:+R", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "S:+R", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "S:+R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:+R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:+R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{48=>nil, 57=>:enemy}, 57, "S:+R", true], [{48=>nil, 57=>nil}, 57, "S:+R", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{49=>nil}, 49, "S:+R", false]], 40=>[[{30=>:enemy}, 30, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{30=>nil}, 30, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{31=>nil, 22=>:enemy}, 22, "S:+R", true], [{31=>nil, 22=>nil}, 22, "S:+R", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{39=>nil, 38=>:enemy}, 38, "S:+R", true], [{39=>nil, 38=>nil}, 38, "S:+R", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "S:+R", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "S:+R", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{41=>nil, 42=>:enemy}, 42, "S:+R", true], [{41=>nil, 42=>nil}, 42, "S:+R", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "S:+R", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "S:+R", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{49=>nil, 58=>:enemy}, 58, "S:+R", true], [{49=>nil, 58=>nil}, 58, "S:+R", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{50=>nil}, 50, "S:+R", false]], 41=>[[{31=>:enemy}, 31, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{31=>nil}, 31, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{32=>nil, 23=>:enemy}, 23, "S:+R", true], [{32=>nil, 23=>nil}, 23, "S:+R", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{40=>nil, 39=>:enemy}, 39, "S:+R", true], [{40=>nil, 39=>nil}, 39, "S:+R", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "S:+R", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "S:+R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:+R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:+R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{42=>nil, 43=>:enemy}, 43, "S:+R", true], [{42=>nil, 43=>nil}, 43, "S:+R", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "S:+R", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{50=>nil, 59=>:enemy}, 59, "S:+R", true], [{50=>nil, 59=>nil}, 59, "S:+R", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{51=>nil}, 51, "S:+R", false]], 42=>[[{32=>:enemy}, 32, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{32=>nil}, 32, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{33=>nil, 24=>:enemy}, 24, "S:+R", true], [{33=>nil, 24=>nil}, 24, "S:+R", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{41=>nil, 40=>:enemy}, 40, "S:+R", true], [{41=>nil, 40=>nil}, 40, "S:+R", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "S:+R", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "S:+R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:+R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:+R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:+R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:+R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{43=>nil, 44=>:enemy}, 44, "S:+R", true], [{43=>nil, 44=>nil}, 44, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{51=>nil, 60=>:enemy}, 60, "S:+R", true], [{51=>nil, 60=>nil}, 60, "S:+R", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{52=>nil}, 52, "S:+R", false]], 43=>[[{33=>:enemy}, 33, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{44=>:enemy}, 44, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{53=>:enemy}, 53, "S:+R", true], [{33=>nil}, 33, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{34=>nil, 25=>:enemy}, 25, "S:+R", true], [{34=>nil, 25=>nil}, 25, "S:+R", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{35=>nil}, 35, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{42=>nil, 41=>:enemy}, 41, "S:+R", true], [{42=>nil, 41=>nil}, 41, "S:+R", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "S:+R", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "S:+R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "S:+R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "S:+R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:+R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:+R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:+R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:+R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{44=>nil}, 44, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{52=>nil, 61=>:enemy}, 61, "S:+R", true], [{52=>nil, 61=>nil}, 61, "S:+R", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{53=>nil}, 53, "S:+R", false]], 44=>[[{34=>:enemy}, 34, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{53=>:enemy}, 53, "S:+R", true], [{34=>nil}, 34, "S:+R", false], [{35=>nil}, 35, "S:+R", false], [{35=>nil, 26=>:enemy}, 26, "S:+R", true], [{35=>nil, 26=>nil}, 26, "S:+R", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{43=>nil, 42=>:enemy}, 42, "S:+R", true], [{43=>nil, 42=>nil}, 42, "S:+R", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "S:+R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "S:+R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "S:+R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:+R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:+R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:+R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{53=>nil}, 53, "S:+R", false], [{53=>nil, 62=>:enemy}, 62, "S:+R", true], [{53=>nil, 62=>nil}, 62, "S:+R", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 45=>[[{36=>:enemy}, 36, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{54=>:enemy}, 54, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{36=>nil}, 36, "S:+R", false], [{36=>nil, 27=>:enemy}, 27, "S:+R", true], [{36=>nil, 27=>nil}, 27, "S:+R", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{46=>nil, 47=>:enemy}, 47, "S:+R", true], [{46=>nil, 47=>nil}, 47, "S:+R", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "S:+R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "S:+R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "S:+R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:+R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:+R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{54=>nil}, 54, "S:+R", false], [{54=>nil, 63=>:enemy}, 63, "S:+R", true], [{54=>nil, 63=>nil}, 63, "S:+R", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false], [{55=>nil}, 55, "S:+R", false]], 46=>[[{36=>:enemy}, 36, "S:+R", true], [{37=>:enemy}, 37, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{45=>:enemy}, 45, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{54=>:enemy}, 54, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{36=>nil}, 36, "S:+R", false], [{37=>nil}, 37, "S:+R", false], [{37=>nil, 28=>:enemy}, 28, "S:+R", true], [{37=>nil, 28=>nil}, 28, "S:+R", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{45=>nil}, 45, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{47=>nil, 48=>:enemy}, 48, "S:+R", true], [{47=>nil, 48=>nil}, 48, "S:+R", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "S:+R", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "S:+R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "S:+R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "S:+R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:+R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:+R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:+R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:+R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{54=>nil}, 54, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{55=>nil, 64=>:enemy}, 64, "S:+R", true], [{55=>nil, 64=>nil}, 64, "S:+R", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false], [{56=>nil}, 56, "S:+R", false]], 47=>[[{37=>:enemy}, 37, "S:+R", true], [{38=>:enemy}, 38, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{37=>nil}, 37, "S:+R", false], [{38=>nil}, 38, "S:+R", false], [{38=>nil, 29=>:enemy}, 29, "S:+R", true], [{38=>nil, 29=>nil}, 29, "S:+R", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{46=>nil, 45=>:enemy}, 45, "S:+R", true], [{46=>nil, 45=>nil}, 45, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{48=>nil, 49=>:enemy}, 49, "S:+R", true], [{48=>nil, 49=>nil}, 49, "S:+R", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "S:+R", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "S:+R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:+R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:+R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:+R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:+R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{56=>nil, 65=>:enemy}, 65, "S:+R", true], [{56=>nil, 65=>nil}, 65, "S:+R", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false], [{57=>nil}, 57, "S:+R", false]], 48=>[[{38=>:enemy}, 38, "S:+R", true], [{39=>:enemy}, 39, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{38=>nil}, 38, "S:+R", false], [{39=>nil}, 39, "S:+R", false], [{39=>nil, 30=>:enemy}, 30, "S:+R", true], [{39=>nil, 30=>nil}, 30, "S:+R", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{47=>nil, 46=>:enemy}, 46, "S:+R", true], [{47=>nil, 46=>nil}, 46, "S:+R", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{49=>nil, 50=>:enemy}, 50, "S:+R", true], [{49=>nil, 50=>nil}, 50, "S:+R", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "S:+R", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "S:+R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:+R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:+R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{57=>nil, 66=>:enemy}, 66, "S:+R", true], [{57=>nil, 66=>nil}, 66, "S:+R", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false], [{58=>nil}, 58, "S:+R", false]], 49=>[[{39=>:enemy}, 39, "S:+R", true], [{40=>:enemy}, 40, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{39=>nil}, 39, "S:+R", false], [{40=>nil}, 40, "S:+R", false], [{40=>nil, 31=>:enemy}, 31, "S:+R", true], [{40=>nil, 31=>nil}, 31, "S:+R", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{48=>nil, 47=>:enemy}, 47, "S:+R", true], [{48=>nil, 47=>nil}, 47, "S:+R", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "S:+R", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "S:+R", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{50=>nil, 51=>:enemy}, 51, "S:+R", true], [{50=>nil, 51=>nil}, 51, "S:+R", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "S:+R", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "S:+R", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{58=>nil, 67=>:enemy}, 67, "S:+R", true], [{58=>nil, 67=>nil}, 67, "S:+R", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false], [{59=>nil}, 59, "S:+R", false]], 50=>[[{40=>:enemy}, 40, "S:+R", true], [{41=>:enemy}, 41, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{40=>nil}, 40, "S:+R", false], [{41=>nil}, 41, "S:+R", false], [{41=>nil, 32=>:enemy}, 32, "S:+R", true], [{41=>nil, 32=>nil}, 32, "S:+R", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{49=>nil, 48=>:enemy}, 48, "S:+R", true], [{49=>nil, 48=>nil}, 48, "S:+R", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "S:+R", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "S:+R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:+R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:+R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{51=>nil, 52=>:enemy}, 52, "S:+R", true], [{51=>nil, 52=>nil}, 52, "S:+R", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "S:+R", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{59=>nil, 68=>:enemy}, 68, "S:+R", true], [{59=>nil, 68=>nil}, 68, "S:+R", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false], [{60=>nil}, 60, "S:+R", false]], 51=>[[{41=>:enemy}, 41, "S:+R", true], [{42=>:enemy}, 42, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{41=>nil}, 41, "S:+R", false], [{42=>nil}, 42, "S:+R", false], [{42=>nil, 33=>:enemy}, 33, "S:+R", true], [{42=>nil, 33=>nil}, 33, "S:+R", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{50=>nil, 49=>:enemy}, 49, "S:+R", true], [{50=>nil, 49=>nil}, 49, "S:+R", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "S:+R", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "S:+R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:+R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:+R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:+R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:+R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{52=>nil, 53=>:enemy}, 53, "S:+R", true], [{52=>nil, 53=>nil}, 53, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{60=>nil, 69=>:enemy}, 69, "S:+R", true], [{60=>nil, 69=>nil}, 69, "S:+R", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false], [{61=>nil}, 61, "S:+R", false]], 52=>[[{42=>:enemy}, 42, "S:+R", true], [{43=>:enemy}, 43, "S:+R", true], [{44=>:enemy}, 44, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{53=>:enemy}, 53, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{62=>:enemy}, 62, "S:+R", true], [{42=>nil}, 42, "S:+R", false], [{43=>nil}, 43, "S:+R", false], [{43=>nil, 34=>:enemy}, 34, "S:+R", true], [{43=>nil, 34=>nil}, 34, "S:+R", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{44=>nil}, 44, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{51=>nil, 50=>:enemy}, 50, "S:+R", true], [{51=>nil, 50=>nil}, 50, "S:+R", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "S:+R", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "S:+R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "S:+R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "S:+R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:+R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:+R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:+R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:+R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{53=>nil}, 53, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{61=>nil, 70=>:enemy}, 70, "S:+R", true], [{61=>nil, 70=>nil}, 70, "S:+R", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false], [{62=>nil}, 62, "S:+R", false]], 53=>[[{43=>:enemy}, 43, "S:+R", true], [{44=>:enemy}, 44, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{62=>:enemy}, 62, "S:+R", true], [{43=>nil}, 43, "S:+R", false], [{44=>nil}, 44, "S:+R", false], [{44=>nil, 35=>:enemy}, 35, "S:+R", true], [{44=>nil, 35=>nil}, 35, "S:+R", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{52=>nil, 51=>:enemy}, 51, "S:+R", true], [{52=>nil, 51=>nil}, 51, "S:+R", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "S:+R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "S:+R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "S:+R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:+R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:+R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:+R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{62=>nil}, 62, "S:+R", false], [{62=>nil, 71=>:enemy}, 71, "S:+R", true], [{62=>nil, 71=>nil}, 71, "S:+R", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 54=>[[{45=>:enemy}, 45, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{63=>:enemy}, 63, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{45=>nil}, 45, "S:+R", false], [{45=>nil, 36=>:enemy}, 36, "S:+R", true], [{45=>nil, 36=>nil}, 36, "S:+R", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "S:+R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{55=>nil, 56=>:enemy}, 56, "S:+R", true], [{55=>nil, 56=>nil}, 56, "S:+R", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "S:+R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "S:+R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "S:+R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:+R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:+R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{63=>nil}, 63, "S:+R", false], [{63=>nil, 72=>:enemy}, 72, "S:+R", true], [{63=>nil, 72=>nil}, 72, "S:+R", false], [{64=>nil}, 64, "S:+R", false]], 55=>[[{45=>:enemy}, 45, "S:+R", true], [{46=>:enemy}, 46, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{54=>:enemy}, 54, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{63=>:enemy}, 63, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{45=>nil}, 45, "S:+R", false], [{46=>nil}, 46, "S:+R", false], [{46=>nil, 37=>:enemy}, 37, "S:+R", true], [{46=>nil, 37=>nil}, 37, "S:+R", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "S:+R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{54=>nil}, 54, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{56=>nil, 57=>:enemy}, 57, "S:+R", true], [{56=>nil, 57=>nil}, 57, "S:+R", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "S:+R", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "S:+R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "S:+R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "S:+R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:+R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:+R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:+R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:+R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{63=>nil}, 63, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{64=>nil, 73=>:enemy}, 73, "S:+R", true], [{64=>nil, 73=>nil}, 73, "S:+R", false], [{65=>nil}, 65, "S:+R", false]], 56=>[[{46=>:enemy}, 46, "S:+R", true], [{47=>:enemy}, 47, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{46=>nil}, 46, "S:+R", false], [{47=>nil}, 47, "S:+R", false], [{47=>nil, 38=>:enemy}, 38, "S:+R", true], [{47=>nil, 38=>nil}, 38, "S:+R", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "S:+R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{55=>nil, 54=>:enemy}, 54, "S:+R", true], [{55=>nil, 54=>nil}, 54, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{57=>nil, 58=>:enemy}, 58, "S:+R", true], [{57=>nil, 58=>nil}, 58, "S:+R", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "S:+R", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "S:+R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:+R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:+R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:+R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:+R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{65=>nil, 74=>:enemy}, 74, "S:+R", true], [{65=>nil, 74=>nil}, 74, "S:+R", false], [{66=>nil}, 66, "S:+R", false]], 57=>[[{47=>:enemy}, 47, "S:+R", true], [{48=>:enemy}, 48, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{47=>nil}, 47, "S:+R", false], [{48=>nil}, 48, "S:+R", false], [{48=>nil, 39=>:enemy}, 39, "S:+R", true], [{48=>nil, 39=>nil}, 39, "S:+R", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "S:+R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{56=>nil, 55=>:enemy}, 55, "S:+R", true], [{56=>nil, 55=>nil}, 55, "S:+R", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{58=>nil, 59=>:enemy}, 59, "S:+R", true], [{58=>nil, 59=>nil}, 59, "S:+R", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "S:+R", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "S:+R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:+R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:+R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{66=>nil, 75=>:enemy}, 75, "S:+R", true], [{66=>nil, 75=>nil}, 75, "S:+R", false], [{67=>nil}, 67, "S:+R", false]], 58=>[[{48=>:enemy}, 48, "S:+R", true], [{49=>:enemy}, 49, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{48=>nil}, 48, "S:+R", false], [{49=>nil}, 49, "S:+R", false], [{49=>nil, 40=>:enemy}, 40, "S:+R", true], [{49=>nil, 40=>nil}, 40, "S:+R", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "S:+R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{57=>nil, 56=>:enemy}, 56, "S:+R", true], [{57=>nil, 56=>nil}, 56, "S:+R", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "S:+R", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "S:+R", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{59=>nil, 60=>:enemy}, 60, "S:+R", true], [{59=>nil, 60=>nil}, 60, "S:+R", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "S:+R", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "S:+R", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{67=>nil, 76=>:enemy}, 76, "S:+R", true], [{67=>nil, 76=>nil}, 76, "S:+R", false], [{68=>nil}, 68, "S:+R", false]], 59=>[[{49=>:enemy}, 49, "S:+R", true], [{50=>:enemy}, 50, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{49=>nil}, 49, "S:+R", false], [{50=>nil}, 50, "S:+R", false], [{50=>nil, 41=>:enemy}, 41, "S:+R", true], [{50=>nil, 41=>nil}, 41, "S:+R", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "S:+R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{58=>nil, 57=>:enemy}, 57, "S:+R", true], [{58=>nil, 57=>nil}, 57, "S:+R", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "S:+R", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "S:+R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:+R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:+R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{60=>nil, 61=>:enemy}, 61, "S:+R", true], [{60=>nil, 61=>nil}, 61, "S:+R", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "S:+R", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{68=>nil, 77=>:enemy}, 77, "S:+R", true], [{68=>nil, 77=>nil}, 77, "S:+R", false], [{69=>nil}, 69, "S:+R", false]], 60=>[[{50=>:enemy}, 50, "S:+R", true], [{51=>:enemy}, 51, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{50=>nil}, 50, "S:+R", false], [{51=>nil}, 51, "S:+R", false], [{51=>nil, 42=>:enemy}, 42, "S:+R", true], [{51=>nil, 42=>nil}, 42, "S:+R", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "S:+R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{59=>nil, 58=>:enemy}, 58, "S:+R", true], [{59=>nil, 58=>nil}, 58, "S:+R", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "S:+R", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "S:+R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:+R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:+R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:+R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:+R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{61=>nil, 62=>:enemy}, 62, "S:+R", true], [{61=>nil, 62=>nil}, 62, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{69=>nil, 78=>:enemy}, 78, "S:+R", true], [{69=>nil, 78=>nil}, 78, "S:+R", false], [{70=>nil}, 70, "S:+R", false]], 61=>[[{51=>:enemy}, 51, "S:+R", true], [{52=>:enemy}, 52, "S:+R", true], [{53=>:enemy}, 53, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{62=>:enemy}, 62, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{71=>:enemy}, 71, "S:+R", true], [{51=>nil}, 51, "S:+R", false], [{52=>nil}, 52, "S:+R", false], [{52=>nil, 43=>:enemy}, 43, "S:+R", true], [{52=>nil, 43=>nil}, 43, "S:+R", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "S:+R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{53=>nil}, 53, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{60=>nil, 59=>:enemy}, 59, "S:+R", true], [{60=>nil, 59=>nil}, 59, "S:+R", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "S:+R", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "S:+R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "S:+R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "S:+R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:+R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:+R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:+R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:+R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{62=>nil}, 62, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{70=>nil, 79=>:enemy}, 79, "S:+R", true], [{70=>nil, 79=>nil}, 79, "S:+R", false], [{71=>nil}, 71, "S:+R", false]], 62=>[[{52=>:enemy}, 52, "S:+R", true], [{53=>:enemy}, 53, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{71=>:enemy}, 71, "S:+R", true], [{52=>nil}, 52, "S:+R", false], [{53=>nil}, 53, "S:+R", false], [{53=>nil, 44=>:enemy}, 44, "S:+R", true], [{53=>nil, 44=>nil}, 44, "S:+R", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "S:+R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{61=>nil, 60=>:enemy}, 60, "S:+R", true], [{61=>nil, 60=>nil}, 60, "S:+R", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "S:+R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "S:+R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "S:+R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:+R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:+R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:+R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{71=>nil}, 71, "S:+R", false], [{71=>nil, 80=>:enemy}, 80, "S:+R", true], [{71=>nil, 80=>nil}, 80, "S:+R", false]], 63=>[[{54=>:enemy}, 54, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{72=>:enemy}, 72, "S:+R", true], [{73=>:enemy}, 73, "S:+R", true], [{54=>nil}, 54, "S:+R", false], [{54=>nil, 45=>:enemy}, 45, "S:+R", true], [{54=>nil, 45=>nil}, 45, "S:+R", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{64=>nil, 65=>:enemy}, 65, "S:+R", true], [{64=>nil, 65=>nil}, 65, "S:+R", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "S:+R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "S:+R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "S:+R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:+R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:+R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{72=>nil}, 72, "S:+R", false], [{73=>nil}, 73, "S:+R", false]], 64=>[[{54=>:enemy}, 54, "S:+R", true], [{55=>:enemy}, 55, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{63=>:enemy}, 63, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{72=>:enemy}, 72, "S:+R", true], [{73=>:enemy}, 73, "S:+R", true], [{74=>:enemy}, 74, "S:+R", true], [{54=>nil}, 54, "S:+R", false], [{55=>nil}, 55, "S:+R", false], [{55=>nil, 46=>:enemy}, 46, "S:+R", true], [{55=>nil, 46=>nil}, 46, "S:+R", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{63=>nil}, 63, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{65=>nil, 66=>:enemy}, 66, "S:+R", true], [{65=>nil, 66=>nil}, 66, "S:+R", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "S:+R", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "S:+R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "S:+R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "S:+R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:+R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:+R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:+R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:+R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{72=>nil}, 72, "S:+R", false], [{73=>nil}, 73, "S:+R", false], [{74=>nil}, 74, "S:+R", false]], 65=>[[{55=>:enemy}, 55, "S:+R", true], [{56=>:enemy}, 56, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{73=>:enemy}, 73, "S:+R", true], [{74=>:enemy}, 74, "S:+R", true], [{75=>:enemy}, 75, "S:+R", true], [{55=>nil}, 55, "S:+R", false], [{56=>nil}, 56, "S:+R", false], [{56=>nil, 47=>:enemy}, 47, "S:+R", true], [{56=>nil, 47=>nil}, 47, "S:+R", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{64=>nil, 63=>:enemy}, 63, "S:+R", true], [{64=>nil, 63=>nil}, 63, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{66=>nil, 67=>:enemy}, 67, "S:+R", true], [{66=>nil, 67=>nil}, 67, "S:+R", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "S:+R", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "S:+R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:+R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:+R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:+R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:+R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{73=>nil}, 73, "S:+R", false], [{74=>nil}, 74, "S:+R", false], [{75=>nil}, 75, "S:+R", false]], 66=>[[{56=>:enemy}, 56, "S:+R", true], [{57=>:enemy}, 57, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{74=>:enemy}, 74, "S:+R", true], [{75=>:enemy}, 75, "S:+R", true], [{76=>:enemy}, 76, "S:+R", true], [{56=>nil}, 56, "S:+R", false], [{57=>nil}, 57, "S:+R", false], [{57=>nil, 48=>:enemy}, 48, "S:+R", true], [{57=>nil, 48=>nil}, 48, "S:+R", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{65=>nil, 64=>:enemy}, 64, "S:+R", true], [{65=>nil, 64=>nil}, 64, "S:+R", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{67=>nil, 68=>:enemy}, 68, "S:+R", true], [{67=>nil, 68=>nil}, 68, "S:+R", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "S:+R", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "S:+R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:+R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:+R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{74=>nil}, 74, "S:+R", false], [{75=>nil}, 75, "S:+R", false], [{76=>nil}, 76, "S:+R", false]], 67=>[[{57=>:enemy}, 57, "S:+R", true], [{58=>:enemy}, 58, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{75=>:enemy}, 75, "S:+R", true], [{76=>:enemy}, 76, "S:+R", true], [{77=>:enemy}, 77, "S:+R", true], [{57=>nil}, 57, "S:+R", false], [{58=>nil}, 58, "S:+R", false], [{58=>nil, 49=>:enemy}, 49, "S:+R", true], [{58=>nil, 49=>nil}, 49, "S:+R", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{66=>nil, 65=>:enemy}, 65, "S:+R", true], [{66=>nil, 65=>nil}, 65, "S:+R", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "S:+R", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "S:+R", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{68=>nil, 69=>:enemy}, 69, "S:+R", true], [{68=>nil, 69=>nil}, 69, "S:+R", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "S:+R", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "S:+R", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{75=>nil}, 75, "S:+R", false], [{76=>nil}, 76, "S:+R", false], [{77=>nil}, 77, "S:+R", false]], 68=>[[{58=>:enemy}, 58, "S:+R", true], [{59=>:enemy}, 59, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{76=>:enemy}, 76, "S:+R", true], [{77=>:enemy}, 77, "S:+R", true], [{78=>:enemy}, 78, "S:+R", true], [{58=>nil}, 58, "S:+R", false], [{59=>nil}, 59, "S:+R", false], [{59=>nil, 50=>:enemy}, 50, "S:+R", true], [{59=>nil, 50=>nil}, 50, "S:+R", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{67=>nil, 66=>:enemy}, 66, "S:+R", true], [{67=>nil, 66=>nil}, 66, "S:+R", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "S:+R", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "S:+R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:+R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:+R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{69=>nil, 70=>:enemy}, 70, "S:+R", true], [{69=>nil, 70=>nil}, 70, "S:+R", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "S:+R", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "S:+R", false], [{76=>nil}, 76, "S:+R", false], [{77=>nil}, 77, "S:+R", false], [{78=>nil}, 78, "S:+R", false]], 69=>[[{59=>:enemy}, 59, "S:+R", true], [{60=>:enemy}, 60, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{77=>:enemy}, 77, "S:+R", true], [{78=>:enemy}, 78, "S:+R", true], [{79=>:enemy}, 79, "S:+R", true], [{59=>nil}, 59, "S:+R", false], [{60=>nil}, 60, "S:+R", false], [{60=>nil, 51=>:enemy}, 51, "S:+R", true], [{60=>nil, 51=>nil}, 51, "S:+R", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{68=>nil, 67=>:enemy}, 67, "S:+R", true], [{68=>nil, 67=>nil}, 67, "S:+R", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "S:+R", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "S:+R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:+R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:+R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:+R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:+R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{70=>nil, 71=>:enemy}, 71, "S:+R", true], [{70=>nil, 71=>nil}, 71, "S:+R", false], [{77=>nil}, 77, "S:+R", false], [{78=>nil}, 78, "S:+R", false], [{79=>nil}, 79, "S:+R", false]], 70=>[[{60=>:enemy}, 60, "S:+R", true], [{61=>:enemy}, 61, "S:+R", true], [{62=>:enemy}, 62, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{71=>:enemy}, 71, "S:+R", true], [{78=>:enemy}, 78, "S:+R", true], [{79=>:enemy}, 79, "S:+R", true], [{80=>:enemy}, 80, "S:+R", true], [{60=>nil}, 60, "S:+R", false], [{61=>nil}, 61, "S:+R", false], [{61=>nil, 52=>:enemy}, 52, "S:+R", true], [{61=>nil, 52=>nil}, 52, "S:+R", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{62=>nil}, 62, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{69=>nil, 68=>:enemy}, 68, "S:+R", true], [{69=>nil, 68=>nil}, 68, "S:+R", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "S:+R", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "S:+R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "S:+R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "S:+R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:+R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:+R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:+R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:+R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{71=>nil}, 71, "S:+R", false], [{78=>nil}, 78, "S:+R", false], [{79=>nil}, 79, "S:+R", false], [{80=>nil}, 80, "S:+R", false]], 71=>[[{61=>:enemy}, 61, "S:+R", true], [{62=>:enemy}, 62, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{79=>:enemy}, 79, "S:+R", true], [{80=>:enemy}, 80, "S:+R", true], [{61=>nil}, 61, "S:+R", false], [{62=>nil}, 62, "S:+R", false], [{62=>nil, 53=>:enemy}, 53, "S:+R", true], [{62=>nil, 53=>nil}, 53, "S:+R", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{70=>nil, 69=>:enemy}, 69, "S:+R", true], [{70=>nil, 69=>nil}, 69, "S:+R", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "S:+R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "S:+R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "S:+R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:+R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:+R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:+R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:+R", false], [{79=>nil}, 79, "S:+R", false], [{80=>nil}, 80, "S:+R", false]], 72=>[[{63=>:enemy}, 63, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{73=>:enemy}, 73, "S:+R", true], [{63=>nil}, 63, "S:+R", false], [{63=>nil, 54=>:enemy}, 54, "S:+R", true], [{63=>nil, 54=>nil}, 54, "S:+R", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{73=>nil}, 73, "S:+R", false], [{73=>nil, 74=>:enemy}, 74, "S:+R", true], [{73=>nil, 74=>nil}, 74, "S:+R", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "S:+R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "S:+R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "S:+R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:+R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:+R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 73=>[[{63=>:enemy}, 63, "S:+R", true], [{64=>:enemy}, 64, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{72=>:enemy}, 72, "S:+R", true], [{74=>:enemy}, 74, "S:+R", true], [{63=>nil}, 63, "S:+R", false], [{64=>nil}, 64, "S:+R", false], [{64=>nil, 55=>:enemy}, 55, "S:+R", true], [{64=>nil, 55=>nil}, 55, "S:+R", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{72=>nil}, 72, "S:+R", false], [{74=>nil}, 74, "S:+R", false], [{74=>nil, 75=>:enemy}, 75, "S:+R", true], [{74=>nil, 75=>nil}, 75, "S:+R", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "S:+R", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "S:+R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "S:+R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "S:+R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:+R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:+R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:+R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:+R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 74=>[[{64=>:enemy}, 64, "S:+R", true], [{65=>:enemy}, 65, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{73=>:enemy}, 73, "S:+R", true], [{75=>:enemy}, 75, "S:+R", true], [{64=>nil}, 64, "S:+R", false], [{65=>nil}, 65, "S:+R", false], [{65=>nil, 56=>:enemy}, 56, "S:+R", true], [{65=>nil, 56=>nil}, 56, "S:+R", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{73=>nil}, 73, "S:+R", false], [{73=>nil, 72=>:enemy}, 72, "S:+R", true], [{73=>nil, 72=>nil}, 72, "S:+R", false], [{75=>nil}, 75, "S:+R", false], [{75=>nil, 76=>:enemy}, 76, "S:+R", true], [{75=>nil, 76=>nil}, 76, "S:+R", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "S:+R", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "S:+R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:+R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:+R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:+R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:+R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 75=>[[{65=>:enemy}, 65, "S:+R", true], [{66=>:enemy}, 66, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{74=>:enemy}, 74, "S:+R", true], [{76=>:enemy}, 76, "S:+R", true], [{65=>nil}, 65, "S:+R", false], [{66=>nil}, 66, "S:+R", false], [{66=>nil, 57=>:enemy}, 57, "S:+R", true], [{66=>nil, 57=>nil}, 57, "S:+R", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{74=>nil}, 74, "S:+R", false], [{74=>nil, 73=>:enemy}, 73, "S:+R", true], [{74=>nil, 73=>nil}, 73, "S:+R", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false], [{76=>nil}, 76, "S:+R", false], [{76=>nil, 77=>:enemy}, 77, "S:+R", true], [{76=>nil, 77=>nil}, 77, "S:+R", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "S:+R", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "S:+R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:+R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:+R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 76=>[[{66=>:enemy}, 66, "S:+R", true], [{67=>:enemy}, 67, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{75=>:enemy}, 75, "S:+R", true], [{77=>:enemy}, 77, "S:+R", true], [{66=>nil}, 66, "S:+R", false], [{67=>nil}, 67, "S:+R", false], [{67=>nil, 58=>:enemy}, 58, "S:+R", true], [{67=>nil, 58=>nil}, 58, "S:+R", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{75=>nil}, 75, "S:+R", false], [{75=>nil, 74=>:enemy}, 74, "S:+R", true], [{75=>nil, 74=>nil}, 74, "S:+R", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "S:+R", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "S:+R", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false], [{77=>nil}, 77, "S:+R", false], [{77=>nil, 78=>:enemy}, 78, "S:+R", true], [{77=>nil, 78=>nil}, 78, "S:+R", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "S:+R", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "S:+R", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 77=>[[{67=>:enemy}, 67, "S:+R", true], [{68=>:enemy}, 68, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{76=>:enemy}, 76, "S:+R", true], [{78=>:enemy}, 78, "S:+R", true], [{67=>nil}, 67, "S:+R", false], [{68=>nil}, 68, "S:+R", false], [{68=>nil, 59=>:enemy}, 59, "S:+R", true], [{68=>nil, 59=>nil}, 59, "S:+R", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{76=>nil}, 76, "S:+R", false], [{76=>nil, 75=>:enemy}, 75, "S:+R", true], [{76=>nil, 75=>nil}, 75, "S:+R", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "S:+R", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "S:+R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:+R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:+R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false], [{78=>nil}, 78, "S:+R", false], [{78=>nil, 79=>:enemy}, 79, "S:+R", true], [{78=>nil, 79=>nil}, 79, "S:+R", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "S:+R", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "S:+R", false]], 78=>[[{68=>:enemy}, 68, "S:+R", true], [{69=>:enemy}, 69, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{77=>:enemy}, 77, "S:+R", true], [{79=>:enemy}, 79, "S:+R", true], [{68=>nil}, 68, "S:+R", false], [{69=>nil}, 69, "S:+R", false], [{69=>nil, 60=>:enemy}, 60, "S:+R", true], [{69=>nil, 60=>nil}, 60, "S:+R", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{77=>nil}, 77, "S:+R", false], [{77=>nil, 76=>:enemy}, 76, "S:+R", true], [{77=>nil, 76=>nil}, 76, "S:+R", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "S:+R", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "S:+R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:+R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:+R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:+R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:+R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false], [{79=>nil}, 79, "S:+R", false], [{79=>nil, 80=>:enemy}, 80, "S:+R", true], [{79=>nil, 80=>nil}, 80, "S:+R", false]], 79=>[[{69=>:enemy}, 69, "S:+R", true], [{70=>:enemy}, 70, "S:+R", true], [{71=>:enemy}, 71, "S:+R", true], [{78=>:enemy}, 78, "S:+R", true], [{80=>:enemy}, 80, "S:+R", true], [{69=>nil}, 69, "S:+R", false], [{70=>nil}, 70, "S:+R", false], [{70=>nil, 61=>:enemy}, 61, "S:+R", true], [{70=>nil, 61=>nil}, 61, "S:+R", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{71=>nil}, 71, "S:+R", false], [{78=>nil}, 78, "S:+R", false], [{78=>nil, 77=>:enemy}, 77, "S:+R", true], [{78=>nil, 77=>nil}, 77, "S:+R", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "S:+R", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "S:+R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "S:+R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "S:+R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:+R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:+R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:+R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:+R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false], [{80=>nil}, 80, "S:+R", false]], 80=>[[{70=>:enemy}, 70, "S:+R", true], [{71=>:enemy}, 71, "S:+R", true], [{79=>:enemy}, 79, "S:+R", true], [{70=>nil}, 70, "S:+R", false], [{71=>nil}, 71, "S:+R", false], [{71=>nil, 62=>:enemy}, 62, "S:+R", true], [{71=>nil, 62=>nil}, 62, "S:+R", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{79=>nil}, 79, "S:+R", false], [{79=>nil, 78=>:enemy}, 78, "S:+R", true], [{79=>nil, 78=>nil}, 78, "S:+R", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "S:+R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "S:+R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "S:+R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:+R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:+R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:+R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:+R", false]], nil=>[]}, "S:+S"=>{0=>[[{1=>:enemy}, 1, "S:+S", true], [{9=>:enemy}, 9, "S:+S", true], [{1=>nil}, 1, "S:+S", false], [{9=>nil}, 9, "S:+S", false]], 1=>[[{0=>:enemy}, 0, "S:+S", true], [{2=>:enemy}, 2, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{0=>nil}, 0, "S:+S", false], [{2=>nil}, 2, "S:+S", false], [{10=>nil}, 10, "S:+S", false]], 2=>[[{1=>:enemy}, 1, "S:+S", true], [{3=>:enemy}, 3, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{1=>nil}, 1, "S:+S", false], [{3=>nil}, 3, "S:+S", false], [{11=>nil}, 11, "S:+S", false]], 3=>[[{2=>:enemy}, 2, "S:+S", true], [{4=>:enemy}, 4, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{2=>nil}, 2, "S:+S", false], [{4=>nil}, 4, "S:+S", false], [{12=>nil}, 12, "S:+S", false]], 4=>[[{3=>:enemy}, 3, "S:+S", true], [{5=>:enemy}, 5, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{3=>nil}, 3, "S:+S", false], [{5=>nil}, 5, "S:+S", false], [{13=>nil}, 13, "S:+S", false]], 5=>[[{4=>:enemy}, 4, "S:+S", true], [{6=>:enemy}, 6, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{4=>nil}, 4, "S:+S", false], [{6=>nil}, 6, "S:+S", false], [{14=>nil}, 14, "S:+S", false]], 6=>[[{5=>:enemy}, 5, "S:+S", true], [{7=>:enemy}, 7, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{5=>nil}, 5, "S:+S", false], [{7=>nil}, 7, "S:+S", false], [{15=>nil}, 15, "S:+S", false]], 7=>[[{6=>:enemy}, 6, "S:+S", true], [{8=>:enemy}, 8, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{6=>nil}, 6, "S:+S", false], [{8=>nil}, 8, "S:+S", false], [{16=>nil}, 16, "S:+S", false]], 8=>[[{7=>:enemy}, 7, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{7=>nil}, 7, "S:+S", false], [{17=>nil}, 17, "S:+S", false]], 9=>[[{0=>:enemy}, 0, "S:+S", true], [{1=>:enemy}, 1, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{18=>:enemy}, 18, "S:+S", true], [{0=>nil}, 0, "S:+S", false], [{1=>nil}, 1, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{18=>nil}, 18, "S:+S", false]], 10=>[[{0=>:enemy}, 0, "S:+S", true], [{1=>:enemy}, 1, "S:+S", true], [{2=>:enemy}, 2, "S:+S", true], [{9=>:enemy}, 9, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{0=>nil}, 0, "S:+S", false], [{1=>nil}, 1, "S:+S", false], [{2=>nil}, 2, "S:+S", false], [{9=>nil}, 9, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{19=>nil}, 19, "S:+S", false]], 11=>[[{1=>:enemy}, 1, "S:+S", true], [{2=>:enemy}, 2, "S:+S", true], [{3=>:enemy}, 3, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{1=>nil}, 1, "S:+S", false], [{2=>nil}, 2, "S:+S", false], [{3=>nil}, 3, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{20=>nil}, 20, "S:+S", false]], 12=>[[{2=>:enemy}, 2, "S:+S", true], [{3=>:enemy}, 3, "S:+S", true], [{4=>:enemy}, 4, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{2=>nil}, 2, "S:+S", false], [{3=>nil}, 3, "S:+S", false], [{4=>nil}, 4, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{21=>nil}, 21, "S:+S", false]], 13=>[[{3=>:enemy}, 3, "S:+S", true], [{4=>:enemy}, 4, "S:+S", true], [{5=>:enemy}, 5, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{3=>nil}, 3, "S:+S", false], [{4=>nil}, 4, "S:+S", false], [{5=>nil}, 5, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{22=>nil}, 22, "S:+S", false]], 14=>[[{4=>:enemy}, 4, "S:+S", true], [{5=>:enemy}, 5, "S:+S", true], [{6=>:enemy}, 6, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{4=>nil}, 4, "S:+S", false], [{5=>nil}, 5, "S:+S", false], [{6=>nil}, 6, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{23=>nil}, 23, "S:+S", false]], 15=>[[{5=>:enemy}, 5, "S:+S", true], [{6=>:enemy}, 6, "S:+S", true], [{7=>:enemy}, 7, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{5=>nil}, 5, "S:+S", false], [{6=>nil}, 6, "S:+S", false], [{7=>nil}, 7, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{24=>nil}, 24, "S:+S", false]], 16=>[[{6=>:enemy}, 6, "S:+S", true], [{7=>:enemy}, 7, "S:+S", true], [{8=>:enemy}, 8, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{6=>nil}, 6, "S:+S", false], [{7=>nil}, 7, "S:+S", false], [{8=>nil}, 8, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{17=>nil}, 17, "S:+S", false], [{25=>nil}, 25, "S:+S", false]], 17=>[[{7=>:enemy}, 7, "S:+S", true], [{8=>:enemy}, 8, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{7=>nil}, 7, "S:+S", false], [{8=>nil}, 8, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{26=>nil}, 26, "S:+S", false]], 18=>[[{9=>:enemy}, 9, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{27=>:enemy}, 27, "S:+S", true], [{9=>nil}, 9, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{27=>nil}, 27, "S:+S", false]], 19=>[[{9=>:enemy}, 9, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{18=>:enemy}, 18, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{9=>nil}, 9, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{18=>nil}, 18, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{28=>nil}, 28, "S:+S", false]], 20=>[[{10=>:enemy}, 10, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{10=>nil}, 10, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{29=>nil}, 29, "S:+S", false]], 21=>[[{11=>:enemy}, 11, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{11=>nil}, 11, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{30=>nil}, 30, "S:+S", false]], 22=>[[{12=>:enemy}, 12, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{12=>nil}, 12, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{31=>nil}, 31, "S:+S", false]], 23=>[[{13=>:enemy}, 13, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{13=>nil}, 13, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{32=>nil}, 32, "S:+S", false]], 24=>[[{14=>:enemy}, 14, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{14=>nil}, 14, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{33=>nil}, 33, "S:+S", false]], 25=>[[{15=>:enemy}, 15, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{15=>nil}, 15, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{17=>nil}, 17, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{26=>nil}, 26, "S:+S", false], [{34=>nil}, 34, "S:+S", false]], 26=>[[{16=>:enemy}, 16, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{35=>:enemy}, 35, "S:+S", true], [{16=>nil}, 16, "S:+S", false], [{17=>nil}, 17, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{35=>nil}, 35, "S:+S", false]], 27=>[[{18=>:enemy}, 18, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{36=>:enemy}, 36, "S:+S", true], [{18=>nil}, 18, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{28=>nil}, 28, "S:+S", false], [{36=>nil}, 36, "S:+S", false]], 28=>[[{18=>:enemy}, 18, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{27=>:enemy}, 27, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{37=>:enemy}, 37, "S:+S", true], [{18=>nil}, 18, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{27=>nil}, 27, "S:+S", false], [{29=>nil}, 29, "S:+S", false], [{37=>nil}, 37, "S:+S", false]], 29=>[[{19=>:enemy}, 19, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{38=>:enemy}, 38, "S:+S", true], [{19=>nil}, 19, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{28=>nil}, 28, "S:+S", false], [{30=>nil}, 30, "S:+S", false], [{38=>nil}, 38, "S:+S", false]], 30=>[[{20=>:enemy}, 20, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{39=>:enemy}, 39, "S:+S", true], [{20=>nil}, 20, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{29=>nil}, 29, "S:+S", false], [{31=>nil}, 31, "S:+S", false], [{39=>nil}, 39, "S:+S", false]], 31=>[[{21=>:enemy}, 21, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{40=>:enemy}, 40, "S:+S", true], [{21=>nil}, 21, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{30=>nil}, 30, "S:+S", false], [{32=>nil}, 32, "S:+S", false], [{40=>nil}, 40, "S:+S", false]], 32=>[[{22=>:enemy}, 22, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{41=>:enemy}, 41, "S:+S", true], [{22=>nil}, 22, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{31=>nil}, 31, "S:+S", false], [{33=>nil}, 33, "S:+S", false], [{41=>nil}, 41, "S:+S", false]], 33=>[[{23=>:enemy}, 23, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{42=>:enemy}, 42, "S:+S", true], [{23=>nil}, 23, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{32=>nil}, 32, "S:+S", false], [{34=>nil}, 34, "S:+S", false], [{42=>nil}, 42, "S:+S", false]], 34=>[[{24=>:enemy}, 24, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{35=>:enemy}, 35, "S:+S", true], [{43=>:enemy}, 43, "S:+S", true], [{24=>nil}, 24, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{26=>nil}, 26, "S:+S", false], [{33=>nil}, 33, "S:+S", false], [{35=>nil}, 35, "S:+S", false], [{43=>nil}, 43, "S:+S", false]], 35=>[[{25=>:enemy}, 25, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{44=>:enemy}, 44, "S:+S", true], [{25=>nil}, 25, "S:+S", false], [{26=>nil}, 26, "S:+S", false], [{34=>nil}, 34, "S:+S", false], [{44=>nil}, 44, "S:+S", false]], 36=>[[{27=>:enemy}, 27, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{37=>:enemy}, 37, "S:+S", true], [{45=>:enemy}, 45, "S:+S", true], [{27=>nil}, 27, "S:+S", false], [{28=>nil}, 28, "S:+S", false], [{37=>nil}, 37, "S:+S", false], [{45=>nil}, 45, "S:+S", false]], 37=>[[{27=>:enemy}, 27, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{36=>:enemy}, 36, "S:+S", true], [{38=>:enemy}, 38, "S:+S", true], [{46=>:enemy}, 46, "S:+S", true], [{27=>nil}, 27, "S:+S", false], [{28=>nil}, 28, "S:+S", false], [{29=>nil}, 29, "S:+S", false], [{36=>nil}, 36, "S:+S", false], [{38=>nil}, 38, "S:+S", false], [{46=>nil}, 46, "S:+S", false]], 38=>[[{28=>:enemy}, 28, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{37=>:enemy}, 37, "S:+S", true], [{39=>:enemy}, 39, "S:+S", true], [{47=>:enemy}, 47, "S:+S", true], [{28=>nil}, 28, "S:+S", false], [{29=>nil}, 29, "S:+S", false], [{30=>nil}, 30, "S:+S", false], [{37=>nil}, 37, "S:+S", false], [{39=>nil}, 39, "S:+S", false], [{47=>nil}, 47, "S:+S", false]], 39=>[[{29=>:enemy}, 29, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{38=>:enemy}, 38, "S:+S", true], [{40=>:enemy}, 40, "S:+S", true], [{48=>:enemy}, 48, "S:+S", true], [{29=>nil}, 29, "S:+S", false], [{30=>nil}, 30, "S:+S", false], [{31=>nil}, 31, "S:+S", false], [{38=>nil}, 38, "S:+S", false], [{40=>nil}, 40, "S:+S", false], [{48=>nil}, 48, "S:+S", false]], 40=>[[{30=>:enemy}, 30, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{39=>:enemy}, 39, "S:+S", true], [{41=>:enemy}, 41, "S:+S", true], [{49=>:enemy}, 49, "S:+S", true], [{30=>nil}, 30, "S:+S", false], [{31=>nil}, 31, "S:+S", false], [{32=>nil}, 32, "S:+S", false], [{39=>nil}, 39, "S:+S", false], [{41=>nil}, 41, "S:+S", false], [{49=>nil}, 49, "S:+S", false]], 41=>[[{31=>:enemy}, 31, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{40=>:enemy}, 40, "S:+S", true], [{42=>:enemy}, 42, "S:+S", true], [{50=>:enemy}, 50, "S:+S", true], [{31=>nil}, 31, "S:+S", false], [{32=>nil}, 32, "S:+S", false], [{33=>nil}, 33, "S:+S", false], [{40=>nil}, 40, "S:+S", false], [{42=>nil}, 42, "S:+S", false], [{50=>nil}, 50, "S:+S", false]], 42=>[[{32=>:enemy}, 32, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{41=>:enemy}, 41, "S:+S", true], [{43=>:enemy}, 43, "S:+S", true], [{51=>:enemy}, 51, "S:+S", true], [{32=>nil}, 32, "S:+S", false], [{33=>nil}, 33, "S:+S", false], [{34=>nil}, 34, "S:+S", false], [{41=>nil}, 41, "S:+S", false], [{43=>nil}, 43, "S:+S", false], [{51=>nil}, 51, "S:+S", false]], 43=>[[{33=>:enemy}, 33, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{35=>:enemy}, 35, "S:+S", true], [{42=>:enemy}, 42, "S:+S", true], [{44=>:enemy}, 44, "S:+S", true], [{52=>:enemy}, 52, "S:+S", true], [{33=>nil}, 33, "S:+S", false], [{34=>nil}, 34, "S:+S", false], [{35=>nil}, 35, "S:+S", false], [{42=>nil}, 42, "S:+S", false], [{44=>nil}, 44, "S:+S", false], [{52=>nil}, 52, "S:+S", false]], 44=>[[{34=>:enemy}, 34, "S:+S", true], [{35=>:enemy}, 35, "S:+S", true], [{43=>:enemy}, 43, "S:+S", true], [{53=>:enemy}, 53, "S:+S", true], [{34=>nil}, 34, "S:+S", false], [{35=>nil}, 35, "S:+S", false], [{43=>nil}, 43, "S:+S", false], [{53=>nil}, 53, "S:+S", false]], 45=>[[{36=>:enemy}, 36, "S:+S", true], [{37=>:enemy}, 37, "S:+S", true], [{46=>:enemy}, 46, "S:+S", true], [{54=>:enemy}, 54, "S:+S", true], [{36=>nil}, 36, "S:+S", false], [{37=>nil}, 37, "S:+S", false], [{46=>nil}, 46, "S:+S", false], [{54=>nil}, 54, "S:+S", false]], 46=>[[{36=>:enemy}, 36, "S:+S", true], [{37=>:enemy}, 37, "S:+S", true], [{38=>:enemy}, 38, "S:+S", true], [{45=>:enemy}, 45, "S:+S", true], [{47=>:enemy}, 47, "S:+S", true], [{55=>:enemy}, 55, "S:+S", true], [{36=>nil}, 36, "S:+S", false], [{37=>nil}, 37, "S:+S", false], [{38=>nil}, 38, "S:+S", false], [{45=>nil}, 45, "S:+S", false], [{47=>nil}, 47, "S:+S", false], [{55=>nil}, 55, "S:+S", false]], 47=>[[{37=>:enemy}, 37, "S:+S", true], [{38=>:enemy}, 38, "S:+S", true], [{39=>:enemy}, 39, "S:+S", true], [{46=>:enemy}, 46, "S:+S", true], [{48=>:enemy}, 48, "S:+S", true], [{56=>:enemy}, 56, "S:+S", true], [{37=>nil}, 37, "S:+S", false], [{38=>nil}, 38, "S:+S", false], [{39=>nil}, 39, "S:+S", false], [{46=>nil}, 46, "S:+S", false], [{48=>nil}, 48, "S:+S", false], [{56=>nil}, 56, "S:+S", false]], 48=>[[{38=>:enemy}, 38, "S:+S", true], [{39=>:enemy}, 39, "S:+S", true], [{40=>:enemy}, 40, "S:+S", true], [{47=>:enemy}, 47, "S:+S", true], [{49=>:enemy}, 49, "S:+S", true], [{57=>:enemy}, 57, "S:+S", true], [{38=>nil}, 38, "S:+S", false], [{39=>nil}, 39, "S:+S", false], [{40=>nil}, 40, "S:+S", false], [{47=>nil}, 47, "S:+S", false], [{49=>nil}, 49, "S:+S", false], [{57=>nil}, 57, "S:+S", false]], 49=>[[{39=>:enemy}, 39, "S:+S", true], [{40=>:enemy}, 40, "S:+S", true], [{41=>:enemy}, 41, "S:+S", true], [{48=>:enemy}, 48, "S:+S", true], [{50=>:enemy}, 50, "S:+S", true], [{58=>:enemy}, 58, "S:+S", true], [{39=>nil}, 39, "S:+S", false], [{40=>nil}, 40, "S:+S", false], [{41=>nil}, 41, "S:+S", false], [{48=>nil}, 48, "S:+S", false], [{50=>nil}, 50, "S:+S", false], [{58=>nil}, 58, "S:+S", false]], 50=>[[{40=>:enemy}, 40, "S:+S", true], [{41=>:enemy}, 41, "S:+S", true], [{42=>:enemy}, 42, "S:+S", true], [{49=>:enemy}, 49, "S:+S", true], [{51=>:enemy}, 51, "S:+S", true], [{59=>:enemy}, 59, "S:+S", true], [{40=>nil}, 40, "S:+S", false], [{41=>nil}, 41, "S:+S", false], [{42=>nil}, 42, "S:+S", false], [{49=>nil}, 49, "S:+S", false], [{51=>nil}, 51, "S:+S", false], [{59=>nil}, 59, "S:+S", false]], 51=>[[{41=>:enemy}, 41, "S:+S", true], [{42=>:enemy}, 42, "S:+S", true], [{43=>:enemy}, 43, "S:+S", true], [{50=>:enemy}, 50, "S:+S", true], [{52=>:enemy}, 52, "S:+S", true], [{60=>:enemy}, 60, "S:+S", true], [{41=>nil}, 41, "S:+S", false], [{42=>nil}, 42, "S:+S", false], [{43=>nil}, 43, "S:+S", false], [{50=>nil}, 50, "S:+S", false], [{52=>nil}, 52, "S:+S", false], [{60=>nil}, 60, "S:+S", false]], 52=>[[{42=>:enemy}, 42, "S:+S", true], [{43=>:enemy}, 43, "S:+S", true], [{44=>:enemy}, 44, "S:+S", true], [{51=>:enemy}, 51, "S:+S", true], [{53=>:enemy}, 53, "S:+S", true], [{61=>:enemy}, 61, "S:+S", true], [{42=>nil}, 42, "S:+S", false], [{43=>nil}, 43, "S:+S", false], [{44=>nil}, 44, "S:+S", false], [{51=>nil}, 51, "S:+S", false], [{53=>nil}, 53, "S:+S", false], [{61=>nil}, 61, "S:+S", false]], 53=>[[{43=>:enemy}, 43, "S:+S", true], [{44=>:enemy}, 44, "S:+S", true], [{52=>:enemy}, 52, "S:+S", true], [{62=>:enemy}, 62, "S:+S", true], [{43=>nil}, 43, "S:+S", false], [{44=>nil}, 44, "S:+S", false], [{52=>nil}, 52, "S:+S", false], [{62=>nil}, 62, "S:+S", false]], 54=>[[{45=>:enemy}, 45, "S:+S", true], [{46=>:enemy}, 46, "S:+S", true], [{55=>:enemy}, 55, "S:+S", true], [{63=>:enemy}, 63, "S:+S", true], [{45=>nil}, 45, "S:+S", false], [{46=>nil}, 46, "S:+S", false], [{55=>nil}, 55, "S:+S", false], [{63=>nil}, 63, "S:+S", false]], 55=>[[{45=>:enemy}, 45, "S:+S", true], [{46=>:enemy}, 46, "S:+S", true], [{47=>:enemy}, 47, "S:+S", true], [{54=>:enemy}, 54, "S:+S", true], [{56=>:enemy}, 56, "S:+S", true], [{64=>:enemy}, 64, "S:+S", true], [{45=>nil}, 45, "S:+S", false], [{46=>nil}, 46, "S:+S", false], [{47=>nil}, 47, "S:+S", false], [{54=>nil}, 54, "S:+S", false], [{56=>nil}, 56, "S:+S", false], [{64=>nil}, 64, "S:+S", false]], 56=>[[{46=>:enemy}, 46, "S:+S", true], [{47=>:enemy}, 47, "S:+S", true], [{48=>:enemy}, 48, "S:+S", true], [{55=>:enemy}, 55, "S:+S", true], [{57=>:enemy}, 57, "S:+S", true], [{65=>:enemy}, 65, "S:+S", true], [{46=>nil}, 46, "S:+S", false], [{47=>nil}, 47, "S:+S", false], [{48=>nil}, 48, "S:+S", false], [{55=>nil}, 55, "S:+S", false], [{57=>nil}, 57, "S:+S", false], [{65=>nil}, 65, "S:+S", false]], 57=>[[{47=>:enemy}, 47, "S:+S", true], [{48=>:enemy}, 48, "S:+S", true], [{49=>:enemy}, 49, "S:+S", true], [{56=>:enemy}, 56, "S:+S", true], [{58=>:enemy}, 58, "S:+S", true], [{66=>:enemy}, 66, "S:+S", true], [{47=>nil}, 47, "S:+S", false], [{48=>nil}, 48, "S:+S", false], [{49=>nil}, 49, "S:+S", false], [{56=>nil}, 56, "S:+S", false], [{58=>nil}, 58, "S:+S", false], [{66=>nil}, 66, "S:+S", false]], 58=>[[{48=>:enemy}, 48, "S:+S", true], [{49=>:enemy}, 49, "S:+S", true], [{50=>:enemy}, 50, "S:+S", true], [{57=>:enemy}, 57, "S:+S", true], [{59=>:enemy}, 59, "S:+S", true], [{67=>:enemy}, 67, "S:+S", true], [{48=>nil}, 48, "S:+S", false], [{49=>nil}, 49, "S:+S", false], [{50=>nil}, 50, "S:+S", false], [{57=>nil}, 57, "S:+S", false], [{59=>nil}, 59, "S:+S", false], [{67=>nil}, 67, "S:+S", false]], 59=>[[{49=>:enemy}, 49, "S:+S", true], [{50=>:enemy}, 50, "S:+S", true], [{51=>:enemy}, 51, "S:+S", true], [{58=>:enemy}, 58, "S:+S", true], [{60=>:enemy}, 60, "S:+S", true], [{68=>:enemy}, 68, "S:+S", true], [{49=>nil}, 49, "S:+S", false], [{50=>nil}, 50, "S:+S", false], [{51=>nil}, 51, "S:+S", false], [{58=>nil}, 58, "S:+S", false], [{60=>nil}, 60, "S:+S", false], [{68=>nil}, 68, "S:+S", false]], 60=>[[{50=>:enemy}, 50, "S:+S", true], [{51=>:enemy}, 51, "S:+S", true], [{52=>:enemy}, 52, "S:+S", true], [{59=>:enemy}, 59, "S:+S", true], [{61=>:enemy}, 61, "S:+S", true], [{69=>:enemy}, 69, "S:+S", true], [{50=>nil}, 50, "S:+S", false], [{51=>nil}, 51, "S:+S", false], [{52=>nil}, 52, "S:+S", false], [{59=>nil}, 59, "S:+S", false], [{61=>nil}, 61, "S:+S", false], [{69=>nil}, 69, "S:+S", false]], 61=>[[{51=>:enemy}, 51, "S:+S", true], [{52=>:enemy}, 52, "S:+S", true], [{53=>:enemy}, 53, "S:+S", true], [{60=>:enemy}, 60, "S:+S", true], [{62=>:enemy}, 62, "S:+S", true], [{70=>:enemy}, 70, "S:+S", true], [{51=>nil}, 51, "S:+S", false], [{52=>nil}, 52, "S:+S", false], [{53=>nil}, 53, "S:+S", false], [{60=>nil}, 60, "S:+S", false], [{62=>nil}, 62, "S:+S", false], [{70=>nil}, 70, "S:+S", false]], 62=>[[{52=>:enemy}, 52, "S:+S", true], [{53=>:enemy}, 53, "S:+S", true], [{61=>:enemy}, 61, "S:+S", true], [{71=>:enemy}, 71, "S:+S", true], [{52=>nil}, 52, "S:+S", false], [{53=>nil}, 53, "S:+S", false], [{61=>nil}, 61, "S:+S", false], [{71=>nil}, 71, "S:+S", false]], 63=>[[{54=>:enemy}, 54, "S:+S", true], [{55=>:enemy}, 55, "S:+S", true], [{64=>:enemy}, 64, "S:+S", true], [{72=>:enemy}, 72, "S:+S", true], [{54=>nil}, 54, "S:+S", false], [{55=>nil}, 55, "S:+S", false], [{64=>nil}, 64, "S:+S", false], [{72=>nil}, 72, "S:+S", false]], 64=>[[{54=>:enemy}, 54, "S:+S", true], [{55=>:enemy}, 55, "S:+S", true], [{56=>:enemy}, 56, "S:+S", true], [{63=>:enemy}, 63, "S:+S", true], [{65=>:enemy}, 65, "S:+S", true], [{73=>:enemy}, 73, "S:+S", true], [{54=>nil}, 54, "S:+S", false], [{55=>nil}, 55, "S:+S", false], [{56=>nil}, 56, "S:+S", false], [{63=>nil}, 63, "S:+S", false], [{65=>nil}, 65, "S:+S", false], [{73=>nil}, 73, "S:+S", false]], 65=>[[{55=>:enemy}, 55, "S:+S", true], [{56=>:enemy}, 56, "S:+S", true], [{57=>:enemy}, 57, "S:+S", true], [{64=>:enemy}, 64, "S:+S", true], [{66=>:enemy}, 66, "S:+S", true], [{74=>:enemy}, 74, "S:+S", true], [{55=>nil}, 55, "S:+S", false], [{56=>nil}, 56, "S:+S", false], [{57=>nil}, 57, "S:+S", false], [{64=>nil}, 64, "S:+S", false], [{66=>nil}, 66, "S:+S", false], [{74=>nil}, 74, "S:+S", false]], 66=>[[{56=>:enemy}, 56, "S:+S", true], [{57=>:enemy}, 57, "S:+S", true], [{58=>:enemy}, 58, "S:+S", true], [{65=>:enemy}, 65, "S:+S", true], [{67=>:enemy}, 67, "S:+S", true], [{75=>:enemy}, 75, "S:+S", true], [{56=>nil}, 56, "S:+S", false], [{57=>nil}, 57, "S:+S", false], [{58=>nil}, 58, "S:+S", false], [{65=>nil}, 65, "S:+S", false], [{67=>nil}, 67, "S:+S", false], [{75=>nil}, 75, "S:+S", false]], 67=>[[{57=>:enemy}, 57, "S:+S", true], [{58=>:enemy}, 58, "S:+S", true], [{59=>:enemy}, 59, "S:+S", true], [{66=>:enemy}, 66, "S:+S", true], [{68=>:enemy}, 68, "S:+S", true], [{76=>:enemy}, 76, "S:+S", true], [{57=>nil}, 57, "S:+S", false], [{58=>nil}, 58, "S:+S", false], [{59=>nil}, 59, "S:+S", false], [{66=>nil}, 66, "S:+S", false], [{68=>nil}, 68, "S:+S", false], [{76=>nil}, 76, "S:+S", false]], 68=>[[{58=>:enemy}, 58, "S:+S", true], [{59=>:enemy}, 59, "S:+S", true], [{60=>:enemy}, 60, "S:+S", true], [{67=>:enemy}, 67, "S:+S", true], [{69=>:enemy}, 69, "S:+S", true], [{77=>:enemy}, 77, "S:+S", true], [{58=>nil}, 58, "S:+S", false], [{59=>nil}, 59, "S:+S", false], [{60=>nil}, 60, "S:+S", false], [{67=>nil}, 67, "S:+S", false], [{69=>nil}, 69, "S:+S", false], [{77=>nil}, 77, "S:+S", false]], 69=>[[{59=>:enemy}, 59, "S:+S", true], [{60=>:enemy}, 60, "S:+S", true], [{61=>:enemy}, 61, "S:+S", true], [{68=>:enemy}, 68, "S:+S", true], [{70=>:enemy}, 70, "S:+S", true], [{78=>:enemy}, 78, "S:+S", true], [{59=>nil}, 59, "S:+S", false], [{60=>nil}, 60, "S:+S", false], [{61=>nil}, 61, "S:+S", false], [{68=>nil}, 68, "S:+S", false], [{70=>nil}, 70, "S:+S", false], [{78=>nil}, 78, "S:+S", false]], 70=>[[{60=>:enemy}, 60, "S:+S", true], [{61=>:enemy}, 61, "S:+S", true], [{62=>:enemy}, 62, "S:+S", true], [{69=>:enemy}, 69, "S:+S", true], [{71=>:enemy}, 71, "S:+S", true], [{79=>:enemy}, 79, "S:+S", true], [{60=>nil}, 60, "S:+S", false], [{61=>nil}, 61, "S:+S", false], [{62=>nil}, 62, "S:+S", false], [{69=>nil}, 69, "S:+S", false], [{71=>nil}, 71, "S:+S", false], [{79=>nil}, 79, "S:+S", false]], 71=>[[{61=>:enemy}, 61, "S:+S", true], [{62=>:enemy}, 62, "S:+S", true], [{70=>:enemy}, 70, "S:+S", true], [{80=>:enemy}, 80, "S:+S", true], [{61=>nil}, 61, "S:+S", false], [{62=>nil}, 62, "S:+S", false], [{70=>nil}, 70, "S:+S", false], [{80=>nil}, 80, "S:+S", false]], 72=>[[{63=>:enemy}, 63, "S:+S", true], [{64=>:enemy}, 64, "S:+S", true], [{73=>:enemy}, 73, "S:+S", true], [{63=>nil}, 63, "S:+S", false], [{64=>nil}, 64, "S:+S", false], [{73=>nil}, 73, "S:+S", false]], 73=>[[{63=>:enemy}, 63, "S:+S", true], [{64=>:enemy}, 64, "S:+S", true], [{65=>:enemy}, 65, "S:+S", true], [{72=>:enemy}, 72, "S:+S", true], [{74=>:enemy}, 74, "S:+S", true], [{63=>nil}, 63, "S:+S", false], [{64=>nil}, 64, "S:+S", false], [{65=>nil}, 65, "S:+S", false], [{72=>nil}, 72, "S:+S", false], [{74=>nil}, 74, "S:+S", false]], 74=>[[{64=>:enemy}, 64, "S:+S", true], [{65=>:enemy}, 65, "S:+S", true], [{66=>:enemy}, 66, "S:+S", true], [{73=>:enemy}, 73, "S:+S", true], [{75=>:enemy}, 75, "S:+S", true], [{64=>nil}, 64, "S:+S", false], [{65=>nil}, 65, "S:+S", false], [{66=>nil}, 66, "S:+S", false], [{73=>nil}, 73, "S:+S", false], [{75=>nil}, 75, "S:+S", false]], 75=>[[{65=>:enemy}, 65, "S:+S", true], [{66=>:enemy}, 66, "S:+S", true], [{67=>:enemy}, 67, "S:+S", true], [{74=>:enemy}, 74, "S:+S", true], [{76=>:enemy}, 76, "S:+S", true], [{65=>nil}, 65, "S:+S", false], [{66=>nil}, 66, "S:+S", false], [{67=>nil}, 67, "S:+S", false], [{74=>nil}, 74, "S:+S", false], [{76=>nil}, 76, "S:+S", false]], 76=>[[{66=>:enemy}, 66, "S:+S", true], [{67=>:enemy}, 67, "S:+S", true], [{68=>:enemy}, 68, "S:+S", true], [{75=>:enemy}, 75, "S:+S", true], [{77=>:enemy}, 77, "S:+S", true], [{66=>nil}, 66, "S:+S", false], [{67=>nil}, 67, "S:+S", false], [{68=>nil}, 68, "S:+S", false], [{75=>nil}, 75, "S:+S", false], [{77=>nil}, 77, "S:+S", false]], 77=>[[{67=>:enemy}, 67, "S:+S", true], [{68=>:enemy}, 68, "S:+S", true], [{69=>:enemy}, 69, "S:+S", true], [{76=>:enemy}, 76, "S:+S", true], [{78=>:enemy}, 78, "S:+S", true], [{67=>nil}, 67, "S:+S", false], [{68=>nil}, 68, "S:+S", false], [{69=>nil}, 69, "S:+S", false], [{76=>nil}, 76, "S:+S", false], [{78=>nil}, 78, "S:+S", false]], 78=>[[{68=>:enemy}, 68, "S:+S", true], [{69=>:enemy}, 69, "S:+S", true], [{70=>:enemy}, 70, "S:+S", true], [{77=>:enemy}, 77, "S:+S", true], [{79=>:enemy}, 79, "S:+S", true], [{68=>nil}, 68, "S:+S", false], [{69=>nil}, 69, "S:+S", false], [{70=>nil}, 70, "S:+S", false], [{77=>nil}, 77, "S:+S", false], [{79=>nil}, 79, "S:+S", false]], 79=>[[{69=>:enemy}, 69, "S:+S", true], [{70=>:enemy}, 70, "S:+S", true], [{71=>:enemy}, 71, "S:+S", true], [{78=>:enemy}, 78, "S:+S", true], [{80=>:enemy}, 80, "S:+S", true], [{69=>nil}, 69, "S:+S", false], [{70=>nil}, 70, "S:+S", false], [{71=>nil}, 71, "S:+S", false], [{78=>nil}, 78, "S:+S", false], [{80=>nil}, 80, "S:+S", false]], 80=>[[{70=>:enemy}, 70, "S:+S", true], [{71=>:enemy}, 71, "S:+S", true], [{79=>:enemy}, 79, "S:+S", true], [{70=>nil}, 70, "S:+S", false], [{71=>nil}, 71, "S:+S", false], [{79=>nil}, 79, "S:+S", false]], nil=>[]}, "S:-K"=>{0=>[[{1=>:enemy}, 1, "S:-K", true], [{9=>:enemy}, 9, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{1=>nil}, 1, "S:-K", false], [{9=>nil}, 9, "S:-K", false], [{10=>nil}, 10, "S:-K", false]], 1=>[[{0=>:enemy}, 0, "S:-K", true], [{2=>:enemy}, 2, "S:-K", true], [{9=>:enemy}, 9, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{0=>nil}, 0, "S:-K", false], [{2=>nil}, 2, "S:-K", false], [{9=>nil}, 9, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{11=>nil}, 11, "S:-K", false]], 2=>[[{1=>:enemy}, 1, "S:-K", true], [{3=>:enemy}, 3, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{1=>nil}, 1, "S:-K", false], [{3=>nil}, 3, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{12=>nil}, 12, "S:-K", false]], 3=>[[{2=>:enemy}, 2, "S:-K", true], [{4=>:enemy}, 4, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{2=>nil}, 2, "S:-K", false], [{4=>nil}, 4, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{13=>nil}, 13, "S:-K", false]], 4=>[[{3=>:enemy}, 3, "S:-K", true], [{5=>:enemy}, 5, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{3=>nil}, 3, "S:-K", false], [{5=>nil}, 5, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{14=>nil}, 14, "S:-K", false]], 5=>[[{4=>:enemy}, 4, "S:-K", true], [{6=>:enemy}, 6, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{4=>nil}, 4, "S:-K", false], [{6=>nil}, 6, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{15=>nil}, 15, "S:-K", false]], 6=>[[{5=>:enemy}, 5, "S:-K", true], [{7=>:enemy}, 7, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{5=>nil}, 5, "S:-K", false], [{7=>nil}, 7, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{16=>nil}, 16, "S:-K", false]], 7=>[[{6=>:enemy}, 6, "S:-K", true], [{8=>:enemy}, 8, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{17=>:enemy}, 17, "S:-K", true], [{6=>nil}, 6, "S:-K", false], [{8=>nil}, 8, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{17=>nil}, 17, "S:-K", false]], 8=>[[{7=>:enemy}, 7, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{17=>:enemy}, 17, "S:-K", true], [{7=>nil}, 7, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{17=>nil}, 17, "S:-K", false]], 9=>[[{0=>:enemy}, 0, "S:-K", true], [{1=>:enemy}, 1, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{18=>:enemy}, 18, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{0=>nil}, 0, "S:-K", false], [{1=>nil}, 1, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{18=>nil}, 18, "S:-K", false], [{19=>nil}, 19, "S:-K", false]], 10=>[[{0=>:enemy}, 0, "S:-K", true], [{1=>:enemy}, 1, "S:-K", true], [{2=>:enemy}, 2, "S:-K", true], [{9=>:enemy}, 9, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{18=>:enemy}, 18, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{0=>nil}, 0, "S:-K", false], [{1=>nil}, 1, "S:-K", false], [{2=>nil}, 2, "S:-K", false], [{9=>nil}, 9, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{18=>nil}, 18, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{20=>nil}, 20, "S:-K", false]], 11=>[[{1=>:enemy}, 1, "S:-K", true], [{2=>:enemy}, 2, "S:-K", true], [{3=>:enemy}, 3, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{1=>nil}, 1, "S:-K", false], [{2=>nil}, 2, "S:-K", false], [{3=>nil}, 3, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{21=>nil}, 21, "S:-K", false]], 12=>[[{2=>:enemy}, 2, "S:-K", true], [{3=>:enemy}, 3, "S:-K", true], [{4=>:enemy}, 4, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{2=>nil}, 2, "S:-K", false], [{3=>nil}, 3, "S:-K", false], [{4=>nil}, 4, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{22=>nil}, 22, "S:-K", false]], 13=>[[{3=>:enemy}, 3, "S:-K", true], [{4=>:enemy}, 4, "S:-K", true], [{5=>:enemy}, 5, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{3=>nil}, 3, "S:-K", false], [{4=>nil}, 4, "S:-K", false], [{5=>nil}, 5, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{23=>nil}, 23, "S:-K", false]], 14=>[[{4=>:enemy}, 4, "S:-K", true], [{5=>:enemy}, 5, "S:-K", true], [{6=>:enemy}, 6, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{4=>nil}, 4, "S:-K", false], [{5=>nil}, 5, "S:-K", false], [{6=>nil}, 6, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{24=>nil}, 24, "S:-K", false]], 15=>[[{5=>:enemy}, 5, "S:-K", true], [{6=>:enemy}, 6, "S:-K", true], [{7=>:enemy}, 7, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{5=>nil}, 5, "S:-K", false], [{6=>nil}, 6, "S:-K", false], [{7=>nil}, 7, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{25=>nil}, 25, "S:-K", false]], 16=>[[{6=>:enemy}, 6, "S:-K", true], [{7=>:enemy}, 7, "S:-K", true], [{8=>:enemy}, 8, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{17=>:enemy}, 17, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{26=>:enemy}, 26, "S:-K", true], [{6=>nil}, 6, "S:-K", false], [{7=>nil}, 7, "S:-K", false], [{8=>nil}, 8, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{17=>nil}, 17, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{26=>nil}, 26, "S:-K", false]], 17=>[[{7=>:enemy}, 7, "S:-K", true], [{8=>:enemy}, 8, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{26=>:enemy}, 26, "S:-K", true], [{7=>nil}, 7, "S:-K", false], [{8=>nil}, 8, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{26=>nil}, 26, "S:-K", false]], 18=>[[{9=>:enemy}, 9, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{27=>:enemy}, 27, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{9=>nil}, 9, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{27=>nil}, 27, "S:-K", false], [{28=>nil}, 28, "S:-K", false]], 19=>[[{9=>:enemy}, 9, "S:-K", true], [{10=>:enemy}, 10, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{18=>:enemy}, 18, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{27=>:enemy}, 27, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{9=>nil}, 9, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{18=>nil}, 18, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{27=>nil}, 27, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{29=>nil}, 29, "S:-K", false]], 20=>[[{10=>:enemy}, 10, "S:-K", true], [{11=>:enemy}, 11, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{10=>nil}, 10, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{30=>nil}, 30, "S:-K", false]], 21=>[[{11=>:enemy}, 11, "S:-K", true], [{12=>:enemy}, 12, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{11=>nil}, 11, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{31=>nil}, 31, "S:-K", false]], 22=>[[{12=>:enemy}, 12, "S:-K", true], [{13=>:enemy}, 13, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{12=>nil}, 12, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{32=>nil}, 32, "S:-K", false]], 23=>[[{13=>:enemy}, 13, "S:-K", true], [{14=>:enemy}, 14, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{13=>nil}, 13, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{33=>nil}, 33, "S:-K", false]], 24=>[[{14=>:enemy}, 14, "S:-K", true], [{15=>:enemy}, 15, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{14=>nil}, 14, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{34=>nil}, 34, "S:-K", false]], 25=>[[{15=>:enemy}, 15, "S:-K", true], [{16=>:enemy}, 16, "S:-K", true], [{17=>:enemy}, 17, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{26=>:enemy}, 26, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{35=>:enemy}, 35, "S:-K", true], [{15=>nil}, 15, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{17=>nil}, 17, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{26=>nil}, 26, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{35=>nil}, 35, "S:-K", false]], 26=>[[{16=>:enemy}, 16, "S:-K", true], [{17=>:enemy}, 17, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{35=>:enemy}, 35, "S:-K", true], [{16=>nil}, 16, "S:-K", false], [{17=>nil}, 17, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{35=>nil}, 35, "S:-K", false]], 27=>[[{18=>:enemy}, 18, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{36=>:enemy}, 36, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{18=>nil}, 18, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{36=>nil}, 36, "S:-K", false], [{37=>nil}, 37, "S:-K", false]], 28=>[[{18=>:enemy}, 18, "S:-K", true], [{19=>:enemy}, 19, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{27=>:enemy}, 27, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{36=>:enemy}, 36, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{18=>nil}, 18, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{27=>nil}, 27, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{36=>nil}, 36, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{38=>nil}, 38, "S:-K", false]], 29=>[[{19=>:enemy}, 19, "S:-K", true], [{20=>:enemy}, 20, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{19=>nil}, 19, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{39=>nil}, 39, "S:-K", false]], 30=>[[{20=>:enemy}, 20, "S:-K", true], [{21=>:enemy}, 21, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{20=>nil}, 20, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{40=>nil}, 40, "S:-K", false]], 31=>[[{21=>:enemy}, 21, "S:-K", true], [{22=>:enemy}, 22, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{21=>nil}, 21, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{41=>nil}, 41, "S:-K", false]], 32=>[[{22=>:enemy}, 22, "S:-K", true], [{23=>:enemy}, 23, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{22=>nil}, 22, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{42=>nil}, 42, "S:-K", false]], 33=>[[{23=>:enemy}, 23, "S:-K", true], [{24=>:enemy}, 24, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{23=>nil}, 23, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{43=>nil}, 43, "S:-K", false]], 34=>[[{24=>:enemy}, 24, "S:-K", true], [{25=>:enemy}, 25, "S:-K", true], [{26=>:enemy}, 26, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{35=>:enemy}, 35, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{44=>:enemy}, 44, "S:-K", true], [{24=>nil}, 24, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{26=>nil}, 26, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{35=>nil}, 35, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{44=>nil}, 44, "S:-K", false]], 35=>[[{25=>:enemy}, 25, "S:-K", true], [{26=>:enemy}, 26, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{44=>:enemy}, 44, "S:-K", true], [{25=>nil}, 25, "S:-K", false], [{26=>nil}, 26, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{44=>nil}, 44, "S:-K", false]], 36=>[[{27=>:enemy}, 27, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{45=>:enemy}, 45, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{27=>nil}, 27, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{45=>nil}, 45, "S:-K", false], [{46=>nil}, 46, "S:-K", false]], 37=>[[{27=>:enemy}, 27, "S:-K", true], [{28=>:enemy}, 28, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{36=>:enemy}, 36, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{45=>:enemy}, 45, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{27=>nil}, 27, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{36=>nil}, 36, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{45=>nil}, 45, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{47=>nil}, 47, "S:-K", false]], 38=>[[{28=>:enemy}, 28, "S:-K", true], [{29=>:enemy}, 29, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{28=>nil}, 28, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{48=>nil}, 48, "S:-K", false]], 39=>[[{29=>:enemy}, 29, "S:-K", true], [{30=>:enemy}, 30, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{29=>nil}, 29, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{49=>nil}, 49, "S:-K", false]], 40=>[[{30=>:enemy}, 30, "S:-K", true], [{31=>:enemy}, 31, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{30=>nil}, 30, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{50=>nil}, 50, "S:-K", false]], 41=>[[{31=>:enemy}, 31, "S:-K", true], [{32=>:enemy}, 32, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{31=>nil}, 31, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{51=>nil}, 51, "S:-K", false]], 42=>[[{32=>:enemy}, 32, "S:-K", true], [{33=>:enemy}, 33, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{32=>nil}, 32, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{52=>nil}, 52, "S:-K", false]], 43=>[[{33=>:enemy}, 33, "S:-K", true], [{34=>:enemy}, 34, "S:-K", true], [{35=>:enemy}, 35, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{44=>:enemy}, 44, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{53=>:enemy}, 53, "S:-K", true], [{33=>nil}, 33, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{35=>nil}, 35, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{44=>nil}, 44, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{53=>nil}, 53, "S:-K", false]], 44=>[[{34=>:enemy}, 34, "S:-K", true], [{35=>:enemy}, 35, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{53=>:enemy}, 53, "S:-K", true], [{34=>nil}, 34, "S:-K", false], [{35=>nil}, 35, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{53=>nil}, 53, "S:-K", false]], 45=>[[{36=>:enemy}, 36, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{54=>:enemy}, 54, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{36=>nil}, 36, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{54=>nil}, 54, "S:-K", false], [{55=>nil}, 55, "S:-K", false]], 46=>[[{36=>:enemy}, 36, "S:-K", true], [{37=>:enemy}, 37, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{45=>:enemy}, 45, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{54=>:enemy}, 54, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{36=>nil}, 36, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{45=>nil}, 45, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{54=>nil}, 54, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{56=>nil}, 56, "S:-K", false]], 47=>[[{37=>:enemy}, 37, "S:-K", true], [{38=>:enemy}, 38, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{37=>nil}, 37, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{57=>nil}, 57, "S:-K", false]], 48=>[[{38=>:enemy}, 38, "S:-K", true], [{39=>:enemy}, 39, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{38=>nil}, 38, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{58=>nil}, 58, "S:-K", false]], 49=>[[{39=>:enemy}, 39, "S:-K", true], [{40=>:enemy}, 40, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{39=>nil}, 39, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{59=>nil}, 59, "S:-K", false]], 50=>[[{40=>:enemy}, 40, "S:-K", true], [{41=>:enemy}, 41, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{40=>nil}, 40, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{60=>nil}, 60, "S:-K", false]], 51=>[[{41=>:enemy}, 41, "S:-K", true], [{42=>:enemy}, 42, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{41=>nil}, 41, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{61=>nil}, 61, "S:-K", false]], 52=>[[{42=>:enemy}, 42, "S:-K", true], [{43=>:enemy}, 43, "S:-K", true], [{44=>:enemy}, 44, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{53=>:enemy}, 53, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{62=>:enemy}, 62, "S:-K", true], [{42=>nil}, 42, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{44=>nil}, 44, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{53=>nil}, 53, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{62=>nil}, 62, "S:-K", false]], 53=>[[{43=>:enemy}, 43, "S:-K", true], [{44=>:enemy}, 44, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{62=>:enemy}, 62, "S:-K", true], [{43=>nil}, 43, "S:-K", false], [{44=>nil}, 44, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{62=>nil}, 62, "S:-K", false]], 54=>[[{45=>:enemy}, 45, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{63=>:enemy}, 63, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{45=>nil}, 45, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{63=>nil}, 63, "S:-K", false], [{64=>nil}, 64, "S:-K", false]], 55=>[[{45=>:enemy}, 45, "S:-K", true], [{46=>:enemy}, 46, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{54=>:enemy}, 54, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{63=>:enemy}, 63, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{45=>nil}, 45, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{54=>nil}, 54, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{63=>nil}, 63, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{65=>nil}, 65, "S:-K", false]], 56=>[[{46=>:enemy}, 46, "S:-K", true], [{47=>:enemy}, 47, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{46=>nil}, 46, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{66=>nil}, 66, "S:-K", false]], 57=>[[{47=>:enemy}, 47, "S:-K", true], [{48=>:enemy}, 48, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{47=>nil}, 47, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{67=>nil}, 67, "S:-K", false]], 58=>[[{48=>:enemy}, 48, "S:-K", true], [{49=>:enemy}, 49, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{48=>nil}, 48, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{68=>nil}, 68, "S:-K", false]], 59=>[[{49=>:enemy}, 49, "S:-K", true], [{50=>:enemy}, 50, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{49=>nil}, 49, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{69=>nil}, 69, "S:-K", false]], 60=>[[{50=>:enemy}, 50, "S:-K", true], [{51=>:enemy}, 51, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{50=>nil}, 50, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{70=>nil}, 70, "S:-K", false]], 61=>[[{51=>:enemy}, 51, "S:-K", true], [{52=>:enemy}, 52, "S:-K", true], [{53=>:enemy}, 53, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{62=>:enemy}, 62, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{71=>:enemy}, 71, "S:-K", true], [{51=>nil}, 51, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{53=>nil}, 53, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{62=>nil}, 62, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{71=>nil}, 71, "S:-K", false]], 62=>[[{52=>:enemy}, 52, "S:-K", true], [{53=>:enemy}, 53, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{71=>:enemy}, 71, "S:-K", true], [{52=>nil}, 52, "S:-K", false], [{53=>nil}, 53, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{71=>nil}, 71, "S:-K", false]], 63=>[[{54=>:enemy}, 54, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{72=>:enemy}, 72, "S:-K", true], [{73=>:enemy}, 73, "S:-K", true], [{54=>nil}, 54, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{72=>nil}, 72, "S:-K", false], [{73=>nil}, 73, "S:-K", false]], 64=>[[{54=>:enemy}, 54, "S:-K", true], [{55=>:enemy}, 55, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{63=>:enemy}, 63, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{72=>:enemy}, 72, "S:-K", true], [{73=>:enemy}, 73, "S:-K", true], [{74=>:enemy}, 74, "S:-K", true], [{54=>nil}, 54, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{63=>nil}, 63, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{72=>nil}, 72, "S:-K", false], [{73=>nil}, 73, "S:-K", false], [{74=>nil}, 74, "S:-K", false]], 65=>[[{55=>:enemy}, 55, "S:-K", true], [{56=>:enemy}, 56, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{73=>:enemy}, 73, "S:-K", true], [{74=>:enemy}, 74, "S:-K", true], [{75=>:enemy}, 75, "S:-K", true], [{55=>nil}, 55, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{73=>nil}, 73, "S:-K", false], [{74=>nil}, 74, "S:-K", false], [{75=>nil}, 75, "S:-K", false]], 66=>[[{56=>:enemy}, 56, "S:-K", true], [{57=>:enemy}, 57, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{74=>:enemy}, 74, "S:-K", true], [{75=>:enemy}, 75, "S:-K", true], [{76=>:enemy}, 76, "S:-K", true], [{56=>nil}, 56, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{74=>nil}, 74, "S:-K", false], [{75=>nil}, 75, "S:-K", false], [{76=>nil}, 76, "S:-K", false]], 67=>[[{57=>:enemy}, 57, "S:-K", true], [{58=>:enemy}, 58, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{75=>:enemy}, 75, "S:-K", true], [{76=>:enemy}, 76, "S:-K", true], [{77=>:enemy}, 77, "S:-K", true], [{57=>nil}, 57, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{75=>nil}, 75, "S:-K", false], [{76=>nil}, 76, "S:-K", false], [{77=>nil}, 77, "S:-K", false]], 68=>[[{58=>:enemy}, 58, "S:-K", true], [{59=>:enemy}, 59, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{76=>:enemy}, 76, "S:-K", true], [{77=>:enemy}, 77, "S:-K", true], [{78=>:enemy}, 78, "S:-K", true], [{58=>nil}, 58, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{76=>nil}, 76, "S:-K", false], [{77=>nil}, 77, "S:-K", false], [{78=>nil}, 78, "S:-K", false]], 69=>[[{59=>:enemy}, 59, "S:-K", true], [{60=>:enemy}, 60, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{77=>:enemy}, 77, "S:-K", true], [{78=>:enemy}, 78, "S:-K", true], [{79=>:enemy}, 79, "S:-K", true], [{59=>nil}, 59, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{77=>nil}, 77, "S:-K", false], [{78=>nil}, 78, "S:-K", false], [{79=>nil}, 79, "S:-K", false]], 70=>[[{60=>:enemy}, 60, "S:-K", true], [{61=>:enemy}, 61, "S:-K", true], [{62=>:enemy}, 62, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{71=>:enemy}, 71, "S:-K", true], [{78=>:enemy}, 78, "S:-K", true], [{79=>:enemy}, 79, "S:-K", true], [{80=>:enemy}, 80, "S:-K", true], [{60=>nil}, 60, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{62=>nil}, 62, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{71=>nil}, 71, "S:-K", false], [{78=>nil}, 78, "S:-K", false], [{79=>nil}, 79, "S:-K", false], [{80=>nil}, 80, "S:-K", false]], 71=>[[{61=>:enemy}, 61, "S:-K", true], [{62=>:enemy}, 62, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{79=>:enemy}, 79, "S:-K", true], [{80=>:enemy}, 80, "S:-K", true], [{61=>nil}, 61, "S:-K", false], [{62=>nil}, 62, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{79=>nil}, 79, "S:-K", false], [{80=>nil}, 80, "S:-K", false]], 72=>[[{63=>:enemy}, 63, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{73=>:enemy}, 73, "S:-K", true], [{63=>nil}, 63, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{73=>nil}, 73, "S:-K", false]], 73=>[[{63=>:enemy}, 63, "S:-K", true], [{64=>:enemy}, 64, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{72=>:enemy}, 72, "S:-K", true], [{74=>:enemy}, 74, "S:-K", true], [{63=>nil}, 63, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{72=>nil}, 72, "S:-K", false], [{74=>nil}, 74, "S:-K", false]], 74=>[[{64=>:enemy}, 64, "S:-K", true], [{65=>:enemy}, 65, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{73=>:enemy}, 73, "S:-K", true], [{75=>:enemy}, 75, "S:-K", true], [{64=>nil}, 64, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{73=>nil}, 73, "S:-K", false], [{75=>nil}, 75, "S:-K", false]], 75=>[[{65=>:enemy}, 65, "S:-K", true], [{66=>:enemy}, 66, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{74=>:enemy}, 74, "S:-K", true], [{76=>:enemy}, 76, "S:-K", true], [{65=>nil}, 65, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{74=>nil}, 74, "S:-K", false], [{76=>nil}, 76, "S:-K", false]], 76=>[[{66=>:enemy}, 66, "S:-K", true], [{67=>:enemy}, 67, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{75=>:enemy}, 75, "S:-K", true], [{77=>:enemy}, 77, "S:-K", true], [{66=>nil}, 66, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{75=>nil}, 75, "S:-K", false], [{77=>nil}, 77, "S:-K", false]], 77=>[[{67=>:enemy}, 67, "S:-K", true], [{68=>:enemy}, 68, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{76=>:enemy}, 76, "S:-K", true], [{78=>:enemy}, 78, "S:-K", true], [{67=>nil}, 67, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{76=>nil}, 76, "S:-K", false], [{78=>nil}, 78, "S:-K", false]], 78=>[[{68=>:enemy}, 68, "S:-K", true], [{69=>:enemy}, 69, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{77=>:enemy}, 77, "S:-K", true], [{79=>:enemy}, 79, "S:-K", true], [{68=>nil}, 68, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{77=>nil}, 77, "S:-K", false], [{79=>nil}, 79, "S:-K", false]], 79=>[[{69=>:enemy}, 69, "S:-K", true], [{70=>:enemy}, 70, "S:-K", true], [{71=>:enemy}, 71, "S:-K", true], [{78=>:enemy}, 78, "S:-K", true], [{80=>:enemy}, 80, "S:-K", true], [{69=>nil}, 69, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{71=>nil}, 71, "S:-K", false], [{78=>nil}, 78, "S:-K", false], [{80=>nil}, 80, "S:-K", false]], 80=>[[{70=>:enemy}, 70, "S:-K", true], [{71=>:enemy}, 71, "S:-K", true], [{79=>:enemy}, 79, "S:-K", true], [{70=>nil}, 70, "S:-K", false], [{71=>nil}, 71, "S:-K", false], [{79=>nil}, 79, "S:-K", false]], nil=>[[{0=>nil}, 0, "S:-K", false], [{1=>nil}, 1, "S:-K", false], [{2=>nil}, 2, "S:-K", false], [{3=>nil}, 3, "S:-K", false], [{4=>nil}, 4, "S:-K", false], [{5=>nil}, 5, "S:-K", false], [{6=>nil}, 6, "S:-K", false], [{7=>nil}, 7, "S:-K", false], [{8=>nil}, 8, "S:-K", false], [{9=>nil}, 9, "S:-K", false], [{10=>nil}, 10, "S:-K", false], [{11=>nil}, 11, "S:-K", false], [{12=>nil}, 12, "S:-K", false], [{13=>nil}, 13, "S:-K", false], [{14=>nil}, 14, "S:-K", false], [{15=>nil}, 15, "S:-K", false], [{16=>nil}, 16, "S:-K", false], [{17=>nil}, 17, "S:-K", false], [{18=>nil}, 18, "S:-K", false], [{19=>nil}, 19, "S:-K", false], [{20=>nil}, 20, "S:-K", false], [{21=>nil}, 21, "S:-K", false], [{22=>nil}, 22, "S:-K", false], [{23=>nil}, 23, "S:-K", false], [{24=>nil}, 24, "S:-K", false], [{25=>nil}, 25, "S:-K", false], [{26=>nil}, 26, "S:-K", false], [{27=>nil}, 27, "S:-K", false], [{28=>nil}, 28, "S:-K", false], [{29=>nil}, 29, "S:-K", false], [{30=>nil}, 30, "S:-K", false], [{31=>nil}, 31, "S:-K", false], [{32=>nil}, 32, "S:-K", false], [{33=>nil}, 33, "S:-K", false], [{34=>nil}, 34, "S:-K", false], [{35=>nil}, 35, "S:-K", false], [{36=>nil}, 36, "S:-K", false], [{37=>nil}, 37, "S:-K", false], [{38=>nil}, 38, "S:-K", false], [{39=>nil}, 39, "S:-K", false], [{40=>nil}, 40, "S:-K", false], [{41=>nil}, 41, "S:-K", false], [{42=>nil}, 42, "S:-K", false], [{43=>nil}, 43, "S:-K", false], [{44=>nil}, 44, "S:-K", false], [{45=>nil}, 45, "S:-K", false], [{46=>nil}, 46, "S:-K", false], [{47=>nil}, 47, "S:-K", false], [{48=>nil}, 48, "S:-K", false], [{49=>nil}, 49, "S:-K", false], [{50=>nil}, 50, "S:-K", false], [{51=>nil}, 51, "S:-K", false], [{52=>nil}, 52, "S:-K", false], [{53=>nil}, 53, "S:-K", false], [{54=>nil}, 54, "S:-K", false], [{55=>nil}, 55, "S:-K", false], [{56=>nil}, 56, "S:-K", false], [{57=>nil}, 57, "S:-K", false], [{58=>nil}, 58, "S:-K", false], [{59=>nil}, 59, "S:-K", false], [{60=>nil}, 60, "S:-K", false], [{61=>nil}, 61, "S:-K", false], [{62=>nil}, 62, "S:-K", false], [{63=>nil}, 63, "S:-K", false], [{64=>nil}, 64, "S:-K", false], [{65=>nil}, 65, "S:-K", false], [{66=>nil}, 66, "S:-K", false], [{67=>nil}, 67, "S:-K", false], [{68=>nil}, 68, "S:-K", false], [{69=>nil}, 69, "S:-K", false], [{70=>nil}, 70, "S:-K", false], [{71=>nil}, 71, "S:-K", false], [{72=>nil}, 72, "S:-K", false], [{73=>nil}, 73, "S:-K", false], [{74=>nil}, 74, "S:-K", false], [{75=>nil}, 75, "S:-K", false], [{76=>nil}, 76, "S:-K", false], [{77=>nil}, 77, "S:-K", false], [{78=>nil}, 78, "S:-K", false], [{79=>nil}, 79, "S:-K", false], [{80=>nil}, 80, "S:-K", false]]}, "S:B"=>{0=>[[{10=>:enemy}, 10, "S:+B", true], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 20=>:enemy}, 20, "S:+B", true], [{10=>nil, 20=>nil}, 20, "S:+B", false], [{10=>nil, 20=>nil, 30=>:enemy}, 30, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil}, 30, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>:enemy}, 40, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil}, 40, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 1=>[[{9=>:enemy}, 9, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{9=>nil}, 9, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 21=>:enemy}, 21, "S:+B", true], [{11=>nil, 21=>nil}, 21, "S:+B", false], [{11=>nil, 21=>nil, 31=>:enemy}, 31, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil}, 31, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>:enemy}, 41, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil}, 41, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 2=>[[{10=>:enemy}, 10, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 18=>:enemy}, 18, "S:+B", true], [{10=>nil, 18=>nil}, 18, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 22=>:enemy}, 22, "S:+B", true], [{12=>nil, 22=>nil}, 22, "S:+B", false], [{12=>nil, 22=>nil, 32=>:enemy}, 32, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil}, 32, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>:enemy}, 42, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil}, 42, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 3=>[[{11=>:enemy}, 11, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 19=>:enemy}, 19, "S:+B", true], [{11=>nil, 19=>nil}, 19, "S:+B", false], [{11=>nil, 19=>nil, 27=>:enemy}, 27, "S:+B", true], [{11=>nil, 19=>nil, 27=>nil}, 27, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 23=>:enemy}, 23, "S:+B", true], [{13=>nil, 23=>nil}, 23, "S:+B", false], [{13=>nil, 23=>nil, 33=>:enemy}, 33, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil}, 33, "S:+B", false], [{13=>nil, 23=>nil, 33=>nil, 43=>:enemy}, 43, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil}, 43, "S:+B", false], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 4=>[[{12=>:enemy}, 12, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 20=>:enemy}, 20, "S:+B", true], [{12=>nil, 20=>nil}, 20, "S:+B", false], [{12=>nil, 20=>nil, 28=>:enemy}, 28, "S:+B", true], [{12=>nil, 20=>nil, 28=>nil}, 28, "S:+B", false], [{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, 36, "S:+B", true], [{12=>nil, 20=>nil, 28=>nil, 36=>nil}, 36, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 24=>:enemy}, 24, "S:+B", true], [{14=>nil, 24=>nil}, 24, "S:+B", false], [{14=>nil, 24=>nil, 34=>:enemy}, 34, "S:+B", true], [{14=>nil, 24=>nil, 34=>nil}, 34, "S:+B", false], [{14=>nil, 24=>nil, 34=>nil, 44=>:enemy}, 44, "S:+B", true], [{14=>nil, 24=>nil, 34=>nil, 44=>nil}, 44, "S:+B", false]], 5=>[[{13=>:enemy}, 13, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 21=>:enemy}, 21, "S:+B", true], [{13=>nil, 21=>nil}, 21, "S:+B", false], [{13=>nil, 21=>nil, 29=>:enemy}, 29, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil}, 29, "S:+B", false], [{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, 37, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil}, 37, "S:+B", false], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 25=>:enemy}, 25, "S:+B", true], [{15=>nil, 25=>nil}, 25, "S:+B", false], [{15=>nil, 25=>nil, 35=>:enemy}, 35, "S:+B", true], [{15=>nil, 25=>nil, 35=>nil}, 35, "S:+B", false]], 6=>[[{14=>:enemy}, 14, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 22=>:enemy}, 22, "S:+B", true], [{14=>nil, 22=>nil}, 22, "S:+B", false], [{14=>nil, 22=>nil, 30=>:enemy}, 30, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil}, 30, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, 38, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil}, 38, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 26=>:enemy}, 26, "S:+B", true], [{16=>nil, 26=>nil}, 26, "S:+B", false]], 7=>[[{15=>:enemy}, 15, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 23=>:enemy}, 23, "S:+B", true], [{15=>nil, 23=>nil}, 23, "S:+B", false], [{15=>nil, 23=>nil, 31=>:enemy}, 31, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil}, 31, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, 39, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil}, 39, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{17=>nil}, 17, "S:+B", false]], 8=>[[{16=>:enemy}, 16, "S:+B", true], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 24=>:enemy}, 24, "S:+B", true], [{16=>nil, 24=>nil}, 24, "S:+B", false], [{16=>nil, 24=>nil, 32=>:enemy}, 32, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil}, 32, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, 40, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil}, 40, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false]], 9=>[[{1=>:enemy}, 1, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{1=>nil}, 1, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 29=>:enemy}, 29, "S:+B", true], [{19=>nil, 29=>nil}, 29, "S:+B", false], [{19=>nil, 29=>nil, 39=>:enemy}, 39, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil}, 39, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>:enemy}, 49, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil}, 49, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 10=>[[{0=>:enemy}, 0, "S:+B", true], [{2=>:enemy}, 2, "S:+B", true], [{18=>:enemy}, 18, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{0=>nil}, 0, "S:+B", false], [{2=>nil}, 2, "S:+B", false], [{18=>nil}, 18, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 30=>:enemy}, 30, "S:+B", true], [{20=>nil, 30=>nil}, 30, "S:+B", false], [{20=>nil, 30=>nil, 40=>:enemy}, 40, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil}, 40, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 11=>[[{1=>:enemy}, 1, "S:+B", true], [{3=>:enemy}, 3, "S:+B", true], [{19=>:enemy}, 19, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{1=>nil}, 1, "S:+B", false], [{3=>nil}, 3, "S:+B", false], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 27=>:enemy}, 27, "S:+B", true], [{19=>nil, 27=>nil}, 27, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 31=>:enemy}, 31, "S:+B", true], [{21=>nil, 31=>nil}, 31, "S:+B", false], [{21=>nil, 31=>nil, 41=>:enemy}, 41, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil}, 41, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 12=>[[{2=>:enemy}, 2, "S:+B", true], [{4=>:enemy}, 4, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{2=>nil}, 2, "S:+B", false], [{4=>nil}, 4, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 28=>:enemy}, 28, "S:+B", true], [{20=>nil, 28=>nil}, 28, "S:+B", false], [{20=>nil, 28=>nil, 36=>:enemy}, 36, "S:+B", true], [{20=>nil, 28=>nil, 36=>nil}, 36, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 32=>:enemy}, 32, "S:+B", true], [{22=>nil, 32=>nil}, 32, "S:+B", false], [{22=>nil, 32=>nil, 42=>:enemy}, 42, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil}, 42, "S:+B", false], [{22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 13=>[[{3=>:enemy}, 3, "S:+B", true], [{5=>:enemy}, 5, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{3=>nil}, 3, "S:+B", false], [{5=>nil}, 5, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 29=>:enemy}, 29, "S:+B", true], [{21=>nil, 29=>nil}, 29, "S:+B", false], [{21=>nil, 29=>nil, 37=>:enemy}, 37, "S:+B", true], [{21=>nil, 29=>nil, 37=>nil}, 37, "S:+B", false], [{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 33=>:enemy}, 33, "S:+B", true], [{23=>nil, 33=>nil}, 33, "S:+B", false], [{23=>nil, 33=>nil, 43=>:enemy}, 43, "S:+B", true], [{23=>nil, 33=>nil, 43=>nil}, 43, "S:+B", false], [{23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 14=>[[{4=>:enemy}, 4, "S:+B", true], [{6=>:enemy}, 6, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{4=>nil}, 4, "S:+B", false], [{6=>nil}, 6, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 30=>:enemy}, 30, "S:+B", true], [{22=>nil, 30=>nil}, 30, "S:+B", false], [{22=>nil, 30=>nil, 38=>:enemy}, 38, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil}, 38, "S:+B", false], [{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 34=>:enemy}, 34, "S:+B", true], [{24=>nil, 34=>nil}, 34, "S:+B", false], [{24=>nil, 34=>nil, 44=>:enemy}, 44, "S:+B", true], [{24=>nil, 34=>nil, 44=>nil}, 44, "S:+B", false]], 15=>[[{5=>:enemy}, 5, "S:+B", true], [{7=>:enemy}, 7, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{5=>nil}, 5, "S:+B", false], [{7=>nil}, 7, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 31=>:enemy}, 31, "S:+B", true], [{23=>nil, 31=>nil}, 31, "S:+B", false], [{23=>nil, 31=>nil, 39=>:enemy}, 39, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil}, 39, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 35=>:enemy}, 35, "S:+B", true], [{25=>nil, 35=>nil}, 35, "S:+B", false]], 16=>[[{6=>:enemy}, 6, "S:+B", true], [{8=>:enemy}, 8, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{6=>nil}, 6, "S:+B", false], [{8=>nil}, 8, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 32=>:enemy}, 32, "S:+B", true], [{24=>nil, 32=>nil}, 32, "S:+B", false], [{24=>nil, 32=>nil, 40=>:enemy}, 40, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil}, 40, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{26=>nil}, 26, "S:+B", false]], 17=>[[{7=>:enemy}, 7, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{7=>nil}, 7, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 33=>:enemy}, 33, "S:+B", true], [{25=>nil, 33=>nil}, 33, "S:+B", false], [{25=>nil, 33=>nil, 41=>:enemy}, 41, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil}, 41, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, 49, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil}, 49, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false]], 18=>[[{10=>:enemy}, 10, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 2=>:enemy}, 2, "S:+B", true], [{10=>nil, 2=>nil}, 2, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 38=>:enemy}, 38, "S:+B", true], [{28=>nil, 38=>nil}, 38, "S:+B", false], [{28=>nil, 38=>nil, 48=>:enemy}, 48, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil}, 48, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>:enemy}, 58, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil}, 58, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "S:+B", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:+B", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:+B", false]], 19=>[[{9=>:enemy}, 9, "S:+B", true], [{11=>:enemy}, 11, "S:+B", true], [{27=>:enemy}, 27, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{9=>nil}, 9, "S:+B", false], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 3=>:enemy}, 3, "S:+B", true], [{11=>nil, 3=>nil}, 3, "S:+B", false], [{27=>nil}, 27, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 39=>:enemy}, 39, "S:+B", true], [{29=>nil, 39=>nil}, 39, "S:+B", false], [{29=>nil, 39=>nil, 49=>:enemy}, 49, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil}, 49, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:+B", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:+B", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:+B", false]], 20=>[[{10=>:enemy}, 10, "S:+B", true], [{12=>:enemy}, 12, "S:+B", true], [{28=>:enemy}, 28, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{10=>nil}, 10, "S:+B", false], [{10=>nil, 0=>:enemy}, 0, "S:+B", true], [{10=>nil, 0=>nil}, 0, "S:+B", false], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 4=>:enemy}, 4, "S:+B", true], [{12=>nil, 4=>nil}, 4, "S:+B", false], [{28=>nil}, 28, "S:+B", false], [{28=>nil, 36=>:enemy}, 36, "S:+B", true], [{28=>nil, 36=>nil}, 36, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 40=>:enemy}, 40, "S:+B", true], [{30=>nil, 40=>nil}, 40, "S:+B", false], [{30=>nil, 40=>nil, 50=>:enemy}, 50, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil}, 50, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:+B", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:+B", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:+B", false]], 21=>[[{11=>:enemy}, 11, "S:+B", true], [{13=>:enemy}, 13, "S:+B", true], [{29=>:enemy}, 29, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{11=>nil}, 11, "S:+B", false], [{11=>nil, 1=>:enemy}, 1, "S:+B", true], [{11=>nil, 1=>nil}, 1, "S:+B", false], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 5=>:enemy}, 5, "S:+B", true], [{13=>nil, 5=>nil}, 5, "S:+B", false], [{29=>nil}, 29, "S:+B", false], [{29=>nil, 37=>:enemy}, 37, "S:+B", true], [{29=>nil, 37=>nil}, 37, "S:+B", false], [{29=>nil, 37=>nil, 45=>:enemy}, 45, "S:+B", true], [{29=>nil, 37=>nil, 45=>nil}, 45, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 41=>:enemy}, 41, "S:+B", true], [{31=>nil, 41=>nil}, 41, "S:+B", false], [{31=>nil, 41=>nil, 51=>:enemy}, 51, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil}, 51, "S:+B", false], [{31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "S:+B", false], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:+B", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:+B", false]], 22=>[[{12=>:enemy}, 12, "S:+B", true], [{14=>:enemy}, 14, "S:+B", true], [{30=>:enemy}, 30, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{12=>nil}, 12, "S:+B", false], [{12=>nil, 2=>:enemy}, 2, "S:+B", true], [{12=>nil, 2=>nil}, 2, "S:+B", false], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 6=>:enemy}, 6, "S:+B", true], [{14=>nil, 6=>nil}, 6, "S:+B", false], [{30=>nil}, 30, "S:+B", false], [{30=>nil, 38=>:enemy}, 38, "S:+B", true], [{30=>nil, 38=>nil}, 38, "S:+B", false], [{30=>nil, 38=>nil, 46=>:enemy}, 46, "S:+B", true], [{30=>nil, 38=>nil, 46=>nil}, 46, "S:+B", false], [{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "S:+B", true], [{30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 42=>:enemy}, 42, "S:+B", true], [{32=>nil, 42=>nil}, 42, "S:+B", false], [{32=>nil, 42=>nil, 52=>:enemy}, 52, "S:+B", true], [{32=>nil, 42=>nil, 52=>nil}, 52, "S:+B", false], [{32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "S:+B", true], [{32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "S:+B", false]], 23=>[[{13=>:enemy}, 13, "S:+B", true], [{15=>:enemy}, 15, "S:+B", true], [{31=>:enemy}, 31, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{13=>nil}, 13, "S:+B", false], [{13=>nil, 3=>:enemy}, 3, "S:+B", true], [{13=>nil, 3=>nil}, 3, "S:+B", false], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 7=>:enemy}, 7, "S:+B", true], [{15=>nil, 7=>nil}, 7, "S:+B", false], [{31=>nil}, 31, "S:+B", false], [{31=>nil, 39=>:enemy}, 39, "S:+B", true], [{31=>nil, 39=>nil}, 39, "S:+B", false], [{31=>nil, 39=>nil, 47=>:enemy}, 47, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil}, 47, "S:+B", false], [{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "S:+B", false], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:+B", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 43=>:enemy}, 43, "S:+B", true], [{33=>nil, 43=>nil}, 43, "S:+B", false], [{33=>nil, 43=>nil, 53=>:enemy}, 53, "S:+B", true], [{33=>nil, 43=>nil, 53=>nil}, 53, "S:+B", false]], 24=>[[{14=>:enemy}, 14, "S:+B", true], [{16=>:enemy}, 16, "S:+B", true], [{32=>:enemy}, 32, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{14=>nil}, 14, "S:+B", false], [{14=>nil, 4=>:enemy}, 4, "S:+B", true], [{14=>nil, 4=>nil}, 4, "S:+B", false], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 8=>:enemy}, 8, "S:+B", true], [{16=>nil, 8=>nil}, 8, "S:+B", false], [{32=>nil}, 32, "S:+B", false], [{32=>nil, 40=>:enemy}, 40, "S:+B", true], [{32=>nil, 40=>nil}, 40, "S:+B", false], [{32=>nil, 40=>nil, 48=>:enemy}, 48, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil}, 48, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:+B", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:+B", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 44=>:enemy}, 44, "S:+B", true], [{34=>nil, 44=>nil}, 44, "S:+B", false]], 25=>[[{15=>:enemy}, 15, "S:+B", true], [{17=>:enemy}, 17, "S:+B", true], [{33=>:enemy}, 33, "S:+B", true], [{35=>:enemy}, 35, "S:+B", true], [{15=>nil}, 15, "S:+B", false], [{15=>nil, 5=>:enemy}, 5, "S:+B", true], [{15=>nil, 5=>nil}, 5, "S:+B", false], [{17=>nil}, 17, "S:+B", false], [{33=>nil}, 33, "S:+B", false], [{33=>nil, 41=>:enemy}, 41, "S:+B", true], [{33=>nil, 41=>nil}, 41, "S:+B", false], [{33=>nil, 41=>nil, 49=>:enemy}, 49, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil}, 49, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:+B", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:+B", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:+B", false], [{35=>nil}, 35, "S:+B", false]], 26=>[[{16=>:enemy}, 16, "S:+B", true], [{34=>:enemy}, 34, "S:+B", true], [{16=>nil}, 16, "S:+B", false], [{16=>nil, 6=>:enemy}, 6, "S:+B", true], [{16=>nil, 6=>nil}, 6, "S:+B", false], [{34=>nil}, 34, "S:+B", false], [{34=>nil, 42=>:enemy}, 42, "S:+B", true], [{34=>nil, 42=>nil}, 42, "S:+B", false], [{34=>nil, 42=>nil, 50=>:enemy}, 50, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil}, 50, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, 58, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil}, 58, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "S:+B", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:+B", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:+B", false]], 27=>[[{19=>:enemy}, 19, "S:+B", true], [{37=>:enemy}, 37, "S:B", true], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 11=>:enemy}, 11, "S:+B", true], [{19=>nil, 11=>nil}, 11, "S:+B", false], [{19=>nil, 11=>nil, 3=>:enemy}, 3, "S:+B", true], [{19=>nil, 11=>nil, 3=>nil}, 3, "S:+B", false], [{37=>nil}, 37, "S:B", false], [{37=>nil, 47=>:enemy}, 47, "S:B", true], [{37=>nil, 47=>nil}, 47, "S:B", false], [{37=>nil, 47=>nil, 57=>:enemy}, 57, "S:B", true], [{37=>nil, 47=>nil, 57=>nil}, 57, "S:B", false], [{37=>nil, 47=>nil, 57=>nil, 67=>:enemy}, 67, "S:B", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil}, 67, "S:B", false], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "S:B", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "S:B", false]], 28=>[[{18=>:enemy}, 18, "S:+B", true], [{20=>:enemy}, 20, "S:+B", true], [{36=>:enemy}, 36, "S:B", true], [{38=>:enemy}, 38, "S:B", true], [{18=>nil}, 18, "S:+B", false], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 12=>:enemy}, 12, "S:+B", true], [{20=>nil, 12=>nil}, 12, "S:+B", false], [{20=>nil, 12=>nil, 4=>:enemy}, 4, "S:+B", true], [{20=>nil, 12=>nil, 4=>nil}, 4, "S:+B", false], [{36=>nil}, 36, "S:B", false], [{38=>nil}, 38, "S:B", false], [{38=>nil, 48=>:enemy}, 48, "S:B", true], [{38=>nil, 48=>nil}, 48, "S:B", false], [{38=>nil, 48=>nil, 58=>:enemy}, 58, "S:B", true], [{38=>nil, 48=>nil, 58=>nil}, 58, "S:B", false], [{38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "S:B", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "S:B", false], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:B", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:B", false]], 29=>[[{19=>:enemy}, 19, "S:+B", true], [{21=>:enemy}, 21, "S:+B", true], [{37=>:enemy}, 37, "S:B", true], [{39=>:enemy}, 39, "S:B", true], [{19=>nil}, 19, "S:+B", false], [{19=>nil, 9=>:enemy}, 9, "S:+B", true], [{19=>nil, 9=>nil}, 9, "S:+B", false], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 13=>:enemy}, 13, "S:+B", true], [{21=>nil, 13=>nil}, 13, "S:+B", false], [{21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{37=>nil}, 37, "S:B", false], [{37=>nil, 45=>:enemy}, 45, "S:B", true], [{37=>nil, 45=>nil}, 45, "S:B", false], [{39=>nil}, 39, "S:B", false], [{39=>nil, 49=>:enemy}, 49, "S:B", true], [{39=>nil, 49=>nil}, 49, "S:B", false], [{39=>nil, 49=>nil, 59=>:enemy}, 59, "S:B", true], [{39=>nil, 49=>nil, 59=>nil}, 59, "S:B", false], [{39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "S:B", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "S:B", false], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:B", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:B", false]], 30=>[[{20=>:enemy}, 20, "S:+B", true], [{22=>:enemy}, 22, "S:+B", true], [{38=>:enemy}, 38, "S:B", true], [{40=>:enemy}, 40, "S:B", true], [{20=>nil}, 20, "S:+B", false], [{20=>nil, 10=>:enemy}, 10, "S:+B", true], [{20=>nil, 10=>nil}, 10, "S:+B", false], [{20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 14=>:enemy}, 14, "S:+B", true], [{22=>nil, 14=>nil}, 14, "S:+B", false], [{22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{38=>nil}, 38, "S:B", false], [{38=>nil, 46=>:enemy}, 46, "S:B", true], [{38=>nil, 46=>nil}, 46, "S:B", false], [{38=>nil, 46=>nil, 54=>:enemy}, 54, "S:B", true], [{38=>nil, 46=>nil, 54=>nil}, 54, "S:B", false], [{40=>nil}, 40, "S:B", false], [{40=>nil, 50=>:enemy}, 50, "S:B", true], [{40=>nil, 50=>nil}, 50, "S:B", false], [{40=>nil, 50=>nil, 60=>:enemy}, 60, "S:B", true], [{40=>nil, 50=>nil, 60=>nil}, 60, "S:B", false], [{40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "S:B", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "S:B", false], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:B", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:B", false]], 31=>[[{21=>:enemy}, 21, "S:+B", true], [{23=>:enemy}, 23, "S:+B", true], [{39=>:enemy}, 39, "S:B", true], [{41=>:enemy}, 41, "S:B", true], [{21=>nil}, 21, "S:+B", false], [{21=>nil, 11=>:enemy}, 11, "S:+B", true], [{21=>nil, 11=>nil}, 11, "S:+B", false], [{21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 15=>:enemy}, 15, "S:+B", true], [{23=>nil, 15=>nil}, 15, "S:+B", false], [{23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{39=>nil}, 39, "S:B", false], [{39=>nil, 47=>:enemy}, 47, "S:B", true], [{39=>nil, 47=>nil}, 47, "S:B", false], [{39=>nil, 47=>nil, 55=>:enemy}, 55, "S:B", true], [{39=>nil, 47=>nil, 55=>nil}, 55, "S:B", false], [{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "S:B", true], [{39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "S:B", false], [{41=>nil}, 41, "S:B", false], [{41=>nil, 51=>:enemy}, 51, "S:B", true], [{41=>nil, 51=>nil}, 51, "S:B", false], [{41=>nil, 51=>nil, 61=>:enemy}, 61, "S:B", true], [{41=>nil, 51=>nil, 61=>nil}, 61, "S:B", false], [{41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "S:B", true], [{41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "S:B", false]], 32=>[[{22=>:enemy}, 22, "S:+B", true], [{24=>:enemy}, 24, "S:+B", true], [{40=>:enemy}, 40, "S:B", true], [{42=>:enemy}, 42, "S:B", true], [{22=>nil}, 22, "S:+B", false], [{22=>nil, 12=>:enemy}, 12, "S:+B", true], [{22=>nil, 12=>nil}, 12, "S:+B", false], [{22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 16=>:enemy}, 16, "S:+B", true], [{24=>nil, 16=>nil}, 16, "S:+B", false], [{24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{40=>nil}, 40, "S:B", false], [{40=>nil, 48=>:enemy}, 48, "S:B", true], [{40=>nil, 48=>nil}, 48, "S:B", false], [{40=>nil, 48=>nil, 56=>:enemy}, 56, "S:B", true], [{40=>nil, 48=>nil, 56=>nil}, 56, "S:B", false], [{40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "S:B", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "S:B", false], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:B", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:B", false], [{42=>nil}, 42, "S:B", false], [{42=>nil, 52=>:enemy}, 52, "S:B", true], [{42=>nil, 52=>nil}, 52, "S:B", false], [{42=>nil, 52=>nil, 62=>:enemy}, 62, "S:B", true], [{42=>nil, 52=>nil, 62=>nil}, 62, "S:B", false]], 33=>[[{23=>:enemy}, 23, "S:+B", true], [{25=>:enemy}, 25, "S:+B", true], [{41=>:enemy}, 41, "S:B", true], [{43=>:enemy}, 43, "S:B", true], [{23=>nil}, 23, "S:+B", false], [{23=>nil, 13=>:enemy}, 13, "S:+B", true], [{23=>nil, 13=>nil}, 13, "S:+B", false], [{23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 17=>:enemy}, 17, "S:+B", true], [{25=>nil, 17=>nil}, 17, "S:+B", false], [{41=>nil}, 41, "S:B", false], [{41=>nil, 49=>:enemy}, 49, "S:B", true], [{41=>nil, 49=>nil}, 49, "S:B", false], [{41=>nil, 49=>nil, 57=>:enemy}, 57, "S:B", true], [{41=>nil, 49=>nil, 57=>nil}, 57, "S:B", false], [{41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "S:B", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "S:B", false], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:B", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:B", false], [{43=>nil}, 43, "S:B", false], [{43=>nil, 53=>:enemy}, 53, "S:B", true], [{43=>nil, 53=>nil}, 53, "S:B", false]], 34=>[[{24=>:enemy}, 24, "S:+B", true], [{26=>:enemy}, 26, "S:+B", true], [{42=>:enemy}, 42, "S:B", true], [{44=>:enemy}, 44, "S:B", true], [{24=>nil}, 24, "S:+B", false], [{24=>nil, 14=>:enemy}, 14, "S:+B", true], [{24=>nil, 14=>nil}, 14, "S:+B", false], [{24=>nil, 14=>nil, 4=>:enemy}, 4, "S:+B", true], [{24=>nil, 14=>nil, 4=>nil}, 4, "S:+B", false], [{26=>nil}, 26, "S:+B", false], [{42=>nil}, 42, "S:B", false], [{42=>nil, 50=>:enemy}, 50, "S:B", true], [{42=>nil, 50=>nil}, 50, "S:B", false], [{42=>nil, 50=>nil, 58=>:enemy}, 58, "S:B", true], [{42=>nil, 50=>nil, 58=>nil}, 58, "S:B", false], [{42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "S:B", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "S:B", false], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:B", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:B", false], [{44=>nil}, 44, "S:B", false]], 35=>[[{25=>:enemy}, 25, "S:+B", true], [{43=>:enemy}, 43, "S:B", true], [{25=>nil}, 25, "S:+B", false], [{25=>nil, 15=>:enemy}, 15, "S:+B", true], [{25=>nil, 15=>nil}, 15, "S:+B", false], [{25=>nil, 15=>nil, 5=>:enemy}, 5, "S:+B", true], [{25=>nil, 15=>nil, 5=>nil}, 5, "S:+B", false], [{43=>nil}, 43, "S:B", false], [{43=>nil, 51=>:enemy}, 51, "S:B", true], [{43=>nil, 51=>nil}, 51, "S:B", false], [{43=>nil, 51=>nil, 59=>:enemy}, 59, "S:B", true], [{43=>nil, 51=>nil, 59=>nil}, 59, "S:B", false], [{43=>nil, 51=>nil, 59=>nil, 67=>:enemy}, 67, "S:B", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil}, 67, "S:B", false], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "S:B", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "S:B", false]], 36=>[[{28=>:enemy}, 28, "S:B", true], [{46=>:enemy}, 46, "S:B", true], [{28=>nil}, 28, "S:B", false], [{28=>nil, 20=>:enemy}, 20, "S:+B", true], [{28=>nil, 20=>nil}, 20, "S:+B", false], [{28=>nil, 20=>nil, 12=>:enemy}, 12, "S:+B", true], [{28=>nil, 20=>nil, 12=>nil}, 12, "S:+B", false], [{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, 4, "S:+B", true], [{28=>nil, 20=>nil, 12=>nil, 4=>nil}, 4, "S:+B", false], [{46=>nil}, 46, "S:B", false], [{46=>nil, 56=>:enemy}, 56, "S:B", true], [{46=>nil, 56=>nil}, 56, "S:B", false], [{46=>nil, 56=>nil, 66=>:enemy}, 66, "S:B", true], [{46=>nil, 56=>nil, 66=>nil}, 66, "S:B", false], [{46=>nil, 56=>nil, 66=>nil, 76=>:enemy}, 76, "S:B", true], [{46=>nil, 56=>nil, 66=>nil, 76=>nil}, 76, "S:B", false]], 37=>[[{27=>:enemy}, 27, "S:B", true], [{29=>:enemy}, 29, "S:B", true], [{45=>:enemy}, 45, "S:B", true], [{47=>:enemy}, 47, "S:B", true], [{27=>nil}, 27, "S:B", false], [{29=>nil}, 29, "S:B", false], [{29=>nil, 21=>:enemy}, 21, "S:+B", true], [{29=>nil, 21=>nil}, 21, "S:+B", false], [{29=>nil, 21=>nil, 13=>:enemy}, 13, "S:+B", true], [{29=>nil, 21=>nil, 13=>nil}, 13, "S:+B", false], [{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{45=>nil}, 45, "S:B", false], [{47=>nil}, 47, "S:B", false], [{47=>nil, 57=>:enemy}, 57, "S:B", true], [{47=>nil, 57=>nil}, 57, "S:B", false], [{47=>nil, 57=>nil, 67=>:enemy}, 67, "S:B", true], [{47=>nil, 57=>nil, 67=>nil}, 67, "S:B", false], [{47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "S:B", true], [{47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "S:B", false]], 38=>[[{28=>:enemy}, 28, "S:B", true], [{30=>:enemy}, 30, "S:B", true], [{46=>:enemy}, 46, "S:B", true], [{48=>:enemy}, 48, "S:B", true], [{28=>nil}, 28, "S:B", false], [{28=>nil, 18=>:enemy}, 18, "S:+B", true], [{28=>nil, 18=>nil}, 18, "S:+B", false], [{30=>nil}, 30, "S:B", false], [{30=>nil, 22=>:enemy}, 22, "S:+B", true], [{30=>nil, 22=>nil}, 22, "S:+B", false], [{30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{46=>nil}, 46, "S:B", false], [{46=>nil, 54=>:enemy}, 54, "S:B", true], [{46=>nil, 54=>nil}, 54, "S:B", false], [{48=>nil}, 48, "S:B", false], [{48=>nil, 58=>:enemy}, 58, "S:B", true], [{48=>nil, 58=>nil}, 58, "S:B", false], [{48=>nil, 58=>nil, 68=>:enemy}, 68, "S:B", true], [{48=>nil, 58=>nil, 68=>nil}, 68, "S:B", false], [{48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "S:B", true], [{48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "S:B", false]], 39=>[[{29=>:enemy}, 29, "S:B", true], [{31=>:enemy}, 31, "S:B", true], [{47=>:enemy}, 47, "S:B", true], [{49=>:enemy}, 49, "S:B", true], [{29=>nil}, 29, "S:B", false], [{29=>nil, 19=>:enemy}, 19, "S:+B", true], [{29=>nil, 19=>nil}, 19, "S:+B", false], [{29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{31=>nil}, 31, "S:B", false], [{31=>nil, 23=>:enemy}, 23, "S:+B", true], [{31=>nil, 23=>nil}, 23, "S:+B", false], [{31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{47=>nil}, 47, "S:B", false], [{47=>nil, 55=>:enemy}, 55, "S:B", true], [{47=>nil, 55=>nil}, 55, "S:B", false], [{47=>nil, 55=>nil, 63=>:enemy}, 63, "S:B", true], [{47=>nil, 55=>nil, 63=>nil}, 63, "S:B", false], [{49=>nil}, 49, "S:B", false], [{49=>nil, 59=>:enemy}, 59, "S:B", true], [{49=>nil, 59=>nil}, 59, "S:B", false], [{49=>nil, 59=>nil, 69=>:enemy}, 69, "S:B", true], [{49=>nil, 59=>nil, 69=>nil}, 69, "S:B", false], [{49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "S:B", true], [{49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "S:B", false]], 40=>[[{30=>:enemy}, 30, "S:B", true], [{32=>:enemy}, 32, "S:B", true], [{48=>:enemy}, 48, "S:B", true], [{50=>:enemy}, 50, "S:B", true], [{30=>nil}, 30, "S:B", false], [{30=>nil, 20=>:enemy}, 20, "S:+B", true], [{30=>nil, 20=>nil}, 20, "S:+B", false], [{30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{32=>nil}, 32, "S:B", false], [{32=>nil, 24=>:enemy}, 24, "S:+B", true], [{32=>nil, 24=>nil}, 24, "S:+B", false], [{32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{48=>nil}, 48, "S:B", false], [{48=>nil, 56=>:enemy}, 56, "S:B", true], [{48=>nil, 56=>nil}, 56, "S:B", false], [{48=>nil, 56=>nil, 64=>:enemy}, 64, "S:B", true], [{48=>nil, 56=>nil, 64=>nil}, 64, "S:B", false], [{48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "S:B", true], [{48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "S:B", false], [{50=>nil}, 50, "S:B", false], [{50=>nil, 60=>:enemy}, 60, "S:B", true], [{50=>nil, 60=>nil}, 60, "S:B", false], [{50=>nil, 60=>nil, 70=>:enemy}, 70, "S:B", true], [{50=>nil, 60=>nil, 70=>nil}, 70, "S:B", false], [{50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "S:B", true], [{50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "S:B", false]], 41=>[[{31=>:enemy}, 31, "S:B", true], [{33=>:enemy}, 33, "S:B", true], [{49=>:enemy}, 49, "S:B", true], [{51=>:enemy}, 51, "S:B", true], [{31=>nil}, 31, "S:B", false], [{31=>nil, 21=>:enemy}, 21, "S:+B", true], [{31=>nil, 21=>nil}, 21, "S:+B", false], [{31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{33=>nil}, 33, "S:B", false], [{33=>nil, 25=>:enemy}, 25, "S:+B", true], [{33=>nil, 25=>nil}, 25, "S:+B", false], [{33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{49=>nil}, 49, "S:B", false], [{49=>nil, 57=>:enemy}, 57, "S:B", true], [{49=>nil, 57=>nil}, 57, "S:B", false], [{49=>nil, 57=>nil, 65=>:enemy}, 65, "S:B", true], [{49=>nil, 57=>nil, 65=>nil}, 65, "S:B", false], [{49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "S:B", true], [{49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "S:B", false], [{51=>nil}, 51, "S:B", false], [{51=>nil, 61=>:enemy}, 61, "S:B", true], [{51=>nil, 61=>nil}, 61, "S:B", false], [{51=>nil, 61=>nil, 71=>:enemy}, 71, "S:B", true], [{51=>nil, 61=>nil, 71=>nil}, 71, "S:B", false]], 42=>[[{32=>:enemy}, 32, "S:B", true], [{34=>:enemy}, 34, "S:B", true], [{50=>:enemy}, 50, "S:B", true], [{52=>:enemy}, 52, "S:B", true], [{32=>nil}, 32, "S:B", false], [{32=>nil, 22=>:enemy}, 22, "S:+B", true], [{32=>nil, 22=>nil}, 22, "S:+B", false], [{32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{34=>nil}, 34, "S:B", false], [{34=>nil, 26=>:enemy}, 26, "S:+B", true], [{34=>nil, 26=>nil}, 26, "S:+B", false], [{50=>nil}, 50, "S:B", false], [{50=>nil, 58=>:enemy}, 58, "S:B", true], [{50=>nil, 58=>nil}, 58, "S:B", false], [{50=>nil, 58=>nil, 66=>:enemy}, 66, "S:B", true], [{50=>nil, 58=>nil, 66=>nil}, 66, "S:B", false], [{50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "S:B", true], [{50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "S:B", false], [{52=>nil}, 52, "S:B", false], [{52=>nil, 62=>:enemy}, 62, "S:B", true], [{52=>nil, 62=>nil}, 62, "S:B", false]], 43=>[[{33=>:enemy}, 33, "S:B", true], [{35=>:enemy}, 35, "S:B", true], [{51=>:enemy}, 51, "S:B", true], [{53=>:enemy}, 53, "S:B", true], [{33=>nil}, 33, "S:B", false], [{33=>nil, 23=>:enemy}, 23, "S:+B", true], [{33=>nil, 23=>nil}, 23, "S:+B", false], [{33=>nil, 23=>nil, 13=>:enemy}, 13, "S:+B", true], [{33=>nil, 23=>nil, 13=>nil}, 13, "S:+B", false], [{33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{35=>nil}, 35, "S:B", false], [{51=>nil}, 51, "S:B", false], [{51=>nil, 59=>:enemy}, 59, "S:B", true], [{51=>nil, 59=>nil}, 59, "S:B", false], [{51=>nil, 59=>nil, 67=>:enemy}, 67, "S:B", true], [{51=>nil, 59=>nil, 67=>nil}, 67, "S:B", false], [{51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "S:B", true], [{51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "S:B", false], [{53=>nil}, 53, "S:B", false]], 44=>[[{34=>:enemy}, 34, "S:B", true], [{52=>:enemy}, 52, "S:B", true], [{34=>nil}, 34, "S:B", false], [{34=>nil, 24=>:enemy}, 24, "S:+B", true], [{34=>nil, 24=>nil}, 24, "S:+B", false], [{34=>nil, 24=>nil, 14=>:enemy}, 14, "S:+B", true], [{34=>nil, 24=>nil, 14=>nil}, 14, "S:+B", false], [{34=>nil, 24=>nil, 14=>nil, 4=>:enemy}, 4, "S:+B", true], [{34=>nil, 24=>nil, 14=>nil, 4=>nil}, 4, "S:+B", false], [{52=>nil}, 52, "S:B", false], [{52=>nil, 60=>:enemy}, 60, "S:B", true], [{52=>nil, 60=>nil}, 60, "S:B", false], [{52=>nil, 60=>nil, 68=>:enemy}, 68, "S:B", true], [{52=>nil, 60=>nil, 68=>nil}, 68, "S:B", false], [{52=>nil, 60=>nil, 68=>nil, 76=>:enemy}, 76, "S:B", true], [{52=>nil, 60=>nil, 68=>nil, 76=>nil}, 76, "S:B", false]], 45=>[[{37=>:enemy}, 37, "S:B", true], [{55=>:enemy}, 55, "S:B", true], [{37=>nil}, 37, "S:B", false], [{37=>nil, 29=>:enemy}, 29, "S:B", true], [{37=>nil, 29=>nil}, 29, "S:B", false], [{37=>nil, 29=>nil, 21=>:enemy}, 21, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil}, 21, "S:+B", false], [{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, 13, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil}, 13, "S:+B", false], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "S:+B", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "S:+B", false], [{55=>nil}, 55, "S:B", false], [{55=>nil, 65=>:enemy}, 65, "S:B", true], [{55=>nil, 65=>nil}, 65, "S:B", false], [{55=>nil, 65=>nil, 75=>:enemy}, 75, "S:B", true], [{55=>nil, 65=>nil, 75=>nil}, 75, "S:B", false]], 46=>[[{36=>:enemy}, 36, "S:B", true], [{38=>:enemy}, 38, "S:B", true], [{54=>:enemy}, 54, "S:B", true], [{56=>:enemy}, 56, "S:B", true], [{36=>nil}, 36, "S:B", false], [{38=>nil}, 38, "S:B", false], [{38=>nil, 30=>:enemy}, 30, "S:B", true], [{38=>nil, 30=>nil}, 30, "S:B", false], [{38=>nil, 30=>nil, 22=>:enemy}, 22, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil}, 22, "S:+B", false], [{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{54=>nil}, 54, "S:B", false], [{56=>nil}, 56, "S:B", false], [{56=>nil, 66=>:enemy}, 66, "S:B", true], [{56=>nil, 66=>nil}, 66, "S:B", false], [{56=>nil, 66=>nil, 76=>:enemy}, 76, "S:B", true], [{56=>nil, 66=>nil, 76=>nil}, 76, "S:B", false]], 47=>[[{37=>:enemy}, 37, "S:B", true], [{39=>:enemy}, 39, "S:B", true], [{55=>:enemy}, 55, "S:B", true], [{57=>:enemy}, 57, "S:B", true], [{37=>nil}, 37, "S:B", false], [{37=>nil, 27=>:enemy}, 27, "S:B", true], [{37=>nil, 27=>nil}, 27, "S:B", false], [{39=>nil}, 39, "S:B", false], [{39=>nil, 31=>:enemy}, 31, "S:B", true], [{39=>nil, 31=>nil}, 31, "S:B", false], [{39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{55=>nil}, 55, "S:B", false], [{55=>nil, 63=>:enemy}, 63, "S:B", true], [{55=>nil, 63=>nil}, 63, "S:B", false], [{57=>nil}, 57, "S:B", false], [{57=>nil, 67=>:enemy}, 67, "S:B", true], [{57=>nil, 67=>nil}, 67, "S:B", false], [{57=>nil, 67=>nil, 77=>:enemy}, 77, "S:B", true], [{57=>nil, 67=>nil, 77=>nil}, 77, "S:B", false]], 48=>[[{38=>:enemy}, 38, "S:B", true], [{40=>:enemy}, 40, "S:B", true], [{56=>:enemy}, 56, "S:B", true], [{58=>:enemy}, 58, "S:B", true], [{38=>nil}, 38, "S:B", false], [{38=>nil, 28=>:enemy}, 28, "S:B", true], [{38=>nil, 28=>nil}, 28, "S:B", false], [{38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{40=>nil}, 40, "S:B", false], [{40=>nil, 32=>:enemy}, 32, "S:B", true], [{40=>nil, 32=>nil}, 32, "S:B", false], [{40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{56=>nil}, 56, "S:B", false], [{56=>nil, 64=>:enemy}, 64, "S:B", true], [{56=>nil, 64=>nil}, 64, "S:B", false], [{56=>nil, 64=>nil, 72=>:enemy}, 72, "S:B", true], [{56=>nil, 64=>nil, 72=>nil}, 72, "S:B", false], [{58=>nil}, 58, "S:B", false], [{58=>nil, 68=>:enemy}, 68, "S:B", true], [{58=>nil, 68=>nil}, 68, "S:B", false], [{58=>nil, 68=>nil, 78=>:enemy}, 78, "S:B", true], [{58=>nil, 68=>nil, 78=>nil}, 78, "S:B", false]], 49=>[[{39=>:enemy}, 39, "S:B", true], [{41=>:enemy}, 41, "S:B", true], [{57=>:enemy}, 57, "S:B", true], [{59=>:enemy}, 59, "S:B", true], [{39=>nil}, 39, "S:B", false], [{39=>nil, 29=>:enemy}, 29, "S:B", true], [{39=>nil, 29=>nil}, 29, "S:B", false], [{39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{41=>nil}, 41, "S:B", false], [{41=>nil, 33=>:enemy}, 33, "S:B", true], [{41=>nil, 33=>nil}, 33, "S:B", false], [{41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{57=>nil}, 57, "S:B", false], [{57=>nil, 65=>:enemy}, 65, "S:B", true], [{57=>nil, 65=>nil}, 65, "S:B", false], [{57=>nil, 65=>nil, 73=>:enemy}, 73, "S:B", true], [{57=>nil, 65=>nil, 73=>nil}, 73, "S:B", false], [{59=>nil}, 59, "S:B", false], [{59=>nil, 69=>:enemy}, 69, "S:B", true], [{59=>nil, 69=>nil}, 69, "S:B", false], [{59=>nil, 69=>nil, 79=>:enemy}, 79, "S:B", true], [{59=>nil, 69=>nil, 79=>nil}, 79, "S:B", false]], 50=>[[{40=>:enemy}, 40, "S:B", true], [{42=>:enemy}, 42, "S:B", true], [{58=>:enemy}, 58, "S:B", true], [{60=>:enemy}, 60, "S:B", true], [{40=>nil}, 40, "S:B", false], [{40=>nil, 30=>:enemy}, 30, "S:B", true], [{40=>nil, 30=>nil}, 30, "S:B", false], [{40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{42=>nil}, 42, "S:B", false], [{42=>nil, 34=>:enemy}, 34, "S:B", true], [{42=>nil, 34=>nil}, 34, "S:B", false], [{42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{58=>nil}, 58, "S:B", false], [{58=>nil, 66=>:enemy}, 66, "S:B", true], [{58=>nil, 66=>nil}, 66, "S:B", false], [{58=>nil, 66=>nil, 74=>:enemy}, 74, "S:B", true], [{58=>nil, 66=>nil, 74=>nil}, 74, "S:B", false], [{60=>nil}, 60, "S:B", false], [{60=>nil, 70=>:enemy}, 70, "S:B", true], [{60=>nil, 70=>nil}, 70, "S:B", false], [{60=>nil, 70=>nil, 80=>:enemy}, 80, "S:B", true], [{60=>nil, 70=>nil, 80=>nil}, 80, "S:B", false]], 51=>[[{41=>:enemy}, 41, "S:B", true], [{43=>:enemy}, 43, "S:B", true], [{59=>:enemy}, 59, "S:B", true], [{61=>:enemy}, 61, "S:B", true], [{41=>nil}, 41, "S:B", false], [{41=>nil, 31=>:enemy}, 31, "S:B", true], [{41=>nil, 31=>nil}, 31, "S:B", false], [{41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{43=>nil}, 43, "S:B", false], [{43=>nil, 35=>:enemy}, 35, "S:B", true], [{43=>nil, 35=>nil}, 35, "S:B", false], [{59=>nil}, 59, "S:B", false], [{59=>nil, 67=>:enemy}, 67, "S:B", true], [{59=>nil, 67=>nil}, 67, "S:B", false], [{59=>nil, 67=>nil, 75=>:enemy}, 75, "S:B", true], [{59=>nil, 67=>nil, 75=>nil}, 75, "S:B", false], [{61=>nil}, 61, "S:B", false], [{61=>nil, 71=>:enemy}, 71, "S:B", true], [{61=>nil, 71=>nil}, 71, "S:B", false]], 52=>[[{42=>:enemy}, 42, "S:B", true], [{44=>:enemy}, 44, "S:B", true], [{60=>:enemy}, 60, "S:B", true], [{62=>:enemy}, 62, "S:B", true], [{42=>nil}, 42, "S:B", false], [{42=>nil, 32=>:enemy}, 32, "S:B", true], [{42=>nil, 32=>nil}, 32, "S:B", false], [{42=>nil, 32=>nil, 22=>:enemy}, 22, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil}, 22, "S:+B", false], [{42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{44=>nil}, 44, "S:B", false], [{60=>nil}, 60, "S:B", false], [{60=>nil, 68=>:enemy}, 68, "S:B", true], [{60=>nil, 68=>nil}, 68, "S:B", false], [{60=>nil, 68=>nil, 76=>:enemy}, 76, "S:B", true], [{60=>nil, 68=>nil, 76=>nil}, 76, "S:B", false], [{62=>nil}, 62, "S:B", false]], 53=>[[{43=>:enemy}, 43, "S:B", true], [{61=>:enemy}, 61, "S:B", true], [{43=>nil}, 43, "S:B", false], [{43=>nil, 33=>:enemy}, 33, "S:B", true], [{43=>nil, 33=>nil}, 33, "S:B", false], [{43=>nil, 33=>nil, 23=>:enemy}, 23, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil}, 23, "S:+B", false], [{43=>nil, 33=>nil, 23=>nil, 13=>:enemy}, 13, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil}, 13, "S:+B", false], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "S:+B", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "S:+B", false], [{61=>nil}, 61, "S:B", false], [{61=>nil, 69=>:enemy}, 69, "S:B", true], [{61=>nil, 69=>nil}, 69, "S:B", false], [{61=>nil, 69=>nil, 77=>:enemy}, 77, "S:B", true], [{61=>nil, 69=>nil, 77=>nil}, 77, "S:B", false]], 54=>[[{46=>:enemy}, 46, "S:B", true], [{64=>:enemy}, 64, "S:B", true], [{46=>nil}, 46, "S:B", false], [{46=>nil, 38=>:enemy}, 38, "S:B", true], [{46=>nil, 38=>nil}, 38, "S:B", false], [{46=>nil, 38=>nil, 30=>:enemy}, 30, "S:B", true], [{46=>nil, 38=>nil, 30=>nil}, 30, "S:B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, 22, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil}, 22, "S:+B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "S:+B", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "S:+B", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "S:+B", false], [{64=>nil}, 64, "S:B", false], [{64=>nil, 74=>:enemy}, 74, "S:B", true], [{64=>nil, 74=>nil}, 74, "S:B", false]], 55=>[[{45=>:enemy}, 45, "S:B", true], [{47=>:enemy}, 47, "S:B", true], [{63=>:enemy}, 63, "S:B", true], [{65=>:enemy}, 65, "S:B", true], [{45=>nil}, 45, "S:B", false], [{47=>nil}, 47, "S:B", false], [{47=>nil, 39=>:enemy}, 39, "S:B", true], [{47=>nil, 39=>nil}, 39, "S:B", false], [{47=>nil, 39=>nil, 31=>:enemy}, 31, "S:B", true], [{47=>nil, 39=>nil, 31=>nil}, 31, "S:B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{63=>nil}, 63, "S:B", false], [{65=>nil}, 65, "S:B", false], [{65=>nil, 75=>:enemy}, 75, "S:B", true], [{65=>nil, 75=>nil}, 75, "S:B", false]], 56=>[[{46=>:enemy}, 46, "S:B", true], [{48=>:enemy}, 48, "S:B", true], [{64=>:enemy}, 64, "S:B", true], [{66=>:enemy}, 66, "S:B", true], [{46=>nil}, 46, "S:B", false], [{46=>nil, 36=>:enemy}, 36, "S:B", true], [{46=>nil, 36=>nil}, 36, "S:B", false], [{48=>nil}, 48, "S:B", false], [{48=>nil, 40=>:enemy}, 40, "S:B", true], [{48=>nil, 40=>nil}, 40, "S:B", false], [{48=>nil, 40=>nil, 32=>:enemy}, 32, "S:B", true], [{48=>nil, 40=>nil, 32=>nil}, 32, "S:B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{64=>nil}, 64, "S:B", false], [{64=>nil, 72=>:enemy}, 72, "S:B", true], [{64=>nil, 72=>nil}, 72, "S:B", false], [{66=>nil}, 66, "S:B", false], [{66=>nil, 76=>:enemy}, 76, "S:B", true], [{66=>nil, 76=>nil}, 76, "S:B", false]], 57=>[[{47=>:enemy}, 47, "S:B", true], [{49=>:enemy}, 49, "S:B", true], [{65=>:enemy}, 65, "S:B", true], [{67=>:enemy}, 67, "S:B", true], [{47=>nil}, 47, "S:B", false], [{47=>nil, 37=>:enemy}, 37, "S:B", true], [{47=>nil, 37=>nil}, 37, "S:B", false], [{47=>nil, 37=>nil, 27=>:enemy}, 27, "S:B", true], [{47=>nil, 37=>nil, 27=>nil}, 27, "S:B", false], [{49=>nil}, 49, "S:B", false], [{49=>nil, 41=>:enemy}, 41, "S:B", true], [{49=>nil, 41=>nil}, 41, "S:B", false], [{49=>nil, 41=>nil, 33=>:enemy}, 33, "S:B", true], [{49=>nil, 41=>nil, 33=>nil}, 33, "S:B", false], [{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{65=>nil}, 65, "S:B", false], [{65=>nil, 73=>:enemy}, 73, "S:B", true], [{65=>nil, 73=>nil}, 73, "S:B", false], [{67=>nil}, 67, "S:B", false], [{67=>nil, 77=>:enemy}, 77, "S:B", true], [{67=>nil, 77=>nil}, 77, "S:B", false]], 58=>[[{48=>:enemy}, 48, "S:B", true], [{50=>:enemy}, 50, "S:B", true], [{66=>:enemy}, 66, "S:B", true], [{68=>:enemy}, 68, "S:B", true], [{48=>nil}, 48, "S:B", false], [{48=>nil, 38=>:enemy}, 38, "S:B", true], [{48=>nil, 38=>nil}, 38, "S:B", false], [{48=>nil, 38=>nil, 28=>:enemy}, 28, "S:B", true], [{48=>nil, 38=>nil, 28=>nil}, 28, "S:B", false], [{48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{50=>nil}, 50, "S:B", false], [{50=>nil, 42=>:enemy}, 42, "S:B", true], [{50=>nil, 42=>nil}, 42, "S:B", false], [{50=>nil, 42=>nil, 34=>:enemy}, 34, "S:B", true], [{50=>nil, 42=>nil, 34=>nil}, 34, "S:B", false], [{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{66=>nil}, 66, "S:B", false], [{66=>nil, 74=>:enemy}, 74, "S:B", true], [{66=>nil, 74=>nil}, 74, "S:B", false], [{68=>nil}, 68, "S:B", false], [{68=>nil, 78=>:enemy}, 78, "S:B", true], [{68=>nil, 78=>nil}, 78, "S:B", false]], 59=>[[{49=>:enemy}, 49, "S:B", true], [{51=>:enemy}, 51, "S:B", true], [{67=>:enemy}, 67, "S:B", true], [{69=>:enemy}, 69, "S:B", true], [{49=>nil}, 49, "S:B", false], [{49=>nil, 39=>:enemy}, 39, "S:B", true], [{49=>nil, 39=>nil}, 39, "S:B", false], [{49=>nil, 39=>nil, 29=>:enemy}, 29, "S:B", true], [{49=>nil, 39=>nil, 29=>nil}, 29, "S:B", false], [{49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{51=>nil}, 51, "S:B", false], [{51=>nil, 43=>:enemy}, 43, "S:B", true], [{51=>nil, 43=>nil}, 43, "S:B", false], [{51=>nil, 43=>nil, 35=>:enemy}, 35, "S:B", true], [{51=>nil, 43=>nil, 35=>nil}, 35, "S:B", false], [{67=>nil}, 67, "S:B", false], [{67=>nil, 75=>:enemy}, 75, "S:B", true], [{67=>nil, 75=>nil}, 75, "S:B", false], [{69=>nil}, 69, "S:B", false], [{69=>nil, 79=>:enemy}, 79, "S:B", true], [{69=>nil, 79=>nil}, 79, "S:B", false]], 60=>[[{50=>:enemy}, 50, "S:B", true], [{52=>:enemy}, 52, "S:B", true], [{68=>:enemy}, 68, "S:B", true], [{70=>:enemy}, 70, "S:B", true], [{50=>nil}, 50, "S:B", false], [{50=>nil, 40=>:enemy}, 40, "S:B", true], [{50=>nil, 40=>nil}, 40, "S:B", false], [{50=>nil, 40=>nil, 30=>:enemy}, 30, "S:B", true], [{50=>nil, 40=>nil, 30=>nil}, 30, "S:B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{52=>nil}, 52, "S:B", false], [{52=>nil, 44=>:enemy}, 44, "S:B", true], [{52=>nil, 44=>nil}, 44, "S:B", false], [{68=>nil}, 68, "S:B", false], [{68=>nil, 76=>:enemy}, 76, "S:B", true], [{68=>nil, 76=>nil}, 76, "S:B", false], [{70=>nil}, 70, "S:B", false], [{70=>nil, 80=>:enemy}, 80, "S:B", true], [{70=>nil, 80=>nil}, 80, "S:B", false]], 61=>[[{51=>:enemy}, 51, "S:B", true], [{53=>:enemy}, 53, "S:B", true], [{69=>:enemy}, 69, "S:B", true], [{71=>:enemy}, 71, "S:B", true], [{51=>nil}, 51, "S:B", false], [{51=>nil, 41=>:enemy}, 41, "S:B", true], [{51=>nil, 41=>nil}, 41, "S:B", false], [{51=>nil, 41=>nil, 31=>:enemy}, 31, "S:B", true], [{51=>nil, 41=>nil, 31=>nil}, 31, "S:B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{53=>nil}, 53, "S:B", false], [{69=>nil}, 69, "S:B", false], [{69=>nil, 77=>:enemy}, 77, "S:B", true], [{69=>nil, 77=>nil}, 77, "S:B", false], [{71=>nil}, 71, "S:B", false]], 62=>[[{52=>:enemy}, 52, "S:B", true], [{70=>:enemy}, 70, "S:B", true], [{52=>nil}, 52, "S:B", false], [{52=>nil, 42=>:enemy}, 42, "S:B", true], [{52=>nil, 42=>nil}, 42, "S:B", false], [{52=>nil, 42=>nil, 32=>:enemy}, 32, "S:B", true], [{52=>nil, 42=>nil, 32=>nil}, 32, "S:B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>:enemy}, 22, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil}, 22, "S:+B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "S:+B", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "S:+B", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "S:+B", false], [{70=>nil}, 70, "S:B", false], [{70=>nil, 78=>:enemy}, 78, "S:B", true], [{70=>nil, 78=>nil}, 78, "S:B", false]], 63=>[[{55=>:enemy}, 55, "S:B", true], [{73=>:enemy}, 73, "S:B", true], [{55=>nil}, 55, "S:B", false], [{55=>nil, 47=>:enemy}, 47, "S:B", true], [{55=>nil, 47=>nil}, 47, "S:B", false], [{55=>nil, 47=>nil, 39=>:enemy}, 39, "S:B", true], [{55=>nil, 47=>nil, 39=>nil}, 39, "S:B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, 31, "S:B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil}, 31, "S:B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "S:+B", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "S:+B", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "S:+B", false], [{73=>nil}, 73, "S:B", false]], 64=>[[{54=>:enemy}, 54, "S:B", true], [{56=>:enemy}, 56, "S:B", true], [{72=>:enemy}, 72, "S:B", true], [{74=>:enemy}, 74, "S:B", true], [{54=>nil}, 54, "S:B", false], [{56=>nil}, 56, "S:B", false], [{56=>nil, 48=>:enemy}, 48, "S:B", true], [{56=>nil, 48=>nil}, 48, "S:B", false], [{56=>nil, 48=>nil, 40=>:enemy}, 40, "S:B", true], [{56=>nil, 48=>nil, 40=>nil}, 40, "S:B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "S:B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "S:B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false], [{72=>nil}, 72, "S:B", false], [{74=>nil}, 74, "S:B", false]], 65=>[[{55=>:enemy}, 55, "S:B", true], [{57=>:enemy}, 57, "S:B", true], [{73=>:enemy}, 73, "S:B", true], [{75=>:enemy}, 75, "S:B", true], [{55=>nil}, 55, "S:B", false], [{55=>nil, 45=>:enemy}, 45, "S:B", true], [{55=>nil, 45=>nil}, 45, "S:B", false], [{57=>nil}, 57, "S:B", false], [{57=>nil, 49=>:enemy}, 49, "S:B", true], [{57=>nil, 49=>nil}, 49, "S:B", false], [{57=>nil, 49=>nil, 41=>:enemy}, 41, "S:B", true], [{57=>nil, 49=>nil, 41=>nil}, 41, "S:B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "S:B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "S:B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false], [{73=>nil}, 73, "S:B", false], [{75=>nil}, 75, "S:B", false]], 66=>[[{56=>:enemy}, 56, "S:B", true], [{58=>:enemy}, 58, "S:B", true], [{74=>:enemy}, 74, "S:B", true], [{76=>:enemy}, 76, "S:B", true], [{56=>nil}, 56, "S:B", false], [{56=>nil, 46=>:enemy}, 46, "S:B", true], [{56=>nil, 46=>nil}, 46, "S:B", false], [{56=>nil, 46=>nil, 36=>:enemy}, 36, "S:B", true], [{56=>nil, 46=>nil, 36=>nil}, 36, "S:B", false], [{58=>nil}, 58, "S:B", false], [{58=>nil, 50=>:enemy}, 50, "S:B", true], [{58=>nil, 50=>nil}, 50, "S:B", false], [{58=>nil, 50=>nil, 42=>:enemy}, 42, "S:B", true], [{58=>nil, 50=>nil, 42=>nil}, 42, "S:B", false], [{58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "S:B", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "S:B", false], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false], [{74=>nil}, 74, "S:B", false], [{76=>nil}, 76, "S:B", false]], 67=>[[{57=>:enemy}, 57, "S:B", true], [{59=>:enemy}, 59, "S:B", true], [{75=>:enemy}, 75, "S:B", true], [{77=>:enemy}, 77, "S:B", true], [{57=>nil}, 57, "S:B", false], [{57=>nil, 47=>:enemy}, 47, "S:B", true], [{57=>nil, 47=>nil}, 47, "S:B", false], [{57=>nil, 47=>nil, 37=>:enemy}, 37, "S:B", true], [{57=>nil, 47=>nil, 37=>nil}, 37, "S:B", false], [{57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "S:B", true], [{57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "S:B", false], [{59=>nil}, 59, "S:B", false], [{59=>nil, 51=>:enemy}, 51, "S:B", true], [{59=>nil, 51=>nil}, 51, "S:B", false], [{59=>nil, 51=>nil, 43=>:enemy}, 43, "S:B", true], [{59=>nil, 51=>nil, 43=>nil}, 43, "S:B", false], [{59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "S:B", true], [{59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "S:B", false], [{75=>nil}, 75, "S:B", false], [{77=>nil}, 77, "S:B", false]], 68=>[[{58=>:enemy}, 58, "S:B", true], [{60=>:enemy}, 60, "S:B", true], [{76=>:enemy}, 76, "S:B", true], [{78=>:enemy}, 78, "S:B", true], [{58=>nil}, 58, "S:B", false], [{58=>nil, 48=>:enemy}, 48, "S:B", true], [{58=>nil, 48=>nil}, 48, "S:B", false], [{58=>nil, 48=>nil, 38=>:enemy}, 38, "S:B", true], [{58=>nil, 48=>nil, 38=>nil}, 38, "S:B", false], [{58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "S:B", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "S:B", false], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{60=>nil}, 60, "S:B", false], [{60=>nil, 52=>:enemy}, 52, "S:B", true], [{60=>nil, 52=>nil}, 52, "S:B", false], [{60=>nil, 52=>nil, 44=>:enemy}, 44, "S:B", true], [{60=>nil, 52=>nil, 44=>nil}, 44, "S:B", false], [{76=>nil}, 76, "S:B", false], [{78=>nil}, 78, "S:B", false]], 69=>[[{59=>:enemy}, 59, "S:B", true], [{61=>:enemy}, 61, "S:B", true], [{77=>:enemy}, 77, "S:B", true], [{79=>:enemy}, 79, "S:B", true], [{59=>nil}, 59, "S:B", false], [{59=>nil, 49=>:enemy}, 49, "S:B", true], [{59=>nil, 49=>nil}, 49, "S:B", false], [{59=>nil, 49=>nil, 39=>:enemy}, 39, "S:B", true], [{59=>nil, 49=>nil, 39=>nil}, 39, "S:B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "S:B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "S:B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{61=>nil}, 61, "S:B", false], [{61=>nil, 53=>:enemy}, 53, "S:B", true], [{61=>nil, 53=>nil}, 53, "S:B", false], [{77=>nil}, 77, "S:B", false], [{79=>nil}, 79, "S:B", false]], 70=>[[{60=>:enemy}, 60, "S:B", true], [{62=>:enemy}, 62, "S:B", true], [{78=>:enemy}, 78, "S:B", true], [{80=>:enemy}, 80, "S:B", true], [{60=>nil}, 60, "S:B", false], [{60=>nil, 50=>:enemy}, 50, "S:B", true], [{60=>nil, 50=>nil}, 50, "S:B", false], [{60=>nil, 50=>nil, 40=>:enemy}, 40, "S:B", true], [{60=>nil, 50=>nil, 40=>nil}, 40, "S:B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "S:B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "S:B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false], [{62=>nil}, 62, "S:B", false], [{78=>nil}, 78, "S:B", false], [{80=>nil}, 80, "S:B", false]], 71=>[[{61=>:enemy}, 61, "S:B", true], [{79=>:enemy}, 79, "S:B", true], [{61=>nil}, 61, "S:B", false], [{61=>nil, 51=>:enemy}, 51, "S:B", true], [{61=>nil, 51=>nil}, 51, "S:B", false], [{61=>nil, 51=>nil, 41=>:enemy}, 41, "S:B", true], [{61=>nil, 51=>nil, 41=>nil}, 41, "S:B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>:enemy}, 31, "S:B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil}, 31, "S:B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "S:+B", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "S:+B", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "S:+B", false], [{79=>nil}, 79, "S:B", false]], 72=>[[{64=>:enemy}, 64, "S:B", true], [{64=>nil}, 64, "S:B", false], [{64=>nil, 56=>:enemy}, 56, "S:B", true], [{64=>nil, 56=>nil}, 56, "S:B", false], [{64=>nil, 56=>nil, 48=>:enemy}, 48, "S:B", true], [{64=>nil, 56=>nil, 48=>nil}, 48, "S:B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>:enemy}, 40, "S:B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil}, 40, "S:B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "S:B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "S:B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "S:+B", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "S:+B", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "S:+B", false]], 73=>[[{63=>:enemy}, 63, "S:B", true], [{65=>:enemy}, 65, "S:B", true], [{63=>nil}, 63, "S:B", false], [{65=>nil}, 65, "S:B", false], [{65=>nil, 57=>:enemy}, 57, "S:B", true], [{65=>nil, 57=>nil}, 57, "S:B", false], [{65=>nil, 57=>nil, 49=>:enemy}, 49, "S:B", true], [{65=>nil, 57=>nil, 49=>nil}, 49, "S:B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>:enemy}, 41, "S:B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil}, 41, "S:B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "S:B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "S:B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "S:+B", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "S:+B", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "S:+B", false]], 74=>[[{64=>:enemy}, 64, "S:B", true], [{66=>:enemy}, 66, "S:B", true], [{64=>nil}, 64, "S:B", false], [{64=>nil, 54=>:enemy}, 54, "S:B", true], [{64=>nil, 54=>nil}, 54, "S:B", false], [{66=>nil}, 66, "S:B", false], [{66=>nil, 58=>:enemy}, 58, "S:B", true], [{66=>nil, 58=>nil}, 58, "S:B", false], [{66=>nil, 58=>nil, 50=>:enemy}, 50, "S:B", true], [{66=>nil, 58=>nil, 50=>nil}, 50, "S:B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>:enemy}, 42, "S:B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil}, 42, "S:B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "S:B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "S:B", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "S:+B", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "S:+B", false]], 75=>[[{65=>:enemy}, 65, "S:B", true], [{67=>:enemy}, 67, "S:B", true], [{65=>nil}, 65, "S:B", false], [{65=>nil, 55=>:enemy}, 55, "S:B", true], [{65=>nil, 55=>nil}, 55, "S:B", false], [{65=>nil, 55=>nil, 45=>:enemy}, 45, "S:B", true], [{65=>nil, 55=>nil, 45=>nil}, 45, "S:B", false], [{67=>nil}, 67, "S:B", false], [{67=>nil, 59=>:enemy}, 59, "S:B", true], [{67=>nil, 59=>nil}, 59, "S:B", false], [{67=>nil, 59=>nil, 51=>:enemy}, 51, "S:B", true], [{67=>nil, 59=>nil, 51=>nil}, 51, "S:B", false], [{67=>nil, 59=>nil, 51=>nil, 43=>:enemy}, 43, "S:B", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil}, 43, "S:B", false], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "S:B", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "S:B", false]], 76=>[[{66=>:enemy}, 66, "S:B", true], [{68=>:enemy}, 68, "S:B", true], [{66=>nil}, 66, "S:B", false], [{66=>nil, 56=>:enemy}, 56, "S:B", true], [{66=>nil, 56=>nil}, 56, "S:B", false], [{66=>nil, 56=>nil, 46=>:enemy}, 46, "S:B", true], [{66=>nil, 56=>nil, 46=>nil}, 46, "S:B", false], [{66=>nil, 56=>nil, 46=>nil, 36=>:enemy}, 36, "S:B", true], [{66=>nil, 56=>nil, 46=>nil, 36=>nil}, 36, "S:B", false], [{68=>nil}, 68, "S:B", false], [{68=>nil, 60=>:enemy}, 60, "S:B", true], [{68=>nil, 60=>nil}, 60, "S:B", false], [{68=>nil, 60=>nil, 52=>:enemy}, 52, "S:B", true], [{68=>nil, 60=>nil, 52=>nil}, 52, "S:B", false], [{68=>nil, 60=>nil, 52=>nil, 44=>:enemy}, 44, "S:B", true], [{68=>nil, 60=>nil, 52=>nil, 44=>nil}, 44, "S:B", false]], 77=>[[{67=>:enemy}, 67, "S:B", true], [{69=>:enemy}, 69, "S:B", true], [{67=>nil}, 67, "S:B", false], [{67=>nil, 57=>:enemy}, 57, "S:B", true], [{67=>nil, 57=>nil}, 57, "S:B", false], [{67=>nil, 57=>nil, 47=>:enemy}, 47, "S:B", true], [{67=>nil, 57=>nil, 47=>nil}, 47, "S:B", false], [{67=>nil, 57=>nil, 47=>nil, 37=>:enemy}, 37, "S:B", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil}, 37, "S:B", false], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "S:B", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "S:B", false], [{69=>nil}, 69, "S:B", false], [{69=>nil, 61=>:enemy}, 61, "S:B", true], [{69=>nil, 61=>nil}, 61, "S:B", false], [{69=>nil, 61=>nil, 53=>:enemy}, 53, "S:B", true], [{69=>nil, 61=>nil, 53=>nil}, 53, "S:B", false]], 78=>[[{68=>:enemy}, 68, "S:B", true], [{70=>:enemy}, 70, "S:B", true], [{68=>nil}, 68, "S:B", false], [{68=>nil, 58=>:enemy}, 58, "S:B", true], [{68=>nil, 58=>nil}, 58, "S:B", false], [{68=>nil, 58=>nil, 48=>:enemy}, 48, "S:B", true], [{68=>nil, 58=>nil, 48=>nil}, 48, "S:B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>:enemy}, 38, "S:B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil}, 38, "S:B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "S:B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "S:B", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "S:+B", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "S:+B", false], [{70=>nil}, 70, "S:B", false], [{70=>nil, 62=>:enemy}, 62, "S:B", true], [{70=>nil, 62=>nil}, 62, "S:B", false]], 79=>[[{69=>:enemy}, 69, "S:B", true], [{71=>:enemy}, 71, "S:B", true], [{69=>nil}, 69, "S:B", false], [{69=>nil, 59=>:enemy}, 59, "S:B", true], [{69=>nil, 59=>nil}, 59, "S:B", false], [{69=>nil, 59=>nil, 49=>:enemy}, 49, "S:B", true], [{69=>nil, 59=>nil, 49=>nil}, 49, "S:B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>:enemy}, 39, "S:B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil}, 39, "S:B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "S:B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "S:B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "S:+B", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "S:+B", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "S:+B", false], [{71=>nil}, 71, "S:B", false]], 80=>[[{70=>:enemy}, 70, "S:B", true], [{70=>nil}, 70, "S:B", false], [{70=>nil, 60=>:enemy}, 60, "S:B", true], [{70=>nil, 60=>nil}, 60, "S:B", false], [{70=>nil, 60=>nil, 50=>:enemy}, 50, "S:B", true], [{70=>nil, 60=>nil, 50=>nil}, 50, "S:B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>:enemy}, 40, "S:B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil}, 40, "S:B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "S:B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "S:B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "S:+B", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "S:+B", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "S:+B", false]], nil=>[[{0=>nil}, 0, "S:B", false], [{1=>nil}, 1, "S:B", false], [{2=>nil}, 2, "S:B", false], [{3=>nil}, 3, "S:B", false], [{4=>nil}, 4, "S:B", false], [{5=>nil}, 5, "S:B", false], [{6=>nil}, 6, "S:B", false], [{7=>nil}, 7, "S:B", false], [{8=>nil}, 8, "S:B", false], [{9=>nil}, 9, "S:B", false], [{10=>nil}, 10, "S:B", false], [{11=>nil}, 11, "S:B", false], [{12=>nil}, 12, "S:B", false], [{13=>nil}, 13, "S:B", false], [{14=>nil}, 14, "S:B", false], [{15=>nil}, 15, "S:B", false], [{16=>nil}, 16, "S:B", false], [{17=>nil}, 17, "S:B", false], [{18=>nil}, 18, "S:B", false], [{19=>nil}, 19, "S:B", false], [{20=>nil}, 20, "S:B", false], [{21=>nil}, 21, "S:B", false], [{22=>nil}, 22, "S:B", false], [{23=>nil}, 23, "S:B", false], [{24=>nil}, 24, "S:B", false], [{25=>nil}, 25, "S:B", false], [{26=>nil}, 26, "S:B", false], [{27=>nil}, 27, "S:B", false], [{28=>nil}, 28, "S:B", false], [{29=>nil}, 29, "S:B", false], [{30=>nil}, 30, "S:B", false], [{31=>nil}, 31, "S:B", false], [{32=>nil}, 32, "S:B", false], [{33=>nil}, 33, "S:B", false], [{34=>nil}, 34, "S:B", false], [{35=>nil}, 35, "S:B", false], [{36=>nil}, 36, "S:B", false], [{37=>nil}, 37, "S:B", false], [{38=>nil}, 38, "S:B", false], [{39=>nil}, 39, "S:B", false], [{40=>nil}, 40, "S:B", false], [{41=>nil}, 41, "S:B", false], [{42=>nil}, 42, "S:B", false], [{43=>nil}, 43, "S:B", false], [{44=>nil}, 44, "S:B", false], [{45=>nil}, 45, "S:B", false], [{46=>nil}, 46, "S:B", false], [{47=>nil}, 47, "S:B", false], [{48=>nil}, 48, "S:B", false], [{49=>nil}, 49, "S:B", false], [{50=>nil}, 50, "S:B", false], [{51=>nil}, 51, "S:B", false], [{52=>nil}, 52, "S:B", false], [{53=>nil}, 53, "S:B", false], [{54=>nil}, 54, "S:B", false], [{55=>nil}, 55, "S:B", false], [{56=>nil}, 56, "S:B", false], [{57=>nil}, 57, "S:B", false], [{58=>nil}, 58, "S:B", false], [{59=>nil}, 59, "S:B", false], [{60=>nil}, 60, "S:B", false], [{61=>nil}, 61, "S:B", false], [{62=>nil}, 62, "S:B", false], [{63=>nil}, 63, "S:B", false], [{64=>nil}, 64, "S:B", false], [{65=>nil}, 65, "S:B", false], [{66=>nil}, 66, "S:B", false], [{67=>nil}, 67, "S:B", false], [{68=>nil}, 68, "S:B", false], [{69=>nil}, 69, "S:B", false], [{70=>nil}, 70, "S:B", false], [{71=>nil}, 71, "S:B", false], [{72=>nil}, 72, "S:B", false], [{73=>nil}, 73, "S:B", false], [{74=>nil}, 74, "S:B", false], [{75=>nil}, 75, "S:B", false], [{76=>nil}, 76, "S:B", false], [{77=>nil}, 77, "S:B", false], [{78=>nil}, 78, "S:B", false], [{79=>nil}, 79, "S:B", false], [{80=>nil}, 80, "S:B", false]]}, "S:G"=>{0=>[[{1=>:enemy}, 1, "S:G", true], [{9=>:enemy}, 9, "S:G", true], [{1=>nil}, 1, "S:G", false], [{9=>nil}, 9, "S:G", false]], 1=>[[{0=>:enemy}, 0, "S:G", true], [{2=>:enemy}, 2, "S:G", true], [{10=>:enemy}, 10, "S:G", true], [{0=>nil}, 0, "S:G", false], [{2=>nil}, 2, "S:G", false], [{10=>nil}, 10, "S:G", false]], 2=>[[{1=>:enemy}, 1, "S:G", true], [{3=>:enemy}, 3, "S:G", true], [{11=>:enemy}, 11, "S:G", true], [{1=>nil}, 1, "S:G", false], [{3=>nil}, 3, "S:G", false], [{11=>nil}, 11, "S:G", false]], 3=>[[{2=>:enemy}, 2, "S:G", true], [{4=>:enemy}, 4, "S:G", true], [{12=>:enemy}, 12, "S:G", true], [{2=>nil}, 2, "S:G", false], [{4=>nil}, 4, "S:G", false], [{12=>nil}, 12, "S:G", false]], 4=>[[{3=>:enemy}, 3, "S:G", true], [{5=>:enemy}, 5, "S:G", true], [{13=>:enemy}, 13, "S:G", true], [{3=>nil}, 3, "S:G", false], [{5=>nil}, 5, "S:G", false], [{13=>nil}, 13, "S:G", false]], 5=>[[{4=>:enemy}, 4, "S:G", true], [{6=>:enemy}, 6, "S:G", true], [{14=>:enemy}, 14, "S:G", true], [{4=>nil}, 4, "S:G", false], [{6=>nil}, 6, "S:G", false], [{14=>nil}, 14, "S:G", false]], 6=>[[{5=>:enemy}, 5, "S:G", true], [{7=>:enemy}, 7, "S:G", true], [{15=>:enemy}, 15, "S:G", true], [{5=>nil}, 5, "S:G", false], [{7=>nil}, 7, "S:G", false], [{15=>nil}, 15, "S:G", false]], 7=>[[{6=>:enemy}, 6, "S:G", true], [{8=>:enemy}, 8, "S:G", true], [{16=>:enemy}, 16, "S:G", true], [{6=>nil}, 6, "S:G", false], [{8=>nil}, 8, "S:G", false], [{16=>nil}, 16, "S:G", false]], 8=>[[{7=>:enemy}, 7, "S:G", true], [{17=>:enemy}, 17, "S:G", true], [{7=>nil}, 7, "S:G", false], [{17=>nil}, 17, "S:G", false]], 9=>[[{0=>:enemy}, 0, "S:G", true], [{1=>:enemy}, 1, "S:G", true], [{10=>:enemy}, 10, "S:G", true], [{18=>:enemy}, 18, "S:G", true], [{0=>nil}, 0, "S:G", false], [{1=>nil}, 1, "S:G", false], [{10=>nil}, 10, "S:G", false], [{18=>nil}, 18, "S:G", false]], 10=>[[{0=>:enemy}, 0, "S:G", true], [{1=>:enemy}, 1, "S:G", true], [{2=>:enemy}, 2, "S:G", true], [{9=>:enemy}, 9, "S:G", true], [{11=>:enemy}, 11, "S:G", true], [{19=>:enemy}, 19, "S:G", true], [{0=>nil}, 0, "S:G", false], [{1=>nil}, 1, "S:G", false], [{2=>nil}, 2, "S:G", false], [{9=>nil}, 9, "S:G", false], [{11=>nil}, 11, "S:G", false], [{19=>nil}, 19, "S:G", false]], 11=>[[{1=>:enemy}, 1, "S:G", true], [{2=>:enemy}, 2, "S:G", true], [{3=>:enemy}, 3, "S:G", true], [{10=>:enemy}, 10, "S:G", true], [{12=>:enemy}, 12, "S:G", true], [{20=>:enemy}, 20, "S:G", true], [{1=>nil}, 1, "S:G", false], [{2=>nil}, 2, "S:G", false], [{3=>nil}, 3, "S:G", false], [{10=>nil}, 10, "S:G", false], [{12=>nil}, 12, "S:G", false], [{20=>nil}, 20, "S:G", false]], 12=>[[{2=>:enemy}, 2, "S:G", true], [{3=>:enemy}, 3, "S:G", true], [{4=>:enemy}, 4, "S:G", true], [{11=>:enemy}, 11, "S:G", true], [{13=>:enemy}, 13, "S:G", true], [{21=>:enemy}, 21, "S:G", true], [{2=>nil}, 2, "S:G", false], [{3=>nil}, 3, "S:G", false], [{4=>nil}, 4, "S:G", false], [{11=>nil}, 11, "S:G", false], [{13=>nil}, 13, "S:G", false], [{21=>nil}, 21, "S:G", false]], 13=>[[{3=>:enemy}, 3, "S:G", true], [{4=>:enemy}, 4, "S:G", true], [{5=>:enemy}, 5, "S:G", true], [{12=>:enemy}, 12, "S:G", true], [{14=>:enemy}, 14, "S:G", true], [{22=>:enemy}, 22, "S:G", true], [{3=>nil}, 3, "S:G", false], [{4=>nil}, 4, "S:G", false], [{5=>nil}, 5, "S:G", false], [{12=>nil}, 12, "S:G", false], [{14=>nil}, 14, "S:G", false], [{22=>nil}, 22, "S:G", false]], 14=>[[{4=>:enemy}, 4, "S:G", true], [{5=>:enemy}, 5, "S:G", true], [{6=>:enemy}, 6, "S:G", true], [{13=>:enemy}, 13, "S:G", true], [{15=>:enemy}, 15, "S:G", true], [{23=>:enemy}, 23, "S:G", true], [{4=>nil}, 4, "S:G", false], [{5=>nil}, 5, "S:G", false], [{6=>nil}, 6, "S:G", false], [{13=>nil}, 13, "S:G", false], [{15=>nil}, 15, "S:G", false], [{23=>nil}, 23, "S:G", false]], 15=>[[{5=>:enemy}, 5, "S:G", true], [{6=>:enemy}, 6, "S:G", true], [{7=>:enemy}, 7, "S:G", true], [{14=>:enemy}, 14, "S:G", true], [{16=>:enemy}, 16, "S:G", true], [{24=>:enemy}, 24, "S:G", true], [{5=>nil}, 5, "S:G", false], [{6=>nil}, 6, "S:G", false], [{7=>nil}, 7, "S:G", false], [{14=>nil}, 14, "S:G", false], [{16=>nil}, 16, "S:G", false], [{24=>nil}, 24, "S:G", false]], 16=>[[{6=>:enemy}, 6, "S:G", true], [{7=>:enemy}, 7, "S:G", true], [{8=>:enemy}, 8, "S:G", true], [{15=>:enemy}, 15, "S:G", true], [{17=>:enemy}, 17, "S:G", true], [{25=>:enemy}, 25, "S:G", true], [{6=>nil}, 6, "S:G", false], [{7=>nil}, 7, "S:G", false], [{8=>nil}, 8, "S:G", false], [{15=>nil}, 15, "S:G", false], [{17=>nil}, 17, "S:G", false], [{25=>nil}, 25, "S:G", false]], 17=>[[{7=>:enemy}, 7, "S:G", true], [{8=>:enemy}, 8, "S:G", true], [{16=>:enemy}, 16, "S:G", true], [{26=>:enemy}, 26, "S:G", true], [{7=>nil}, 7, "S:G", false], [{8=>nil}, 8, "S:G", false], [{16=>nil}, 16, "S:G", false], [{26=>nil}, 26, "S:G", false]], 18=>[[{9=>:enemy}, 9, "S:G", true], [{10=>:enemy}, 10, "S:G", true], [{19=>:enemy}, 19, "S:G", true], [{27=>:enemy}, 27, "S:G", true], [{9=>nil}, 9, "S:G", false], [{10=>nil}, 10, "S:G", false], [{19=>nil}, 19, "S:G", false], [{27=>nil}, 27, "S:G", false]], 19=>[[{9=>:enemy}, 9, "S:G", true], [{10=>:enemy}, 10, "S:G", true], [{11=>:enemy}, 11, "S:G", true], [{18=>:enemy}, 18, "S:G", true], [{20=>:enemy}, 20, "S:G", true], [{28=>:enemy}, 28, "S:G", true], [{9=>nil}, 9, "S:G", false], [{10=>nil}, 10, "S:G", false], [{11=>nil}, 11, "S:G", false], [{18=>nil}, 18, "S:G", false], [{20=>nil}, 20, "S:G", false], [{28=>nil}, 28, "S:G", false]], 20=>[[{10=>:enemy}, 10, "S:G", true], [{11=>:enemy}, 11, "S:G", true], [{12=>:enemy}, 12, "S:G", true], [{19=>:enemy}, 19, "S:G", true], [{21=>:enemy}, 21, "S:G", true], [{29=>:enemy}, 29, "S:G", true], [{10=>nil}, 10, "S:G", false], [{11=>nil}, 11, "S:G", false], [{12=>nil}, 12, "S:G", false], [{19=>nil}, 19, "S:G", false], [{21=>nil}, 21, "S:G", false], [{29=>nil}, 29, "S:G", false]], 21=>[[{11=>:enemy}, 11, "S:G", true], [{12=>:enemy}, 12, "S:G", true], [{13=>:enemy}, 13, "S:G", true], [{20=>:enemy}, 20, "S:G", true], [{22=>:enemy}, 22, "S:G", true], [{30=>:enemy}, 30, "S:G", true], [{11=>nil}, 11, "S:G", false], [{12=>nil}, 12, "S:G", false], [{13=>nil}, 13, "S:G", false], [{20=>nil}, 20, "S:G", false], [{22=>nil}, 22, "S:G", false], [{30=>nil}, 30, "S:G", false]], 22=>[[{12=>:enemy}, 12, "S:G", true], [{13=>:enemy}, 13, "S:G", true], [{14=>:enemy}, 14, "S:G", true], [{21=>:enemy}, 21, "S:G", true], [{23=>:enemy}, 23, "S:G", true], [{31=>:enemy}, 31, "S:G", true], [{12=>nil}, 12, "S:G", false], [{13=>nil}, 13, "S:G", false], [{14=>nil}, 14, "S:G", false], [{21=>nil}, 21, "S:G", false], [{23=>nil}, 23, "S:G", false], [{31=>nil}, 31, "S:G", false]], 23=>[[{13=>:enemy}, 13, "S:G", true], [{14=>:enemy}, 14, "S:G", true], [{15=>:enemy}, 15, "S:G", true], [{22=>:enemy}, 22, "S:G", true], [{24=>:enemy}, 24, "S:G", true], [{32=>:enemy}, 32, "S:G", true], [{13=>nil}, 13, "S:G", false], [{14=>nil}, 14, "S:G", false], [{15=>nil}, 15, "S:G", false], [{22=>nil}, 22, "S:G", false], [{24=>nil}, 24, "S:G", false], [{32=>nil}, 32, "S:G", false]], 24=>[[{14=>:enemy}, 14, "S:G", true], [{15=>:enemy}, 15, "S:G", true], [{16=>:enemy}, 16, "S:G", true], [{23=>:enemy}, 23, "S:G", true], [{25=>:enemy}, 25, "S:G", true], [{33=>:enemy}, 33, "S:G", true], [{14=>nil}, 14, "S:G", false], [{15=>nil}, 15, "S:G", false], [{16=>nil}, 16, "S:G", false], [{23=>nil}, 23, "S:G", false], [{25=>nil}, 25, "S:G", false], [{33=>nil}, 33, "S:G", false]], 25=>[[{15=>:enemy}, 15, "S:G", true], [{16=>:enemy}, 16, "S:G", true], [{17=>:enemy}, 17, "S:G", true], [{24=>:enemy}, 24, "S:G", true], [{26=>:enemy}, 26, "S:G", true], [{34=>:enemy}, 34, "S:G", true], [{15=>nil}, 15, "S:G", false], [{16=>nil}, 16, "S:G", false], [{17=>nil}, 17, "S:G", false], [{24=>nil}, 24, "S:G", false], [{26=>nil}, 26, "S:G", false], [{34=>nil}, 34, "S:G", false]], 26=>[[{16=>:enemy}, 16, "S:G", true], [{17=>:enemy}, 17, "S:G", true], [{25=>:enemy}, 25, "S:G", true], [{35=>:enemy}, 35, "S:G", true], [{16=>nil}, 16, "S:G", false], [{17=>nil}, 17, "S:G", false], [{25=>nil}, 25, "S:G", false], [{35=>nil}, 35, "S:G", false]], 27=>[[{18=>:enemy}, 18, "S:G", true], [{19=>:enemy}, 19, "S:G", true], [{28=>:enemy}, 28, "S:G", true], [{36=>:enemy}, 36, "S:G", true], [{18=>nil}, 18, "S:G", false], [{19=>nil}, 19, "S:G", false], [{28=>nil}, 28, "S:G", false], [{36=>nil}, 36, "S:G", false]], 28=>[[{18=>:enemy}, 18, "S:G", true], [{19=>:enemy}, 19, "S:G", true], [{20=>:enemy}, 20, "S:G", true], [{27=>:enemy}, 27, "S:G", true], [{29=>:enemy}, 29, "S:G", true], [{37=>:enemy}, 37, "S:G", true], [{18=>nil}, 18, "S:G", false], [{19=>nil}, 19, "S:G", false], [{20=>nil}, 20, "S:G", false], [{27=>nil}, 27, "S:G", false], [{29=>nil}, 29, "S:G", false], [{37=>nil}, 37, "S:G", false]], 29=>[[{19=>:enemy}, 19, "S:G", true], [{20=>:enemy}, 20, "S:G", true], [{21=>:enemy}, 21, "S:G", true], [{28=>:enemy}, 28, "S:G", true], [{30=>:enemy}, 30, "S:G", true], [{38=>:enemy}, 38, "S:G", true], [{19=>nil}, 19, "S:G", false], [{20=>nil}, 20, "S:G", false], [{21=>nil}, 21, "S:G", false], [{28=>nil}, 28, "S:G", false], [{30=>nil}, 30, "S:G", false], [{38=>nil}, 38, "S:G", false]], 30=>[[{20=>:enemy}, 20, "S:G", true], [{21=>:enemy}, 21, "S:G", true], [{22=>:enemy}, 22, "S:G", true], [{29=>:enemy}, 29, "S:G", true], [{31=>:enemy}, 31, "S:G", true], [{39=>:enemy}, 39, "S:G", true], [{20=>nil}, 20, "S:G", false], [{21=>nil}, 21, "S:G", false], [{22=>nil}, 22, "S:G", false], [{29=>nil}, 29, "S:G", false], [{31=>nil}, 31, "S:G", false], [{39=>nil}, 39, "S:G", false]], 31=>[[{21=>:enemy}, 21, "S:G", true], [{22=>:enemy}, 22, "S:G", true], [{23=>:enemy}, 23, "S:G", true], [{30=>:enemy}, 30, "S:G", true], [{32=>:enemy}, 32, "S:G", true], [{40=>:enemy}, 40, "S:G", true], [{21=>nil}, 21, "S:G", false], [{22=>nil}, 22, "S:G", false], [{23=>nil}, 23, "S:G", false], [{30=>nil}, 30, "S:G", false], [{32=>nil}, 32, "S:G", false], [{40=>nil}, 40, "S:G", false]], 32=>[[{22=>:enemy}, 22, "S:G", true], [{23=>:enemy}, 23, "S:G", true], [{24=>:enemy}, 24, "S:G", true], [{31=>:enemy}, 31, "S:G", true], [{33=>:enemy}, 33, "S:G", true], [{41=>:enemy}, 41, "S:G", true], [{22=>nil}, 22, "S:G", false], [{23=>nil}, 23, "S:G", false], [{24=>nil}, 24, "S:G", false], [{31=>nil}, 31, "S:G", false], [{33=>nil}, 33, "S:G", false], [{41=>nil}, 41, "S:G", false]], 33=>[[{23=>:enemy}, 23, "S:G", true], [{24=>:enemy}, 24, "S:G", true], [{25=>:enemy}, 25, "S:G", true], [{32=>:enemy}, 32, "S:G", true], [{34=>:enemy}, 34, "S:G", true], [{42=>:enemy}, 42, "S:G", true], [{23=>nil}, 23, "S:G", false], [{24=>nil}, 24, "S:G", false], [{25=>nil}, 25, "S:G", false], [{32=>nil}, 32, "S:G", false], [{34=>nil}, 34, "S:G", false], [{42=>nil}, 42, "S:G", false]], 34=>[[{24=>:enemy}, 24, "S:G", true], [{25=>:enemy}, 25, "S:G", true], [{26=>:enemy}, 26, "S:G", true], [{33=>:enemy}, 33, "S:G", true], [{35=>:enemy}, 35, "S:G", true], [{43=>:enemy}, 43, "S:G", true], [{24=>nil}, 24, "S:G", false], [{25=>nil}, 25, "S:G", false], [{26=>nil}, 26, "S:G", false], [{33=>nil}, 33, "S:G", false], [{35=>nil}, 35, "S:G", false], [{43=>nil}, 43, "S:G", false]], 35=>[[{25=>:enemy}, 25, "S:G", true], [{26=>:enemy}, 26, "S:G", true], [{34=>:enemy}, 34, "S:G", true], [{44=>:enemy}, 44, "S:G", true], [{25=>nil}, 25, "S:G", false], [{26=>nil}, 26, "S:G", false], [{34=>nil}, 34, "S:G", false], [{44=>nil}, 44, "S:G", false]], 36=>[[{27=>:enemy}, 27, "S:G", true], [{28=>:enemy}, 28, "S:G", true], [{37=>:enemy}, 37, "S:G", true], [{45=>:enemy}, 45, "S:G", true], [{27=>nil}, 27, "S:G", false], [{28=>nil}, 28, "S:G", false], [{37=>nil}, 37, "S:G", false], [{45=>nil}, 45, "S:G", false]], 37=>[[{27=>:enemy}, 27, "S:G", true], [{28=>:enemy}, 28, "S:G", true], [{29=>:enemy}, 29, "S:G", true], [{36=>:enemy}, 36, "S:G", true], [{38=>:enemy}, 38, "S:G", true], [{46=>:enemy}, 46, "S:G", true], [{27=>nil}, 27, "S:G", false], [{28=>nil}, 28, "S:G", false], [{29=>nil}, 29, "S:G", false], [{36=>nil}, 36, "S:G", false], [{38=>nil}, 38, "S:G", false], [{46=>nil}, 46, "S:G", false]], 38=>[[{28=>:enemy}, 28, "S:G", true], [{29=>:enemy}, 29, "S:G", true], [{30=>:enemy}, 30, "S:G", true], [{37=>:enemy}, 37, "S:G", true], [{39=>:enemy}, 39, "S:G", true], [{47=>:enemy}, 47, "S:G", true], [{28=>nil}, 28, "S:G", false], [{29=>nil}, 29, "S:G", false], [{30=>nil}, 30, "S:G", false], [{37=>nil}, 37, "S:G", false], [{39=>nil}, 39, "S:G", false], [{47=>nil}, 47, "S:G", false]], 39=>[[{29=>:enemy}, 29, "S:G", true], [{30=>:enemy}, 30, "S:G", true], [{31=>:enemy}, 31, "S:G", true], [{38=>:enemy}, 38, "S:G", true], [{40=>:enemy}, 40, "S:G", true], [{48=>:enemy}, 48, "S:G", true], [{29=>nil}, 29, "S:G", false], [{30=>nil}, 30, "S:G", false], [{31=>nil}, 31, "S:G", false], [{38=>nil}, 38, "S:G", false], [{40=>nil}, 40, "S:G", false], [{48=>nil}, 48, "S:G", false]], 40=>[[{30=>:enemy}, 30, "S:G", true], [{31=>:enemy}, 31, "S:G", true], [{32=>:enemy}, 32, "S:G", true], [{39=>:enemy}, 39, "S:G", true], [{41=>:enemy}, 41, "S:G", true], [{49=>:enemy}, 49, "S:G", true], [{30=>nil}, 30, "S:G", false], [{31=>nil}, 31, "S:G", false], [{32=>nil}, 32, "S:G", false], [{39=>nil}, 39, "S:G", false], [{41=>nil}, 41, "S:G", false], [{49=>nil}, 49, "S:G", false]], 41=>[[{31=>:enemy}, 31, "S:G", true], [{32=>:enemy}, 32, "S:G", true], [{33=>:enemy}, 33, "S:G", true], [{40=>:enemy}, 40, "S:G", true], [{42=>:enemy}, 42, "S:G", true], [{50=>:enemy}, 50, "S:G", true], [{31=>nil}, 31, "S:G", false], [{32=>nil}, 32, "S:G", false], [{33=>nil}, 33, "S:G", false], [{40=>nil}, 40, "S:G", false], [{42=>nil}, 42, "S:G", false], [{50=>nil}, 50, "S:G", false]], 42=>[[{32=>:enemy}, 32, "S:G", true], [{33=>:enemy}, 33, "S:G", true], [{34=>:enemy}, 34, "S:G", true], [{41=>:enemy}, 41, "S:G", true], [{43=>:enemy}, 43, "S:G", true], [{51=>:enemy}, 51, "S:G", true], [{32=>nil}, 32, "S:G", false], [{33=>nil}, 33, "S:G", false], [{34=>nil}, 34, "S:G", false], [{41=>nil}, 41, "S:G", false], [{43=>nil}, 43, "S:G", false], [{51=>nil}, 51, "S:G", false]], 43=>[[{33=>:enemy}, 33, "S:G", true], [{34=>:enemy}, 34, "S:G", true], [{35=>:enemy}, 35, "S:G", true], [{42=>:enemy}, 42, "S:G", true], [{44=>:enemy}, 44, "S:G", true], [{52=>:enemy}, 52, "S:G", true], [{33=>nil}, 33, "S:G", false], [{34=>nil}, 34, "S:G", false], [{35=>nil}, 35, "S:G", false], [{42=>nil}, 42, "S:G", false], [{44=>nil}, 44, "S:G", false], [{52=>nil}, 52, "S:G", false]], 44=>[[{34=>:enemy}, 34, "S:G", true], [{35=>:enemy}, 35, "S:G", true], [{43=>:enemy}, 43, "S:G", true], [{53=>:enemy}, 53, "S:G", true], [{34=>nil}, 34, "S:G", false], [{35=>nil}, 35, "S:G", false], [{43=>nil}, 43, "S:G", false], [{53=>nil}, 53, "S:G", false]], 45=>[[{36=>:enemy}, 36, "S:G", true], [{37=>:enemy}, 37, "S:G", true], [{46=>:enemy}, 46, "S:G", true], [{54=>:enemy}, 54, "S:G", true], [{36=>nil}, 36, "S:G", false], [{37=>nil}, 37, "S:G", false], [{46=>nil}, 46, "S:G", false], [{54=>nil}, 54, "S:G", false]], 46=>[[{36=>:enemy}, 36, "S:G", true], [{37=>:enemy}, 37, "S:G", true], [{38=>:enemy}, 38, "S:G", true], [{45=>:enemy}, 45, "S:G", true], [{47=>:enemy}, 47, "S:G", true], [{55=>:enemy}, 55, "S:G", true], [{36=>nil}, 36, "S:G", false], [{37=>nil}, 37, "S:G", false], [{38=>nil}, 38, "S:G", false], [{45=>nil}, 45, "S:G", false], [{47=>nil}, 47, "S:G", false], [{55=>nil}, 55, "S:G", false]], 47=>[[{37=>:enemy}, 37, "S:G", true], [{38=>:enemy}, 38, "S:G", true], [{39=>:enemy}, 39, "S:G", true], [{46=>:enemy}, 46, "S:G", true], [{48=>:enemy}, 48, "S:G", true], [{56=>:enemy}, 56, "S:G", true], [{37=>nil}, 37, "S:G", false], [{38=>nil}, 38, "S:G", false], [{39=>nil}, 39, "S:G", false], [{46=>nil}, 46, "S:G", false], [{48=>nil}, 48, "S:G", false], [{56=>nil}, 56, "S:G", false]], 48=>[[{38=>:enemy}, 38, "S:G", true], [{39=>:enemy}, 39, "S:G", true], [{40=>:enemy}, 40, "S:G", true], [{47=>:enemy}, 47, "S:G", true], [{49=>:enemy}, 49, "S:G", true], [{57=>:enemy}, 57, "S:G", true], [{38=>nil}, 38, "S:G", false], [{39=>nil}, 39, "S:G", false], [{40=>nil}, 40, "S:G", false], [{47=>nil}, 47, "S:G", false], [{49=>nil}, 49, "S:G", false], [{57=>nil}, 57, "S:G", false]], 49=>[[{39=>:enemy}, 39, "S:G", true], [{40=>:enemy}, 40, "S:G", true], [{41=>:enemy}, 41, "S:G", true], [{48=>:enemy}, 48, "S:G", true], [{50=>:enemy}, 50, "S:G", true], [{58=>:enemy}, 58, "S:G", true], [{39=>nil}, 39, "S:G", false], [{40=>nil}, 40, "S:G", false], [{41=>nil}, 41, "S:G", false], [{48=>nil}, 48, "S:G", false], [{50=>nil}, 50, "S:G", false], [{58=>nil}, 58, "S:G", false]], 50=>[[{40=>:enemy}, 40, "S:G", true], [{41=>:enemy}, 41, "S:G", true], [{42=>:enemy}, 42, "S:G", true], [{49=>:enemy}, 49, "S:G", true], [{51=>:enemy}, 51, "S:G", true], [{59=>:enemy}, 59, "S:G", true], [{40=>nil}, 40, "S:G", false], [{41=>nil}, 41, "S:G", false], [{42=>nil}, 42, "S:G", false], [{49=>nil}, 49, "S:G", false], [{51=>nil}, 51, "S:G", false], [{59=>nil}, 59, "S:G", false]], 51=>[[{41=>:enemy}, 41, "S:G", true], [{42=>:enemy}, 42, "S:G", true], [{43=>:enemy}, 43, "S:G", true], [{50=>:enemy}, 50, "S:G", true], [{52=>:enemy}, 52, "S:G", true], [{60=>:enemy}, 60, "S:G", true], [{41=>nil}, 41, "S:G", false], [{42=>nil}, 42, "S:G", false], [{43=>nil}, 43, "S:G", false], [{50=>nil}, 50, "S:G", false], [{52=>nil}, 52, "S:G", false], [{60=>nil}, 60, "S:G", false]], 52=>[[{42=>:enemy}, 42, "S:G", true], [{43=>:enemy}, 43, "S:G", true], [{44=>:enemy}, 44, "S:G", true], [{51=>:enemy}, 51, "S:G", true], [{53=>:enemy}, 53, "S:G", true], [{61=>:enemy}, 61, "S:G", true], [{42=>nil}, 42, "S:G", false], [{43=>nil}, 43, "S:G", false], [{44=>nil}, 44, "S:G", false], [{51=>nil}, 51, "S:G", false], [{53=>nil}, 53, "S:G", false], [{61=>nil}, 61, "S:G", false]], 53=>[[{43=>:enemy}, 43, "S:G", true], [{44=>:enemy}, 44, "S:G", true], [{52=>:enemy}, 52, "S:G", true], [{62=>:enemy}, 62, "S:G", true], [{43=>nil}, 43, "S:G", false], [{44=>nil}, 44, "S:G", false], [{52=>nil}, 52, "S:G", false], [{62=>nil}, 62, "S:G", false]], 54=>[[{45=>:enemy}, 45, "S:G", true], [{46=>:enemy}, 46, "S:G", true], [{55=>:enemy}, 55, "S:G", true], [{63=>:enemy}, 63, "S:G", true], [{45=>nil}, 45, "S:G", false], [{46=>nil}, 46, "S:G", false], [{55=>nil}, 55, "S:G", false], [{63=>nil}, 63, "S:G", false]], 55=>[[{45=>:enemy}, 45, "S:G", true], [{46=>:enemy}, 46, "S:G", true], [{47=>:enemy}, 47, "S:G", true], [{54=>:enemy}, 54, "S:G", true], [{56=>:enemy}, 56, "S:G", true], [{64=>:enemy}, 64, "S:G", true], [{45=>nil}, 45, "S:G", false], [{46=>nil}, 46, "S:G", false], [{47=>nil}, 47, "S:G", false], [{54=>nil}, 54, "S:G", false], [{56=>nil}, 56, "S:G", false], [{64=>nil}, 64, "S:G", false]], 56=>[[{46=>:enemy}, 46, "S:G", true], [{47=>:enemy}, 47, "S:G", true], [{48=>:enemy}, 48, "S:G", true], [{55=>:enemy}, 55, "S:G", true], [{57=>:enemy}, 57, "S:G", true], [{65=>:enemy}, 65, "S:G", true], [{46=>nil}, 46, "S:G", false], [{47=>nil}, 47, "S:G", false], [{48=>nil}, 48, "S:G", false], [{55=>nil}, 55, "S:G", false], [{57=>nil}, 57, "S:G", false], [{65=>nil}, 65, "S:G", false]], 57=>[[{47=>:enemy}, 47, "S:G", true], [{48=>:enemy}, 48, "S:G", true], [{49=>:enemy}, 49, "S:G", true], [{56=>:enemy}, 56, "S:G", true], [{58=>:enemy}, 58, "S:G", true], [{66=>:enemy}, 66, "S:G", true], [{47=>nil}, 47, "S:G", false], [{48=>nil}, 48, "S:G", false], [{49=>nil}, 49, "S:G", false], [{56=>nil}, 56, "S:G", false], [{58=>nil}, 58, "S:G", false], [{66=>nil}, 66, "S:G", false]], 58=>[[{48=>:enemy}, 48, "S:G", true], [{49=>:enemy}, 49, "S:G", true], [{50=>:enemy}, 50, "S:G", true], [{57=>:enemy}, 57, "S:G", true], [{59=>:enemy}, 59, "S:G", true], [{67=>:enemy}, 67, "S:G", true], [{48=>nil}, 48, "S:G", false], [{49=>nil}, 49, "S:G", false], [{50=>nil}, 50, "S:G", false], [{57=>nil}, 57, "S:G", false], [{59=>nil}, 59, "S:G", false], [{67=>nil}, 67, "S:G", false]], 59=>[[{49=>:enemy}, 49, "S:G", true], [{50=>:enemy}, 50, "S:G", true], [{51=>:enemy}, 51, "S:G", true], [{58=>:enemy}, 58, "S:G", true], [{60=>:enemy}, 60, "S:G", true], [{68=>:enemy}, 68, "S:G", true], [{49=>nil}, 49, "S:G", false], [{50=>nil}, 50, "S:G", false], [{51=>nil}, 51, "S:G", false], [{58=>nil}, 58, "S:G", false], [{60=>nil}, 60, "S:G", false], [{68=>nil}, 68, "S:G", false]], 60=>[[{50=>:enemy}, 50, "S:G", true], [{51=>:enemy}, 51, "S:G", true], [{52=>:enemy}, 52, "S:G", true], [{59=>:enemy}, 59, "S:G", true], [{61=>:enemy}, 61, "S:G", true], [{69=>:enemy}, 69, "S:G", true], [{50=>nil}, 50, "S:G", false], [{51=>nil}, 51, "S:G", false], [{52=>nil}, 52, "S:G", false], [{59=>nil}, 59, "S:G", false], [{61=>nil}, 61, "S:G", false], [{69=>nil}, 69, "S:G", false]], 61=>[[{51=>:enemy}, 51, "S:G", true], [{52=>:enemy}, 52, "S:G", true], [{53=>:enemy}, 53, "S:G", true], [{60=>:enemy}, 60, "S:G", true], [{62=>:enemy}, 62, "S:G", true], [{70=>:enemy}, 70, "S:G", true], [{51=>nil}, 51, "S:G", false], [{52=>nil}, 52, "S:G", false], [{53=>nil}, 53, "S:G", false], [{60=>nil}, 60, "S:G", false], [{62=>nil}, 62, "S:G", false], [{70=>nil}, 70, "S:G", false]], 62=>[[{52=>:enemy}, 52, "S:G", true], [{53=>:enemy}, 53, "S:G", true], [{61=>:enemy}, 61, "S:G", true], [{71=>:enemy}, 71, "S:G", true], [{52=>nil}, 52, "S:G", false], [{53=>nil}, 53, "S:G", false], [{61=>nil}, 61, "S:G", false], [{71=>nil}, 71, "S:G", false]], 63=>[[{54=>:enemy}, 54, "S:G", true], [{55=>:enemy}, 55, "S:G", true], [{64=>:enemy}, 64, "S:G", true], [{72=>:enemy}, 72, "S:G", true], [{54=>nil}, 54, "S:G", false], [{55=>nil}, 55, "S:G", false], [{64=>nil}, 64, "S:G", false], [{72=>nil}, 72, "S:G", false]], 64=>[[{54=>:enemy}, 54, "S:G", true], [{55=>:enemy}, 55, "S:G", true], [{56=>:enemy}, 56, "S:G", true], [{63=>:enemy}, 63, "S:G", true], [{65=>:enemy}, 65, "S:G", true], [{73=>:enemy}, 73, "S:G", true], [{54=>nil}, 54, "S:G", false], [{55=>nil}, 55, "S:G", false], [{56=>nil}, 56, "S:G", false], [{63=>nil}, 63, "S:G", false], [{65=>nil}, 65, "S:G", false], [{73=>nil}, 73, "S:G", false]], 65=>[[{55=>:enemy}, 55, "S:G", true], [{56=>:enemy}, 56, "S:G", true], [{57=>:enemy}, 57, "S:G", true], [{64=>:enemy}, 64, "S:G", true], [{66=>:enemy}, 66, "S:G", true], [{74=>:enemy}, 74, "S:G", true], [{55=>nil}, 55, "S:G", false], [{56=>nil}, 56, "S:G", false], [{57=>nil}, 57, "S:G", false], [{64=>nil}, 64, "S:G", false], [{66=>nil}, 66, "S:G", false], [{74=>nil}, 74, "S:G", false]], 66=>[[{56=>:enemy}, 56, "S:G", true], [{57=>:enemy}, 57, "S:G", true], [{58=>:enemy}, 58, "S:G", true], [{65=>:enemy}, 65, "S:G", true], [{67=>:enemy}, 67, "S:G", true], [{75=>:enemy}, 75, "S:G", true], [{56=>nil}, 56, "S:G", false], [{57=>nil}, 57, "S:G", false], [{58=>nil}, 58, "S:G", false], [{65=>nil}, 65, "S:G", false], [{67=>nil}, 67, "S:G", false], [{75=>nil}, 75, "S:G", false]], 67=>[[{57=>:enemy}, 57, "S:G", true], [{58=>:enemy}, 58, "S:G", true], [{59=>:enemy}, 59, "S:G", true], [{66=>:enemy}, 66, "S:G", true], [{68=>:enemy}, 68, "S:G", true], [{76=>:enemy}, 76, "S:G", true], [{57=>nil}, 57, "S:G", false], [{58=>nil}, 58, "S:G", false], [{59=>nil}, 59, "S:G", false], [{66=>nil}, 66, "S:G", false], [{68=>nil}, 68, "S:G", false], [{76=>nil}, 76, "S:G", false]], 68=>[[{58=>:enemy}, 58, "S:G", true], [{59=>:enemy}, 59, "S:G", true], [{60=>:enemy}, 60, "S:G", true], [{67=>:enemy}, 67, "S:G", true], [{69=>:enemy}, 69, "S:G", true], [{77=>:enemy}, 77, "S:G", true], [{58=>nil}, 58, "S:G", false], [{59=>nil}, 59, "S:G", false], [{60=>nil}, 60, "S:G", false], [{67=>nil}, 67, "S:G", false], [{69=>nil}, 69, "S:G", false], [{77=>nil}, 77, "S:G", false]], 69=>[[{59=>:enemy}, 59, "S:G", true], [{60=>:enemy}, 60, "S:G", true], [{61=>:enemy}, 61, "S:G", true], [{68=>:enemy}, 68, "S:G", true], [{70=>:enemy}, 70, "S:G", true], [{78=>:enemy}, 78, "S:G", true], [{59=>nil}, 59, "S:G", false], [{60=>nil}, 60, "S:G", false], [{61=>nil}, 61, "S:G", false], [{68=>nil}, 68, "S:G", false], [{70=>nil}, 70, "S:G", false], [{78=>nil}, 78, "S:G", false]], 70=>[[{60=>:enemy}, 60, "S:G", true], [{61=>:enemy}, 61, "S:G", true], [{62=>:enemy}, 62, "S:G", true], [{69=>:enemy}, 69, "S:G", true], [{71=>:enemy}, 71, "S:G", true], [{79=>:enemy}, 79, "S:G", true], [{60=>nil}, 60, "S:G", false], [{61=>nil}, 61, "S:G", false], [{62=>nil}, 62, "S:G", false], [{69=>nil}, 69, "S:G", false], [{71=>nil}, 71, "S:G", false], [{79=>nil}, 79, "S:G", false]], 71=>[[{61=>:enemy}, 61, "S:G", true], [{62=>:enemy}, 62, "S:G", true], [{70=>:enemy}, 70, "S:G", true], [{80=>:enemy}, 80, "S:G", true], [{61=>nil}, 61, "S:G", false], [{62=>nil}, 62, "S:G", false], [{70=>nil}, 70, "S:G", false], [{80=>nil}, 80, "S:G", false]], 72=>[[{63=>:enemy}, 63, "S:G", true], [{64=>:enemy}, 64, "S:G", true], [{73=>:enemy}, 73, "S:G", true], [{63=>nil}, 63, "S:G", false], [{64=>nil}, 64, "S:G", false], [{73=>nil}, 73, "S:G", false]], 73=>[[{63=>:enemy}, 63, "S:G", true], [{64=>:enemy}, 64, "S:G", true], [{65=>:enemy}, 65, "S:G", true], [{72=>:enemy}, 72, "S:G", true], [{74=>:enemy}, 74, "S:G", true], [{63=>nil}, 63, "S:G", false], [{64=>nil}, 64, "S:G", false], [{65=>nil}, 65, "S:G", false], [{72=>nil}, 72, "S:G", false], [{74=>nil}, 74, "S:G", false]], 74=>[[{64=>:enemy}, 64, "S:G", true], [{65=>:enemy}, 65, "S:G", true], [{66=>:enemy}, 66, "S:G", true], [{73=>:enemy}, 73, "S:G", true], [{75=>:enemy}, 75, "S:G", true], [{64=>nil}, 64, "S:G", false], [{65=>nil}, 65, "S:G", false], [{66=>nil}, 66, "S:G", false], [{73=>nil}, 73, "S:G", false], [{75=>nil}, 75, "S:G", false]], 75=>[[{65=>:enemy}, 65, "S:G", true], [{66=>:enemy}, 66, "S:G", true], [{67=>:enemy}, 67, "S:G", true], [{74=>:enemy}, 74, "S:G", true], [{76=>:enemy}, 76, "S:G", true], [{65=>nil}, 65, "S:G", false], [{66=>nil}, 66, "S:G", false], [{67=>nil}, 67, "S:G", false], [{74=>nil}, 74, "S:G", false], [{76=>nil}, 76, "S:G", false]], 76=>[[{66=>:enemy}, 66, "S:G", true], [{67=>:enemy}, 67, "S:G", true], [{68=>:enemy}, 68, "S:G", true], [{75=>:enemy}, 75, "S:G", true], [{77=>:enemy}, 77, "S:G", true], [{66=>nil}, 66, "S:G", false], [{67=>nil}, 67, "S:G", false], [{68=>nil}, 68, "S:G", false], [{75=>nil}, 75, "S:G", false], [{77=>nil}, 77, "S:G", false]], 77=>[[{67=>:enemy}, 67, "S:G", true], [{68=>:enemy}, 68, "S:G", true], [{69=>:enemy}, 69, "S:G", true], [{76=>:enemy}, 76, "S:G", true], [{78=>:enemy}, 78, "S:G", true], [{67=>nil}, 67, "S:G", false], [{68=>nil}, 68, "S:G", false], [{69=>nil}, 69, "S:G", false], [{76=>nil}, 76, "S:G", false], [{78=>nil}, 78, "S:G", false]], 78=>[[{68=>:enemy}, 68, "S:G", true], [{69=>:enemy}, 69, "S:G", true], [{70=>:enemy}, 70, "S:G", true], [{77=>:enemy}, 77, "S:G", true], [{79=>:enemy}, 79, "S:G", true], [{68=>nil}, 68, "S:G", false], [{69=>nil}, 69, "S:G", false], [{70=>nil}, 70, "S:G", false], [{77=>nil}, 77, "S:G", false], [{79=>nil}, 79, "S:G", false]], 79=>[[{69=>:enemy}, 69, "S:G", true], [{70=>:enemy}, 70, "S:G", true], [{71=>:enemy}, 71, "S:G", true], [{78=>:enemy}, 78, "S:G", true], [{80=>:enemy}, 80, "S:G", true], [{69=>nil}, 69, "S:G", false], [{70=>nil}, 70, "S:G", false], [{71=>nil}, 71, "S:G", false], [{78=>nil}, 78, "S:G", false], [{80=>nil}, 80, "S:G", false]], 80=>[[{70=>:enemy}, 70, "S:G", true], [{71=>:enemy}, 71, "S:G", true], [{79=>:enemy}, 79, "S:G", true], [{70=>nil}, 70, "S:G", false], [{71=>nil}, 71, "S:G", false], [{79=>nil}, 79, "S:G", false]], nil=>[[{0=>nil}, 0, "S:G", false], [{1=>nil}, 1, "S:G", false], [{2=>nil}, 2, "S:G", false], [{3=>nil}, 3, "S:G", false], [{4=>nil}, 4, "S:G", false], [{5=>nil}, 5, "S:G", false], [{6=>nil}, 6, "S:G", false], [{7=>nil}, 7, "S:G", false], [{8=>nil}, 8, "S:G", false], [{9=>nil}, 9, "S:G", false], [{10=>nil}, 10, "S:G", false], [{11=>nil}, 11, "S:G", false], [{12=>nil}, 12, "S:G", false], [{13=>nil}, 13, "S:G", false], [{14=>nil}, 14, "S:G", false], [{15=>nil}, 15, "S:G", false], [{16=>nil}, 16, "S:G", false], [{17=>nil}, 17, "S:G", false], [{18=>nil}, 18, "S:G", false], [{19=>nil}, 19, "S:G", false], [{20=>nil}, 20, "S:G", false], [{21=>nil}, 21, "S:G", false], [{22=>nil}, 22, "S:G", false], [{23=>nil}, 23, "S:G", false], [{24=>nil}, 24, "S:G", false], [{25=>nil}, 25, "S:G", false], [{26=>nil}, 26, "S:G", false], [{27=>nil}, 27, "S:G", false], [{28=>nil}, 28, "S:G", false], [{29=>nil}, 29, "S:G", false], [{30=>nil}, 30, "S:G", false], [{31=>nil}, 31, "S:G", false], [{32=>nil}, 32, "S:G", false], [{33=>nil}, 33, "S:G", false], [{34=>nil}, 34, "S:G", false], [{35=>nil}, 35, "S:G", false], [{36=>nil}, 36, "S:G", false], [{37=>nil}, 37, "S:G", false], [{38=>nil}, 38, "S:G", false], [{39=>nil}, 39, "S:G", false], [{40=>nil}, 40, "S:G", false], [{41=>nil}, 41, "S:G", false], [{42=>nil}, 42, "S:G", false], [{43=>nil}, 43, "S:G", false], [{44=>nil}, 44, "S:G", false], [{45=>nil}, 45, "S:G", false], [{46=>nil}, 46, "S:G", false], [{47=>nil}, 47, "S:G", false], [{48=>nil}, 48, "S:G", false], [{49=>nil}, 49, "S:G", false], [{50=>nil}, 50, "S:G", false], [{51=>nil}, 51, "S:G", false], [{52=>nil}, 52, "S:G", false], [{53=>nil}, 53, "S:G", false], [{54=>nil}, 54, "S:G", false], [{55=>nil}, 55, "S:G", false], [{56=>nil}, 56, "S:G", false], [{57=>nil}, 57, "S:G", false], [{58=>nil}, 58, "S:G", false], [{59=>nil}, 59, "S:G", false], [{60=>nil}, 60, "S:G", false], [{61=>nil}, 61, "S:G", false], [{62=>nil}, 62, "S:G", false], [{63=>nil}, 63, "S:G", false], [{64=>nil}, 64, "S:G", false], [{65=>nil}, 65, "S:G", false], [{66=>nil}, 66, "S:G", false], [{67=>nil}, 67, "S:G", false], [{68=>nil}, 68, "S:G", false], [{69=>nil}, 69, "S:G", false], [{70=>nil}, 70, "S:G", false], [{71=>nil}, 71, "S:G", false], [{72=>nil}, 72, "S:G", false], [{73=>nil}, 73, "S:G", false], [{74=>nil}, 74, "S:G", false], [{75=>nil}, 75, "S:G", false], [{76=>nil}, 76, "S:G", false], [{77=>nil}, 77, "S:G", false], [{78=>nil}, 78, "S:G", false], [{79=>nil}, 79, "S:G", false], [{80=>nil}, 80, "S:G", false]]}, "S:L"=>{0=>[], 1=>[], 2=>[], 3=>[], 4=>[], 5=>[], 6=>[], 7=>[], 8=>[], 9=>[[{0=>:enemy}, 0, "S:+L", true], [{0=>nil}, 0, "S:+L", false]], 10=>[[{1=>:enemy}, 1, "S:+L", true], [{1=>nil}, 1, "S:+L", false]], 11=>[[{2=>:enemy}, 2, "S:+L", true], [{2=>nil}, 2, "S:+L", false]], 12=>[[{3=>:enemy}, 3, "S:+L", true], [{3=>nil}, 3, "S:+L", false]], 13=>[[{4=>:enemy}, 4, "S:+L", true], [{4=>nil}, 4, "S:+L", false]], 14=>[[{5=>:enemy}, 5, "S:+L", true], [{5=>nil}, 5, "S:+L", false]], 15=>[[{6=>:enemy}, 6, "S:+L", true], [{6=>nil}, 6, "S:+L", false]], 16=>[[{7=>:enemy}, 7, "S:+L", true], [{7=>nil}, 7, "S:+L", false]], 17=>[[{8=>:enemy}, 8, "S:+L", true], [{8=>nil}, 8, "S:+L", false]], 18=>[[{9=>:enemy}, 9, "S:+L", true], [{9=>nil}, 9, "S:+L", false], [{9=>nil, 0=>:enemy}, 0, "S:+L", true], [{9=>nil, 0=>nil}, 0, "S:+L", false]], 19=>[[{10=>:enemy}, 10, "S:+L", true], [{10=>nil}, 10, "S:+L", false], [{10=>nil, 1=>:enemy}, 1, "S:+L", true], [{10=>nil, 1=>nil}, 1, "S:+L", false]], 20=>[[{11=>:enemy}, 11, "S:+L", true], [{11=>nil}, 11, "S:+L", false], [{11=>nil, 2=>:enemy}, 2, "S:+L", true], [{11=>nil, 2=>nil}, 2, "S:+L", false]], 21=>[[{12=>:enemy}, 12, "S:+L", true], [{12=>nil}, 12, "S:+L", false], [{12=>nil, 3=>:enemy}, 3, "S:+L", true], [{12=>nil, 3=>nil}, 3, "S:+L", false]], 22=>[[{13=>:enemy}, 13, "S:+L", true], [{13=>nil}, 13, "S:+L", false], [{13=>nil, 4=>:enemy}, 4, "S:+L", true], [{13=>nil, 4=>nil}, 4, "S:+L", false]], 23=>[[{14=>:enemy}, 14, "S:+L", true], [{14=>nil}, 14, "S:+L", false], [{14=>nil, 5=>:enemy}, 5, "S:+L", true], [{14=>nil, 5=>nil}, 5, "S:+L", false]], 24=>[[{15=>:enemy}, 15, "S:+L", true], [{15=>nil}, 15, "S:+L", false], [{15=>nil, 6=>:enemy}, 6, "S:+L", true], [{15=>nil, 6=>nil}, 6, "S:+L", false]], 25=>[[{16=>:enemy}, 16, "S:+L", true], [{16=>nil}, 16, "S:+L", false], [{16=>nil, 7=>:enemy}, 7, "S:+L", true], [{16=>nil, 7=>nil}, 7, "S:+L", false]], 26=>[[{17=>:enemy}, 17, "S:+L", true], [{17=>nil}, 17, "S:+L", false], [{17=>nil, 8=>:enemy}, 8, "S:+L", true], [{17=>nil, 8=>nil}, 8, "S:+L", false]], 27=>[[{18=>:enemy}, 18, "S:+L", true], [{18=>nil}, 18, "S:+L", false], [{18=>nil, 9=>:enemy}, 9, "S:+L", true], [{18=>nil, 9=>nil}, 9, "S:+L", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 28=>[[{19=>:enemy}, 19, "S:+L", true], [{19=>nil}, 19, "S:+L", false], [{19=>nil, 10=>:enemy}, 10, "S:+L", true], [{19=>nil, 10=>nil}, 10, "S:+L", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 29=>[[{20=>:enemy}, 20, "S:+L", true], [{20=>nil}, 20, "S:+L", false], [{20=>nil, 11=>:enemy}, 11, "S:+L", true], [{20=>nil, 11=>nil}, 11, "S:+L", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 30=>[[{21=>:enemy}, 21, "S:+L", true], [{21=>nil}, 21, "S:+L", false], [{21=>nil, 12=>:enemy}, 12, "S:+L", true], [{21=>nil, 12=>nil}, 12, "S:+L", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 31=>[[{22=>:enemy}, 22, "S:+L", true], [{22=>nil}, 22, "S:+L", false], [{22=>nil, 13=>:enemy}, 13, "S:+L", true], [{22=>nil, 13=>nil}, 13, "S:+L", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 32=>[[{23=>:enemy}, 23, "S:+L", true], [{23=>nil}, 23, "S:+L", false], [{23=>nil, 14=>:enemy}, 14, "S:+L", true], [{23=>nil, 14=>nil}, 14, "S:+L", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 33=>[[{24=>:enemy}, 24, "S:+L", true], [{24=>nil}, 24, "S:+L", false], [{24=>nil, 15=>:enemy}, 15, "S:+L", true], [{24=>nil, 15=>nil}, 15, "S:+L", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 34=>[[{25=>:enemy}, 25, "S:+L", true], [{25=>nil}, 25, "S:+L", false], [{25=>nil, 16=>:enemy}, 16, "S:+L", true], [{25=>nil, 16=>nil}, 16, "S:+L", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 35=>[[{26=>:enemy}, 26, "S:+L", true], [{26=>nil}, 26, "S:+L", false], [{26=>nil, 17=>:enemy}, 17, "S:+L", true], [{26=>nil, 17=>nil}, 17, "S:+L", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], 36=>[[{27=>:enemy}, 27, "S:L", true], [{27=>nil}, 27, "S:L", false], [{27=>nil, 18=>:enemy}, 18, "S:+L", true], [{27=>nil, 18=>nil}, 18, "S:+L", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 37=>[[{28=>:enemy}, 28, "S:L", true], [{28=>nil}, 28, "S:L", false], [{28=>nil, 19=>:enemy}, 19, "S:+L", true], [{28=>nil, 19=>nil}, 19, "S:+L", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 38=>[[{29=>:enemy}, 29, "S:L", true], [{29=>nil}, 29, "S:L", false], [{29=>nil, 20=>:enemy}, 20, "S:+L", true], [{29=>nil, 20=>nil}, 20, "S:+L", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 39=>[[{30=>:enemy}, 30, "S:L", true], [{30=>nil}, 30, "S:L", false], [{30=>nil, 21=>:enemy}, 21, "S:+L", true], [{30=>nil, 21=>nil}, 21, "S:+L", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 40=>[[{31=>:enemy}, 31, "S:L", true], [{31=>nil}, 31, "S:L", false], [{31=>nil, 22=>:enemy}, 22, "S:+L", true], [{31=>nil, 22=>nil}, 22, "S:+L", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 41=>[[{32=>:enemy}, 32, "S:L", true], [{32=>nil}, 32, "S:L", false], [{32=>nil, 23=>:enemy}, 23, "S:+L", true], [{32=>nil, 23=>nil}, 23, "S:+L", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 42=>[[{33=>:enemy}, 33, "S:L", true], [{33=>nil}, 33, "S:L", false], [{33=>nil, 24=>:enemy}, 24, "S:+L", true], [{33=>nil, 24=>nil}, 24, "S:+L", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 43=>[[{34=>:enemy}, 34, "S:L", true], [{34=>nil}, 34, "S:L", false], [{34=>nil, 25=>:enemy}, 25, "S:+L", true], [{34=>nil, 25=>nil}, 25, "S:+L", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 44=>[[{35=>:enemy}, 35, "S:L", true], [{35=>nil}, 35, "S:L", false], [{35=>nil, 26=>:enemy}, 26, "S:+L", true], [{35=>nil, 26=>nil}, 26, "S:+L", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], 45=>[[{36=>:enemy}, 36, "S:L", true], [{36=>nil}, 36, "S:L", false], [{36=>nil, 27=>:enemy}, 27, "S:L", true], [{36=>nil, 27=>nil}, 27, "S:L", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 46=>[[{37=>:enemy}, 37, "S:L", true], [{37=>nil}, 37, "S:L", false], [{37=>nil, 28=>:enemy}, 28, "S:L", true], [{37=>nil, 28=>nil}, 28, "S:L", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 47=>[[{38=>:enemy}, 38, "S:L", true], [{38=>nil}, 38, "S:L", false], [{38=>nil, 29=>:enemy}, 29, "S:L", true], [{38=>nil, 29=>nil}, 29, "S:L", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 48=>[[{39=>:enemy}, 39, "S:L", true], [{39=>nil}, 39, "S:L", false], [{39=>nil, 30=>:enemy}, 30, "S:L", true], [{39=>nil, 30=>nil}, 30, "S:L", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 49=>[[{40=>:enemy}, 40, "S:L", true], [{40=>nil}, 40, "S:L", false], [{40=>nil, 31=>:enemy}, 31, "S:L", true], [{40=>nil, 31=>nil}, 31, "S:L", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 50=>[[{41=>:enemy}, 41, "S:L", true], [{41=>nil}, 41, "S:L", false], [{41=>nil, 32=>:enemy}, 32, "S:L", true], [{41=>nil, 32=>nil}, 32, "S:L", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 51=>[[{42=>:enemy}, 42, "S:L", true], [{42=>nil}, 42, "S:L", false], [{42=>nil, 33=>:enemy}, 33, "S:L", true], [{42=>nil, 33=>nil}, 33, "S:L", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 52=>[[{43=>:enemy}, 43, "S:L", true], [{43=>nil}, 43, "S:L", false], [{43=>nil, 34=>:enemy}, 34, "S:L", true], [{43=>nil, 34=>nil}, 34, "S:L", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 53=>[[{44=>:enemy}, 44, "S:L", true], [{44=>nil}, 44, "S:L", false], [{44=>nil, 35=>:enemy}, 35, "S:L", true], [{44=>nil, 35=>nil}, 35, "S:L", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], 54=>[[{45=>:enemy}, 45, "S:L", true], [{45=>nil}, 45, "S:L", false], [{45=>nil, 36=>:enemy}, 36, "S:L", true], [{45=>nil, 36=>nil}, 36, "S:L", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "S:L", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "S:L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 55=>[[{46=>:enemy}, 46, "S:L", true], [{46=>nil}, 46, "S:L", false], [{46=>nil, 37=>:enemy}, 37, "S:L", true], [{46=>nil, 37=>nil}, 37, "S:L", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "S:L", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "S:L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 56=>[[{47=>:enemy}, 47, "S:L", true], [{47=>nil}, 47, "S:L", false], [{47=>nil, 38=>:enemy}, 38, "S:L", true], [{47=>nil, 38=>nil}, 38, "S:L", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "S:L", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "S:L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 57=>[[{48=>:enemy}, 48, "S:L", true], [{48=>nil}, 48, "S:L", false], [{48=>nil, 39=>:enemy}, 39, "S:L", true], [{48=>nil, 39=>nil}, 39, "S:L", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "S:L", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "S:L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 58=>[[{49=>:enemy}, 49, "S:L", true], [{49=>nil}, 49, "S:L", false], [{49=>nil, 40=>:enemy}, 40, "S:L", true], [{49=>nil, 40=>nil}, 40, "S:L", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "S:L", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "S:L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 59=>[[{50=>:enemy}, 50, "S:L", true], [{50=>nil}, 50, "S:L", false], [{50=>nil, 41=>:enemy}, 41, "S:L", true], [{50=>nil, 41=>nil}, 41, "S:L", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "S:L", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "S:L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 60=>[[{51=>:enemy}, 51, "S:L", true], [{51=>nil}, 51, "S:L", false], [{51=>nil, 42=>:enemy}, 42, "S:L", true], [{51=>nil, 42=>nil}, 42, "S:L", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "S:L", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "S:L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 61=>[[{52=>:enemy}, 52, "S:L", true], [{52=>nil}, 52, "S:L", false], [{52=>nil, 43=>:enemy}, 43, "S:L", true], [{52=>nil, 43=>nil}, 43, "S:L", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "S:L", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "S:L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 62=>[[{53=>:enemy}, 53, "S:L", true], [{53=>nil}, 53, "S:L", false], [{53=>nil, 44=>:enemy}, 44, "S:L", true], [{53=>nil, 44=>nil}, 44, "S:L", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "S:L", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "S:L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], 63=>[[{54=>:enemy}, 54, "S:L", true], [{54=>nil}, 54, "S:L", false], [{54=>nil, 45=>:enemy}, 45, "S:L", true], [{54=>nil, 45=>nil}, 45, "S:L", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "S:L", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "S:L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 64=>[[{55=>:enemy}, 55, "S:L", true], [{55=>nil}, 55, "S:L", false], [{55=>nil, 46=>:enemy}, 46, "S:L", true], [{55=>nil, 46=>nil}, 46, "S:L", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "S:L", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "S:L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 65=>[[{56=>:enemy}, 56, "S:L", true], [{56=>nil}, 56, "S:L", false], [{56=>nil, 47=>:enemy}, 47, "S:L", true], [{56=>nil, 47=>nil}, 47, "S:L", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "S:L", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "S:L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 66=>[[{57=>:enemy}, 57, "S:L", true], [{57=>nil}, 57, "S:L", false], [{57=>nil, 48=>:enemy}, 48, "S:L", true], [{57=>nil, 48=>nil}, 48, "S:L", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "S:L", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "S:L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 67=>[[{58=>:enemy}, 58, "S:L", true], [{58=>nil}, 58, "S:L", false], [{58=>nil, 49=>:enemy}, 49, "S:L", true], [{58=>nil, 49=>nil}, 49, "S:L", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "S:L", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "S:L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 68=>[[{59=>:enemy}, 59, "S:L", true], [{59=>nil}, 59, "S:L", false], [{59=>nil, 50=>:enemy}, 50, "S:L", true], [{59=>nil, 50=>nil}, 50, "S:L", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "S:L", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "S:L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 69=>[[{60=>:enemy}, 60, "S:L", true], [{60=>nil}, 60, "S:L", false], [{60=>nil, 51=>:enemy}, 51, "S:L", true], [{60=>nil, 51=>nil}, 51, "S:L", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "S:L", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "S:L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 70=>[[{61=>:enemy}, 61, "S:L", true], [{61=>nil}, 61, "S:L", false], [{61=>nil, 52=>:enemy}, 52, "S:L", true], [{61=>nil, 52=>nil}, 52, "S:L", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "S:L", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "S:L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 71=>[[{62=>:enemy}, 62, "S:L", true], [{62=>nil}, 62, "S:L", false], [{62=>nil, 53=>:enemy}, 53, "S:L", true], [{62=>nil, 53=>nil}, 53, "S:L", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "S:L", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "S:L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], 72=>[[{63=>:enemy}, 63, "S:L", true], [{63=>nil}, 63, "S:L", false], [{63=>nil, 54=>:enemy}, 54, "S:L", true], [{63=>nil, 54=>nil}, 54, "S:L", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "S:L", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "S:L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "S:L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "S:L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+L", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+L", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+L", false]], 73=>[[{64=>:enemy}, 64, "S:L", true], [{64=>nil}, 64, "S:L", false], [{64=>nil, 55=>:enemy}, 55, "S:L", true], [{64=>nil, 55=>nil}, 55, "S:L", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "S:L", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "S:L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "S:L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "S:L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+L", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+L", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+L", false]], 74=>[[{65=>:enemy}, 65, "S:L", true], [{65=>nil}, 65, "S:L", false], [{65=>nil, 56=>:enemy}, 56, "S:L", true], [{65=>nil, 56=>nil}, 56, "S:L", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "S:L", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "S:L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "S:L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "S:L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+L", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+L", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+L", false]], 75=>[[{66=>:enemy}, 66, "S:L", true], [{66=>nil}, 66, "S:L", false], [{66=>nil, 57=>:enemy}, 57, "S:L", true], [{66=>nil, 57=>nil}, 57, "S:L", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "S:L", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "S:L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "S:L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "S:L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+L", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+L", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+L", false]], 76=>[[{67=>:enemy}, 67, "S:L", true], [{67=>nil}, 67, "S:L", false], [{67=>nil, 58=>:enemy}, 58, "S:L", true], [{67=>nil, 58=>nil}, 58, "S:L", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "S:L", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "S:L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "S:L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "S:L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+L", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+L", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+L", false]], 77=>[[{68=>:enemy}, 68, "S:L", true], [{68=>nil}, 68, "S:L", false], [{68=>nil, 59=>:enemy}, 59, "S:L", true], [{68=>nil, 59=>nil}, 59, "S:L", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "S:L", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "S:L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "S:L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "S:L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+L", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+L", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+L", false]], 78=>[[{69=>:enemy}, 69, "S:L", true], [{69=>nil}, 69, "S:L", false], [{69=>nil, 60=>:enemy}, 60, "S:L", true], [{69=>nil, 60=>nil}, 60, "S:L", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "S:L", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "S:L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "S:L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "S:L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+L", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+L", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+L", false]], 79=>[[{70=>:enemy}, 70, "S:L", true], [{70=>nil}, 70, "S:L", false], [{70=>nil, 61=>:enemy}, 61, "S:L", true], [{70=>nil, 61=>nil}, 61, "S:L", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "S:L", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "S:L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "S:L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "S:L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+L", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+L", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+L", false]], 80=>[[{71=>:enemy}, 71, "S:L", true], [{71=>nil}, 71, "S:L", false], [{71=>nil, 62=>:enemy}, 62, "S:L", true], [{71=>nil, 62=>nil}, 62, "S:L", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "S:L", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "S:L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "S:L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "S:L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+L", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+L", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+L", false]], nil=>[[{9=>nil}, 9, "S:L", false], [{10=>nil}, 10, "S:L", false], [{11=>nil}, 11, "S:L", false], [{12=>nil}, 12, "S:L", false], [{13=>nil}, 13, "S:L", false], [{14=>nil}, 14, "S:L", false], [{15=>nil}, 15, "S:L", false], [{16=>nil}, 16, "S:L", false], [{17=>nil}, 17, "S:L", false], [{18=>nil}, 18, "S:L", false], [{19=>nil}, 19, "S:L", false], [{20=>nil}, 20, "S:L", false], [{21=>nil}, 21, "S:L", false], [{22=>nil}, 22, "S:L", false], [{23=>nil}, 23, "S:L", false], [{24=>nil}, 24, "S:L", false], [{25=>nil}, 25, "S:L", false], [{26=>nil}, 26, "S:L", false], [{27=>nil}, 27, "S:L", false], [{28=>nil}, 28, "S:L", false], [{29=>nil}, 29, "S:L", false], [{30=>nil}, 30, "S:L", false], [{31=>nil}, 31, "S:L", false], [{32=>nil}, 32, "S:L", false], [{33=>nil}, 33, "S:L", false], [{34=>nil}, 34, "S:L", false], [{35=>nil}, 35, "S:L", false], [{36=>nil}, 36, "S:L", false], [{37=>nil}, 37, "S:L", false], [{38=>nil}, 38, "S:L", false], [{39=>nil}, 39, "S:L", false], [{40=>nil}, 40, "S:L", false], [{41=>nil}, 41, "S:L", false], [{42=>nil}, 42, "S:L", false], [{43=>nil}, 43, "S:L", false], [{44=>nil}, 44, "S:L", false], [{45=>nil}, 45, "S:L", false], [{46=>nil}, 46, "S:L", false], [{47=>nil}, 47, "S:L", false], [{48=>nil}, 48, "S:L", false], [{49=>nil}, 49, "S:L", false], [{50=>nil}, 50, "S:L", false], [{51=>nil}, 51, "S:L", false], [{52=>nil}, 52, "S:L", false], [{53=>nil}, 53, "S:L", false], [{54=>nil}, 54, "S:L", false], [{55=>nil}, 55, "S:L", false], [{56=>nil}, 56, "S:L", false], [{57=>nil}, 57, "S:L", false], [{58=>nil}, 58, "S:L", false], [{59=>nil}, 59, "S:L", false], [{60=>nil}, 60, "S:L", false], [{61=>nil}, 61, "S:L", false], [{62=>nil}, 62, "S:L", false], [{63=>nil}, 63, "S:L", false], [{64=>nil}, 64, "S:L", false], [{65=>nil}, 65, "S:L", false], [{66=>nil}, 66, "S:L", false], [{67=>nil}, 67, "S:L", false], [{68=>nil}, 68, "S:L", false], [{69=>nil}, 69, "S:L", false], [{70=>nil}, 70, "S:L", false], [{71=>nil}, 71, "S:L", false], [{72=>nil}, 72, "S:L", false], [{73=>nil}, 73, "S:L", false], [{74=>nil}, 74, "S:L", false], [{75=>nil}, 75, "S:L", false], [{76=>nil}, 76, "S:L", false], [{77=>nil}, 77, "S:L", false], [{78=>nil}, 78, "S:L", false], [{79=>nil}, 79, "S:L", false], [{80=>nil}, 80, "S:L", false]]}, "S:N"=>{0=>[], 1=>[], 2=>[], 3=>[], 4=>[], 5=>[], 6=>[], 7=>[], 8=>[], 9=>[], 10=>[], 11=>[], 12=>[], 13=>[], 14=>[], 15=>[], 16=>[], 17=>[], 18=>[[{1=>:enemy}, 1, "S:+N", true], [{1=>nil}, 1, "S:+N", false]], 19=>[[{0=>:enemy}, 0, "S:+N", true], [{2=>:enemy}, 2, "S:+N", true], [{0=>nil}, 0, "S:+N", false], [{2=>nil}, 2, "S:+N", false]], 20=>[[{1=>:enemy}, 1, "S:+N", true], [{3=>:enemy}, 3, "S:+N", true], [{1=>nil}, 1, "S:+N", false], [{3=>nil}, 3, "S:+N", false]], 21=>[[{2=>:enemy}, 2, "S:+N", true], [{4=>:enemy}, 4, "S:+N", true], [{2=>nil}, 2, "S:+N", false], [{4=>nil}, 4, "S:+N", false]], 22=>[[{3=>:enemy}, 3, "S:+N", true], [{5=>:enemy}, 5, "S:+N", true], [{3=>nil}, 3, "S:+N", false], [{5=>nil}, 5, "S:+N", false]], 23=>[[{4=>:enemy}, 4, "S:+N", true], [{6=>:enemy}, 6, "S:+N", true], [{4=>nil}, 4, "S:+N", false], [{6=>nil}, 6, "S:+N", false]], 24=>[[{5=>:enemy}, 5, "S:+N", true], [{7=>:enemy}, 7, "S:+N", true], [{5=>nil}, 5, "S:+N", false], [{7=>nil}, 7, "S:+N", false]], 25=>[[{6=>:enemy}, 6, "S:+N", true], [{8=>:enemy}, 8, "S:+N", true], [{6=>nil}, 6, "S:+N", false], [{8=>nil}, 8, "S:+N", false]], 26=>[[{7=>:enemy}, 7, "S:+N", true], [{7=>nil}, 7, "S:+N", false]], 27=>[[{10=>:enemy}, 10, "S:+N", true], [{10=>nil}, 10, "S:+N", false]], 28=>[[{9=>:enemy}, 9, "S:+N", true], [{11=>:enemy}, 11, "S:+N", true], [{9=>nil}, 9, "S:+N", false], [{11=>nil}, 11, "S:+N", false]], 29=>[[{10=>:enemy}, 10, "S:+N", true], [{12=>:enemy}, 12, "S:+N", true], [{10=>nil}, 10, "S:+N", false], [{12=>nil}, 12, "S:+N", false]], 30=>[[{11=>:enemy}, 11, "S:+N", true], [{13=>:enemy}, 13, "S:+N", true], [{11=>nil}, 11, "S:+N", false], [{13=>nil}, 13, "S:+N", false]], 31=>[[{12=>:enemy}, 12, "S:+N", true], [{14=>:enemy}, 14, "S:+N", true], [{12=>nil}, 12, "S:+N", false], [{14=>nil}, 14, "S:+N", false]], 32=>[[{13=>:enemy}, 13, "S:+N", true], [{15=>:enemy}, 15, "S:+N", true], [{13=>nil}, 13, "S:+N", false], [{15=>nil}, 15, "S:+N", false]], 33=>[[{14=>:enemy}, 14, "S:+N", true], [{16=>:enemy}, 16, "S:+N", true], [{14=>nil}, 14, "S:+N", false], [{16=>nil}, 16, "S:+N", false]], 34=>[[{15=>:enemy}, 15, "S:+N", true], [{17=>:enemy}, 17, "S:+N", true], [{15=>nil}, 15, "S:+N", false], [{17=>nil}, 17, "S:+N", false]], 35=>[[{16=>:enemy}, 16, "S:+N", true], [{16=>nil}, 16, "S:+N", false]], 36=>[[{19=>:enemy}, 19, "S:+N", true], [{19=>nil}, 19, "S:+N", false]], 37=>[[{18=>:enemy}, 18, "S:+N", true], [{20=>:enemy}, 20, "S:+N", true], [{18=>nil}, 18, "S:+N", false], [{20=>nil}, 20, "S:+N", false]], 38=>[[{19=>:enemy}, 19, "S:+N", true], [{21=>:enemy}, 21, "S:+N", true], [{19=>nil}, 19, "S:+N", false], [{21=>nil}, 21, "S:+N", false]], 39=>[[{20=>:enemy}, 20, "S:+N", true], [{22=>:enemy}, 22, "S:+N", true], [{20=>nil}, 20, "S:+N", false], [{22=>nil}, 22, "S:+N", false]], 40=>[[{21=>:enemy}, 21, "S:+N", true], [{23=>:enemy}, 23, "S:+N", true], [{21=>nil}, 21, "S:+N", false], [{23=>nil}, 23, "S:+N", false]], 41=>[[{22=>:enemy}, 22, "S:+N", true], [{24=>:enemy}, 24, "S:+N", true], [{22=>nil}, 22, "S:+N", false], [{24=>nil}, 24, "S:+N", false]], 42=>[[{23=>:enemy}, 23, "S:+N", true], [{25=>:enemy}, 25, "S:+N", true], [{23=>nil}, 23, "S:+N", false], [{25=>nil}, 25, "S:+N", false]], 43=>[[{24=>:enemy}, 24, "S:+N", true], [{26=>:enemy}, 26, "S:+N", true], [{24=>nil}, 24, "S:+N", false], [{26=>nil}, 26, "S:+N", false]], 44=>[[{25=>:enemy}, 25, "S:+N", true], [{25=>nil}, 25, "S:+N", false]], 45=>[[{28=>:enemy}, 28, "S:N", true], [{28=>nil}, 28, "S:N", false]], 46=>[[{27=>:enemy}, 27, "S:N", true], [{29=>:enemy}, 29, "S:N", true], [{27=>nil}, 27, "S:N", false], [{29=>nil}, 29, "S:N", false]], 47=>[[{28=>:enemy}, 28, "S:N", true], [{30=>:enemy}, 30, "S:N", true], [{28=>nil}, 28, "S:N", false], [{30=>nil}, 30, "S:N", false]], 48=>[[{29=>:enemy}, 29, "S:N", true], [{31=>:enemy}, 31, "S:N", true], [{29=>nil}, 29, "S:N", false], [{31=>nil}, 31, "S:N", false]], 49=>[[{30=>:enemy}, 30, "S:N", true], [{32=>:enemy}, 32, "S:N", true], [{30=>nil}, 30, "S:N", false], [{32=>nil}, 32, "S:N", false]], 50=>[[{31=>:enemy}, 31, "S:N", true], [{33=>:enemy}, 33, "S:N", true], [{31=>nil}, 31, "S:N", false], [{33=>nil}, 33, "S:N", false]], 51=>[[{32=>:enemy}, 32, "S:N", true], [{34=>:enemy}, 34, "S:N", true], [{32=>nil}, 32, "S:N", false], [{34=>nil}, 34, "S:N", false]], 52=>[[{33=>:enemy}, 33, "S:N", true], [{35=>:enemy}, 35, "S:N", true], [{33=>nil}, 33, "S:N", false], [{35=>nil}, 35, "S:N", false]], 53=>[[{34=>:enemy}, 34, "S:N", true], [{34=>nil}, 34, "S:N", false]], 54=>[[{37=>:enemy}, 37, "S:N", true], [{37=>nil}, 37, "S:N", false]], 55=>[[{36=>:enemy}, 36, "S:N", true], [{38=>:enemy}, 38, "S:N", true], [{36=>nil}, 36, "S:N", false], [{38=>nil}, 38, "S:N", false]], 56=>[[{37=>:enemy}, 37, "S:N", true], [{39=>:enemy}, 39, "S:N", true], [{37=>nil}, 37, "S:N", false], [{39=>nil}, 39, "S:N", false]], 57=>[[{38=>:enemy}, 38, "S:N", true], [{40=>:enemy}, 40, "S:N", true], [{38=>nil}, 38, "S:N", false], [{40=>nil}, 40, "S:N", false]], 58=>[[{39=>:enemy}, 39, "S:N", true], [{41=>:enemy}, 41, "S:N", true], [{39=>nil}, 39, "S:N", false], [{41=>nil}, 41, "S:N", false]], 59=>[[{40=>:enemy}, 40, "S:N", true], [{42=>:enemy}, 42, "S:N", true], [{40=>nil}, 40, "S:N", false], [{42=>nil}, 42, "S:N", false]], 60=>[[{41=>:enemy}, 41, "S:N", true], [{43=>:enemy}, 43, "S:N", true], [{41=>nil}, 41, "S:N", false], [{43=>nil}, 43, "S:N", false]], 61=>[[{42=>:enemy}, 42, "S:N", true], [{44=>:enemy}, 44, "S:N", true], [{42=>nil}, 42, "S:N", false], [{44=>nil}, 44, "S:N", false]], 62=>[[{43=>:enemy}, 43, "S:N", true], [{43=>nil}, 43, "S:N", false]], 63=>[[{46=>:enemy}, 46, "S:N", true], [{46=>nil}, 46, "S:N", false]], 64=>[[{45=>:enemy}, 45, "S:N", true], [{47=>:enemy}, 47, "S:N", true], [{45=>nil}, 45, "S:N", false], [{47=>nil}, 47, "S:N", false]], 65=>[[{46=>:enemy}, 46, "S:N", true], [{48=>:enemy}, 48, "S:N", true], [{46=>nil}, 46, "S:N", false], [{48=>nil}, 48, "S:N", false]], 66=>[[{47=>:enemy}, 47, "S:N", true], [{49=>:enemy}, 49, "S:N", true], [{47=>nil}, 47, "S:N", false], [{49=>nil}, 49, "S:N", false]], 67=>[[{48=>:enemy}, 48, "S:N", true], [{50=>:enemy}, 50, "S:N", true], [{48=>nil}, 48, "S:N", false], [{50=>nil}, 50, "S:N", false]], 68=>[[{49=>:enemy}, 49, "S:N", true], [{51=>:enemy}, 51, "S:N", true], [{49=>nil}, 49, "S:N", false], [{51=>nil}, 51, "S:N", false]], 69=>[[{50=>:enemy}, 50, "S:N", true], [{52=>:enemy}, 52, "S:N", true], [{50=>nil}, 50, "S:N", false], [{52=>nil}, 52, "S:N", false]], 70=>[[{51=>:enemy}, 51, "S:N", true], [{53=>:enemy}, 53, "S:N", true], [{51=>nil}, 51, "S:N", false], [{53=>nil}, 53, "S:N", false]], 71=>[[{52=>:enemy}, 52, "S:N", true], [{52=>nil}, 52, "S:N", false]], 72=>[[{55=>:enemy}, 55, "S:N", true], [{55=>nil}, 55, "S:N", false]], 73=>[[{54=>:enemy}, 54, "S:N", true], [{56=>:enemy}, 56, "S:N", true], [{54=>nil}, 54, "S:N", false], [{56=>nil}, 56, "S:N", false]], 74=>[[{55=>:enemy}, 55, "S:N", true], [{57=>:enemy}, 57, "S:N", true], [{55=>nil}, 55, "S:N", false], [{57=>nil}, 57, "S:N", false]], 75=>[[{56=>:enemy}, 56, "S:N", true], [{58=>:enemy}, 58, "S:N", true], [{56=>nil}, 56, "S:N", false], [{58=>nil}, 58, "S:N", false]], 76=>[[{57=>:enemy}, 57, "S:N", true], [{59=>:enemy}, 59, "S:N", true], [{57=>nil}, 57, "S:N", false], [{59=>nil}, 59, "S:N", false]], 77=>[[{58=>:enemy}, 58, "S:N", true], [{60=>:enemy}, 60, "S:N", true], [{58=>nil}, 58, "S:N", false], [{60=>nil}, 60, "S:N", false]], 78=>[[{59=>:enemy}, 59, "S:N", true], [{61=>:enemy}, 61, "S:N", true], [{59=>nil}, 59, "S:N", false], [{61=>nil}, 61, "S:N", false]], 79=>[[{60=>:enemy}, 60, "S:N", true], [{62=>:enemy}, 62, "S:N", true], [{60=>nil}, 60, "S:N", false], [{62=>nil}, 62, "S:N", false]], 80=>[[{61=>:enemy}, 61, "S:N", true], [{61=>nil}, 61, "S:N", false]], nil=>[[{18=>nil}, 18, "S:N", false], [{19=>nil}, 19, "S:N", false], [{20=>nil}, 20, "S:N", false], [{21=>nil}, 21, "S:N", false], [{22=>nil}, 22, "S:N", false], [{23=>nil}, 23, "S:N", false], [{24=>nil}, 24, "S:N", false], [{25=>nil}, 25, "S:N", false], [{26=>nil}, 26, "S:N", false], [{27=>nil}, 27, "S:N", false], [{28=>nil}, 28, "S:N", false], [{29=>nil}, 29, "S:N", false], [{30=>nil}, 30, "S:N", false], [{31=>nil}, 31, "S:N", false], [{32=>nil}, 32, "S:N", false], [{33=>nil}, 33, "S:N", false], [{34=>nil}, 34, "S:N", false], [{35=>nil}, 35, "S:N", false], [{36=>nil}, 36, "S:N", false], [{37=>nil}, 37, "S:N", false], [{38=>nil}, 38, "S:N", false], [{39=>nil}, 39, "S:N", false], [{40=>nil}, 40, "S:N", false], [{41=>nil}, 41, "S:N", false], [{42=>nil}, 42, "S:N", false], [{43=>nil}, 43, "S:N", false], [{44=>nil}, 44, "S:N", false], [{45=>nil}, 45, "S:N", false], [{46=>nil}, 46, "S:N", false], [{47=>nil}, 47, "S:N", false], [{48=>nil}, 48, "S:N", false], [{49=>nil}, 49, "S:N", false], [{50=>nil}, 50, "S:N", false], [{51=>nil}, 51, "S:N", false], [{52=>nil}, 52, "S:N", false], [{53=>nil}, 53, "S:N", false], [{54=>nil}, 54, "S:N", false], [{55=>nil}, 55, "S:N", false], [{56=>nil}, 56, "S:N", false], [{57=>nil}, 57, "S:N", false], [{58=>nil}, 58, "S:N", false], [{59=>nil}, 59, "S:N", false], [{60=>nil}, 60, "S:N", false], [{61=>nil}, 61, "S:N", false], [{62=>nil}, 62, "S:N", false], [{63=>nil}, 63, "S:N", false], [{64=>nil}, 64, "S:N", false], [{65=>nil}, 65, "S:N", false], [{66=>nil}, 66, "S:N", false], [{67=>nil}, 67, "S:N", false], [{68=>nil}, 68, "S:N", false], [{69=>nil}, 69, "S:N", false], [{70=>nil}, 70, "S:N", false], [{71=>nil}, 71, "S:N", false], [{72=>nil}, 72, "S:N", false], [{73=>nil}, 73, "S:N", false], [{74=>nil}, 74, "S:N", false], [{75=>nil}, 75, "S:N", false], [{76=>nil}, 76, "S:N", false], [{77=>nil}, 77, "S:N", false], [{78=>nil}, 78, "S:N", false], [{79=>nil}, 79, "S:N", false], [{80=>nil}, 80, "S:N", false]]}, "S:P"=>{0=>[], 1=>[], 2=>[], 3=>[], 4=>[], 5=>[], 6=>[], 7=>[], 8=>[], 9=>[[{0=>:enemy}, 0, "S:+P", true], [{0=>nil}, 0, "S:+P", false]], 10=>[[{1=>:enemy}, 1, "S:+P", true], [{1=>nil}, 1, "S:+P", false]], 11=>[[{2=>:enemy}, 2, "S:+P", true], [{2=>nil}, 2, "S:+P", false]], 12=>[[{3=>:enemy}, 3, "S:+P", true], [{3=>nil}, 3, "S:+P", false]], 13=>[[{4=>:enemy}, 4, "S:+P", true], [{4=>nil}, 4, "S:+P", false]], 14=>[[{5=>:enemy}, 5, "S:+P", true], [{5=>nil}, 5, "S:+P", false]], 15=>[[{6=>:enemy}, 6, "S:+P", true], [{6=>nil}, 6, "S:+P", false]], 16=>[[{7=>:enemy}, 7, "S:+P", true], [{7=>nil}, 7, "S:+P", false]], 17=>[[{8=>:enemy}, 8, "S:+P", true], [{8=>nil}, 8, "S:+P", false]], 18=>[[{9=>:enemy}, 9, "S:+P", true], [{9=>nil}, 9, "S:+P", false]], 19=>[[{10=>:enemy}, 10, "S:+P", true], [{10=>nil}, 10, "S:+P", false]], 20=>[[{11=>:enemy}, 11, "S:+P", true], [{11=>nil}, 11, "S:+P", false]], 21=>[[{12=>:enemy}, 12, "S:+P", true], [{12=>nil}, 12, "S:+P", false]], 22=>[[{13=>:enemy}, 13, "S:+P", true], [{13=>nil}, 13, "S:+P", false]], 23=>[[{14=>:enemy}, 14, "S:+P", true], [{14=>nil}, 14, "S:+P", false]], 24=>[[{15=>:enemy}, 15, "S:+P", true], [{15=>nil}, 15, "S:+P", false]], 25=>[[{16=>:enemy}, 16, "S:+P", true], [{16=>nil}, 16, "S:+P", false]], 26=>[[{17=>:enemy}, 17, "S:+P", true], [{17=>nil}, 17, "S:+P", false]], 27=>[[{18=>:enemy}, 18, "S:+P", true], [{18=>nil}, 18, "S:+P", false]], 28=>[[{19=>:enemy}, 19, "S:+P", true], [{19=>nil}, 19, "S:+P", false]], 29=>[[{20=>:enemy}, 20, "S:+P", true], [{20=>nil}, 20, "S:+P", false]], 30=>[[{21=>:enemy}, 21, "S:+P", true], [{21=>nil}, 21, "S:+P", false]], 31=>[[{22=>:enemy}, 22, "S:+P", true], [{22=>nil}, 22, "S:+P", false]], 32=>[[{23=>:enemy}, 23, "S:+P", true], [{23=>nil}, 23, "S:+P", false]], 33=>[[{24=>:enemy}, 24, "S:+P", true], [{24=>nil}, 24, "S:+P", false]], 34=>[[{25=>:enemy}, 25, "S:+P", true], [{25=>nil}, 25, "S:+P", false]], 35=>[[{26=>:enemy}, 26, "S:+P", true], [{26=>nil}, 26, "S:+P", false]], 36=>[[{27=>:enemy}, 27, "S:P", true], [{27=>nil}, 27, "S:P", false]], 37=>[[{28=>:enemy}, 28, "S:P", true], [{28=>nil}, 28, "S:P", false]], 38=>[[{29=>:enemy}, 29, "S:P", true], [{29=>nil}, 29, "S:P", false]], 39=>[[{30=>:enemy}, 30, "S:P", true], [{30=>nil}, 30, "S:P", false]], 40=>[[{31=>:enemy}, 31, "S:P", true], [{31=>nil}, 31, "S:P", false]], 41=>[[{32=>:enemy}, 32, "S:P", true], [{32=>nil}, 32, "S:P", false]], 42=>[[{33=>:enemy}, 33, "S:P", true], [{33=>nil}, 33, "S:P", false]], 43=>[[{34=>:enemy}, 34, "S:P", true], [{34=>nil}, 34, "S:P", false]], 44=>[[{35=>:enemy}, 35, "S:P", true], [{35=>nil}, 35, "S:P", false]], 45=>[[{36=>:enemy}, 36, "S:P", true], [{36=>nil}, 36, "S:P", false]], 46=>[[{37=>:enemy}, 37, "S:P", true], [{37=>nil}, 37, "S:P", false]], 47=>[[{38=>:enemy}, 38, "S:P", true], [{38=>nil}, 38, "S:P", false]], 48=>[[{39=>:enemy}, 39, "S:P", true], [{39=>nil}, 39, "S:P", false]], 49=>[[{40=>:enemy}, 40, "S:P", true], [{40=>nil}, 40, "S:P", false]], 50=>[[{41=>:enemy}, 41, "S:P", true], [{41=>nil}, 41, "S:P", false]], 51=>[[{42=>:enemy}, 42, "S:P", true], [{42=>nil}, 42, "S:P", false]], 52=>[[{43=>:enemy}, 43, "S:P", true], [{43=>nil}, 43, "S:P", false]], 53=>[[{44=>:enemy}, 44, "S:P", true], [{44=>nil}, 44, "S:P", false]], 54=>[[{45=>:enemy}, 45, "S:P", true], [{45=>nil}, 45, "S:P", false]], 55=>[[{46=>:enemy}, 46, "S:P", true], [{46=>nil}, 46, "S:P", false]], 56=>[[{47=>:enemy}, 47, "S:P", true], [{47=>nil}, 47, "S:P", false]], 57=>[[{48=>:enemy}, 48, "S:P", true], [{48=>nil}, 48, "S:P", false]], 58=>[[{49=>:enemy}, 49, "S:P", true], [{49=>nil}, 49, "S:P", false]], 59=>[[{50=>:enemy}, 50, "S:P", true], [{50=>nil}, 50, "S:P", false]], 60=>[[{51=>:enemy}, 51, "S:P", true], [{51=>nil}, 51, "S:P", false]], 61=>[[{52=>:enemy}, 52, "S:P", true], [{52=>nil}, 52, "S:P", false]], 62=>[[{53=>:enemy}, 53, "S:P", true], [{53=>nil}, 53, "S:P", false]], 63=>[[{54=>:enemy}, 54, "S:P", true], [{54=>nil}, 54, "S:P", false]], 64=>[[{55=>:enemy}, 55, "S:P", true], [{55=>nil}, 55, "S:P", false]], 65=>[[{56=>:enemy}, 56, "S:P", true], [{56=>nil}, 56, "S:P", false]], 66=>[[{57=>:enemy}, 57, "S:P", true], [{57=>nil}, 57, "S:P", false]], 67=>[[{58=>:enemy}, 58, "S:P", true], [{58=>nil}, 58, "S:P", false]], 68=>[[{59=>:enemy}, 59, "S:P", true], [{59=>nil}, 59, "S:P", false]], 69=>[[{60=>:enemy}, 60, "S:P", true], [{60=>nil}, 60, "S:P", false]], 70=>[[{61=>:enemy}, 61, "S:P", true], [{61=>nil}, 61, "S:P", false]], 71=>[[{62=>:enemy}, 62, "S:P", true], [{62=>nil}, 62, "S:P", false]], 72=>[[{63=>:enemy}, 63, "S:P", true], [{63=>nil}, 63, "S:P", false]], 73=>[[{64=>:enemy}, 64, "S:P", true], [{64=>nil}, 64, "S:P", false]], 74=>[[{65=>:enemy}, 65, "S:P", true], [{65=>nil}, 65, "S:P", false]], 75=>[[{66=>:enemy}, 66, "S:P", true], [{66=>nil}, 66, "S:P", false]], 76=>[[{67=>:enemy}, 67, "S:P", true], [{67=>nil}, 67, "S:P", false]], 77=>[[{68=>:enemy}, 68, "S:P", true], [{68=>nil}, 68, "S:P", false]], 78=>[[{69=>:enemy}, 69, "S:P", true], [{69=>nil}, 69, "S:P", false]], 79=>[[{70=>:enemy}, 70, "S:P", true], [{70=>nil}, 70, "S:P", false]], 80=>[[{71=>:enemy}, 71, "S:P", true], [{71=>nil}, 71, "S:P", false]], nil=>[[{9=>nil}, 9, "S:P", false], [{10=>nil}, 10, "S:P", false], [{11=>nil}, 11, "S:P", false], [{12=>nil}, 12, "S:P", false], [{13=>nil}, 13, "S:P", false], [{14=>nil}, 14, "S:P", false], [{15=>nil}, 15, "S:P", false], [{16=>nil}, 16, "S:P", false], [{17=>nil}, 17, "S:P", false], [{18=>nil}, 18, "S:P", false], [{19=>nil}, 19, "S:P", false], [{20=>nil}, 20, "S:P", false], [{21=>nil}, 21, "S:P", false], [{22=>nil}, 22, "S:P", false], [{23=>nil}, 23, "S:P", false], [{24=>nil}, 24, "S:P", false], [{25=>nil}, 25, "S:P", false], [{26=>nil}, 26, "S:P", false], [{27=>nil}, 27, "S:P", false], [{28=>nil}, 28, "S:P", false], [{29=>nil}, 29, "S:P", false], [{30=>nil}, 30, "S:P", false], [{31=>nil}, 31, "S:P", false], [{32=>nil}, 32, "S:P", false], [{33=>nil}, 33, "S:P", false], [{34=>nil}, 34, "S:P", false], [{35=>nil}, 35, "S:P", false], [{36=>nil}, 36, "S:P", false], [{37=>nil}, 37, "S:P", false], [{38=>nil}, 38, "S:P", false], [{39=>nil}, 39, "S:P", false], [{40=>nil}, 40, "S:P", false], [{41=>nil}, 41, "S:P", false], [{42=>nil}, 42, "S:P", false], [{43=>nil}, 43, "S:P", false], [{44=>nil}, 44, "S:P", false], [{45=>nil}, 45, "S:P", false], [{46=>nil}, 46, "S:P", false], [{47=>nil}, 47, "S:P", false], [{48=>nil}, 48, "S:P", false], [{49=>nil}, 49, "S:P", false], [{50=>nil}, 50, "S:P", false], [{51=>nil}, 51, "S:P", false], [{52=>nil}, 52, "S:P", false], [{53=>nil}, 53, "S:P", false], [{54=>nil}, 54, "S:P", false], [{55=>nil}, 55, "S:P", false], [{56=>nil}, 56, "S:P", false], [{57=>nil}, 57, "S:P", false], [{58=>nil}, 58, "S:P", false], [{59=>nil}, 59, "S:P", false], [{60=>nil}, 60, "S:P", false], [{61=>nil}, 61, "S:P", false], [{62=>nil}, 62, "S:P", false], [{63=>nil}, 63, "S:P", false], [{64=>nil}, 64, "S:P", false], [{65=>nil}, 65, "S:P", false], [{66=>nil}, 66, "S:P", false], [{67=>nil}, 67, "S:P", false], [{68=>nil}, 68, "S:P", false], [{69=>nil}, 69, "S:P", false], [{70=>nil}, 70, "S:P", false], [{71=>nil}, 71, "S:P", false], [{72=>nil}, 72, "S:P", false], [{73=>nil}, 73, "S:P", false], [{74=>nil}, 74, "S:P", false], [{75=>nil}, 75, "S:P", false], [{76=>nil}, 76, "S:P", false], [{77=>nil}, 77, "S:P", false], [{78=>nil}, 78, "S:P", false], [{79=>nil}, 79, "S:P", false], [{80=>nil}, 80, "S:P", false]]}, "S:R"=>{0=>[[{1=>:enemy}, 1, "S:+R", true], [{9=>:enemy}, 9, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{1=>nil, 2=>:enemy}, 2, "S:+R", true], [{1=>nil, 2=>nil}, 2, "S:+R", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{9=>nil}, 9, "S:+R", false], [{9=>nil, 18=>:enemy}, 18, "S:+R", true], [{9=>nil, 18=>nil}, 18, "S:+R", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false]], 1=>[[{0=>:enemy}, 0, "S:+R", true], [{2=>:enemy}, 2, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{0=>nil}, 0, "S:+R", false], [{2=>nil}, 2, "S:+R", false], [{2=>nil, 3=>:enemy}, 3, "S:+R", true], [{2=>nil, 3=>nil}, 3, "S:+R", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 19=>:enemy}, 19, "S:+R", true], [{10=>nil, 19=>nil}, 19, "S:+R", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false]], 2=>[[{1=>:enemy}, 1, "S:+R", true], [{3=>:enemy}, 3, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{1=>nil, 0=>:enemy}, 0, "S:+R", true], [{1=>nil, 0=>nil}, 0, "S:+R", false], [{3=>nil}, 3, "S:+R", false], [{3=>nil, 4=>:enemy}, 4, "S:+R", true], [{3=>nil, 4=>nil}, 4, "S:+R", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 20=>:enemy}, 20, "S:+R", true], [{11=>nil, 20=>nil}, 20, "S:+R", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false]], 3=>[[{2=>:enemy}, 2, "S:+R", true], [{4=>:enemy}, 4, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{2=>nil}, 2, "S:+R", false], [{2=>nil, 1=>:enemy}, 1, "S:+R", true], [{2=>nil, 1=>nil}, 1, "S:+R", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{4=>nil}, 4, "S:+R", false], [{4=>nil, 5=>:enemy}, 5, "S:+R", true], [{4=>nil, 5=>nil}, 5, "S:+R", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "S:+R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 21=>:enemy}, 21, "S:+R", true], [{12=>nil, 21=>nil}, 21, "S:+R", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false]], 4=>[[{3=>:enemy}, 3, "S:+R", true], [{5=>:enemy}, 5, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{3=>nil}, 3, "S:+R", false], [{3=>nil, 2=>:enemy}, 2, "S:+R", true], [{3=>nil, 2=>nil}, 2, "S:+R", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{5=>nil}, 5, "S:+R", false], [{5=>nil, 6=>:enemy}, 6, "S:+R", true], [{5=>nil, 6=>nil}, 6, "S:+R", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "S:+R", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "S:+R", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 22=>:enemy}, 22, "S:+R", true], [{13=>nil, 22=>nil}, 22, "S:+R", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false]], 5=>[[{4=>:enemy}, 4, "S:+R", true], [{6=>:enemy}, 6, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{4=>nil}, 4, "S:+R", false], [{4=>nil, 3=>:enemy}, 3, "S:+R", true], [{4=>nil, 3=>nil}, 3, "S:+R", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{6=>nil}, 6, "S:+R", false], [{6=>nil, 7=>:enemy}, 7, "S:+R", true], [{6=>nil, 7=>nil}, 7, "S:+R", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "S:+R", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 23=>:enemy}, 23, "S:+R", true], [{14=>nil, 23=>nil}, 23, "S:+R", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false]], 6=>[[{5=>:enemy}, 5, "S:+R", true], [{7=>:enemy}, 7, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{5=>nil}, 5, "S:+R", false], [{5=>nil, 4=>:enemy}, 4, "S:+R", true], [{5=>nil, 4=>nil}, 4, "S:+R", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{7=>nil}, 7, "S:+R", false], [{7=>nil, 8=>:enemy}, 8, "S:+R", true], [{7=>nil, 8=>nil}, 8, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 24=>:enemy}, 24, "S:+R", true], [{15=>nil, 24=>nil}, 24, "S:+R", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false]], 7=>[[{6=>:enemy}, 6, "S:+R", true], [{8=>:enemy}, 8, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{6=>nil}, 6, "S:+R", false], [{6=>nil, 5=>:enemy}, 5, "S:+R", true], [{6=>nil, 5=>nil}, 5, "S:+R", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{8=>nil}, 8, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 25=>:enemy}, 25, "S:+R", true], [{16=>nil, 25=>nil}, 25, "S:+R", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false]], 8=>[[{7=>:enemy}, 7, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{7=>nil}, 7, "S:+R", false], [{7=>nil, 6=>:enemy}, 6, "S:+R", true], [{7=>nil, 6=>nil}, 6, "S:+R", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "S:+R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "S:+R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{17=>nil, 26=>:enemy}, 26, "S:+R", true], [{17=>nil, 26=>nil}, 26, "S:+R", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 9=>[[{0=>:enemy}, 0, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{18=>:enemy}, 18, "S:+R", true], [{0=>nil}, 0, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 11=>:enemy}, 11, "S:+R", true], [{10=>nil, 11=>nil}, 11, "S:+R", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{18=>nil}, 18, "S:+R", false], [{18=>nil, 27=>:enemy}, 27, "S:+R", true], [{18=>nil, 27=>nil}, 27, "S:+R", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false]], 10=>[[{1=>:enemy}, 1, "S:+R", true], [{9=>:enemy}, 9, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{1=>nil}, 1, "S:+R", false], [{9=>nil}, 9, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 12=>:enemy}, 12, "S:+R", true], [{11=>nil, 12=>nil}, 12, "S:+R", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 28=>:enemy}, 28, "S:+R", true], [{19=>nil, 28=>nil}, 28, "S:+R", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false]], 11=>[[{2=>:enemy}, 2, "S:+R", true], [{10=>:enemy}, 10, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{2=>nil}, 2, "S:+R", false], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 9=>:enemy}, 9, "S:+R", true], [{10=>nil, 9=>nil}, 9, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 13=>:enemy}, 13, "S:+R", true], [{12=>nil, 13=>nil}, 13, "S:+R", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 29=>:enemy}, 29, "S:+R", true], [{20=>nil, 29=>nil}, 29, "S:+R", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false]], 12=>[[{3=>:enemy}, 3, "S:+R", true], [{11=>:enemy}, 11, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{3=>nil}, 3, "S:+R", false], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 10=>:enemy}, 10, "S:+R", true], [{11=>nil, 10=>nil}, 10, "S:+R", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 14=>:enemy}, 14, "S:+R", true], [{13=>nil, 14=>nil}, 14, "S:+R", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "S:+R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 30=>:enemy}, 30, "S:+R", true], [{21=>nil, 30=>nil}, 30, "S:+R", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false]], 13=>[[{4=>:enemy}, 4, "S:+R", true], [{12=>:enemy}, 12, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{4=>nil}, 4, "S:+R", false], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 11=>:enemy}, 11, "S:+R", true], [{12=>nil, 11=>nil}, 11, "S:+R", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 15=>:enemy}, 15, "S:+R", true], [{14=>nil, 15=>nil}, 15, "S:+R", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "S:+R", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "S:+R", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 31=>:enemy}, 31, "S:+R", true], [{22=>nil, 31=>nil}, 31, "S:+R", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false]], 14=>[[{5=>:enemy}, 5, "S:+R", true], [{13=>:enemy}, 13, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{5=>nil}, 5, "S:+R", false], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 12=>:enemy}, 12, "S:+R", true], [{13=>nil, 12=>nil}, 12, "S:+R", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 16=>:enemy}, 16, "S:+R", true], [{15=>nil, 16=>nil}, 16, "S:+R", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "S:+R", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 32=>:enemy}, 32, "S:+R", true], [{23=>nil, 32=>nil}, 32, "S:+R", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false]], 15=>[[{6=>:enemy}, 6, "S:+R", true], [{14=>:enemy}, 14, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{6=>nil}, 6, "S:+R", false], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 13=>:enemy}, 13, "S:+R", true], [{14=>nil, 13=>nil}, 13, "S:+R", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 17=>:enemy}, 17, "S:+R", true], [{16=>nil, 17=>nil}, 17, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 33=>:enemy}, 33, "S:+R", true], [{24=>nil, 33=>nil}, 33, "S:+R", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false]], 16=>[[{7=>:enemy}, 7, "S:+R", true], [{15=>:enemy}, 15, "S:+R", true], [{17=>:enemy}, 17, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{7=>nil}, 7, "S:+R", false], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 14=>:enemy}, 14, "S:+R", true], [{15=>nil, 14=>nil}, 14, "S:+R", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{17=>nil}, 17, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 34=>:enemy}, 34, "S:+R", true], [{25=>nil, 34=>nil}, 34, "S:+R", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false]], 17=>[[{8=>:enemy}, 8, "S:+R", true], [{16=>:enemy}, 16, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{8=>nil}, 8, "S:+R", false], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 15=>:enemy}, 15, "S:+R", true], [{16=>nil, 15=>nil}, 15, "S:+R", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "S:+R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "S:+R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{26=>nil, 35=>:enemy}, 35, "S:+R", true], [{26=>nil, 35=>nil}, 35, "S:+R", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 18=>[[{9=>:enemy}, 9, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{27=>:enemy}, 27, "S:+R", true], [{9=>nil}, 9, "S:+R", false], [{9=>nil, 0=>:enemy}, 0, "S:+R", true], [{9=>nil, 0=>nil}, 0, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 20=>:enemy}, 20, "S:+R", true], [{19=>nil, 20=>nil}, 20, "S:+R", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{27=>nil}, 27, "S:+R", false], [{27=>nil, 36=>:enemy}, 36, "S:+R", true], [{27=>nil, 36=>nil}, 36, "S:+R", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:+R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:+R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:+R", false]], 19=>[[{10=>:enemy}, 10, "S:+R", true], [{18=>:enemy}, 18, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{28=>:enemy}, 28, "S:+R", true], [{10=>nil}, 10, "S:+R", false], [{10=>nil, 1=>:enemy}, 1, "S:+R", true], [{10=>nil, 1=>nil}, 1, "S:+R", false], [{18=>nil}, 18, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 21=>:enemy}, 21, "S:+R", true], [{20=>nil, 21=>nil}, 21, "S:+R", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{28=>nil}, 28, "S:+R", false], [{28=>nil, 37=>:enemy}, 37, "S:+R", true], [{28=>nil, 37=>nil}, 37, "S:+R", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:+R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:+R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:+R", false]], 20=>[[{11=>:enemy}, 11, "S:+R", true], [{19=>:enemy}, 19, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{29=>:enemy}, 29, "S:+R", true], [{11=>nil}, 11, "S:+R", false], [{11=>nil, 2=>:enemy}, 2, "S:+R", true], [{11=>nil, 2=>nil}, 2, "S:+R", false], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 18=>:enemy}, 18, "S:+R", true], [{19=>nil, 18=>nil}, 18, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 22=>:enemy}, 22, "S:+R", true], [{21=>nil, 22=>nil}, 22, "S:+R", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{29=>nil}, 29, "S:+R", false], [{29=>nil, 38=>:enemy}, 38, "S:+R", true], [{29=>nil, 38=>nil}, 38, "S:+R", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:+R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:+R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:+R", false]], 21=>[[{12=>:enemy}, 12, "S:+R", true], [{20=>:enemy}, 20, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{30=>:enemy}, 30, "S:+R", true], [{12=>nil}, 12, "S:+R", false], [{12=>nil, 3=>:enemy}, 3, "S:+R", true], [{12=>nil, 3=>nil}, 3, "S:+R", false], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 19=>:enemy}, 19, "S:+R", true], [{20=>nil, 19=>nil}, 19, "S:+R", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 23=>:enemy}, 23, "S:+R", true], [{22=>nil, 23=>nil}, 23, "S:+R", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "S:+R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{30=>nil}, 30, "S:+R", false], [{30=>nil, 39=>:enemy}, 39, "S:+R", true], [{30=>nil, 39=>nil}, 39, "S:+R", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:+R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:+R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:+R", false]], 22=>[[{13=>:enemy}, 13, "S:+R", true], [{21=>:enemy}, 21, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{31=>:enemy}, 31, "S:+R", true], [{13=>nil}, 13, "S:+R", false], [{13=>nil, 4=>:enemy}, 4, "S:+R", true], [{13=>nil, 4=>nil}, 4, "S:+R", false], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 20=>:enemy}, 20, "S:+R", true], [{21=>nil, 20=>nil}, 20, "S:+R", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 24=>:enemy}, 24, "S:+R", true], [{23=>nil, 24=>nil}, 24, "S:+R", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "S:+R", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "S:+R", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{31=>nil}, 31, "S:+R", false], [{31=>nil, 40=>:enemy}, 40, "S:+R", true], [{31=>nil, 40=>nil}, 40, "S:+R", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:+R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:+R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:+R", false]], 23=>[[{14=>:enemy}, 14, "S:+R", true], [{22=>:enemy}, 22, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{32=>:enemy}, 32, "S:+R", true], [{14=>nil}, 14, "S:+R", false], [{14=>nil, 5=>:enemy}, 5, "S:+R", true], [{14=>nil, 5=>nil}, 5, "S:+R", false], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 21=>:enemy}, 21, "S:+R", true], [{22=>nil, 21=>nil}, 21, "S:+R", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 25=>:enemy}, 25, "S:+R", true], [{24=>nil, 25=>nil}, 25, "S:+R", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "S:+R", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "S:+R", false], [{32=>nil}, 32, "S:+R", false], [{32=>nil, 41=>:enemy}, 41, "S:+R", true], [{32=>nil, 41=>nil}, 41, "S:+R", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:+R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:+R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:+R", false]], 24=>[[{15=>:enemy}, 15, "S:+R", true], [{23=>:enemy}, 23, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{33=>:enemy}, 33, "S:+R", true], [{15=>nil}, 15, "S:+R", false], [{15=>nil, 6=>:enemy}, 6, "S:+R", true], [{15=>nil, 6=>nil}, 6, "S:+R", false], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 22=>:enemy}, 22, "S:+R", true], [{23=>nil, 22=>nil}, 22, "S:+R", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 26=>:enemy}, 26, "S:+R", true], [{25=>nil, 26=>nil}, 26, "S:+R", false], [{33=>nil}, 33, "S:+R", false], [{33=>nil, 42=>:enemy}, 42, "S:+R", true], [{33=>nil, 42=>nil}, 42, "S:+R", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:+R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:+R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:+R", false]], 25=>[[{16=>:enemy}, 16, "S:+R", true], [{24=>:enemy}, 24, "S:+R", true], [{26=>:enemy}, 26, "S:+R", true], [{34=>:enemy}, 34, "S:+R", true], [{16=>nil}, 16, "S:+R", false], [{16=>nil, 7=>:enemy}, 7, "S:+R", true], [{16=>nil, 7=>nil}, 7, "S:+R", false], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 23=>:enemy}, 23, "S:+R", true], [{24=>nil, 23=>nil}, 23, "S:+R", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{26=>nil}, 26, "S:+R", false], [{34=>nil}, 34, "S:+R", false], [{34=>nil, 43=>:enemy}, 43, "S:+R", true], [{34=>nil, 43=>nil}, 43, "S:+R", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:+R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:+R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:+R", false]], 26=>[[{17=>:enemy}, 17, "S:+R", true], [{25=>:enemy}, 25, "S:+R", true], [{35=>:enemy}, 35, "S:+R", true], [{17=>nil}, 17, "S:+R", false], [{17=>nil, 8=>:enemy}, 8, "S:+R", true], [{17=>nil, 8=>nil}, 8, "S:+R", false], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 24=>:enemy}, 24, "S:+R", true], [{25=>nil, 24=>nil}, 24, "S:+R", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "S:+R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "S:+R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "S:+R", false], [{35=>nil}, 35, "S:+R", false], [{35=>nil, 44=>:enemy}, 44, "S:+R", true], [{35=>nil, 44=>nil}, 44, "S:+R", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:+R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:+R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:+R", false]], 27=>[[{18=>:enemy}, 18, "S:+R", true], [{28=>:enemy}, 28, "S:R", true], [{36=>:enemy}, 36, "S:R", true], [{18=>nil}, 18, "S:+R", false], [{18=>nil, 9=>:enemy}, 9, "S:+R", true], [{18=>nil, 9=>nil}, 9, "S:+R", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{28=>nil}, 28, "S:R", false], [{28=>nil, 29=>:enemy}, 29, "S:R", true], [{28=>nil, 29=>nil}, 29, "S:R", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "S:R", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "S:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "S:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "S:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "S:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "S:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{36=>nil}, 36, "S:R", false], [{36=>nil, 45=>:enemy}, 45, "S:R", true], [{36=>nil, 45=>nil}, 45, "S:R", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "S:R", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "S:R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "S:R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "S:R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:R", false]], 28=>[[{19=>:enemy}, 19, "S:+R", true], [{27=>:enemy}, 27, "S:R", true], [{29=>:enemy}, 29, "S:R", true], [{37=>:enemy}, 37, "S:R", true], [{19=>nil}, 19, "S:+R", false], [{19=>nil, 10=>:enemy}, 10, "S:+R", true], [{19=>nil, 10=>nil}, 10, "S:+R", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{27=>nil}, 27, "S:R", false], [{29=>nil}, 29, "S:R", false], [{29=>nil, 30=>:enemy}, 30, "S:R", true], [{29=>nil, 30=>nil}, 30, "S:R", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "S:R", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "S:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "S:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "S:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{37=>nil}, 37, "S:R", false], [{37=>nil, 46=>:enemy}, 46, "S:R", true], [{37=>nil, 46=>nil}, 46, "S:R", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "S:R", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "S:R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "S:R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "S:R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:R", false]], 29=>[[{20=>:enemy}, 20, "S:+R", true], [{28=>:enemy}, 28, "S:R", true], [{30=>:enemy}, 30, "S:R", true], [{38=>:enemy}, 38, "S:R", true], [{20=>nil}, 20, "S:+R", false], [{20=>nil, 11=>:enemy}, 11, "S:+R", true], [{20=>nil, 11=>nil}, 11, "S:+R", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{28=>nil}, 28, "S:R", false], [{28=>nil, 27=>:enemy}, 27, "S:R", true], [{28=>nil, 27=>nil}, 27, "S:R", false], [{30=>nil}, 30, "S:R", false], [{30=>nil, 31=>:enemy}, 31, "S:R", true], [{30=>nil, 31=>nil}, 31, "S:R", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "S:R", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "S:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "S:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "S:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{38=>nil}, 38, "S:R", false], [{38=>nil, 47=>:enemy}, 47, "S:R", true], [{38=>nil, 47=>nil}, 47, "S:R", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "S:R", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "S:R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "S:R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "S:R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:R", false]], 30=>[[{21=>:enemy}, 21, "S:+R", true], [{29=>:enemy}, 29, "S:R", true], [{31=>:enemy}, 31, "S:R", true], [{39=>:enemy}, 39, "S:R", true], [{21=>nil}, 21, "S:+R", false], [{21=>nil, 12=>:enemy}, 12, "S:+R", true], [{21=>nil, 12=>nil}, 12, "S:+R", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{29=>nil}, 29, "S:R", false], [{29=>nil, 28=>:enemy}, 28, "S:R", true], [{29=>nil, 28=>nil}, 28, "S:R", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{31=>nil}, 31, "S:R", false], [{31=>nil, 32=>:enemy}, 32, "S:R", true], [{31=>nil, 32=>nil}, 32, "S:R", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "S:R", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "S:R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "S:R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "S:R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{39=>nil}, 39, "S:R", false], [{39=>nil, 48=>:enemy}, 48, "S:R", true], [{39=>nil, 48=>nil}, 48, "S:R", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "S:R", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "S:R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "S:R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "S:R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:R", false]], 31=>[[{22=>:enemy}, 22, "S:+R", true], [{30=>:enemy}, 30, "S:R", true], [{32=>:enemy}, 32, "S:R", true], [{40=>:enemy}, 40, "S:R", true], [{22=>nil}, 22, "S:+R", false], [{22=>nil, 13=>:enemy}, 13, "S:+R", true], [{22=>nil, 13=>nil}, 13, "S:+R", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{30=>nil}, 30, "S:R", false], [{30=>nil, 29=>:enemy}, 29, "S:R", true], [{30=>nil, 29=>nil}, 29, "S:R", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "S:R", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "S:R", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{32=>nil}, 32, "S:R", false], [{32=>nil, 33=>:enemy}, 33, "S:R", true], [{32=>nil, 33=>nil}, 33, "S:R", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "S:R", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "S:R", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{40=>nil}, 40, "S:R", false], [{40=>nil, 49=>:enemy}, 49, "S:R", true], [{40=>nil, 49=>nil}, 49, "S:R", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "S:R", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "S:R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "S:R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "S:R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:R", false]], 32=>[[{23=>:enemy}, 23, "S:+R", true], [{31=>:enemy}, 31, "S:R", true], [{33=>:enemy}, 33, "S:R", true], [{41=>:enemy}, 41, "S:R", true], [{23=>nil}, 23, "S:+R", false], [{23=>nil, 14=>:enemy}, 14, "S:+R", true], [{23=>nil, 14=>nil}, 14, "S:+R", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{31=>nil}, 31, "S:R", false], [{31=>nil, 30=>:enemy}, 30, "S:R", true], [{31=>nil, 30=>nil}, 30, "S:R", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "S:R", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "S:R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{33=>nil}, 33, "S:R", false], [{33=>nil, 34=>:enemy}, 34, "S:R", true], [{33=>nil, 34=>nil}, 34, "S:R", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "S:R", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "S:R", false], [{41=>nil}, 41, "S:R", false], [{41=>nil, 50=>:enemy}, 50, "S:R", true], [{41=>nil, 50=>nil}, 50, "S:R", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "S:R", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "S:R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "S:R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "S:R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:R", false]], 33=>[[{24=>:enemy}, 24, "S:+R", true], [{32=>:enemy}, 32, "S:R", true], [{34=>:enemy}, 34, "S:R", true], [{42=>:enemy}, 42, "S:R", true], [{24=>nil}, 24, "S:+R", false], [{24=>nil, 15=>:enemy}, 15, "S:+R", true], [{24=>nil, 15=>nil}, 15, "S:+R", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{32=>nil}, 32, "S:R", false], [{32=>nil, 31=>:enemy}, 31, "S:R", true], [{32=>nil, 31=>nil}, 31, "S:R", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "S:R", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "S:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{34=>nil}, 34, "S:R", false], [{34=>nil, 35=>:enemy}, 35, "S:R", true], [{34=>nil, 35=>nil}, 35, "S:R", false], [{42=>nil}, 42, "S:R", false], [{42=>nil, 51=>:enemy}, 51, "S:R", true], [{42=>nil, 51=>nil}, 51, "S:R", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "S:R", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "S:R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "S:R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "S:R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:R", false]], 34=>[[{25=>:enemy}, 25, "S:+R", true], [{33=>:enemy}, 33, "S:R", true], [{35=>:enemy}, 35, "S:R", true], [{43=>:enemy}, 43, "S:R", true], [{25=>nil}, 25, "S:+R", false], [{25=>nil, 16=>:enemy}, 16, "S:+R", true], [{25=>nil, 16=>nil}, 16, "S:+R", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{33=>nil}, 33, "S:R", false], [{33=>nil, 32=>:enemy}, 32, "S:R", true], [{33=>nil, 32=>nil}, 32, "S:R", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "S:R", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "S:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "S:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "S:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{35=>nil}, 35, "S:R", false], [{43=>nil}, 43, "S:R", false], [{43=>nil, 52=>:enemy}, 52, "S:R", true], [{43=>nil, 52=>nil}, 52, "S:R", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "S:R", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "S:R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "S:R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "S:R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:R", false]], 35=>[[{26=>:enemy}, 26, "S:+R", true], [{34=>:enemy}, 34, "S:R", true], [{44=>:enemy}, 44, "S:R", true], [{26=>nil}, 26, "S:+R", false], [{26=>nil, 17=>:enemy}, 17, "S:+R", true], [{26=>nil, 17=>nil}, 17, "S:+R", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{34=>nil}, 34, "S:R", false], [{34=>nil, 33=>:enemy}, 33, "S:R", true], [{34=>nil, 33=>nil}, 33, "S:R", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "S:R", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "S:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "S:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "S:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "S:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "S:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "S:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "S:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "S:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "S:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "S:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "S:R", false], [{44=>nil}, 44, "S:R", false], [{44=>nil, 53=>:enemy}, 53, "S:R", true], [{44=>nil, 53=>nil}, 53, "S:R", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "S:R", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "S:R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "S:R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "S:R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:R", false]], 36=>[[{27=>:enemy}, 27, "S:R", true], [{37=>:enemy}, 37, "S:R", true], [{45=>:enemy}, 45, "S:R", true], [{27=>nil}, 27, "S:R", false], [{27=>nil, 18=>:enemy}, 18, "S:+R", true], [{27=>nil, 18=>nil}, 18, "S:+R", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{37=>nil}, 37, "S:R", false], [{37=>nil, 38=>:enemy}, 38, "S:R", true], [{37=>nil, 38=>nil}, 38, "S:R", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "S:R", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "S:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "S:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "S:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "S:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "S:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{45=>nil}, 45, "S:R", false], [{45=>nil, 54=>:enemy}, 54, "S:R", true], [{45=>nil, 54=>nil}, 54, "S:R", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "S:R", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "S:R", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "S:R", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "S:R", false]], 37=>[[{28=>:enemy}, 28, "S:R", true], [{36=>:enemy}, 36, "S:R", true], [{38=>:enemy}, 38, "S:R", true], [{46=>:enemy}, 46, "S:R", true], [{28=>nil}, 28, "S:R", false], [{28=>nil, 19=>:enemy}, 19, "S:+R", true], [{28=>nil, 19=>nil}, 19, "S:+R", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{36=>nil}, 36, "S:R", false], [{38=>nil}, 38, "S:R", false], [{38=>nil, 39=>:enemy}, 39, "S:R", true], [{38=>nil, 39=>nil}, 39, "S:R", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "S:R", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "S:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "S:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "S:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{46=>nil}, 46, "S:R", false], [{46=>nil, 55=>:enemy}, 55, "S:R", true], [{46=>nil, 55=>nil}, 55, "S:R", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "S:R", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "S:R", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "S:R", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "S:R", false]], 38=>[[{29=>:enemy}, 29, "S:R", true], [{37=>:enemy}, 37, "S:R", true], [{39=>:enemy}, 39, "S:R", true], [{47=>:enemy}, 47, "S:R", true], [{29=>nil}, 29, "S:R", false], [{29=>nil, 20=>:enemy}, 20, "S:+R", true], [{29=>nil, 20=>nil}, 20, "S:+R", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{37=>nil}, 37, "S:R", false], [{37=>nil, 36=>:enemy}, 36, "S:R", true], [{37=>nil, 36=>nil}, 36, "S:R", false], [{39=>nil}, 39, "S:R", false], [{39=>nil, 40=>:enemy}, 40, "S:R", true], [{39=>nil, 40=>nil}, 40, "S:R", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "S:R", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "S:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "S:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "S:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{47=>nil}, 47, "S:R", false], [{47=>nil, 56=>:enemy}, 56, "S:R", true], [{47=>nil, 56=>nil}, 56, "S:R", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "S:R", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "S:R", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "S:R", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "S:R", false]], 39=>[[{30=>:enemy}, 30, "S:R", true], [{38=>:enemy}, 38, "S:R", true], [{40=>:enemy}, 40, "S:R", true], [{48=>:enemy}, 48, "S:R", true], [{30=>nil}, 30, "S:R", false], [{30=>nil, 21=>:enemy}, 21, "S:+R", true], [{30=>nil, 21=>nil}, 21, "S:+R", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{38=>nil}, 38, "S:R", false], [{38=>nil, 37=>:enemy}, 37, "S:R", true], [{38=>nil, 37=>nil}, 37, "S:R", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{40=>nil}, 40, "S:R", false], [{40=>nil, 41=>:enemy}, 41, "S:R", true], [{40=>nil, 41=>nil}, 41, "S:R", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "S:R", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "S:R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "S:R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "S:R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{48=>nil}, 48, "S:R", false], [{48=>nil, 57=>:enemy}, 57, "S:R", true], [{48=>nil, 57=>nil}, 57, "S:R", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "S:R", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "S:R", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "S:R", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "S:R", false]], 40=>[[{31=>:enemy}, 31, "S:R", true], [{39=>:enemy}, 39, "S:R", true], [{41=>:enemy}, 41, "S:R", true], [{49=>:enemy}, 49, "S:R", true], [{31=>nil}, 31, "S:R", false], [{31=>nil, 22=>:enemy}, 22, "S:+R", true], [{31=>nil, 22=>nil}, 22, "S:+R", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{39=>nil}, 39, "S:R", false], [{39=>nil, 38=>:enemy}, 38, "S:R", true], [{39=>nil, 38=>nil}, 38, "S:R", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "S:R", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "S:R", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{41=>nil}, 41, "S:R", false], [{41=>nil, 42=>:enemy}, 42, "S:R", true], [{41=>nil, 42=>nil}, 42, "S:R", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "S:R", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "S:R", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{49=>nil}, 49, "S:R", false], [{49=>nil, 58=>:enemy}, 58, "S:R", true], [{49=>nil, 58=>nil}, 58, "S:R", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "S:R", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "S:R", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "S:R", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "S:R", false]], 41=>[[{32=>:enemy}, 32, "S:R", true], [{40=>:enemy}, 40, "S:R", true], [{42=>:enemy}, 42, "S:R", true], [{50=>:enemy}, 50, "S:R", true], [{32=>nil}, 32, "S:R", false], [{32=>nil, 23=>:enemy}, 23, "S:+R", true], [{32=>nil, 23=>nil}, 23, "S:+R", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{40=>nil}, 40, "S:R", false], [{40=>nil, 39=>:enemy}, 39, "S:R", true], [{40=>nil, 39=>nil}, 39, "S:R", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "S:R", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "S:R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{42=>nil}, 42, "S:R", false], [{42=>nil, 43=>:enemy}, 43, "S:R", true], [{42=>nil, 43=>nil}, 43, "S:R", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "S:R", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "S:R", false], [{50=>nil}, 50, "S:R", false], [{50=>nil, 59=>:enemy}, 59, "S:R", true], [{50=>nil, 59=>nil}, 59, "S:R", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "S:R", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "S:R", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "S:R", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "S:R", false]], 42=>[[{33=>:enemy}, 33, "S:R", true], [{41=>:enemy}, 41, "S:R", true], [{43=>:enemy}, 43, "S:R", true], [{51=>:enemy}, 51, "S:R", true], [{33=>nil}, 33, "S:R", false], [{33=>nil, 24=>:enemy}, 24, "S:+R", true], [{33=>nil, 24=>nil}, 24, "S:+R", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{41=>nil}, 41, "S:R", false], [{41=>nil, 40=>:enemy}, 40, "S:R", true], [{41=>nil, 40=>nil}, 40, "S:R", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "S:R", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "S:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{43=>nil}, 43, "S:R", false], [{43=>nil, 44=>:enemy}, 44, "S:R", true], [{43=>nil, 44=>nil}, 44, "S:R", false], [{51=>nil}, 51, "S:R", false], [{51=>nil, 60=>:enemy}, 60, "S:R", true], [{51=>nil, 60=>nil}, 60, "S:R", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "S:R", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "S:R", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "S:R", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "S:R", false]], 43=>[[{34=>:enemy}, 34, "S:R", true], [{42=>:enemy}, 42, "S:R", true], [{44=>:enemy}, 44, "S:R", true], [{52=>:enemy}, 52, "S:R", true], [{34=>nil}, 34, "S:R", false], [{34=>nil, 25=>:enemy}, 25, "S:+R", true], [{34=>nil, 25=>nil}, 25, "S:+R", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{42=>nil}, 42, "S:R", false], [{42=>nil, 41=>:enemy}, 41, "S:R", true], [{42=>nil, 41=>nil}, 41, "S:R", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "S:R", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "S:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "S:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "S:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{44=>nil}, 44, "S:R", false], [{52=>nil}, 52, "S:R", false], [{52=>nil, 61=>:enemy}, 61, "S:R", true], [{52=>nil, 61=>nil}, 61, "S:R", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "S:R", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "S:R", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "S:R", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "S:R", false]], 44=>[[{35=>:enemy}, 35, "S:R", true], [{43=>:enemy}, 43, "S:R", true], [{53=>:enemy}, 53, "S:R", true], [{35=>nil}, 35, "S:R", false], [{35=>nil, 26=>:enemy}, 26, "S:+R", true], [{35=>nil, 26=>nil}, 26, "S:+R", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{43=>nil}, 43, "S:R", false], [{43=>nil, 42=>:enemy}, 42, "S:R", true], [{43=>nil, 42=>nil}, 42, "S:R", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "S:R", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "S:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "S:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "S:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "S:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "S:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "S:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "S:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "S:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "S:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "S:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "S:R", false], [{53=>nil}, 53, "S:R", false], [{53=>nil, 62=>:enemy}, 62, "S:R", true], [{53=>nil, 62=>nil}, 62, "S:R", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "S:R", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "S:R", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "S:R", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "S:R", false]], 45=>[[{36=>:enemy}, 36, "S:R", true], [{46=>:enemy}, 46, "S:R", true], [{54=>:enemy}, 54, "S:R", true], [{36=>nil}, 36, "S:R", false], [{36=>nil, 27=>:enemy}, 27, "S:R", true], [{36=>nil, 27=>nil}, 27, "S:R", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{46=>nil}, 46, "S:R", false], [{46=>nil, 47=>:enemy}, 47, "S:R", true], [{46=>nil, 47=>nil}, 47, "S:R", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "S:R", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "S:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "S:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "S:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "S:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "S:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{54=>nil}, 54, "S:R", false], [{54=>nil, 63=>:enemy}, 63, "S:R", true], [{54=>nil, 63=>nil}, 63, "S:R", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "S:R", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "S:R", false]], 46=>[[{37=>:enemy}, 37, "S:R", true], [{45=>:enemy}, 45, "S:R", true], [{47=>:enemy}, 47, "S:R", true], [{55=>:enemy}, 55, "S:R", true], [{37=>nil}, 37, "S:R", false], [{37=>nil, 28=>:enemy}, 28, "S:R", true], [{37=>nil, 28=>nil}, 28, "S:R", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{45=>nil}, 45, "S:R", false], [{47=>nil}, 47, "S:R", false], [{47=>nil, 48=>:enemy}, 48, "S:R", true], [{47=>nil, 48=>nil}, 48, "S:R", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "S:R", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "S:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "S:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "S:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{55=>nil}, 55, "S:R", false], [{55=>nil, 64=>:enemy}, 64, "S:R", true], [{55=>nil, 64=>nil}, 64, "S:R", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "S:R", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "S:R", false]], 47=>[[{38=>:enemy}, 38, "S:R", true], [{46=>:enemy}, 46, "S:R", true], [{48=>:enemy}, 48, "S:R", true], [{56=>:enemy}, 56, "S:R", true], [{38=>nil}, 38, "S:R", false], [{38=>nil, 29=>:enemy}, 29, "S:R", true], [{38=>nil, 29=>nil}, 29, "S:R", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{46=>nil}, 46, "S:R", false], [{46=>nil, 45=>:enemy}, 45, "S:R", true], [{46=>nil, 45=>nil}, 45, "S:R", false], [{48=>nil}, 48, "S:R", false], [{48=>nil, 49=>:enemy}, 49, "S:R", true], [{48=>nil, 49=>nil}, 49, "S:R", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "S:R", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "S:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "S:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "S:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{56=>nil}, 56, "S:R", false], [{56=>nil, 65=>:enemy}, 65, "S:R", true], [{56=>nil, 65=>nil}, 65, "S:R", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "S:R", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "S:R", false]], 48=>[[{39=>:enemy}, 39, "S:R", true], [{47=>:enemy}, 47, "S:R", true], [{49=>:enemy}, 49, "S:R", true], [{57=>:enemy}, 57, "S:R", true], [{39=>nil}, 39, "S:R", false], [{39=>nil, 30=>:enemy}, 30, "S:R", true], [{39=>nil, 30=>nil}, 30, "S:R", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{47=>nil}, 47, "S:R", false], [{47=>nil, 46=>:enemy}, 46, "S:R", true], [{47=>nil, 46=>nil}, 46, "S:R", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{49=>nil}, 49, "S:R", false], [{49=>nil, 50=>:enemy}, 50, "S:R", true], [{49=>nil, 50=>nil}, 50, "S:R", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "S:R", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "S:R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "S:R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "S:R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{57=>nil}, 57, "S:R", false], [{57=>nil, 66=>:enemy}, 66, "S:R", true], [{57=>nil, 66=>nil}, 66, "S:R", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "S:R", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "S:R", false]], 49=>[[{40=>:enemy}, 40, "S:R", true], [{48=>:enemy}, 48, "S:R", true], [{50=>:enemy}, 50, "S:R", true], [{58=>:enemy}, 58, "S:R", true], [{40=>nil}, 40, "S:R", false], [{40=>nil, 31=>:enemy}, 31, "S:R", true], [{40=>nil, 31=>nil}, 31, "S:R", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{48=>nil}, 48, "S:R", false], [{48=>nil, 47=>:enemy}, 47, "S:R", true], [{48=>nil, 47=>nil}, 47, "S:R", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "S:R", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "S:R", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{50=>nil}, 50, "S:R", false], [{50=>nil, 51=>:enemy}, 51, "S:R", true], [{50=>nil, 51=>nil}, 51, "S:R", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "S:R", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "S:R", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{58=>nil}, 58, "S:R", false], [{58=>nil, 67=>:enemy}, 67, "S:R", true], [{58=>nil, 67=>nil}, 67, "S:R", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "S:R", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "S:R", false]], 50=>[[{41=>:enemy}, 41, "S:R", true], [{49=>:enemy}, 49, "S:R", true], [{51=>:enemy}, 51, "S:R", true], [{59=>:enemy}, 59, "S:R", true], [{41=>nil}, 41, "S:R", false], [{41=>nil, 32=>:enemy}, 32, "S:R", true], [{41=>nil, 32=>nil}, 32, "S:R", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{49=>nil}, 49, "S:R", false], [{49=>nil, 48=>:enemy}, 48, "S:R", true], [{49=>nil, 48=>nil}, 48, "S:R", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "S:R", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "S:R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{51=>nil}, 51, "S:R", false], [{51=>nil, 52=>:enemy}, 52, "S:R", true], [{51=>nil, 52=>nil}, 52, "S:R", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "S:R", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "S:R", false], [{59=>nil}, 59, "S:R", false], [{59=>nil, 68=>:enemy}, 68, "S:R", true], [{59=>nil, 68=>nil}, 68, "S:R", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "S:R", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "S:R", false]], 51=>[[{42=>:enemy}, 42, "S:R", true], [{50=>:enemy}, 50, "S:R", true], [{52=>:enemy}, 52, "S:R", true], [{60=>:enemy}, 60, "S:R", true], [{42=>nil}, 42, "S:R", false], [{42=>nil, 33=>:enemy}, 33, "S:R", true], [{42=>nil, 33=>nil}, 33, "S:R", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{50=>nil}, 50, "S:R", false], [{50=>nil, 49=>:enemy}, 49, "S:R", true], [{50=>nil, 49=>nil}, 49, "S:R", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "S:R", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "S:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{52=>nil}, 52, "S:R", false], [{52=>nil, 53=>:enemy}, 53, "S:R", true], [{52=>nil, 53=>nil}, 53, "S:R", false], [{60=>nil}, 60, "S:R", false], [{60=>nil, 69=>:enemy}, 69, "S:R", true], [{60=>nil, 69=>nil}, 69, "S:R", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "S:R", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "S:R", false]], 52=>[[{43=>:enemy}, 43, "S:R", true], [{51=>:enemy}, 51, "S:R", true], [{53=>:enemy}, 53, "S:R", true], [{61=>:enemy}, 61, "S:R", true], [{43=>nil}, 43, "S:R", false], [{43=>nil, 34=>:enemy}, 34, "S:R", true], [{43=>nil, 34=>nil}, 34, "S:R", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{51=>nil}, 51, "S:R", false], [{51=>nil, 50=>:enemy}, 50, "S:R", true], [{51=>nil, 50=>nil}, 50, "S:R", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "S:R", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "S:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "S:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "S:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{53=>nil}, 53, "S:R", false], [{61=>nil}, 61, "S:R", false], [{61=>nil, 70=>:enemy}, 70, "S:R", true], [{61=>nil, 70=>nil}, 70, "S:R", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "S:R", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "S:R", false]], 53=>[[{44=>:enemy}, 44, "S:R", true], [{52=>:enemy}, 52, "S:R", true], [{62=>:enemy}, 62, "S:R", true], [{44=>nil}, 44, "S:R", false], [{44=>nil, 35=>:enemy}, 35, "S:R", true], [{44=>nil, 35=>nil}, 35, "S:R", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{52=>nil}, 52, "S:R", false], [{52=>nil, 51=>:enemy}, 51, "S:R", true], [{52=>nil, 51=>nil}, 51, "S:R", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "S:R", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "S:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "S:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "S:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "S:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "S:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "S:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "S:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "S:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "S:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "S:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "S:R", false], [{62=>nil}, 62, "S:R", false], [{62=>nil, 71=>:enemy}, 71, "S:R", true], [{62=>nil, 71=>nil}, 71, "S:R", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "S:R", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "S:R", false]], 54=>[[{45=>:enemy}, 45, "S:R", true], [{55=>:enemy}, 55, "S:R", true], [{63=>:enemy}, 63, "S:R", true], [{45=>nil}, 45, "S:R", false], [{45=>nil, 36=>:enemy}, 36, "S:R", true], [{45=>nil, 36=>nil}, 36, "S:R", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "S:R", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "S:R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{55=>nil}, 55, "S:R", false], [{55=>nil, 56=>:enemy}, 56, "S:R", true], [{55=>nil, 56=>nil}, 56, "S:R", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "S:R", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "S:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "S:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "S:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "S:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "S:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{63=>nil}, 63, "S:R", false], [{63=>nil, 72=>:enemy}, 72, "S:R", true], [{63=>nil, 72=>nil}, 72, "S:R", false]], 55=>[[{46=>:enemy}, 46, "S:R", true], [{54=>:enemy}, 54, "S:R", true], [{56=>:enemy}, 56, "S:R", true], [{64=>:enemy}, 64, "S:R", true], [{46=>nil}, 46, "S:R", false], [{46=>nil, 37=>:enemy}, 37, "S:R", true], [{46=>nil, 37=>nil}, 37, "S:R", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "S:R", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "S:R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{54=>nil}, 54, "S:R", false], [{56=>nil}, 56, "S:R", false], [{56=>nil, 57=>:enemy}, 57, "S:R", true], [{56=>nil, 57=>nil}, 57, "S:R", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "S:R", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "S:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "S:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "S:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{64=>nil}, 64, "S:R", false], [{64=>nil, 73=>:enemy}, 73, "S:R", true], [{64=>nil, 73=>nil}, 73, "S:R", false]], 56=>[[{47=>:enemy}, 47, "S:R", true], [{55=>:enemy}, 55, "S:R", true], [{57=>:enemy}, 57, "S:R", true], [{65=>:enemy}, 65, "S:R", true], [{47=>nil}, 47, "S:R", false], [{47=>nil, 38=>:enemy}, 38, "S:R", true], [{47=>nil, 38=>nil}, 38, "S:R", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "S:R", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "S:R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{55=>nil}, 55, "S:R", false], [{55=>nil, 54=>:enemy}, 54, "S:R", true], [{55=>nil, 54=>nil}, 54, "S:R", false], [{57=>nil}, 57, "S:R", false], [{57=>nil, 58=>:enemy}, 58, "S:R", true], [{57=>nil, 58=>nil}, 58, "S:R", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "S:R", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "S:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "S:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "S:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{65=>nil}, 65, "S:R", false], [{65=>nil, 74=>:enemy}, 74, "S:R", true], [{65=>nil, 74=>nil}, 74, "S:R", false]], 57=>[[{48=>:enemy}, 48, "S:R", true], [{56=>:enemy}, 56, "S:R", true], [{58=>:enemy}, 58, "S:R", true], [{66=>:enemy}, 66, "S:R", true], [{48=>nil}, 48, "S:R", false], [{48=>nil, 39=>:enemy}, 39, "S:R", true], [{48=>nil, 39=>nil}, 39, "S:R", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "S:R", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "S:R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{56=>nil}, 56, "S:R", false], [{56=>nil, 55=>:enemy}, 55, "S:R", true], [{56=>nil, 55=>nil}, 55, "S:R", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{58=>nil}, 58, "S:R", false], [{58=>nil, 59=>:enemy}, 59, "S:R", true], [{58=>nil, 59=>nil}, 59, "S:R", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "S:R", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "S:R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "S:R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "S:R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{66=>nil}, 66, "S:R", false], [{66=>nil, 75=>:enemy}, 75, "S:R", true], [{66=>nil, 75=>nil}, 75, "S:R", false]], 58=>[[{49=>:enemy}, 49, "S:R", true], [{57=>:enemy}, 57, "S:R", true], [{59=>:enemy}, 59, "S:R", true], [{67=>:enemy}, 67, "S:R", true], [{49=>nil}, 49, "S:R", false], [{49=>nil, 40=>:enemy}, 40, "S:R", true], [{49=>nil, 40=>nil}, 40, "S:R", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "S:R", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "S:R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{57=>nil}, 57, "S:R", false], [{57=>nil, 56=>:enemy}, 56, "S:R", true], [{57=>nil, 56=>nil}, 56, "S:R", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "S:R", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "S:R", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{59=>nil}, 59, "S:R", false], [{59=>nil, 60=>:enemy}, 60, "S:R", true], [{59=>nil, 60=>nil}, 60, "S:R", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "S:R", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "S:R", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{67=>nil}, 67, "S:R", false], [{67=>nil, 76=>:enemy}, 76, "S:R", true], [{67=>nil, 76=>nil}, 76, "S:R", false]], 59=>[[{50=>:enemy}, 50, "S:R", true], [{58=>:enemy}, 58, "S:R", true], [{60=>:enemy}, 60, "S:R", true], [{68=>:enemy}, 68, "S:R", true], [{50=>nil}, 50, "S:R", false], [{50=>nil, 41=>:enemy}, 41, "S:R", true], [{50=>nil, 41=>nil}, 41, "S:R", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "S:R", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "S:R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{58=>nil}, 58, "S:R", false], [{58=>nil, 57=>:enemy}, 57, "S:R", true], [{58=>nil, 57=>nil}, 57, "S:R", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "S:R", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "S:R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{60=>nil}, 60, "S:R", false], [{60=>nil, 61=>:enemy}, 61, "S:R", true], [{60=>nil, 61=>nil}, 61, "S:R", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "S:R", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "S:R", false], [{68=>nil}, 68, "S:R", false], [{68=>nil, 77=>:enemy}, 77, "S:R", true], [{68=>nil, 77=>nil}, 77, "S:R", false]], 60=>[[{51=>:enemy}, 51, "S:R", true], [{59=>:enemy}, 59, "S:R", true], [{61=>:enemy}, 61, "S:R", true], [{69=>:enemy}, 69, "S:R", true], [{51=>nil}, 51, "S:R", false], [{51=>nil, 42=>:enemy}, 42, "S:R", true], [{51=>nil, 42=>nil}, 42, "S:R", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "S:R", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "S:R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{59=>nil}, 59, "S:R", false], [{59=>nil, 58=>:enemy}, 58, "S:R", true], [{59=>nil, 58=>nil}, 58, "S:R", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "S:R", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "S:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{61=>nil}, 61, "S:R", false], [{61=>nil, 62=>:enemy}, 62, "S:R", true], [{61=>nil, 62=>nil}, 62, "S:R", false], [{69=>nil}, 69, "S:R", false], [{69=>nil, 78=>:enemy}, 78, "S:R", true], [{69=>nil, 78=>nil}, 78, "S:R", false]], 61=>[[{52=>:enemy}, 52, "S:R", true], [{60=>:enemy}, 60, "S:R", true], [{62=>:enemy}, 62, "S:R", true], [{70=>:enemy}, 70, "S:R", true], [{52=>nil}, 52, "S:R", false], [{52=>nil, 43=>:enemy}, 43, "S:R", true], [{52=>nil, 43=>nil}, 43, "S:R", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "S:R", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "S:R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{60=>nil}, 60, "S:R", false], [{60=>nil, 59=>:enemy}, 59, "S:R", true], [{60=>nil, 59=>nil}, 59, "S:R", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "S:R", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "S:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "S:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "S:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{62=>nil}, 62, "S:R", false], [{70=>nil}, 70, "S:R", false], [{70=>nil, 79=>:enemy}, 79, "S:R", true], [{70=>nil, 79=>nil}, 79, "S:R", false]], 62=>[[{53=>:enemy}, 53, "S:R", true], [{61=>:enemy}, 61, "S:R", true], [{71=>:enemy}, 71, "S:R", true], [{53=>nil}, 53, "S:R", false], [{53=>nil, 44=>:enemy}, 44, "S:R", true], [{53=>nil, 44=>nil}, 44, "S:R", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "S:R", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "S:R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{61=>nil}, 61, "S:R", false], [{61=>nil, 60=>:enemy}, 60, "S:R", true], [{61=>nil, 60=>nil}, 60, "S:R", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "S:R", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "S:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "S:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "S:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "S:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "S:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "S:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "S:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "S:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "S:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "S:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "S:R", false], [{71=>nil}, 71, "S:R", false], [{71=>nil, 80=>:enemy}, 80, "S:R", true], [{71=>nil, 80=>nil}, 80, "S:R", false]], 63=>[[{54=>:enemy}, 54, "S:R", true], [{64=>:enemy}, 64, "S:R", true], [{72=>:enemy}, 72, "S:R", true], [{54=>nil}, 54, "S:R", false], [{54=>nil, 45=>:enemy}, 45, "S:R", true], [{54=>nil, 45=>nil}, 45, "S:R", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "S:R", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "S:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{64=>nil}, 64, "S:R", false], [{64=>nil, 65=>:enemy}, 65, "S:R", true], [{64=>nil, 65=>nil}, 65, "S:R", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "S:R", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "S:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "S:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "S:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "S:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "S:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{72=>nil}, 72, "S:R", false]], 64=>[[{55=>:enemy}, 55, "S:R", true], [{63=>:enemy}, 63, "S:R", true], [{65=>:enemy}, 65, "S:R", true], [{73=>:enemy}, 73, "S:R", true], [{55=>nil}, 55, "S:R", false], [{55=>nil, 46=>:enemy}, 46, "S:R", true], [{55=>nil, 46=>nil}, 46, "S:R", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "S:R", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "S:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{63=>nil}, 63, "S:R", false], [{65=>nil}, 65, "S:R", false], [{65=>nil, 66=>:enemy}, 66, "S:R", true], [{65=>nil, 66=>nil}, 66, "S:R", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "S:R", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "S:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "S:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "S:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{73=>nil}, 73, "S:R", false]], 65=>[[{56=>:enemy}, 56, "S:R", true], [{64=>:enemy}, 64, "S:R", true], [{66=>:enemy}, 66, "S:R", true], [{74=>:enemy}, 74, "S:R", true], [{56=>nil}, 56, "S:R", false], [{56=>nil, 47=>:enemy}, 47, "S:R", true], [{56=>nil, 47=>nil}, 47, "S:R", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "S:R", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "S:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{64=>nil}, 64, "S:R", false], [{64=>nil, 63=>:enemy}, 63, "S:R", true], [{64=>nil, 63=>nil}, 63, "S:R", false], [{66=>nil}, 66, "S:R", false], [{66=>nil, 67=>:enemy}, 67, "S:R", true], [{66=>nil, 67=>nil}, 67, "S:R", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "S:R", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "S:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "S:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "S:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{74=>nil}, 74, "S:R", false]], 66=>[[{57=>:enemy}, 57, "S:R", true], [{65=>:enemy}, 65, "S:R", true], [{67=>:enemy}, 67, "S:R", true], [{75=>:enemy}, 75, "S:R", true], [{57=>nil}, 57, "S:R", false], [{57=>nil, 48=>:enemy}, 48, "S:R", true], [{57=>nil, 48=>nil}, 48, "S:R", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "S:R", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "S:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{65=>nil}, 65, "S:R", false], [{65=>nil, 64=>:enemy}, 64, "S:R", true], [{65=>nil, 64=>nil}, 64, "S:R", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{67=>nil}, 67, "S:R", false], [{67=>nil, 68=>:enemy}, 68, "S:R", true], [{67=>nil, 68=>nil}, 68, "S:R", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "S:R", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "S:R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "S:R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "S:R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{75=>nil}, 75, "S:R", false]], 67=>[[{58=>:enemy}, 58, "S:R", true], [{66=>:enemy}, 66, "S:R", true], [{68=>:enemy}, 68, "S:R", true], [{76=>:enemy}, 76, "S:R", true], [{58=>nil}, 58, "S:R", false], [{58=>nil, 49=>:enemy}, 49, "S:R", true], [{58=>nil, 49=>nil}, 49, "S:R", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "S:R", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "S:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{66=>nil}, 66, "S:R", false], [{66=>nil, 65=>:enemy}, 65, "S:R", true], [{66=>nil, 65=>nil}, 65, "S:R", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "S:R", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "S:R", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{68=>nil}, 68, "S:R", false], [{68=>nil, 69=>:enemy}, 69, "S:R", true], [{68=>nil, 69=>nil}, 69, "S:R", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "S:R", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "S:R", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{76=>nil}, 76, "S:R", false]], 68=>[[{59=>:enemy}, 59, "S:R", true], [{67=>:enemy}, 67, "S:R", true], [{69=>:enemy}, 69, "S:R", true], [{77=>:enemy}, 77, "S:R", true], [{59=>nil}, 59, "S:R", false], [{59=>nil, 50=>:enemy}, 50, "S:R", true], [{59=>nil, 50=>nil}, 50, "S:R", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "S:R", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "S:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{67=>nil}, 67, "S:R", false], [{67=>nil, 66=>:enemy}, 66, "S:R", true], [{67=>nil, 66=>nil}, 66, "S:R", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "S:R", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "S:R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{69=>nil}, 69, "S:R", false], [{69=>nil, 70=>:enemy}, 70, "S:R", true], [{69=>nil, 70=>nil}, 70, "S:R", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "S:R", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "S:R", false], [{77=>nil}, 77, "S:R", false]], 69=>[[{60=>:enemy}, 60, "S:R", true], [{68=>:enemy}, 68, "S:R", true], [{70=>:enemy}, 70, "S:R", true], [{78=>:enemy}, 78, "S:R", true], [{60=>nil}, 60, "S:R", false], [{60=>nil, 51=>:enemy}, 51, "S:R", true], [{60=>nil, 51=>nil}, 51, "S:R", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "S:R", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "S:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{68=>nil}, 68, "S:R", false], [{68=>nil, 67=>:enemy}, 67, "S:R", true], [{68=>nil, 67=>nil}, 67, "S:R", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "S:R", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "S:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{70=>nil}, 70, "S:R", false], [{70=>nil, 71=>:enemy}, 71, "S:R", true], [{70=>nil, 71=>nil}, 71, "S:R", false], [{78=>nil}, 78, "S:R", false]], 70=>[[{61=>:enemy}, 61, "S:R", true], [{69=>:enemy}, 69, "S:R", true], [{71=>:enemy}, 71, "S:R", true], [{79=>:enemy}, 79, "S:R", true], [{61=>nil}, 61, "S:R", false], [{61=>nil, 52=>:enemy}, 52, "S:R", true], [{61=>nil, 52=>nil}, 52, "S:R", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "S:R", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "S:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{69=>nil}, 69, "S:R", false], [{69=>nil, 68=>:enemy}, 68, "S:R", true], [{69=>nil, 68=>nil}, 68, "S:R", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "S:R", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "S:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "S:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "S:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{71=>nil}, 71, "S:R", false], [{79=>nil}, 79, "S:R", false]], 71=>[[{62=>:enemy}, 62, "S:R", true], [{70=>:enemy}, 70, "S:R", true], [{80=>:enemy}, 80, "S:R", true], [{62=>nil}, 62, "S:R", false], [{62=>nil, 53=>:enemy}, 53, "S:R", true], [{62=>nil, 53=>nil}, 53, "S:R", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "S:R", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "S:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{70=>nil}, 70, "S:R", false], [{70=>nil, 69=>:enemy}, 69, "S:R", true], [{70=>nil, 69=>nil}, 69, "S:R", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "S:R", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "S:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "S:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "S:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "S:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "S:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "S:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "S:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "S:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "S:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "S:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "S:R", false], [{80=>nil}, 80, "S:R", false]], 72=>[[{63=>:enemy}, 63, "S:R", true], [{73=>:enemy}, 73, "S:R", true], [{63=>nil}, 63, "S:R", false], [{63=>nil, 54=>:enemy}, 54, "S:R", true], [{63=>nil, 54=>nil}, 54, "S:R", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "S:R", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "S:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "S:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "S:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "S:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "S:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "S:+R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "S:+R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "S:+R", false], [{73=>nil}, 73, "S:R", false], [{73=>nil, 74=>:enemy}, 74, "S:R", true], [{73=>nil, 74=>nil}, 74, "S:R", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "S:R", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "S:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "S:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "S:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "S:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "S:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 73=>[[{64=>:enemy}, 64, "S:R", true], [{72=>:enemy}, 72, "S:R", true], [{74=>:enemy}, 74, "S:R", true], [{64=>nil}, 64, "S:R", false], [{64=>nil, 55=>:enemy}, 55, "S:R", true], [{64=>nil, 55=>nil}, 55, "S:R", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "S:R", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "S:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "S:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "S:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "S:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "S:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "S:+R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "S:+R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "S:+R", false], [{72=>nil}, 72, "S:R", false], [{74=>nil}, 74, "S:R", false], [{74=>nil, 75=>:enemy}, 75, "S:R", true], [{74=>nil, 75=>nil}, 75, "S:R", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "S:R", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "S:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "S:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "S:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 74=>[[{65=>:enemy}, 65, "S:R", true], [{73=>:enemy}, 73, "S:R", true], [{75=>:enemy}, 75, "S:R", true], [{65=>nil}, 65, "S:R", false], [{65=>nil, 56=>:enemy}, 56, "S:R", true], [{65=>nil, 56=>nil}, 56, "S:R", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "S:R", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "S:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "S:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "S:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "S:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "S:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "S:+R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "S:+R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "S:+R", false], [{73=>nil}, 73, "S:R", false], [{73=>nil, 72=>:enemy}, 72, "S:R", true], [{73=>nil, 72=>nil}, 72, "S:R", false], [{75=>nil}, 75, "S:R", false], [{75=>nil, 76=>:enemy}, 76, "S:R", true], [{75=>nil, 76=>nil}, 76, "S:R", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "S:R", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "S:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "S:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "S:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 75=>[[{66=>:enemy}, 66, "S:R", true], [{74=>:enemy}, 74, "S:R", true], [{76=>:enemy}, 76, "S:R", true], [{66=>nil}, 66, "S:R", false], [{66=>nil, 57=>:enemy}, 57, "S:R", true], [{66=>nil, 57=>nil}, 57, "S:R", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "S:R", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "S:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "S:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "S:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "S:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "S:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "S:+R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "S:+R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "S:+R", false], [{74=>nil}, 74, "S:R", false], [{74=>nil, 73=>:enemy}, 73, "S:R", true], [{74=>nil, 73=>nil}, 73, "S:R", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false], [{76=>nil}, 76, "S:R", false], [{76=>nil, 77=>:enemy}, 77, "S:R", true], [{76=>nil, 77=>nil}, 77, "S:R", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "S:R", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "S:R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "S:R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "S:R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 76=>[[{67=>:enemy}, 67, "S:R", true], [{75=>:enemy}, 75, "S:R", true], [{77=>:enemy}, 77, "S:R", true], [{67=>nil}, 67, "S:R", false], [{67=>nil, 58=>:enemy}, 58, "S:R", true], [{67=>nil, 58=>nil}, 58, "S:R", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "S:R", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "S:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "S:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "S:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "S:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "S:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "S:+R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "S:+R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "S:+R", false], [{75=>nil}, 75, "S:R", false], [{75=>nil, 74=>:enemy}, 74, "S:R", true], [{75=>nil, 74=>nil}, 74, "S:R", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "S:R", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "S:R", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false], [{77=>nil}, 77, "S:R", false], [{77=>nil, 78=>:enemy}, 78, "S:R", true], [{77=>nil, 78=>nil}, 78, "S:R", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "S:R", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "S:R", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 77=>[[{68=>:enemy}, 68, "S:R", true], [{76=>:enemy}, 76, "S:R", true], [{78=>:enemy}, 78, "S:R", true], [{68=>nil}, 68, "S:R", false], [{68=>nil, 59=>:enemy}, 59, "S:R", true], [{68=>nil, 59=>nil}, 59, "S:R", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "S:R", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "S:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "S:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "S:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "S:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "S:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "S:+R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "S:+R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "S:+R", false], [{76=>nil}, 76, "S:R", false], [{76=>nil, 75=>:enemy}, 75, "S:R", true], [{76=>nil, 75=>nil}, 75, "S:R", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "S:R", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "S:R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false], [{78=>nil}, 78, "S:R", false], [{78=>nil, 79=>:enemy}, 79, "S:R", true], [{78=>nil, 79=>nil}, 79, "S:R", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "S:R", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "S:R", false]], 78=>[[{69=>:enemy}, 69, "S:R", true], [{77=>:enemy}, 77, "S:R", true], [{79=>:enemy}, 79, "S:R", true], [{69=>nil}, 69, "S:R", false], [{69=>nil, 60=>:enemy}, 60, "S:R", true], [{69=>nil, 60=>nil}, 60, "S:R", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "S:R", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "S:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "S:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "S:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "S:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "S:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "S:+R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "S:+R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "S:+R", false], [{77=>nil}, 77, "S:R", false], [{77=>nil, 76=>:enemy}, 76, "S:R", true], [{77=>nil, 76=>nil}, 76, "S:R", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "S:R", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "S:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false], [{79=>nil}, 79, "S:R", false], [{79=>nil, 80=>:enemy}, 80, "S:R", true], [{79=>nil, 80=>nil}, 80, "S:R", false]], 79=>[[{70=>:enemy}, 70, "S:R", true], [{78=>:enemy}, 78, "S:R", true], [{80=>:enemy}, 80, "S:R", true], [{70=>nil}, 70, "S:R", false], [{70=>nil, 61=>:enemy}, 61, "S:R", true], [{70=>nil, 61=>nil}, 61, "S:R", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "S:R", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "S:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "S:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "S:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "S:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "S:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "S:+R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "S:+R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "S:+R", false], [{78=>nil}, 78, "S:R", false], [{78=>nil, 77=>:enemy}, 77, "S:R", true], [{78=>nil, 77=>nil}, 77, "S:R", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "S:R", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "S:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "S:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "S:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false], [{80=>nil}, 80, "S:R", false]], 80=>[[{71=>:enemy}, 71, "S:R", true], [{79=>:enemy}, 79, "S:R", true], [{71=>nil}, 71, "S:R", false], [{71=>nil, 62=>:enemy}, 62, "S:R", true], [{71=>nil, 62=>nil}, 62, "S:R", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "S:R", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "S:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "S:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "S:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "S:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "S:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "S:+R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "S:+R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "S:+R", false], [{79=>nil}, 79, "S:R", false], [{79=>nil, 78=>:enemy}, 78, "S:R", true], [{79=>nil, 78=>nil}, 78, "S:R", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "S:R", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "S:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "S:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "S:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "S:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "S:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "S:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "S:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "S:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "S:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "S:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "S:R", false]], nil=>[[{0=>nil}, 0, "S:R", false], [{1=>nil}, 1, "S:R", false], [{2=>nil}, 2, "S:R", false], [{3=>nil}, 3, "S:R", false], [{4=>nil}, 4, "S:R", false], [{5=>nil}, 5, "S:R", false], [{6=>nil}, 6, "S:R", false], [{7=>nil}, 7, "S:R", false], [{8=>nil}, 8, "S:R", false], [{9=>nil}, 9, "S:R", false], [{10=>nil}, 10, "S:R", false], [{11=>nil}, 11, "S:R", false], [{12=>nil}, 12, "S:R", false], [{13=>nil}, 13, "S:R", false], [{14=>nil}, 14, "S:R", false], [{15=>nil}, 15, "S:R", false], [{16=>nil}, 16, "S:R", false], [{17=>nil}, 17, "S:R", false], [{18=>nil}, 18, "S:R", false], [{19=>nil}, 19, "S:R", false], [{20=>nil}, 20, "S:R", false], [{21=>nil}, 21, "S:R", false], [{22=>nil}, 22, "S:R", false], [{23=>nil}, 23, "S:R", false], [{24=>nil}, 24, "S:R", false], [{25=>nil}, 25, "S:R", false], [{26=>nil}, 26, "S:R", false], [{27=>nil}, 27, "S:R", false], [{28=>nil}, 28, "S:R", false], [{29=>nil}, 29, "S:R", false], [{30=>nil}, 30, "S:R", false], [{31=>nil}, 31, "S:R", false], [{32=>nil}, 32, "S:R", false], [{33=>nil}, 33, "S:R", false], [{34=>nil}, 34, "S:R", false], [{35=>nil}, 35, "S:R", false], [{36=>nil}, 36, "S:R", false], [{37=>nil}, 37, "S:R", false], [{38=>nil}, 38, "S:R", false], [{39=>nil}, 39, "S:R", false], [{40=>nil}, 40, "S:R", false], [{41=>nil}, 41, "S:R", false], [{42=>nil}, 42, "S:R", false], [{43=>nil}, 43, "S:R", false], [{44=>nil}, 44, "S:R", false], [{45=>nil}, 45, "S:R", false], [{46=>nil}, 46, "S:R", false], [{47=>nil}, 47, "S:R", false], [{48=>nil}, 48, "S:R", false], [{49=>nil}, 49, "S:R", false], [{50=>nil}, 50, "S:R", false], [{51=>nil}, 51, "S:R", false], [{52=>nil}, 52, "S:R", false], [{53=>nil}, 53, "S:R", false], [{54=>nil}, 54, "S:R", false], [{55=>nil}, 55, "S:R", false], [{56=>nil}, 56, "S:R", false], [{57=>nil}, 57, "S:R", false], [{58=>nil}, 58, "S:R", false], [{59=>nil}, 59, "S:R", false], [{60=>nil}, 60, "S:R", false], [{61=>nil}, 61, "S:R", false], [{62=>nil}, 62, "S:R", false], [{63=>nil}, 63, "S:R", false], [{64=>nil}, 64, "S:R", false], [{65=>nil}, 65, "S:R", false], [{66=>nil}, 66, "S:R", false], [{67=>nil}, 67, "S:R", false], [{68=>nil}, 68, "S:R", false], [{69=>nil}, 69, "S:R", false], [{70=>nil}, 70, "S:R", false], [{71=>nil}, 71, "S:R", false], [{72=>nil}, 72, "S:R", false], [{73=>nil}, 73, "S:R", false], [{74=>nil}, 74, "S:R", false], [{75=>nil}, 75, "S:R", false], [{76=>nil}, 76, "S:R", false], [{77=>nil}, 77, "S:R", false], [{78=>nil}, 78, "S:R", false], [{79=>nil}, 79, "S:R", false], [{80=>nil}, 80, "S:R", false]]}, "S:S"=>{0=>[[{10=>:enemy}, 10, "S:+S", true], [{10=>nil}, 10, "S:+S", false]], 1=>[[{9=>:enemy}, 9, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{9=>nil}, 9, "S:+S", false], [{11=>nil}, 11, "S:+S", false]], 2=>[[{10=>:enemy}, 10, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{10=>nil}, 10, "S:+S", false], [{12=>nil}, 12, "S:+S", false]], 3=>[[{11=>:enemy}, 11, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{11=>nil}, 11, "S:+S", false], [{13=>nil}, 13, "S:+S", false]], 4=>[[{12=>:enemy}, 12, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{12=>nil}, 12, "S:+S", false], [{14=>nil}, 14, "S:+S", false]], 5=>[[{13=>:enemy}, 13, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{13=>nil}, 13, "S:+S", false], [{15=>nil}, 15, "S:+S", false]], 6=>[[{14=>:enemy}, 14, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{14=>nil}, 14, "S:+S", false], [{16=>nil}, 16, "S:+S", false]], 7=>[[{15=>:enemy}, 15, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{15=>nil}, 15, "S:+S", false], [{17=>nil}, 17, "S:+S", false]], 8=>[[{16=>:enemy}, 16, "S:+S", true], [{16=>nil}, 16, "S:+S", false]], 9=>[[{0=>:enemy}, 0, "S:+S", true], [{1=>:enemy}, 1, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{0=>nil}, 0, "S:+S", false], [{1=>nil}, 1, "S:+S", false], [{19=>nil}, 19, "S:+S", false]], 10=>[[{0=>:enemy}, 0, "S:+S", true], [{1=>:enemy}, 1, "S:+S", true], [{2=>:enemy}, 2, "S:+S", true], [{18=>:enemy}, 18, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{0=>nil}, 0, "S:+S", false], [{1=>nil}, 1, "S:+S", false], [{2=>nil}, 2, "S:+S", false], [{18=>nil}, 18, "S:+S", false], [{20=>nil}, 20, "S:+S", false]], 11=>[[{1=>:enemy}, 1, "S:+S", true], [{2=>:enemy}, 2, "S:+S", true], [{3=>:enemy}, 3, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{1=>nil}, 1, "S:+S", false], [{2=>nil}, 2, "S:+S", false], [{3=>nil}, 3, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{21=>nil}, 21, "S:+S", false]], 12=>[[{2=>:enemy}, 2, "S:+S", true], [{3=>:enemy}, 3, "S:+S", true], [{4=>:enemy}, 4, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{2=>nil}, 2, "S:+S", false], [{3=>nil}, 3, "S:+S", false], [{4=>nil}, 4, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{22=>nil}, 22, "S:+S", false]], 13=>[[{3=>:enemy}, 3, "S:+S", true], [{4=>:enemy}, 4, "S:+S", true], [{5=>:enemy}, 5, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{3=>nil}, 3, "S:+S", false], [{4=>nil}, 4, "S:+S", false], [{5=>nil}, 5, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{23=>nil}, 23, "S:+S", false]], 14=>[[{4=>:enemy}, 4, "S:+S", true], [{5=>:enemy}, 5, "S:+S", true], [{6=>:enemy}, 6, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{4=>nil}, 4, "S:+S", false], [{5=>nil}, 5, "S:+S", false], [{6=>nil}, 6, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{24=>nil}, 24, "S:+S", false]], 15=>[[{5=>:enemy}, 5, "S:+S", true], [{6=>:enemy}, 6, "S:+S", true], [{7=>:enemy}, 7, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{5=>nil}, 5, "S:+S", false], [{6=>nil}, 6, "S:+S", false], [{7=>nil}, 7, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{25=>nil}, 25, "S:+S", false]], 16=>[[{6=>:enemy}, 6, "S:+S", true], [{7=>:enemy}, 7, "S:+S", true], [{8=>:enemy}, 8, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{6=>nil}, 6, "S:+S", false], [{7=>nil}, 7, "S:+S", false], [{8=>nil}, 8, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{26=>nil}, 26, "S:+S", false]], 17=>[[{7=>:enemy}, 7, "S:+S", true], [{8=>:enemy}, 8, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{7=>nil}, 7, "S:+S", false], [{8=>nil}, 8, "S:+S", false], [{25=>nil}, 25, "S:+S", false]], 18=>[[{9=>:enemy}, 9, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{9=>nil}, 9, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{28=>nil}, 28, "S:+S", false]], 19=>[[{9=>:enemy}, 9, "S:+S", true], [{10=>:enemy}, 10, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{27=>:enemy}, 27, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{9=>nil}, 9, "S:+S", false], [{10=>nil}, 10, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{27=>nil}, 27, "S:+S", false], [{29=>nil}, 29, "S:+S", false]], 20=>[[{10=>:enemy}, 10, "S:+S", true], [{11=>:enemy}, 11, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{28=>:enemy}, 28, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{10=>nil}, 10, "S:+S", false], [{11=>nil}, 11, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{28=>nil}, 28, "S:+S", false], [{30=>nil}, 30, "S:+S", false]], 21=>[[{11=>:enemy}, 11, "S:+S", true], [{12=>:enemy}, 12, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{29=>:enemy}, 29, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{11=>nil}, 11, "S:+S", false], [{12=>nil}, 12, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{29=>nil}, 29, "S:+S", false], [{31=>nil}, 31, "S:+S", false]], 22=>[[{12=>:enemy}, 12, "S:+S", true], [{13=>:enemy}, 13, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{30=>:enemy}, 30, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{12=>nil}, 12, "S:+S", false], [{13=>nil}, 13, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{30=>nil}, 30, "S:+S", false], [{32=>nil}, 32, "S:+S", false]], 23=>[[{13=>:enemy}, 13, "S:+S", true], [{14=>:enemy}, 14, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{31=>:enemy}, 31, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{13=>nil}, 13, "S:+S", false], [{14=>nil}, 14, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{31=>nil}, 31, "S:+S", false], [{33=>nil}, 33, "S:+S", false]], 24=>[[{14=>:enemy}, 14, "S:+S", true], [{15=>:enemy}, 15, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{32=>:enemy}, 32, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{14=>nil}, 14, "S:+S", false], [{15=>nil}, 15, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{32=>nil}, 32, "S:+S", false], [{34=>nil}, 34, "S:+S", false]], 25=>[[{15=>:enemy}, 15, "S:+S", true], [{16=>:enemy}, 16, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{33=>:enemy}, 33, "S:+S", true], [{35=>:enemy}, 35, "S:+S", true], [{15=>nil}, 15, "S:+S", false], [{16=>nil}, 16, "S:+S", false], [{17=>nil}, 17, "S:+S", false], [{33=>nil}, 33, "S:+S", false], [{35=>nil}, 35, "S:+S", false]], 26=>[[{16=>:enemy}, 16, "S:+S", true], [{17=>:enemy}, 17, "S:+S", true], [{34=>:enemy}, 34, "S:+S", true], [{16=>nil}, 16, "S:+S", false], [{17=>nil}, 17, "S:+S", false], [{34=>nil}, 34, "S:+S", false]], 27=>[[{18=>:enemy}, 18, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{37=>:enemy}, 37, "S:S", true], [{18=>nil}, 18, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{37=>nil}, 37, "S:S", false]], 28=>[[{18=>:enemy}, 18, "S:+S", true], [{19=>:enemy}, 19, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{36=>:enemy}, 36, "S:S", true], [{38=>:enemy}, 38, "S:S", true], [{18=>nil}, 18, "S:+S", false], [{19=>nil}, 19, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{36=>nil}, 36, "S:S", false], [{38=>nil}, 38, "S:S", false]], 29=>[[{19=>:enemy}, 19, "S:+S", true], [{20=>:enemy}, 20, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{37=>:enemy}, 37, "S:S", true], [{39=>:enemy}, 39, "S:S", true], [{19=>nil}, 19, "S:+S", false], [{20=>nil}, 20, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{37=>nil}, 37, "S:S", false], [{39=>nil}, 39, "S:S", false]], 30=>[[{20=>:enemy}, 20, "S:+S", true], [{21=>:enemy}, 21, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{38=>:enemy}, 38, "S:S", true], [{40=>:enemy}, 40, "S:S", true], [{20=>nil}, 20, "S:+S", false], [{21=>nil}, 21, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{38=>nil}, 38, "S:S", false], [{40=>nil}, 40, "S:S", false]], 31=>[[{21=>:enemy}, 21, "S:+S", true], [{22=>:enemy}, 22, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{39=>:enemy}, 39, "S:S", true], [{41=>:enemy}, 41, "S:S", true], [{21=>nil}, 21, "S:+S", false], [{22=>nil}, 22, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{39=>nil}, 39, "S:S", false], [{41=>nil}, 41, "S:S", false]], 32=>[[{22=>:enemy}, 22, "S:+S", true], [{23=>:enemy}, 23, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{40=>:enemy}, 40, "S:S", true], [{42=>:enemy}, 42, "S:S", true], [{22=>nil}, 22, "S:+S", false], [{23=>nil}, 23, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{40=>nil}, 40, "S:S", false], [{42=>nil}, 42, "S:S", false]], 33=>[[{23=>:enemy}, 23, "S:+S", true], [{24=>:enemy}, 24, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{41=>:enemy}, 41, "S:S", true], [{43=>:enemy}, 43, "S:S", true], [{23=>nil}, 23, "S:+S", false], [{24=>nil}, 24, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{41=>nil}, 41, "S:S", false], [{43=>nil}, 43, "S:S", false]], 34=>[[{24=>:enemy}, 24, "S:+S", true], [{25=>:enemy}, 25, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{42=>:enemy}, 42, "S:S", true], [{44=>:enemy}, 44, "S:S", true], [{24=>nil}, 24, "S:+S", false], [{25=>nil}, 25, "S:+S", false], [{26=>nil}, 26, "S:+S", false], [{42=>nil}, 42, "S:S", false], [{44=>nil}, 44, "S:S", false]], 35=>[[{25=>:enemy}, 25, "S:+S", true], [{26=>:enemy}, 26, "S:+S", true], [{43=>:enemy}, 43, "S:S", true], [{25=>nil}, 25, "S:+S", false], [{26=>nil}, 26, "S:+S", false], [{43=>nil}, 43, "S:S", false]], 36=>[[{27=>:enemy}, 27, "S:S", true], [{28=>:enemy}, 28, "S:S", true], [{46=>:enemy}, 46, "S:S", true], [{27=>nil}, 27, "S:S", false], [{28=>nil}, 28, "S:S", false], [{46=>nil}, 46, "S:S", false]], 37=>[[{27=>:enemy}, 27, "S:S", true], [{28=>:enemy}, 28, "S:S", true], [{29=>:enemy}, 29, "S:S", true], [{45=>:enemy}, 45, "S:S", true], [{47=>:enemy}, 47, "S:S", true], [{27=>nil}, 27, "S:S", false], [{28=>nil}, 28, "S:S", false], [{29=>nil}, 29, "S:S", false], [{45=>nil}, 45, "S:S", false], [{47=>nil}, 47, "S:S", false]], 38=>[[{28=>:enemy}, 28, "S:S", true], [{29=>:enemy}, 29, "S:S", true], [{30=>:enemy}, 30, "S:S", true], [{46=>:enemy}, 46, "S:S", true], [{48=>:enemy}, 48, "S:S", true], [{28=>nil}, 28, "S:S", false], [{29=>nil}, 29, "S:S", false], [{30=>nil}, 30, "S:S", false], [{46=>nil}, 46, "S:S", false], [{48=>nil}, 48, "S:S", false]], 39=>[[{29=>:enemy}, 29, "S:S", true], [{30=>:enemy}, 30, "S:S", true], [{31=>:enemy}, 31, "S:S", true], [{47=>:enemy}, 47, "S:S", true], [{49=>:enemy}, 49, "S:S", true], [{29=>nil}, 29, "S:S", false], [{30=>nil}, 30, "S:S", false], [{31=>nil}, 31, "S:S", false], [{47=>nil}, 47, "S:S", false], [{49=>nil}, 49, "S:S", false]], 40=>[[{30=>:enemy}, 30, "S:S", true], [{31=>:enemy}, 31, "S:S", true], [{32=>:enemy}, 32, "S:S", true], [{48=>:enemy}, 48, "S:S", true], [{50=>:enemy}, 50, "S:S", true], [{30=>nil}, 30, "S:S", false], [{31=>nil}, 31, "S:S", false], [{32=>nil}, 32, "S:S", false], [{48=>nil}, 48, "S:S", false], [{50=>nil}, 50, "S:S", false]], 41=>[[{31=>:enemy}, 31, "S:S", true], [{32=>:enemy}, 32, "S:S", true], [{33=>:enemy}, 33, "S:S", true], [{49=>:enemy}, 49, "S:S", true], [{51=>:enemy}, 51, "S:S", true], [{31=>nil}, 31, "S:S", false], [{32=>nil}, 32, "S:S", false], [{33=>nil}, 33, "S:S", false], [{49=>nil}, 49, "S:S", false], [{51=>nil}, 51, "S:S", false]], 42=>[[{32=>:enemy}, 32, "S:S", true], [{33=>:enemy}, 33, "S:S", true], [{34=>:enemy}, 34, "S:S", true], [{50=>:enemy}, 50, "S:S", true], [{52=>:enemy}, 52, "S:S", true], [{32=>nil}, 32, "S:S", false], [{33=>nil}, 33, "S:S", false], [{34=>nil}, 34, "S:S", false], [{50=>nil}, 50, "S:S", false], [{52=>nil}, 52, "S:S", false]], 43=>[[{33=>:enemy}, 33, "S:S", true], [{34=>:enemy}, 34, "S:S", true], [{35=>:enemy}, 35, "S:S", true], [{51=>:enemy}, 51, "S:S", true], [{53=>:enemy}, 53, "S:S", true], [{33=>nil}, 33, "S:S", false], [{34=>nil}, 34, "S:S", false], [{35=>nil}, 35, "S:S", false], [{51=>nil}, 51, "S:S", false], [{53=>nil}, 53, "S:S", false]], 44=>[[{34=>:enemy}, 34, "S:S", true], [{35=>:enemy}, 35, "S:S", true], [{52=>:enemy}, 52, "S:S", true], [{34=>nil}, 34, "S:S", false], [{35=>nil}, 35, "S:S", false], [{52=>nil}, 52, "S:S", false]], 45=>[[{36=>:enemy}, 36, "S:S", true], [{37=>:enemy}, 37, "S:S", true], [{55=>:enemy}, 55, "S:S", true], [{36=>nil}, 36, "S:S", false], [{37=>nil}, 37, "S:S", false], [{55=>nil}, 55, "S:S", false]], 46=>[[{36=>:enemy}, 36, "S:S", true], [{37=>:enemy}, 37, "S:S", true], [{38=>:enemy}, 38, "S:S", true], [{54=>:enemy}, 54, "S:S", true], [{56=>:enemy}, 56, "S:S", true], [{36=>nil}, 36, "S:S", false], [{37=>nil}, 37, "S:S", false], [{38=>nil}, 38, "S:S", false], [{54=>nil}, 54, "S:S", false], [{56=>nil}, 56, "S:S", false]], 47=>[[{37=>:enemy}, 37, "S:S", true], [{38=>:enemy}, 38, "S:S", true], [{39=>:enemy}, 39, "S:S", true], [{55=>:enemy}, 55, "S:S", true], [{57=>:enemy}, 57, "S:S", true], [{37=>nil}, 37, "S:S", false], [{38=>nil}, 38, "S:S", false], [{39=>nil}, 39, "S:S", false], [{55=>nil}, 55, "S:S", false], [{57=>nil}, 57, "S:S", false]], 48=>[[{38=>:enemy}, 38, "S:S", true], [{39=>:enemy}, 39, "S:S", true], [{40=>:enemy}, 40, "S:S", true], [{56=>:enemy}, 56, "S:S", true], [{58=>:enemy}, 58, "S:S", true], [{38=>nil}, 38, "S:S", false], [{39=>nil}, 39, "S:S", false], [{40=>nil}, 40, "S:S", false], [{56=>nil}, 56, "S:S", false], [{58=>nil}, 58, "S:S", false]], 49=>[[{39=>:enemy}, 39, "S:S", true], [{40=>:enemy}, 40, "S:S", true], [{41=>:enemy}, 41, "S:S", true], [{57=>:enemy}, 57, "S:S", true], [{59=>:enemy}, 59, "S:S", true], [{39=>nil}, 39, "S:S", false], [{40=>nil}, 40, "S:S", false], [{41=>nil}, 41, "S:S", false], [{57=>nil}, 57, "S:S", false], [{59=>nil}, 59, "S:S", false]], 50=>[[{40=>:enemy}, 40, "S:S", true], [{41=>:enemy}, 41, "S:S", true], [{42=>:enemy}, 42, "S:S", true], [{58=>:enemy}, 58, "S:S", true], [{60=>:enemy}, 60, "S:S", true], [{40=>nil}, 40, "S:S", false], [{41=>nil}, 41, "S:S", false], [{42=>nil}, 42, "S:S", false], [{58=>nil}, 58, "S:S", false], [{60=>nil}, 60, "S:S", false]], 51=>[[{41=>:enemy}, 41, "S:S", true], [{42=>:enemy}, 42, "S:S", true], [{43=>:enemy}, 43, "S:S", true], [{59=>:enemy}, 59, "S:S", true], [{61=>:enemy}, 61, "S:S", true], [{41=>nil}, 41, "S:S", false], [{42=>nil}, 42, "S:S", false], [{43=>nil}, 43, "S:S", false], [{59=>nil}, 59, "S:S", false], [{61=>nil}, 61, "S:S", false]], 52=>[[{42=>:enemy}, 42, "S:S", true], [{43=>:enemy}, 43, "S:S", true], [{44=>:enemy}, 44, "S:S", true], [{60=>:enemy}, 60, "S:S", true], [{62=>:enemy}, 62, "S:S", true], [{42=>nil}, 42, "S:S", false], [{43=>nil}, 43, "S:S", false], [{44=>nil}, 44, "S:S", false], [{60=>nil}, 60, "S:S", false], [{62=>nil}, 62, "S:S", false]], 53=>[[{43=>:enemy}, 43, "S:S", true], [{44=>:enemy}, 44, "S:S", true], [{61=>:enemy}, 61, "S:S", true], [{43=>nil}, 43, "S:S", false], [{44=>nil}, 44, "S:S", false], [{61=>nil}, 61, "S:S", false]], 54=>[[{45=>:enemy}, 45, "S:S", true], [{46=>:enemy}, 46, "S:S", true], [{64=>:enemy}, 64, "S:S", true], [{45=>nil}, 45, "S:S", false], [{46=>nil}, 46, "S:S", false], [{64=>nil}, 64, "S:S", false]], 55=>[[{45=>:enemy}, 45, "S:S", true], [{46=>:enemy}, 46, "S:S", true], [{47=>:enemy}, 47, "S:S", true], [{63=>:enemy}, 63, "S:S", true], [{65=>:enemy}, 65, "S:S", true], [{45=>nil}, 45, "S:S", false], [{46=>nil}, 46, "S:S", false], [{47=>nil}, 47, "S:S", false], [{63=>nil}, 63, "S:S", false], [{65=>nil}, 65, "S:S", false]], 56=>[[{46=>:enemy}, 46, "S:S", true], [{47=>:enemy}, 47, "S:S", true], [{48=>:enemy}, 48, "S:S", true], [{64=>:enemy}, 64, "S:S", true], [{66=>:enemy}, 66, "S:S", true], [{46=>nil}, 46, "S:S", false], [{47=>nil}, 47, "S:S", false], [{48=>nil}, 48, "S:S", false], [{64=>nil}, 64, "S:S", false], [{66=>nil}, 66, "S:S", false]], 57=>[[{47=>:enemy}, 47, "S:S", true], [{48=>:enemy}, 48, "S:S", true], [{49=>:enemy}, 49, "S:S", true], [{65=>:enemy}, 65, "S:S", true], [{67=>:enemy}, 67, "S:S", true], [{47=>nil}, 47, "S:S", false], [{48=>nil}, 48, "S:S", false], [{49=>nil}, 49, "S:S", false], [{65=>nil}, 65, "S:S", false], [{67=>nil}, 67, "S:S", false]], 58=>[[{48=>:enemy}, 48, "S:S", true], [{49=>:enemy}, 49, "S:S", true], [{50=>:enemy}, 50, "S:S", true], [{66=>:enemy}, 66, "S:S", true], [{68=>:enemy}, 68, "S:S", true], [{48=>nil}, 48, "S:S", false], [{49=>nil}, 49, "S:S", false], [{50=>nil}, 50, "S:S", false], [{66=>nil}, 66, "S:S", false], [{68=>nil}, 68, "S:S", false]], 59=>[[{49=>:enemy}, 49, "S:S", true], [{50=>:enemy}, 50, "S:S", true], [{51=>:enemy}, 51, "S:S", true], [{67=>:enemy}, 67, "S:S", true], [{69=>:enemy}, 69, "S:S", true], [{49=>nil}, 49, "S:S", false], [{50=>nil}, 50, "S:S", false], [{51=>nil}, 51, "S:S", false], [{67=>nil}, 67, "S:S", false], [{69=>nil}, 69, "S:S", false]], 60=>[[{50=>:enemy}, 50, "S:S", true], [{51=>:enemy}, 51, "S:S", true], [{52=>:enemy}, 52, "S:S", true], [{68=>:enemy}, 68, "S:S", true], [{70=>:enemy}, 70, "S:S", true], [{50=>nil}, 50, "S:S", false], [{51=>nil}, 51, "S:S", false], [{52=>nil}, 52, "S:S", false], [{68=>nil}, 68, "S:S", false], [{70=>nil}, 70, "S:S", false]], 61=>[[{51=>:enemy}, 51, "S:S", true], [{52=>:enemy}, 52, "S:S", true], [{53=>:enemy}, 53, "S:S", true], [{69=>:enemy}, 69, "S:S", true], [{71=>:enemy}, 71, "S:S", true], [{51=>nil}, 51, "S:S", false], [{52=>nil}, 52, "S:S", false], [{53=>nil}, 53, "S:S", false], [{69=>nil}, 69, "S:S", false], [{71=>nil}, 71, "S:S", false]], 62=>[[{52=>:enemy}, 52, "S:S", true], [{53=>:enemy}, 53, "S:S", true], [{70=>:enemy}, 70, "S:S", true], [{52=>nil}, 52, "S:S", false], [{53=>nil}, 53, "S:S", false], [{70=>nil}, 70, "S:S", false]], 63=>[[{54=>:enemy}, 54, "S:S", true], [{55=>:enemy}, 55, "S:S", true], [{73=>:enemy}, 73, "S:S", true], [{54=>nil}, 54, "S:S", false], [{55=>nil}, 55, "S:S", false], [{73=>nil}, 73, "S:S", false]], 64=>[[{54=>:enemy}, 54, "S:S", true], [{55=>:enemy}, 55, "S:S", true], [{56=>:enemy}, 56, "S:S", true], [{72=>:enemy}, 72, "S:S", true], [{74=>:enemy}, 74, "S:S", true], [{54=>nil}, 54, "S:S", false], [{55=>nil}, 55, "S:S", false], [{56=>nil}, 56, "S:S", false], [{72=>nil}, 72, "S:S", false], [{74=>nil}, 74, "S:S", false]], 65=>[[{55=>:enemy}, 55, "S:S", true], [{56=>:enemy}, 56, "S:S", true], [{57=>:enemy}, 57, "S:S", true], [{73=>:enemy}, 73, "S:S", true], [{75=>:enemy}, 75, "S:S", true], [{55=>nil}, 55, "S:S", false], [{56=>nil}, 56, "S:S", false], [{57=>nil}, 57, "S:S", false], [{73=>nil}, 73, "S:S", false], [{75=>nil}, 75, "S:S", false]], 66=>[[{56=>:enemy}, 56, "S:S", true], [{57=>:enemy}, 57, "S:S", true], [{58=>:enemy}, 58, "S:S", true], [{74=>:enemy}, 74, "S:S", true], [{76=>:enemy}, 76, "S:S", true], [{56=>nil}, 56, "S:S", false], [{57=>nil}, 57, "S:S", false], [{58=>nil}, 58, "S:S", false], [{74=>nil}, 74, "S:S", false], [{76=>nil}, 76, "S:S", false]], 67=>[[{57=>:enemy}, 57, "S:S", true], [{58=>:enemy}, 58, "S:S", true], [{59=>:enemy}, 59, "S:S", true], [{75=>:enemy}, 75, "S:S", true], [{77=>:enemy}, 77, "S:S", true], [{57=>nil}, 57, "S:S", false], [{58=>nil}, 58, "S:S", false], [{59=>nil}, 59, "S:S", false], [{75=>nil}, 75, "S:S", false], [{77=>nil}, 77, "S:S", false]], 68=>[[{58=>:enemy}, 58, "S:S", true], [{59=>:enemy}, 59, "S:S", true], [{60=>:enemy}, 60, "S:S", true], [{76=>:enemy}, 76, "S:S", true], [{78=>:enemy}, 78, "S:S", true], [{58=>nil}, 58, "S:S", false], [{59=>nil}, 59, "S:S", false], [{60=>nil}, 60, "S:S", false], [{76=>nil}, 76, "S:S", false], [{78=>nil}, 78, "S:S", false]], 69=>[[{59=>:enemy}, 59, "S:S", true], [{60=>:enemy}, 60, "S:S", true], [{61=>:enemy}, 61, "S:S", true], [{77=>:enemy}, 77, "S:S", true], [{79=>:enemy}, 79, "S:S", true], [{59=>nil}, 59, "S:S", false], [{60=>nil}, 60, "S:S", false], [{61=>nil}, 61, "S:S", false], [{77=>nil}, 77, "S:S", false], [{79=>nil}, 79, "S:S", false]], 70=>[[{60=>:enemy}, 60, "S:S", true], [{61=>:enemy}, 61, "S:S", true], [{62=>:enemy}, 62, "S:S", true], [{78=>:enemy}, 78, "S:S", true], [{80=>:enemy}, 80, "S:S", true], [{60=>nil}, 60, "S:S", false], [{61=>nil}, 61, "S:S", false], [{62=>nil}, 62, "S:S", false], [{78=>nil}, 78, "S:S", false], [{80=>nil}, 80, "S:S", false]], 71=>[[{61=>:enemy}, 61, "S:S", true], [{62=>:enemy}, 62, "S:S", true], [{79=>:enemy}, 79, "S:S", true], [{61=>nil}, 61, "S:S", false], [{62=>nil}, 62, "S:S", false], [{79=>nil}, 79, "S:S", false]], 72=>[[{63=>:enemy}, 63, "S:S", true], [{64=>:enemy}, 64, "S:S", true], [{63=>nil}, 63, "S:S", false], [{64=>nil}, 64, "S:S", false]], 73=>[[{63=>:enemy}, 63, "S:S", true], [{64=>:enemy}, 64, "S:S", true], [{65=>:enemy}, 65, "S:S", true], [{63=>nil}, 63, "S:S", false], [{64=>nil}, 64, "S:S", false], [{65=>nil}, 65, "S:S", false]], 74=>[[{64=>:enemy}, 64, "S:S", true], [{65=>:enemy}, 65, "S:S", true], [{66=>:enemy}, 66, "S:S", true], [{64=>nil}, 64, "S:S", false], [{65=>nil}, 65, "S:S", false], [{66=>nil}, 66, "S:S", false]], 75=>[[{65=>:enemy}, 65, "S:S", true], [{66=>:enemy}, 66, "S:S", true], [{67=>:enemy}, 67, "S:S", true], [{65=>nil}, 65, "S:S", false], [{66=>nil}, 66, "S:S", false], [{67=>nil}, 67, "S:S", false]], 76=>[[{66=>:enemy}, 66, "S:S", true], [{67=>:enemy}, 67, "S:S", true], [{68=>:enemy}, 68, "S:S", true], [{66=>nil}, 66, "S:S", false], [{67=>nil}, 67, "S:S", false], [{68=>nil}, 68, "S:S", false]], 77=>[[{67=>:enemy}, 67, "S:S", true], [{68=>:enemy}, 68, "S:S", true], [{69=>:enemy}, 69, "S:S", true], [{67=>nil}, 67, "S:S", false], [{68=>nil}, 68, "S:S", false], [{69=>nil}, 69, "S:S", false]], 78=>[[{68=>:enemy}, 68, "S:S", true], [{69=>:enemy}, 69, "S:S", true], [{70=>:enemy}, 70, "S:S", true], [{68=>nil}, 68, "S:S", false], [{69=>nil}, 69, "S:S", false], [{70=>nil}, 70, "S:S", false]], 79=>[[{69=>:enemy}, 69, "S:S", true], [{70=>:enemy}, 70, "S:S", true], [{71=>:enemy}, 71, "S:S", true], [{69=>nil}, 69, "S:S", false], [{70=>nil}, 70, "S:S", false], [{71=>nil}, 71, "S:S", false]], 80=>[[{70=>:enemy}, 70, "S:S", true], [{71=>:enemy}, 71, "S:S", true], [{70=>nil}, 70, "S:S", false], [{71=>nil}, 71, "S:S", false]], nil=>[[{0=>nil}, 0, "S:S", false], [{1=>nil}, 1, "S:S", false], [{2=>nil}, 2, "S:S", false], [{3=>nil}, 3, "S:S", false], [{4=>nil}, 4, "S:S", false], [{5=>nil}, 5, "S:S", false], [{6=>nil}, 6, "S:S", false], [{7=>nil}, 7, "S:S", false], [{8=>nil}, 8, "S:S", false], [{9=>nil}, 9, "S:S", false], [{10=>nil}, 10, "S:S", false], [{11=>nil}, 11, "S:S", false], [{12=>nil}, 12, "S:S", false], [{13=>nil}, 13, "S:S", false], [{14=>nil}, 14, "S:S", false], [{15=>nil}, 15, "S:S", false], [{16=>nil}, 16, "S:S", false], [{17=>nil}, 17, "S:S", false], [{18=>nil}, 18, "S:S", false], [{19=>nil}, 19, "S:S", false], [{20=>nil}, 20, "S:S", false], [{21=>nil}, 21, "S:S", false], [{22=>nil}, 22, "S:S", false], [{23=>nil}, 23, "S:S", false], [{24=>nil}, 24, "S:S", false], [{25=>nil}, 25, "S:S", false], [{26=>nil}, 26, "S:S", false], [{27=>nil}, 27, "S:S", false], [{28=>nil}, 28, "S:S", false], [{29=>nil}, 29, "S:S", false], [{30=>nil}, 30, "S:S", false], [{31=>nil}, 31, "S:S", false], [{32=>nil}, 32, "S:S", false], [{33=>nil}, 33, "S:S", false], [{34=>nil}, 34, "S:S", false], [{35=>nil}, 35, "S:S", false], [{36=>nil}, 36, "S:S", false], [{37=>nil}, 37, "S:S", false], [{38=>nil}, 38, "S:S", false], [{39=>nil}, 39, "S:S", false], [{40=>nil}, 40, "S:S", false], [{41=>nil}, 41, "S:S", false], [{42=>nil}, 42, "S:S", false], [{43=>nil}, 43, "S:S", false], [{44=>nil}, 44, "S:S", false], [{45=>nil}, 45, "S:S", false], [{46=>nil}, 46, "S:S", false], [{47=>nil}, 47, "S:S", false], [{48=>nil}, 48, "S:S", false], [{49=>nil}, 49, "S:S", false], [{50=>nil}, 50, "S:S", false], [{51=>nil}, 51, "S:S", false], [{52=>nil}, 52, "S:S", false], [{53=>nil}, 53, "S:S", false], [{54=>nil}, 54, "S:S", false], [{55=>nil}, 55, "S:S", false], [{56=>nil}, 56, "S:S", false], [{57=>nil}, 57, "S:S", false], [{58=>nil}, 58, "S:S", false], [{59=>nil}, 59, "S:S", false], [{60=>nil}, 60, "S:S", false], [{61=>nil}, 61, "S:S", false], [{62=>nil}, 62, "S:S", false], [{63=>nil}, 63, "S:S", false], [{64=>nil}, 64, "S:S", false], [{65=>nil}, 65, "S:S", false], [{66=>nil}, 66, "S:S", false], [{67=>nil}, 67, "S:S", false], [{68=>nil}, 68, "S:S", false], [{69=>nil}, 69, "S:S", false], [{70=>nil}, 70, "S:S", false], [{71=>nil}, 71, "S:S", false], [{72=>nil}, 72, "S:S", false], [{73=>nil}, 73, "S:S", false], [{74=>nil}, 74, "S:S", false], [{75=>nil}, 75, "S:S", false], [{76=>nil}, 76, "S:S", false], [{77=>nil}, 77, "S:S", false], [{78=>nil}, 78, "S:S", false], [{79=>nil}, 79, "S:S", false], [{80=>nil}, 80, "S:S", false]]}, "s:+b"=>{0=>[[{1=>:enemy}, 1, "s:+b", true], [{9=>:enemy}, 9, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{1=>nil}, 1, "s:+b", false], [{9=>nil}, 9, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{10=>nil, 20=>:enemy}, 20, "s:+b", true], [{10=>nil, 20=>nil}, 20, "s:+b", false], [{10=>nil, 20=>nil, 30=>:enemy}, 30, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil}, 30, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>:enemy}, 40, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil}, 40, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 1=>[[{0=>:enemy}, 0, "s:+b", true], [{2=>:enemy}, 2, "s:+b", true], [{9=>:enemy}, 9, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{0=>nil}, 0, "s:+b", false], [{2=>nil}, 2, "s:+b", false], [{9=>nil}, 9, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{11=>nil, 21=>:enemy}, 21, "s:+b", true], [{11=>nil, 21=>nil}, 21, "s:+b", false], [{11=>nil, 21=>nil, 31=>:enemy}, 31, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil}, 31, "s:+b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>:enemy}, 41, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil}, 41, "s:+b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "s:+b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 2=>[[{1=>:enemy}, 1, "s:+b", true], [{3=>:enemy}, 3, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{1=>nil}, 1, "s:+b", false], [{3=>nil}, 3, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{10=>nil, 18=>:enemy}, 18, "s:+b", true], [{10=>nil, 18=>nil}, 18, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{12=>nil, 22=>:enemy}, 22, "s:+b", true], [{12=>nil, 22=>nil}, 22, "s:+b", false], [{12=>nil, 22=>nil, 32=>:enemy}, 32, "s:+b", true], [{12=>nil, 22=>nil, 32=>nil}, 32, "s:+b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>:enemy}, 42, "s:+b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil}, 42, "s:+b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "s:+b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "s:+b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 3=>[[{2=>:enemy}, 2, "s:+b", true], [{4=>:enemy}, 4, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{2=>nil}, 2, "s:+b", false], [{4=>nil}, 4, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{11=>nil, 19=>:enemy}, 19, "s:+b", true], [{11=>nil, 19=>nil}, 19, "s:+b", false], [{11=>nil, 19=>nil, 27=>:enemy}, 27, "s:+b", true], [{11=>nil, 19=>nil, 27=>nil}, 27, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{13=>nil, 23=>:enemy}, 23, "s:+b", true], [{13=>nil, 23=>nil}, 23, "s:+b", false], [{13=>nil, 23=>nil, 33=>:enemy}, 33, "s:+b", true], [{13=>nil, 23=>nil, 33=>nil}, 33, "s:+b", false], [{13=>nil, 23=>nil, 33=>nil, 43=>:enemy}, 43, "s:+b", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil}, 43, "s:+b", false], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "s:+b", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "s:+b", false]], 4=>[[{3=>:enemy}, 3, "s:+b", true], [{5=>:enemy}, 5, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{3=>nil}, 3, "s:+b", false], [{5=>nil}, 5, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{12=>nil, 20=>:enemy}, 20, "s:+b", true], [{12=>nil, 20=>nil}, 20, "s:+b", false], [{12=>nil, 20=>nil, 28=>:enemy}, 28, "s:+b", true], [{12=>nil, 20=>nil, 28=>nil}, 28, "s:+b", false], [{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, 36, "s:+b", true], [{12=>nil, 20=>nil, 28=>nil, 36=>nil}, 36, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{14=>nil, 24=>:enemy}, 24, "s:+b", true], [{14=>nil, 24=>nil}, 24, "s:+b", false], [{14=>nil, 24=>nil, 34=>:enemy}, 34, "s:+b", true], [{14=>nil, 24=>nil, 34=>nil}, 34, "s:+b", false], [{14=>nil, 24=>nil, 34=>nil, 44=>:enemy}, 44, "s:+b", true], [{14=>nil, 24=>nil, 34=>nil, 44=>nil}, 44, "s:+b", false]], 5=>[[{4=>:enemy}, 4, "s:+b", true], [{6=>:enemy}, 6, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{4=>nil}, 4, "s:+b", false], [{6=>nil}, 6, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{13=>nil, 21=>:enemy}, 21, "s:+b", true], [{13=>nil, 21=>nil}, 21, "s:+b", false], [{13=>nil, 21=>nil, 29=>:enemy}, 29, "s:+b", true], [{13=>nil, 21=>nil, 29=>nil}, 29, "s:+b", false], [{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, 37, "s:+b", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil}, 37, "s:+b", false], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "s:+b", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{15=>nil, 25=>:enemy}, 25, "s:+b", true], [{15=>nil, 25=>nil}, 25, "s:+b", false], [{15=>nil, 25=>nil, 35=>:enemy}, 35, "s:+b", true], [{15=>nil, 25=>nil, 35=>nil}, 35, "s:+b", false]], 6=>[[{5=>:enemy}, 5, "s:+b", true], [{7=>:enemy}, 7, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{5=>nil}, 5, "s:+b", false], [{7=>nil}, 7, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{14=>nil, 22=>:enemy}, 22, "s:+b", true], [{14=>nil, 22=>nil}, 22, "s:+b", false], [{14=>nil, 22=>nil, 30=>:enemy}, 30, "s:+b", true], [{14=>nil, 22=>nil, 30=>nil}, 30, "s:+b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, 38, "s:+b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil}, 38, "s:+b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "s:+b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "s:+b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{16=>nil, 26=>:enemy}, 26, "s:+b", true], [{16=>nil, 26=>nil}, 26, "s:+b", false]], 7=>[[{6=>:enemy}, 6, "s:+b", true], [{8=>:enemy}, 8, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{17=>:enemy}, 17, "s:+b", true], [{6=>nil}, 6, "s:+b", false], [{8=>nil}, 8, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{15=>nil, 23=>:enemy}, 23, "s:+b", true], [{15=>nil, 23=>nil}, 23, "s:+b", false], [{15=>nil, 23=>nil, 31=>:enemy}, 31, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil}, 31, "s:+b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, 39, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil}, 39, "s:+b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "s:+b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{17=>nil}, 17, "s:+b", false]], 8=>[[{7=>:enemy}, 7, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{17=>:enemy}, 17, "s:+b", true], [{7=>nil}, 7, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{16=>nil, 24=>:enemy}, 24, "s:+b", true], [{16=>nil, 24=>nil}, 24, "s:+b", false], [{16=>nil, 24=>nil, 32=>:enemy}, 32, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil}, 32, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, 40, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil}, 40, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{17=>nil}, 17, "s:+b", false]], 9=>[[{0=>:enemy}, 0, "s:+b", true], [{1=>:enemy}, 1, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{18=>:enemy}, 18, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{0=>nil}, 0, "s:+b", false], [{1=>nil}, 1, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{18=>nil}, 18, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{19=>nil, 29=>:enemy}, 29, "s:+b", true], [{19=>nil, 29=>nil}, 29, "s:+b", false], [{19=>nil, 29=>nil, 39=>:enemy}, 39, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil}, 39, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>:enemy}, 49, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil}, 49, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 10=>[[{0=>:enemy}, 0, "s:+b", true], [{1=>:enemy}, 1, "s:+b", true], [{2=>:enemy}, 2, "s:+b", true], [{9=>:enemy}, 9, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{18=>:enemy}, 18, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{0=>nil}, 0, "s:+b", false], [{1=>nil}, 1, "s:+b", false], [{2=>nil}, 2, "s:+b", false], [{9=>nil}, 9, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{18=>nil}, 18, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{20=>nil, 30=>:enemy}, 30, "s:+b", true], [{20=>nil, 30=>nil}, 30, "s:+b", false], [{20=>nil, 30=>nil, 40=>:enemy}, 40, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil}, 40, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 11=>[[{1=>:enemy}, 1, "s:+b", true], [{2=>:enemy}, 2, "s:+b", true], [{3=>:enemy}, 3, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{1=>nil}, 1, "s:+b", false], [{2=>nil}, 2, "s:+b", false], [{3=>nil}, 3, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{19=>nil, 27=>:enemy}, 27, "s:+b", true], [{19=>nil, 27=>nil}, 27, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{21=>nil, 31=>:enemy}, 31, "s:+b", true], [{21=>nil, 31=>nil}, 31, "s:+b", false], [{21=>nil, 31=>nil, 41=>:enemy}, 41, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil}, 41, "s:+b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "s:+b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 12=>[[{2=>:enemy}, 2, "s:+b", true], [{3=>:enemy}, 3, "s:+b", true], [{4=>:enemy}, 4, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{2=>nil}, 2, "s:+b", false], [{3=>nil}, 3, "s:+b", false], [{4=>nil}, 4, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{20=>nil, 28=>:enemy}, 28, "s:+b", true], [{20=>nil, 28=>nil}, 28, "s:+b", false], [{20=>nil, 28=>nil, 36=>:enemy}, 36, "s:+b", true], [{20=>nil, 28=>nil, 36=>nil}, 36, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{22=>nil, 32=>:enemy}, 32, "s:+b", true], [{22=>nil, 32=>nil}, 32, "s:+b", false], [{22=>nil, 32=>nil, 42=>:enemy}, 42, "s:+b", true], [{22=>nil, 32=>nil, 42=>nil}, 42, "s:+b", false], [{22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "s:+b", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "s:+b", false], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 13=>[[{3=>:enemy}, 3, "s:+b", true], [{4=>:enemy}, 4, "s:+b", true], [{5=>:enemy}, 5, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{3=>nil}, 3, "s:+b", false], [{4=>nil}, 4, "s:+b", false], [{5=>nil}, 5, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{21=>nil, 29=>:enemy}, 29, "s:+b", true], [{21=>nil, 29=>nil}, 29, "s:+b", false], [{21=>nil, 29=>nil, 37=>:enemy}, 37, "s:+b", true], [{21=>nil, 29=>nil, 37=>nil}, 37, "s:+b", false], [{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "s:+b", true], [{21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{23=>nil, 33=>:enemy}, 33, "s:+b", true], [{23=>nil, 33=>nil}, 33, "s:+b", false], [{23=>nil, 33=>nil, 43=>:enemy}, 43, "s:+b", true], [{23=>nil, 33=>nil, 43=>nil}, 43, "s:+b", false], [{23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "s:+b", true], [{23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "s:+b", false]], 14=>[[{4=>:enemy}, 4, "s:+b", true], [{5=>:enemy}, 5, "s:+b", true], [{6=>:enemy}, 6, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{4=>nil}, 4, "s:+b", false], [{5=>nil}, 5, "s:+b", false], [{6=>nil}, 6, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{22=>nil, 30=>:enemy}, 30, "s:+b", true], [{22=>nil, 30=>nil}, 30, "s:+b", false], [{22=>nil, 30=>nil, 38=>:enemy}, 38, "s:+b", true], [{22=>nil, 30=>nil, 38=>nil}, 38, "s:+b", false], [{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "s:+b", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "s:+b", false], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{24=>nil, 34=>:enemy}, 34, "s:+b", true], [{24=>nil, 34=>nil}, 34, "s:+b", false], [{24=>nil, 34=>nil, 44=>:enemy}, 44, "s:+b", true], [{24=>nil, 34=>nil, 44=>nil}, 44, "s:+b", false]], 15=>[[{5=>:enemy}, 5, "s:+b", true], [{6=>:enemy}, 6, "s:+b", true], [{7=>:enemy}, 7, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{5=>nil}, 5, "s:+b", false], [{6=>nil}, 6, "s:+b", false], [{7=>nil}, 7, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{23=>nil, 31=>:enemy}, 31, "s:+b", true], [{23=>nil, 31=>nil}, 31, "s:+b", false], [{23=>nil, 31=>nil, 39=>:enemy}, 39, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil}, 39, "s:+b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "s:+b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{25=>nil, 35=>:enemy}, 35, "s:+b", true], [{25=>nil, 35=>nil}, 35, "s:+b", false]], 16=>[[{6=>:enemy}, 6, "s:+b", true], [{7=>:enemy}, 7, "s:+b", true], [{8=>:enemy}, 8, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{17=>:enemy}, 17, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{26=>:enemy}, 26, "s:+b", true], [{6=>nil}, 6, "s:+b", false], [{7=>nil}, 7, "s:+b", false], [{8=>nil}, 8, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{17=>nil}, 17, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{24=>nil, 32=>:enemy}, 32, "s:+b", true], [{24=>nil, 32=>nil}, 32, "s:+b", false], [{24=>nil, 32=>nil, 40=>:enemy}, 40, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil}, 40, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{26=>nil}, 26, "s:+b", false]], 17=>[[{7=>:enemy}, 7, "s:+b", true], [{8=>:enemy}, 8, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{26=>:enemy}, 26, "s:+b", true], [{7=>nil}, 7, "s:+b", false], [{8=>nil}, 8, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{25=>nil, 33=>:enemy}, 33, "s:+b", true], [{25=>nil, 33=>nil}, 33, "s:+b", false], [{25=>nil, 33=>nil, 41=>:enemy}, 41, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil}, 41, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, 49, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil}, 49, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{26=>nil}, 26, "s:+b", false]], 18=>[[{9=>:enemy}, 9, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{27=>:enemy}, 27, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{9=>nil}, 9, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{10=>nil, 2=>:enemy}, 2, "s:+b", true], [{10=>nil, 2=>nil}, 2, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{27=>nil}, 27, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{28=>nil, 38=>:enemy}, 38, "s:+b", true], [{28=>nil, 38=>nil}, 38, "s:+b", false], [{28=>nil, 38=>nil, 48=>:enemy}, 48, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil}, 48, "s:+b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>:enemy}, 58, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil}, 58, "s:+b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 19=>[[{9=>:enemy}, 9, "s:+b", true], [{10=>:enemy}, 10, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{18=>:enemy}, 18, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{27=>:enemy}, 27, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{9=>nil}, 9, "s:+b", false], [{10=>nil}, 10, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{11=>nil, 3=>:enemy}, 3, "s:+b", true], [{11=>nil, 3=>nil}, 3, "s:+b", false], [{18=>nil}, 18, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{27=>nil}, 27, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{29=>nil, 39=>:enemy}, 39, "s:+b", true], [{29=>nil, 39=>nil}, 39, "s:+b", false], [{29=>nil, 39=>nil, 49=>:enemy}, 49, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil}, 49, "s:+b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 20=>[[{10=>:enemy}, 10, "s:+b", true], [{11=>:enemy}, 11, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{10=>nil}, 10, "s:+b", false], [{10=>nil, 0=>:enemy}, 0, "s:+b", true], [{10=>nil, 0=>nil}, 0, "s:+b", false], [{11=>nil}, 11, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{12=>nil, 4=>:enemy}, 4, "s:+b", true], [{12=>nil, 4=>nil}, 4, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{28=>nil, 36=>:enemy}, 36, "s:+b", true], [{28=>nil, 36=>nil}, 36, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{30=>nil, 40=>:enemy}, 40, "s:+b", true], [{30=>nil, 40=>nil}, 40, "s:+b", false], [{30=>nil, 40=>nil, 50=>:enemy}, 50, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil}, 50, "s:+b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 21=>[[{11=>:enemy}, 11, "s:+b", true], [{12=>:enemy}, 12, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{11=>nil}, 11, "s:+b", false], [{11=>nil, 1=>:enemy}, 1, "s:+b", true], [{11=>nil, 1=>nil}, 1, "s:+b", false], [{12=>nil}, 12, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{13=>nil, 5=>:enemy}, 5, "s:+b", true], [{13=>nil, 5=>nil}, 5, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{29=>nil, 37=>:enemy}, 37, "s:+b", true], [{29=>nil, 37=>nil}, 37, "s:+b", false], [{29=>nil, 37=>nil, 45=>:enemy}, 45, "s:+b", true], [{29=>nil, 37=>nil, 45=>nil}, 45, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{31=>nil, 41=>:enemy}, 41, "s:+b", true], [{31=>nil, 41=>nil}, 41, "s:+b", false], [{31=>nil, 41=>nil, 51=>:enemy}, 51, "s:+b", true], [{31=>nil, 41=>nil, 51=>nil}, 51, "s:+b", false], [{31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 22=>[[{12=>:enemy}, 12, "s:+b", true], [{13=>:enemy}, 13, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{12=>nil}, 12, "s:+b", false], [{12=>nil, 2=>:enemy}, 2, "s:+b", true], [{12=>nil, 2=>nil}, 2, "s:+b", false], [{13=>nil}, 13, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{14=>nil, 6=>:enemy}, 6, "s:+b", true], [{14=>nil, 6=>nil}, 6, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{30=>nil, 38=>:enemy}, 38, "s:+b", true], [{30=>nil, 38=>nil}, 38, "s:+b", false], [{30=>nil, 38=>nil, 46=>:enemy}, 46, "s:+b", true], [{30=>nil, 38=>nil, 46=>nil}, 46, "s:+b", false], [{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{32=>nil, 42=>:enemy}, 42, "s:+b", true], [{32=>nil, 42=>nil}, 42, "s:+b", false], [{32=>nil, 42=>nil, 52=>:enemy}, 52, "s:+b", true], [{32=>nil, 42=>nil, 52=>nil}, 52, "s:+b", false], [{32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 23=>[[{13=>:enemy}, 13, "s:+b", true], [{14=>:enemy}, 14, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{13=>nil}, 13, "s:+b", false], [{13=>nil, 3=>:enemy}, 3, "s:+b", true], [{13=>nil, 3=>nil}, 3, "s:+b", false], [{14=>nil}, 14, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{15=>nil, 7=>:enemy}, 7, "s:+b", true], [{15=>nil, 7=>nil}, 7, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{31=>nil, 39=>:enemy}, 39, "s:+b", true], [{31=>nil, 39=>nil}, 39, "s:+b", false], [{31=>nil, 39=>nil, 47=>:enemy}, 47, "s:+b", true], [{31=>nil, 39=>nil, 47=>nil}, 47, "s:+b", false], [{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{33=>nil, 43=>:enemy}, 43, "s:+b", true], [{33=>nil, 43=>nil}, 43, "s:+b", false], [{33=>nil, 43=>nil, 53=>:enemy}, 53, "s:+b", true], [{33=>nil, 43=>nil, 53=>nil}, 53, "s:+b", false]], 24=>[[{14=>:enemy}, 14, "s:+b", true], [{15=>:enemy}, 15, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{14=>nil}, 14, "s:+b", false], [{14=>nil, 4=>:enemy}, 4, "s:+b", true], [{14=>nil, 4=>nil}, 4, "s:+b", false], [{15=>nil}, 15, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{16=>nil, 8=>:enemy}, 8, "s:+b", true], [{16=>nil, 8=>nil}, 8, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{32=>nil, 40=>:enemy}, 40, "s:+b", true], [{32=>nil, 40=>nil}, 40, "s:+b", false], [{32=>nil, 40=>nil, 48=>:enemy}, 48, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil}, 48, "s:+b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{34=>nil, 44=>:enemy}, 44, "s:+b", true], [{34=>nil, 44=>nil}, 44, "s:+b", false]], 25=>[[{15=>:enemy}, 15, "s:+b", true], [{16=>:enemy}, 16, "s:+b", true], [{17=>:enemy}, 17, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{26=>:enemy}, 26, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{35=>:enemy}, 35, "s:+b", true], [{15=>nil}, 15, "s:+b", false], [{15=>nil, 5=>:enemy}, 5, "s:+b", true], [{15=>nil, 5=>nil}, 5, "s:+b", false], [{16=>nil}, 16, "s:+b", false], [{17=>nil}, 17, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{26=>nil}, 26, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{33=>nil, 41=>:enemy}, 41, "s:+b", true], [{33=>nil, 41=>nil}, 41, "s:+b", false], [{33=>nil, 41=>nil, 49=>:enemy}, 49, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil}, 49, "s:+b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{35=>nil}, 35, "s:+b", false]], 26=>[[{16=>:enemy}, 16, "s:+b", true], [{17=>:enemy}, 17, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{35=>:enemy}, 35, "s:+b", true], [{16=>nil}, 16, "s:+b", false], [{16=>nil, 6=>:enemy}, 6, "s:+b", true], [{16=>nil, 6=>nil}, 6, "s:+b", false], [{17=>nil}, 17, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{34=>nil, 42=>:enemy}, 42, "s:+b", true], [{34=>nil, 42=>nil}, 42, "s:+b", false], [{34=>nil, 42=>nil, 50=>:enemy}, 50, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil}, 50, "s:+b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, 58, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil}, 58, "s:+b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{35=>nil}, 35, "s:+b", false]], 27=>[[{18=>:enemy}, 18, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{36=>:enemy}, 36, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{18=>nil}, 18, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{19=>nil, 11=>:enemy}, 11, "s:+b", true], [{19=>nil, 11=>nil}, 11, "s:+b", false], [{19=>nil, 11=>nil, 3=>:enemy}, 3, "s:+b", true], [{19=>nil, 11=>nil, 3=>nil}, 3, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{36=>nil}, 36, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{37=>nil, 47=>:enemy}, 47, "s:+b", true], [{37=>nil, 47=>nil}, 47, "s:+b", false], [{37=>nil, 47=>nil, 57=>:enemy}, 57, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil}, 57, "s:+b", false], [{37=>nil, 47=>nil, 57=>nil, 67=>:enemy}, 67, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil}, 67, "s:+b", false], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 28=>[[{18=>:enemy}, 18, "s:+b", true], [{19=>:enemy}, 19, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{27=>:enemy}, 27, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{36=>:enemy}, 36, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{18=>nil}, 18, "s:+b", false], [{19=>nil}, 19, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{20=>nil, 12=>:enemy}, 12, "s:+b", true], [{20=>nil, 12=>nil}, 12, "s:+b", false], [{20=>nil, 12=>nil, 4=>:enemy}, 4, "s:+b", true], [{20=>nil, 12=>nil, 4=>nil}, 4, "s:+b", false], [{27=>nil}, 27, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{36=>nil}, 36, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{38=>nil, 48=>:enemy}, 48, "s:+b", true], [{38=>nil, 48=>nil}, 48, "s:+b", false], [{38=>nil, 48=>nil, 58=>:enemy}, 58, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil}, 58, "s:+b", false], [{38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 29=>[[{19=>:enemy}, 19, "s:+b", true], [{20=>:enemy}, 20, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{19=>nil}, 19, "s:+b", false], [{19=>nil, 9=>:enemy}, 9, "s:+b", true], [{19=>nil, 9=>nil}, 9, "s:+b", false], [{20=>nil}, 20, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{21=>nil, 13=>:enemy}, 13, "s:+b", true], [{21=>nil, 13=>nil}, 13, "s:+b", false], [{21=>nil, 13=>nil, 5=>:enemy}, 5, "s:+b", true], [{21=>nil, 13=>nil, 5=>nil}, 5, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{37=>nil, 45=>:enemy}, 45, "s:+b", true], [{37=>nil, 45=>nil}, 45, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{39=>nil, 49=>:enemy}, 49, "s:+b", true], [{39=>nil, 49=>nil}, 49, "s:+b", false], [{39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 30=>[[{20=>:enemy}, 20, "s:+b", true], [{21=>:enemy}, 21, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{20=>nil}, 20, "s:+b", false], [{20=>nil, 10=>:enemy}, 10, "s:+b", true], [{20=>nil, 10=>nil}, 10, "s:+b", false], [{20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{21=>nil}, 21, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{22=>nil, 14=>:enemy}, 14, "s:+b", true], [{22=>nil, 14=>nil}, 14, "s:+b", false], [{22=>nil, 14=>nil, 6=>:enemy}, 6, "s:+b", true], [{22=>nil, 14=>nil, 6=>nil}, 6, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{38=>nil, 46=>:enemy}, 46, "s:+b", true], [{38=>nil, 46=>nil}, 46, "s:+b", false], [{38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{40=>nil, 50=>:enemy}, 50, "s:+b", true], [{40=>nil, 50=>nil}, 50, "s:+b", false], [{40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 31=>[[{21=>:enemy}, 21, "s:+b", true], [{22=>:enemy}, 22, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{21=>nil}, 21, "s:+b", false], [{21=>nil, 11=>:enemy}, 11, "s:+b", true], [{21=>nil, 11=>nil}, 11, "s:+b", false], [{21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{22=>nil}, 22, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{23=>nil, 15=>:enemy}, 15, "s:+b", true], [{23=>nil, 15=>nil}, 15, "s:+b", false], [{23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{39=>nil, 47=>:enemy}, 47, "s:+b", true], [{39=>nil, 47=>nil}, 47, "s:+b", false], [{39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{41=>nil, 51=>:enemy}, 51, "s:+b", true], [{41=>nil, 51=>nil}, 51, "s:+b", false], [{41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 32=>[[{22=>:enemy}, 22, "s:+b", true], [{23=>:enemy}, 23, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{22=>nil}, 22, "s:+b", false], [{22=>nil, 12=>:enemy}, 12, "s:+b", true], [{22=>nil, 12=>nil}, 12, "s:+b", false], [{22=>nil, 12=>nil, 2=>:enemy}, 2, "s:+b", true], [{22=>nil, 12=>nil, 2=>nil}, 2, "s:+b", false], [{23=>nil}, 23, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{24=>nil, 16=>:enemy}, 16, "s:+b", true], [{24=>nil, 16=>nil}, 16, "s:+b", false], [{24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{40=>nil, 48=>:enemy}, 48, "s:+b", true], [{40=>nil, 48=>nil}, 48, "s:+b", false], [{40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{42=>nil, 52=>:enemy}, 52, "s:+b", true], [{42=>nil, 52=>nil}, 52, "s:+b", false], [{42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 33=>[[{23=>:enemy}, 23, "s:+b", true], [{24=>:enemy}, 24, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{23=>nil}, 23, "s:+b", false], [{23=>nil, 13=>:enemy}, 13, "s:+b", true], [{23=>nil, 13=>nil}, 13, "s:+b", false], [{23=>nil, 13=>nil, 3=>:enemy}, 3, "s:+b", true], [{23=>nil, 13=>nil, 3=>nil}, 3, "s:+b", false], [{24=>nil}, 24, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{25=>nil, 17=>:enemy}, 17, "s:+b", true], [{25=>nil, 17=>nil}, 17, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{41=>nil, 49=>:enemy}, 49, "s:+b", true], [{41=>nil, 49=>nil}, 49, "s:+b", false], [{41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{43=>nil, 53=>:enemy}, 53, "s:+b", true], [{43=>nil, 53=>nil}, 53, "s:+b", false]], 34=>[[{24=>:enemy}, 24, "s:+b", true], [{25=>:enemy}, 25, "s:+b", true], [{26=>:enemy}, 26, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{35=>:enemy}, 35, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{44=>:enemy}, 44, "s:+b", true], [{24=>nil}, 24, "s:+b", false], [{24=>nil, 14=>:enemy}, 14, "s:+b", true], [{24=>nil, 14=>nil}, 14, "s:+b", false], [{24=>nil, 14=>nil, 4=>:enemy}, 4, "s:+b", true], [{24=>nil, 14=>nil, 4=>nil}, 4, "s:+b", false], [{25=>nil}, 25, "s:+b", false], [{26=>nil}, 26, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{35=>nil}, 35, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{42=>nil, 50=>:enemy}, 50, "s:+b", true], [{42=>nil, 50=>nil}, 50, "s:+b", false], [{42=>nil, 50=>nil, 58=>:enemy}, 58, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil}, 58, "s:+b", false], [{42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{44=>nil}, 44, "s:+b", false]], 35=>[[{25=>:enemy}, 25, "s:+b", true], [{26=>:enemy}, 26, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{44=>:enemy}, 44, "s:+b", true], [{25=>nil}, 25, "s:+b", false], [{25=>nil, 15=>:enemy}, 15, "s:+b", true], [{25=>nil, 15=>nil}, 15, "s:+b", false], [{25=>nil, 15=>nil, 5=>:enemy}, 5, "s:+b", true], [{25=>nil, 15=>nil, 5=>nil}, 5, "s:+b", false], [{26=>nil}, 26, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{43=>nil, 51=>:enemy}, 51, "s:+b", true], [{43=>nil, 51=>nil}, 51, "s:+b", false], [{43=>nil, 51=>nil, 59=>:enemy}, 59, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil}, 59, "s:+b", false], [{43=>nil, 51=>nil, 59=>nil, 67=>:enemy}, 67, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil}, 67, "s:+b", false], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false], [{44=>nil}, 44, "s:+b", false]], 36=>[[{27=>:enemy}, 27, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{45=>:enemy}, 45, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{27=>nil}, 27, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{28=>nil, 20=>:enemy}, 20, "s:+b", true], [{28=>nil, 20=>nil}, 20, "s:+b", false], [{28=>nil, 20=>nil, 12=>:enemy}, 12, "s:+b", true], [{28=>nil, 20=>nil, 12=>nil}, 12, "s:+b", false], [{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, 4, "s:+b", true], [{28=>nil, 20=>nil, 12=>nil, 4=>nil}, 4, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{45=>nil}, 45, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 56=>:enemy}, 56, "s:+b", true], [{46=>nil, 56=>nil}, 56, "s:+b", false], [{46=>nil, 56=>nil, 66=>:enemy}, 66, "s:+b", true], [{46=>nil, 56=>nil, 66=>nil}, 66, "s:+b", false], [{46=>nil, 56=>nil, 66=>nil, 76=>:enemy}, 76, "s:+b", true], [{46=>nil, 56=>nil, 66=>nil, 76=>nil}, 76, "s:+b", false]], 37=>[[{27=>:enemy}, 27, "s:+b", true], [{28=>:enemy}, 28, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{36=>:enemy}, 36, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{45=>:enemy}, 45, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{27=>nil}, 27, "s:+b", false], [{28=>nil}, 28, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{29=>nil, 21=>:enemy}, 21, "s:+b", true], [{29=>nil, 21=>nil}, 21, "s:+b", false], [{29=>nil, 21=>nil, 13=>:enemy}, 13, "s:+b", true], [{29=>nil, 21=>nil, 13=>nil}, 13, "s:+b", false], [{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "s:+b", true], [{29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "s:+b", false], [{36=>nil}, 36, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{45=>nil}, 45, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 57=>:enemy}, 57, "s:+b", true], [{47=>nil, 57=>nil}, 57, "s:+b", false], [{47=>nil, 57=>nil, 67=>:enemy}, 67, "s:+b", true], [{47=>nil, 57=>nil, 67=>nil}, 67, "s:+b", false], [{47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 38=>[[{28=>:enemy}, 28, "s:+b", true], [{29=>:enemy}, 29, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{28=>nil}, 28, "s:+b", false], [{28=>nil, 18=>:enemy}, 18, "s:+b", true], [{28=>nil, 18=>nil}, 18, "s:+b", false], [{29=>nil}, 29, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{30=>nil, 22=>:enemy}, 22, "s:+b", true], [{30=>nil, 22=>nil}, 22, "s:+b", false], [{30=>nil, 22=>nil, 14=>:enemy}, 14, "s:+b", true], [{30=>nil, 22=>nil, 14=>nil}, 14, "s:+b", false], [{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:+b", true], [{30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 54=>:enemy}, 54, "s:+b", true], [{46=>nil, 54=>nil}, 54, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 58=>:enemy}, 58, "s:+b", true], [{48=>nil, 58=>nil}, 58, "s:+b", false], [{48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 39=>[[{29=>:enemy}, 29, "s:+b", true], [{30=>:enemy}, 30, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{29=>nil}, 29, "s:+b", false], [{29=>nil, 19=>:enemy}, 19, "s:+b", true], [{29=>nil, 19=>nil}, 19, "s:+b", false], [{29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{30=>nil}, 30, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{31=>nil, 23=>:enemy}, 23, "s:+b", true], [{31=>nil, 23=>nil}, 23, "s:+b", false], [{31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 55=>:enemy}, 55, "s:+b", true], [{47=>nil, 55=>nil}, 55, "s:+b", false], [{47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 59=>:enemy}, 59, "s:+b", true], [{49=>nil, 59=>nil}, 59, "s:+b", false], [{49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 40=>[[{30=>:enemy}, 30, "s:+b", true], [{31=>:enemy}, 31, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{30=>nil}, 30, "s:+b", false], [{30=>nil, 20=>:enemy}, 20, "s:+b", true], [{30=>nil, 20=>nil}, 20, "s:+b", false], [{30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{31=>nil}, 31, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{32=>nil, 24=>:enemy}, 24, "s:+b", true], [{32=>nil, 24=>nil}, 24, "s:+b", false], [{32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 56=>:enemy}, 56, "s:+b", true], [{48=>nil, 56=>nil}, 56, "s:+b", false], [{48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 60=>:enemy}, 60, "s:+b", true], [{50=>nil, 60=>nil}, 60, "s:+b", false], [{50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 41=>[[{31=>:enemy}, 31, "s:+b", true], [{32=>:enemy}, 32, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{31=>nil}, 31, "s:+b", false], [{31=>nil, 21=>:enemy}, 21, "s:+b", true], [{31=>nil, 21=>nil}, 21, "s:+b", false], [{31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{32=>nil}, 32, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{33=>nil, 25=>:enemy}, 25, "s:+b", true], [{33=>nil, 25=>nil}, 25, "s:+b", false], [{33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 57=>:enemy}, 57, "s:+b", true], [{49=>nil, 57=>nil}, 57, "s:+b", false], [{49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 61=>:enemy}, 61, "s:+b", true], [{51=>nil, 61=>nil}, 61, "s:+b", false], [{51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 42=>[[{32=>:enemy}, 32, "s:+b", true], [{33=>:enemy}, 33, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{32=>nil}, 32, "s:+b", false], [{32=>nil, 22=>:enemy}, 22, "s:+b", true], [{32=>nil, 22=>nil}, 22, "s:+b", false], [{32=>nil, 22=>nil, 12=>:enemy}, 12, "s:+b", true], [{32=>nil, 22=>nil, 12=>nil}, 12, "s:+b", false], [{32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:+b", true], [{32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:+b", false], [{33=>nil}, 33, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{34=>nil, 26=>:enemy}, 26, "s:+b", true], [{34=>nil, 26=>nil}, 26, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 58=>:enemy}, 58, "s:+b", true], [{50=>nil, 58=>nil}, 58, "s:+b", false], [{50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 62=>:enemy}, 62, "s:+b", true], [{52=>nil, 62=>nil}, 62, "s:+b", false]], 43=>[[{33=>:enemy}, 33, "s:+b", true], [{34=>:enemy}, 34, "s:+b", true], [{35=>:enemy}, 35, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{44=>:enemy}, 44, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{33=>nil}, 33, "s:+b", false], [{33=>nil, 23=>:enemy}, 23, "s:+b", true], [{33=>nil, 23=>nil}, 23, "s:+b", false], [{33=>nil, 23=>nil, 13=>:enemy}, 13, "s:+b", true], [{33=>nil, 23=>nil, 13=>nil}, 13, "s:+b", false], [{33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "s:+b", true], [{33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "s:+b", false], [{34=>nil}, 34, "s:+b", false], [{35=>nil}, 35, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{44=>nil}, 44, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 59=>:enemy}, 59, "s:+b", true], [{51=>nil, 59=>nil}, 59, "s:+b", false], [{51=>nil, 59=>nil, 67=>:enemy}, 67, "s:+b", true], [{51=>nil, 59=>nil, 67=>nil}, 67, "s:+b", false], [{51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{53=>nil}, 53, "s:+b", false]], 44=>[[{34=>:enemy}, 34, "s:+b", true], [{35=>:enemy}, 35, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{34=>nil}, 34, "s:+b", false], [{34=>nil, 24=>:enemy}, 24, "s:+b", true], [{34=>nil, 24=>nil}, 24, "s:+b", false], [{34=>nil, 24=>nil, 14=>:enemy}, 14, "s:+b", true], [{34=>nil, 24=>nil, 14=>nil}, 14, "s:+b", false], [{34=>nil, 24=>nil, 14=>nil, 4=>:enemy}, 4, "s:+b", true], [{34=>nil, 24=>nil, 14=>nil, 4=>nil}, 4, "s:+b", false], [{35=>nil}, 35, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 60=>:enemy}, 60, "s:+b", true], [{52=>nil, 60=>nil}, 60, "s:+b", false], [{52=>nil, 60=>nil, 68=>:enemy}, 68, "s:+b", true], [{52=>nil, 60=>nil, 68=>nil}, 68, "s:+b", false], [{52=>nil, 60=>nil, 68=>nil, 76=>:enemy}, 76, "s:+b", true], [{52=>nil, 60=>nil, 68=>nil, 76=>nil}, 76, "s:+b", false], [{53=>nil}, 53, "s:+b", false]], 45=>[[{36=>:enemy}, 36, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{54=>:enemy}, 54, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{36=>nil}, 36, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{37=>nil, 29=>:enemy}, 29, "s:+b", true], [{37=>nil, 29=>nil}, 29, "s:+b", false], [{37=>nil, 29=>nil, 21=>:enemy}, 21, "s:+b", true], [{37=>nil, 29=>nil, 21=>nil}, 21, "s:+b", false], [{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, 13, "s:+b", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil}, 13, "s:+b", false], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "s:+b", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{54=>nil}, 54, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 65=>:enemy}, 65, "s:+b", true], [{55=>nil, 65=>nil}, 65, "s:+b", false], [{55=>nil, 65=>nil, 75=>:enemy}, 75, "s:+b", true], [{55=>nil, 65=>nil, 75=>nil}, 75, "s:+b", false]], 46=>[[{36=>:enemy}, 36, "s:+b", true], [{37=>:enemy}, 37, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{45=>:enemy}, 45, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{54=>:enemy}, 54, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{36=>nil}, 36, "s:+b", false], [{37=>nil}, 37, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{38=>nil, 30=>:enemy}, 30, "s:+b", true], [{38=>nil, 30=>nil}, 30, "s:+b", false], [{38=>nil, 30=>nil, 22=>:enemy}, 22, "s:+b", true], [{38=>nil, 30=>nil, 22=>nil}, 22, "s:+b", false], [{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "s:+b", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "s:+b", false], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:+b", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:+b", false], [{45=>nil}, 45, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{54=>nil}, 54, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 66=>:enemy}, 66, "s:+b", true], [{56=>nil, 66=>nil}, 66, "s:+b", false], [{56=>nil, 66=>nil, 76=>:enemy}, 76, "s:+b", true], [{56=>nil, 66=>nil, 76=>nil}, 76, "s:+b", false]], 47=>[[{37=>:enemy}, 37, "s:+b", true], [{38=>:enemy}, 38, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{37=>nil}, 37, "s:+b", false], [{37=>nil, 27=>:enemy}, 27, "s:+b", true], [{37=>nil, 27=>nil}, 27, "s:+b", false], [{38=>nil}, 38, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{39=>nil, 31=>:enemy}, 31, "s:+b", true], [{39=>nil, 31=>nil}, 31, "s:+b", false], [{39=>nil, 31=>nil, 23=>:enemy}, 23, "s:+b", true], [{39=>nil, 31=>nil, 23=>nil}, 23, "s:+b", false], [{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 63=>:enemy}, 63, "s:+b", true], [{55=>nil, 63=>nil}, 63, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 67=>:enemy}, 67, "s:+b", true], [{57=>nil, 67=>nil}, 67, "s:+b", false], [{57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 48=>[[{38=>:enemy}, 38, "s:+b", true], [{39=>:enemy}, 39, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{38=>nil}, 38, "s:+b", false], [{38=>nil, 28=>:enemy}, 28, "s:+b", true], [{38=>nil, 28=>nil}, 28, "s:+b", false], [{38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{39=>nil}, 39, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{40=>nil, 32=>:enemy}, 32, "s:+b", true], [{40=>nil, 32=>nil}, 32, "s:+b", false], [{40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 64=>:enemy}, 64, "s:+b", true], [{56=>nil, 64=>nil}, 64, "s:+b", false], [{56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 68=>:enemy}, 68, "s:+b", true], [{58=>nil, 68=>nil}, 68, "s:+b", false], [{58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 49=>[[{39=>:enemy}, 39, "s:+b", true], [{40=>:enemy}, 40, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{39=>nil}, 39, "s:+b", false], [{39=>nil, 29=>:enemy}, 29, "s:+b", true], [{39=>nil, 29=>nil}, 29, "s:+b", false], [{39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{40=>nil}, 40, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{41=>nil, 33=>:enemy}, 33, "s:+b", true], [{41=>nil, 33=>nil}, 33, "s:+b", false], [{41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 65=>:enemy}, 65, "s:+b", true], [{57=>nil, 65=>nil}, 65, "s:+b", false], [{57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 69=>:enemy}, 69, "s:+b", true], [{59=>nil, 69=>nil}, 69, "s:+b", false], [{59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 50=>[[{40=>:enemy}, 40, "s:+b", true], [{41=>:enemy}, 41, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{40=>nil}, 40, "s:+b", false], [{40=>nil, 30=>:enemy}, 30, "s:+b", true], [{40=>nil, 30=>nil}, 30, "s:+b", false], [{40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{41=>nil}, 41, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{42=>nil, 34=>:enemy}, 34, "s:+b", true], [{42=>nil, 34=>nil}, 34, "s:+b", false], [{42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 66=>:enemy}, 66, "s:+b", true], [{58=>nil, 66=>nil}, 66, "s:+b", false], [{58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 70=>:enemy}, 70, "s:+b", true], [{60=>nil, 70=>nil}, 70, "s:+b", false], [{60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 51=>[[{41=>:enemy}, 41, "s:+b", true], [{42=>:enemy}, 42, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{41=>nil}, 41, "s:+b", false], [{41=>nil, 31=>:enemy}, 31, "s:+b", true], [{41=>nil, 31=>nil}, 31, "s:+b", false], [{41=>nil, 31=>nil, 21=>:enemy}, 21, "s:+b", true], [{41=>nil, 31=>nil, 21=>nil}, 21, "s:+b", false], [{41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{42=>nil}, 42, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{43=>nil, 35=>:enemy}, 35, "s:+b", true], [{43=>nil, 35=>nil}, 35, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 67=>:enemy}, 67, "s:+b", true], [{59=>nil, 67=>nil}, 67, "s:+b", false], [{59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 71=>:enemy}, 71, "s:+b", true], [{61=>nil, 71=>nil}, 71, "s:+b", false]], 52=>[[{42=>:enemy}, 42, "s:+b", true], [{43=>:enemy}, 43, "s:+b", true], [{44=>:enemy}, 44, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{42=>nil}, 42, "s:+b", false], [{42=>nil, 32=>:enemy}, 32, "s:+b", true], [{42=>nil, 32=>nil}, 32, "s:+b", false], [{42=>nil, 32=>nil, 22=>:enemy}, 22, "s:+b", true], [{42=>nil, 32=>nil, 22=>nil}, 22, "s:+b", false], [{42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "s:+b", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "s:+b", false], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:+b", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:+b", false], [{43=>nil}, 43, "s:+b", false], [{44=>nil}, 44, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{53=>nil}, 53, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 68=>:enemy}, 68, "s:+b", true], [{60=>nil, 68=>nil}, 68, "s:+b", false], [{60=>nil, 68=>nil, 76=>:enemy}, 76, "s:+b", true], [{60=>nil, 68=>nil, 76=>nil}, 76, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{62=>nil}, 62, "s:+b", false]], 53=>[[{43=>:enemy}, 43, "s:+b", true], [{44=>:enemy}, 44, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{43=>nil}, 43, "s:+b", false], [{43=>nil, 33=>:enemy}, 33, "s:+b", true], [{43=>nil, 33=>nil}, 33, "s:+b", false], [{43=>nil, 33=>nil, 23=>:enemy}, 23, "s:+b", true], [{43=>nil, 33=>nil, 23=>nil}, 23, "s:+b", false], [{43=>nil, 33=>nil, 23=>nil, 13=>:enemy}, 13, "s:+b", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil}, 13, "s:+b", false], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "s:+b", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "s:+b", false], [{44=>nil}, 44, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 69=>:enemy}, 69, "s:+b", true], [{61=>nil, 69=>nil}, 69, "s:+b", false], [{61=>nil, 69=>nil, 77=>:enemy}, 77, "s:+b", true], [{61=>nil, 69=>nil, 77=>nil}, 77, "s:+b", false], [{62=>nil}, 62, "s:+b", false]], 54=>[[{45=>:enemy}, 45, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{63=>:enemy}, 63, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{45=>nil}, 45, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 38=>:enemy}, 38, "s:+b", true], [{46=>nil, 38=>nil}, 38, "s:+b", false], [{46=>nil, 38=>nil, 30=>:enemy}, 30, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil}, 30, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, 22, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil}, 22, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{63=>nil}, 63, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 74=>:enemy}, 74, "s:+b", true], [{64=>nil, 74=>nil}, 74, "s:+b", false]], 55=>[[{45=>:enemy}, 45, "s:+b", true], [{46=>:enemy}, 46, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{54=>:enemy}, 54, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{63=>:enemy}, 63, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{45=>nil}, 45, "s:+b", false], [{46=>nil}, 46, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 39=>:enemy}, 39, "s:+b", true], [{47=>nil, 39=>nil}, 39, "s:+b", false], [{47=>nil, 39=>nil, 31=>:enemy}, 31, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil}, 31, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{54=>nil}, 54, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{63=>nil}, 63, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 75=>:enemy}, 75, "s:+b", true], [{65=>nil, 75=>nil}, 75, "s:+b", false]], 56=>[[{46=>:enemy}, 46, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 36=>:enemy}, 36, "s:+b", true], [{46=>nil, 36=>nil}, 36, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 40=>:enemy}, 40, "s:+b", true], [{48=>nil, 40=>nil}, 40, "s:+b", false], [{48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 72=>:enemy}, 72, "s:+b", true], [{64=>nil, 72=>nil}, 72, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 76=>:enemy}, 76, "s:+b", true], [{66=>nil, 76=>nil}, 76, "s:+b", false]], 57=>[[{47=>:enemy}, 47, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 37=>:enemy}, 37, "s:+b", true], [{47=>nil, 37=>nil}, 37, "s:+b", false], [{47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 41=>:enemy}, 41, "s:+b", true], [{49=>nil, 41=>nil}, 41, "s:+b", false], [{49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 73=>:enemy}, 73, "s:+b", true], [{65=>nil, 73=>nil}, 73, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 77=>:enemy}, 77, "s:+b", true], [{67=>nil, 77=>nil}, 77, "s:+b", false]], 58=>[[{48=>:enemy}, 48, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 38=>:enemy}, 38, "s:+b", true], [{48=>nil, 38=>nil}, 38, "s:+b", false], [{48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 42=>:enemy}, 42, "s:+b", true], [{50=>nil, 42=>nil}, 42, "s:+b", false], [{50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 74=>:enemy}, 74, "s:+b", true], [{66=>nil, 74=>nil}, 74, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 78=>:enemy}, 78, "s:+b", true], [{68=>nil, 78=>nil}, 78, "s:+b", false]], 59=>[[{49=>:enemy}, 49, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 39=>:enemy}, 39, "s:+b", true], [{49=>nil, 39=>nil}, 39, "s:+b", false], [{49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 43=>:enemy}, 43, "s:+b", true], [{51=>nil, 43=>nil}, 43, "s:+b", false], [{51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 75=>:enemy}, 75, "s:+b", true], [{67=>nil, 75=>nil}, 75, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 79=>:enemy}, 79, "s:+b", true], [{69=>nil, 79=>nil}, 79, "s:+b", false]], 60=>[[{50=>:enemy}, 50, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 40=>:enemy}, 40, "s:+b", true], [{50=>nil, 40=>nil}, 40, "s:+b", false], [{50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 44=>:enemy}, 44, "s:+b", true], [{52=>nil, 44=>nil}, 44, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 76=>:enemy}, 76, "s:+b", true], [{68=>nil, 76=>nil}, 76, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 80=>:enemy}, 80, "s:+b", true], [{70=>nil, 80=>nil}, 80, "s:+b", false]], 61=>[[{51=>:enemy}, 51, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 41=>:enemy}, 41, "s:+b", true], [{51=>nil, 41=>nil}, 41, "s:+b", false], [{51=>nil, 41=>nil, 31=>:enemy}, 31, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil}, 31, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{53=>nil}, 53, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{62=>nil}, 62, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 77=>:enemy}, 77, "s:+b", true], [{69=>nil, 77=>nil}, 77, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{71=>nil}, 71, "s:+b", false]], 62=>[[{52=>:enemy}, 52, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 42=>:enemy}, 42, "s:+b", true], [{52=>nil, 42=>nil}, 42, "s:+b", false], [{52=>nil, 42=>nil, 32=>:enemy}, 32, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil}, 32, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>:enemy}, 22, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil}, 22, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:+b", false], [{53=>nil}, 53, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 78=>:enemy}, 78, "s:+b", true], [{70=>nil, 78=>nil}, 78, "s:+b", false], [{71=>nil}, 71, "s:+b", false]], 63=>[[{54=>:enemy}, 54, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{72=>:enemy}, 72, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{54=>nil}, 54, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 47=>:enemy}, 47, "s:+b", true], [{55=>nil, 47=>nil}, 47, "s:+b", false], [{55=>nil, 47=>nil, 39=>:enemy}, 39, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil}, 39, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, 31, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil}, 31, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{72=>nil}, 72, "s:+b", false], [{73=>nil}, 73, "s:+b", false]], 64=>[[{54=>:enemy}, 54, "s:+b", true], [{55=>:enemy}, 55, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{63=>:enemy}, 63, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{72=>:enemy}, 72, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{54=>nil}, 54, "s:+b", false], [{55=>nil}, 55, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 48=>:enemy}, 48, "s:+b", true], [{56=>nil, 48=>nil}, 48, "s:+b", false], [{56=>nil, 48=>nil, 40=>:enemy}, 40, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil}, 40, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{63=>nil}, 63, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{72=>nil}, 72, "s:+b", false], [{73=>nil}, 73, "s:+b", false], [{74=>nil}, 74, "s:+b", false]], 65=>[[{55=>:enemy}, 55, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 45=>:enemy}, 45, "s:+b", true], [{55=>nil, 45=>nil}, 45, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 49=>:enemy}, 49, "s:+b", true], [{57=>nil, 49=>nil}, 49, "s:+b", false], [{57=>nil, 49=>nil, 41=>:enemy}, 41, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil}, 41, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{73=>nil}, 73, "s:+b", false], [{74=>nil}, 74, "s:+b", false], [{75=>nil}, 75, "s:+b", false]], 66=>[[{56=>:enemy}, 56, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 46=>:enemy}, 46, "s:+b", true], [{56=>nil, 46=>nil}, 46, "s:+b", false], [{56=>nil, 46=>nil, 36=>:enemy}, 36, "s:+b", true], [{56=>nil, 46=>nil, 36=>nil}, 36, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 50=>:enemy}, 50, "s:+b", true], [{58=>nil, 50=>nil}, 50, "s:+b", false], [{58=>nil, 50=>nil, 42=>:enemy}, 42, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil}, 42, "s:+b", false], [{58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{74=>nil}, 74, "s:+b", false], [{75=>nil}, 75, "s:+b", false], [{76=>nil}, 76, "s:+b", false]], 67=>[[{57=>:enemy}, 57, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 47=>:enemy}, 47, "s:+b", true], [{57=>nil, 47=>nil}, 47, "s:+b", false], [{57=>nil, 47=>nil, 37=>:enemy}, 37, "s:+b", true], [{57=>nil, 47=>nil, 37=>nil}, 37, "s:+b", false], [{57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 51=>:enemy}, 51, "s:+b", true], [{59=>nil, 51=>nil}, 51, "s:+b", false], [{59=>nil, 51=>nil, 43=>:enemy}, 43, "s:+b", true], [{59=>nil, 51=>nil, 43=>nil}, 43, "s:+b", false], [{59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{75=>nil}, 75, "s:+b", false], [{76=>nil}, 76, "s:+b", false], [{77=>nil}, 77, "s:+b", false]], 68=>[[{58=>:enemy}, 58, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 48=>:enemy}, 48, "s:+b", true], [{58=>nil, 48=>nil}, 48, "s:+b", false], [{58=>nil, 48=>nil, 38=>:enemy}, 38, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil}, 38, "s:+b", false], [{58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 52=>:enemy}, 52, "s:+b", true], [{60=>nil, 52=>nil}, 52, "s:+b", false], [{60=>nil, 52=>nil, 44=>:enemy}, 44, "s:+b", true], [{60=>nil, 52=>nil, 44=>nil}, 44, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{76=>nil}, 76, "s:+b", false], [{77=>nil}, 77, "s:+b", false], [{78=>nil}, 78, "s:+b", false]], 69=>[[{59=>:enemy}, 59, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 49=>:enemy}, 49, "s:+b", true], [{59=>nil, 49=>nil}, 49, "s:+b", false], [{59=>nil, 49=>nil, 39=>:enemy}, 39, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil}, 39, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 53=>:enemy}, 53, "s:+b", true], [{61=>nil, 53=>nil}, 53, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{77=>nil}, 77, "s:+b", false], [{78=>nil}, 78, "s:+b", false], [{79=>nil}, 79, "s:+b", false]], 70=>[[{60=>:enemy}, 60, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{80=>:enemy}, 80, "s:+b", true], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 50=>:enemy}, 50, "s:+b", true], [{60=>nil, 50=>nil}, 50, "s:+b", false], [{60=>nil, 50=>nil, 40=>:enemy}, 40, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil}, 40, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{62=>nil}, 62, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{71=>nil}, 71, "s:+b", false], [{78=>nil}, 78, "s:+b", false], [{79=>nil}, 79, "s:+b", false], [{80=>nil}, 80, "s:+b", false]], 71=>[[{61=>:enemy}, 61, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{80=>:enemy}, 80, "s:+b", true], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 51=>:enemy}, 51, "s:+b", true], [{61=>nil, 51=>nil}, 51, "s:+b", false], [{61=>nil, 51=>nil, 41=>:enemy}, 41, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil}, 41, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>:enemy}, 31, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil}, 31, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{62=>nil}, 62, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{79=>nil}, 79, "s:+b", false], [{80=>nil}, 80, "s:+b", false]], 72=>[[{63=>:enemy}, 63, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{63=>nil}, 63, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 56=>:enemy}, 56, "s:+b", true], [{64=>nil, 56=>nil}, 56, "s:+b", false], [{64=>nil, 56=>nil, 48=>:enemy}, 48, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil}, 48, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>:enemy}, 40, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil}, 40, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{73=>nil}, 73, "s:+b", false]], 73=>[[{63=>:enemy}, 63, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{72=>:enemy}, 72, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{63=>nil}, 63, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 57=>:enemy}, 57, "s:+b", true], [{65=>nil, 57=>nil}, 57, "s:+b", false], [{65=>nil, 57=>nil, 49=>:enemy}, 49, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil}, 49, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>:enemy}, 41, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil}, 41, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{72=>nil}, 72, "s:+b", false], [{74=>nil}, 74, "s:+b", false]], 74=>[[{64=>:enemy}, 64, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 54=>:enemy}, 54, "s:+b", true], [{64=>nil, 54=>nil}, 54, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 58=>:enemy}, 58, "s:+b", true], [{66=>nil, 58=>nil}, 58, "s:+b", false], [{66=>nil, 58=>nil, 50=>:enemy}, 50, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil}, 50, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>:enemy}, 42, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil}, 42, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{73=>nil}, 73, "s:+b", false], [{75=>nil}, 75, "s:+b", false]], 75=>[[{65=>:enemy}, 65, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 55=>:enemy}, 55, "s:+b", true], [{65=>nil, 55=>nil}, 55, "s:+b", false], [{65=>nil, 55=>nil, 45=>:enemy}, 45, "s:+b", true], [{65=>nil, 55=>nil, 45=>nil}, 45, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 59=>:enemy}, 59, "s:+b", true], [{67=>nil, 59=>nil}, 59, "s:+b", false], [{67=>nil, 59=>nil, 51=>:enemy}, 51, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil}, 51, "s:+b", false], [{67=>nil, 59=>nil, 51=>nil, 43=>:enemy}, 43, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil}, 43, "s:+b", false], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false], [{74=>nil}, 74, "s:+b", false], [{76=>nil}, 76, "s:+b", false]], 76=>[[{66=>:enemy}, 66, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 56=>:enemy}, 56, "s:+b", true], [{66=>nil, 56=>nil}, 56, "s:+b", false], [{66=>nil, 56=>nil, 46=>:enemy}, 46, "s:+b", true], [{66=>nil, 56=>nil, 46=>nil}, 46, "s:+b", false], [{66=>nil, 56=>nil, 46=>nil, 36=>:enemy}, 36, "s:+b", true], [{66=>nil, 56=>nil, 46=>nil, 36=>nil}, 36, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 60=>:enemy}, 60, "s:+b", true], [{68=>nil, 60=>nil}, 60, "s:+b", false], [{68=>nil, 60=>nil, 52=>:enemy}, 52, "s:+b", true], [{68=>nil, 60=>nil, 52=>nil}, 52, "s:+b", false], [{68=>nil, 60=>nil, 52=>nil, 44=>:enemy}, 44, "s:+b", true], [{68=>nil, 60=>nil, 52=>nil, 44=>nil}, 44, "s:+b", false], [{75=>nil}, 75, "s:+b", false], [{77=>nil}, 77, "s:+b", false]], 77=>[[{67=>:enemy}, 67, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 57=>:enemy}, 57, "s:+b", true], [{67=>nil, 57=>nil}, 57, "s:+b", false], [{67=>nil, 57=>nil, 47=>:enemy}, 47, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil}, 47, "s:+b", false], [{67=>nil, 57=>nil, 47=>nil, 37=>:enemy}, 37, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil}, 37, "s:+b", false], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 61=>:enemy}, 61, "s:+b", true], [{69=>nil, 61=>nil}, 61, "s:+b", false], [{69=>nil, 61=>nil, 53=>:enemy}, 53, "s:+b", true], [{69=>nil, 61=>nil, 53=>nil}, 53, "s:+b", false], [{76=>nil}, 76, "s:+b", false], [{78=>nil}, 78, "s:+b", false]], 78=>[[{68=>:enemy}, 68, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 58=>:enemy}, 58, "s:+b", true], [{68=>nil, 58=>nil}, 58, "s:+b", false], [{68=>nil, 58=>nil, 48=>:enemy}, 48, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil}, 48, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>:enemy}, 38, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil}, 38, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 62=>:enemy}, 62, "s:+b", true], [{70=>nil, 62=>nil}, 62, "s:+b", false], [{77=>nil}, 77, "s:+b", false], [{79=>nil}, 79, "s:+b", false]], 79=>[[{69=>:enemy}, 69, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{80=>:enemy}, 80, "s:+b", true], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 59=>:enemy}, 59, "s:+b", true], [{69=>nil, 59=>nil}, 59, "s:+b", false], [{69=>nil, 59=>nil, 49=>:enemy}, 49, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil}, 49, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>:enemy}, 39, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil}, 39, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{71=>nil}, 71, "s:+b", false], [{78=>nil}, 78, "s:+b", false], [{80=>nil}, 80, "s:+b", false]], 80=>[[{70=>:enemy}, 70, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 60=>:enemy}, 60, "s:+b", true], [{70=>nil, 60=>nil}, 60, "s:+b", false], [{70=>nil, 60=>nil, 50=>:enemy}, 50, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil}, 50, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>:enemy}, 40, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil}, 40, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{71=>nil}, 71, "s:+b", false], [{79=>nil}, 79, "s:+b", false]], nil=>[]}, "s:+l"=>{0=>[[{1=>:enemy}, 1, "s:+l", true], [{9=>:enemy}, 9, "s:+l", true], [{10=>:enemy}, 10, "s:+l", true], [{1=>nil}, 1, "s:+l", false], [{9=>nil}, 9, "s:+l", false], [{9=>nil, 18=>:enemy}, 18, "s:+l", true], [{9=>nil, 18=>nil}, 18, "s:+l", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{10=>nil}, 10, "s:+l", false]], 1=>[[{0=>:enemy}, 0, "s:+l", true], [{2=>:enemy}, 2, "s:+l", true], [{9=>:enemy}, 9, "s:+l", true], [{10=>:enemy}, 10, "s:+l", true], [{11=>:enemy}, 11, "s:+l", true], [{0=>nil}, 0, "s:+l", false], [{2=>nil}, 2, "s:+l", false], [{9=>nil}, 9, "s:+l", false], [{10=>nil}, 10, "s:+l", false], [{10=>nil, 19=>:enemy}, 19, "s:+l", true], [{10=>nil, 19=>nil}, 19, "s:+l", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{11=>nil}, 11, "s:+l", false]], 2=>[[{1=>:enemy}, 1, "s:+l", true], [{3=>:enemy}, 3, "s:+l", true], [{10=>:enemy}, 10, "s:+l", true], [{11=>:enemy}, 11, "s:+l", true], [{12=>:enemy}, 12, "s:+l", true], [{1=>nil}, 1, "s:+l", false], [{3=>nil}, 3, "s:+l", false], [{10=>nil}, 10, "s:+l", false], [{11=>nil}, 11, "s:+l", false], [{11=>nil, 20=>:enemy}, 20, "s:+l", true], [{11=>nil, 20=>nil}, 20, "s:+l", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{12=>nil}, 12, "s:+l", false]], 3=>[[{2=>:enemy}, 2, "s:+l", true], [{4=>:enemy}, 4, "s:+l", true], [{11=>:enemy}, 11, "s:+l", true], [{12=>:enemy}, 12, "s:+l", true], [{13=>:enemy}, 13, "s:+l", true], [{2=>nil}, 2, "s:+l", false], [{4=>nil}, 4, "s:+l", false], [{11=>nil}, 11, "s:+l", false], [{12=>nil}, 12, "s:+l", false], [{12=>nil, 21=>:enemy}, 21, "s:+l", true], [{12=>nil, 21=>nil}, 21, "s:+l", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{13=>nil}, 13, "s:+l", false]], 4=>[[{3=>:enemy}, 3, "s:+l", true], [{5=>:enemy}, 5, "s:+l", true], [{12=>:enemy}, 12, "s:+l", true], [{13=>:enemy}, 13, "s:+l", true], [{14=>:enemy}, 14, "s:+l", true], [{3=>nil}, 3, "s:+l", false], [{5=>nil}, 5, "s:+l", false], [{12=>nil}, 12, "s:+l", false], [{13=>nil}, 13, "s:+l", false], [{13=>nil, 22=>:enemy}, 22, "s:+l", true], [{13=>nil, 22=>nil}, 22, "s:+l", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{14=>nil}, 14, "s:+l", false]], 5=>[[{4=>:enemy}, 4, "s:+l", true], [{6=>:enemy}, 6, "s:+l", true], [{13=>:enemy}, 13, "s:+l", true], [{14=>:enemy}, 14, "s:+l", true], [{15=>:enemy}, 15, "s:+l", true], [{4=>nil}, 4, "s:+l", false], [{6=>nil}, 6, "s:+l", false], [{13=>nil}, 13, "s:+l", false], [{14=>nil}, 14, "s:+l", false], [{14=>nil, 23=>:enemy}, 23, "s:+l", true], [{14=>nil, 23=>nil}, 23, "s:+l", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{15=>nil}, 15, "s:+l", false]], 6=>[[{5=>:enemy}, 5, "s:+l", true], [{7=>:enemy}, 7, "s:+l", true], [{14=>:enemy}, 14, "s:+l", true], [{15=>:enemy}, 15, "s:+l", true], [{16=>:enemy}, 16, "s:+l", true], [{5=>nil}, 5, "s:+l", false], [{7=>nil}, 7, "s:+l", false], [{14=>nil}, 14, "s:+l", false], [{15=>nil}, 15, "s:+l", false], [{15=>nil, 24=>:enemy}, 24, "s:+l", true], [{15=>nil, 24=>nil}, 24, "s:+l", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{16=>nil}, 16, "s:+l", false]], 7=>[[{6=>:enemy}, 6, "s:+l", true], [{8=>:enemy}, 8, "s:+l", true], [{15=>:enemy}, 15, "s:+l", true], [{16=>:enemy}, 16, "s:+l", true], [{17=>:enemy}, 17, "s:+l", true], [{6=>nil}, 6, "s:+l", false], [{8=>nil}, 8, "s:+l", false], [{15=>nil}, 15, "s:+l", false], [{16=>nil}, 16, "s:+l", false], [{16=>nil, 25=>:enemy}, 25, "s:+l", true], [{16=>nil, 25=>nil}, 25, "s:+l", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{17=>nil}, 17, "s:+l", false]], 8=>[[{7=>:enemy}, 7, "s:+l", true], [{16=>:enemy}, 16, "s:+l", true], [{17=>:enemy}, 17, "s:+l", true], [{7=>nil}, 7, "s:+l", false], [{16=>nil}, 16, "s:+l", false], [{17=>nil}, 17, "s:+l", false], [{17=>nil, 26=>:enemy}, 26, "s:+l", true], [{17=>nil, 26=>nil}, 26, "s:+l", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 9=>[[{0=>:enemy}, 0, "s:+l", true], [{10=>:enemy}, 10, "s:+l", true], [{18=>:enemy}, 18, "s:+l", true], [{19=>:enemy}, 19, "s:+l", true], [{0=>nil}, 0, "s:+l", false], [{10=>nil}, 10, "s:+l", false], [{18=>nil}, 18, "s:+l", false], [{18=>nil, 27=>:enemy}, 27, "s:+l", true], [{18=>nil, 27=>nil}, 27, "s:+l", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{19=>nil}, 19, "s:+l", false]], 10=>[[{1=>:enemy}, 1, "s:+l", true], [{9=>:enemy}, 9, "s:+l", true], [{11=>:enemy}, 11, "s:+l", true], [{18=>:enemy}, 18, "s:+l", true], [{19=>:enemy}, 19, "s:+l", true], [{20=>:enemy}, 20, "s:+l", true], [{1=>nil}, 1, "s:+l", false], [{9=>nil}, 9, "s:+l", false], [{11=>nil}, 11, "s:+l", false], [{18=>nil}, 18, "s:+l", false], [{19=>nil}, 19, "s:+l", false], [{19=>nil, 28=>:enemy}, 28, "s:+l", true], [{19=>nil, 28=>nil}, 28, "s:+l", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{20=>nil}, 20, "s:+l", false]], 11=>[[{2=>:enemy}, 2, "s:+l", true], [{10=>:enemy}, 10, "s:+l", true], [{12=>:enemy}, 12, "s:+l", true], [{19=>:enemy}, 19, "s:+l", true], [{20=>:enemy}, 20, "s:+l", true], [{21=>:enemy}, 21, "s:+l", true], [{2=>nil}, 2, "s:+l", false], [{10=>nil}, 10, "s:+l", false], [{12=>nil}, 12, "s:+l", false], [{19=>nil}, 19, "s:+l", false], [{20=>nil}, 20, "s:+l", false], [{20=>nil, 29=>:enemy}, 29, "s:+l", true], [{20=>nil, 29=>nil}, 29, "s:+l", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{21=>nil}, 21, "s:+l", false]], 12=>[[{3=>:enemy}, 3, "s:+l", true], [{11=>:enemy}, 11, "s:+l", true], [{13=>:enemy}, 13, "s:+l", true], [{20=>:enemy}, 20, "s:+l", true], [{21=>:enemy}, 21, "s:+l", true], [{22=>:enemy}, 22, "s:+l", true], [{3=>nil}, 3, "s:+l", false], [{11=>nil}, 11, "s:+l", false], [{13=>nil}, 13, "s:+l", false], [{20=>nil}, 20, "s:+l", false], [{21=>nil}, 21, "s:+l", false], [{21=>nil, 30=>:enemy}, 30, "s:+l", true], [{21=>nil, 30=>nil}, 30, "s:+l", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{22=>nil}, 22, "s:+l", false]], 13=>[[{4=>:enemy}, 4, "s:+l", true], [{12=>:enemy}, 12, "s:+l", true], [{14=>:enemy}, 14, "s:+l", true], [{21=>:enemy}, 21, "s:+l", true], [{22=>:enemy}, 22, "s:+l", true], [{23=>:enemy}, 23, "s:+l", true], [{4=>nil}, 4, "s:+l", false], [{12=>nil}, 12, "s:+l", false], [{14=>nil}, 14, "s:+l", false], [{21=>nil}, 21, "s:+l", false], [{22=>nil}, 22, "s:+l", false], [{22=>nil, 31=>:enemy}, 31, "s:+l", true], [{22=>nil, 31=>nil}, 31, "s:+l", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{23=>nil}, 23, "s:+l", false]], 14=>[[{5=>:enemy}, 5, "s:+l", true], [{13=>:enemy}, 13, "s:+l", true], [{15=>:enemy}, 15, "s:+l", true], [{22=>:enemy}, 22, "s:+l", true], [{23=>:enemy}, 23, "s:+l", true], [{24=>:enemy}, 24, "s:+l", true], [{5=>nil}, 5, "s:+l", false], [{13=>nil}, 13, "s:+l", false], [{15=>nil}, 15, "s:+l", false], [{22=>nil}, 22, "s:+l", false], [{23=>nil}, 23, "s:+l", false], [{23=>nil, 32=>:enemy}, 32, "s:+l", true], [{23=>nil, 32=>nil}, 32, "s:+l", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{24=>nil}, 24, "s:+l", false]], 15=>[[{6=>:enemy}, 6, "s:+l", true], [{14=>:enemy}, 14, "s:+l", true], [{16=>:enemy}, 16, "s:+l", true], [{23=>:enemy}, 23, "s:+l", true], [{24=>:enemy}, 24, "s:+l", true], [{25=>:enemy}, 25, "s:+l", true], [{6=>nil}, 6, "s:+l", false], [{14=>nil}, 14, "s:+l", false], [{16=>nil}, 16, "s:+l", false], [{23=>nil}, 23, "s:+l", false], [{24=>nil}, 24, "s:+l", false], [{24=>nil, 33=>:enemy}, 33, "s:+l", true], [{24=>nil, 33=>nil}, 33, "s:+l", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{25=>nil}, 25, "s:+l", false]], 16=>[[{7=>:enemy}, 7, "s:+l", true], [{15=>:enemy}, 15, "s:+l", true], [{17=>:enemy}, 17, "s:+l", true], [{24=>:enemy}, 24, "s:+l", true], [{25=>:enemy}, 25, "s:+l", true], [{26=>:enemy}, 26, "s:+l", true], [{7=>nil}, 7, "s:+l", false], [{15=>nil}, 15, "s:+l", false], [{17=>nil}, 17, "s:+l", false], [{24=>nil}, 24, "s:+l", false], [{25=>nil}, 25, "s:+l", false], [{25=>nil, 34=>:enemy}, 34, "s:+l", true], [{25=>nil, 34=>nil}, 34, "s:+l", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{26=>nil}, 26, "s:+l", false]], 17=>[[{8=>:enemy}, 8, "s:+l", true], [{16=>:enemy}, 16, "s:+l", true], [{25=>:enemy}, 25, "s:+l", true], [{26=>:enemy}, 26, "s:+l", true], [{8=>nil}, 8, "s:+l", false], [{16=>nil}, 16, "s:+l", false], [{25=>nil}, 25, "s:+l", false], [{26=>nil}, 26, "s:+l", false], [{26=>nil, 35=>:enemy}, 35, "s:+l", true], [{26=>nil, 35=>nil}, 35, "s:+l", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 18=>[[{9=>:enemy}, 9, "s:+l", true], [{19=>:enemy}, 19, "s:+l", true], [{27=>:enemy}, 27, "s:+l", true], [{28=>:enemy}, 28, "s:+l", true], [{9=>nil}, 9, "s:+l", false], [{19=>nil}, 19, "s:+l", false], [{27=>nil}, 27, "s:+l", false], [{27=>nil, 36=>:enemy}, 36, "s:+l", true], [{27=>nil, 36=>nil}, 36, "s:+l", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "s:+l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{28=>nil}, 28, "s:+l", false]], 19=>[[{10=>:enemy}, 10, "s:+l", true], [{18=>:enemy}, 18, "s:+l", true], [{20=>:enemy}, 20, "s:+l", true], [{27=>:enemy}, 27, "s:+l", true], [{28=>:enemy}, 28, "s:+l", true], [{29=>:enemy}, 29, "s:+l", true], [{10=>nil}, 10, "s:+l", false], [{18=>nil}, 18, "s:+l", false], [{20=>nil}, 20, "s:+l", false], [{27=>nil}, 27, "s:+l", false], [{28=>nil}, 28, "s:+l", false], [{28=>nil, 37=>:enemy}, 37, "s:+l", true], [{28=>nil, 37=>nil}, 37, "s:+l", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "s:+l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{29=>nil}, 29, "s:+l", false]], 20=>[[{11=>:enemy}, 11, "s:+l", true], [{19=>:enemy}, 19, "s:+l", true], [{21=>:enemy}, 21, "s:+l", true], [{28=>:enemy}, 28, "s:+l", true], [{29=>:enemy}, 29, "s:+l", true], [{30=>:enemy}, 30, "s:+l", true], [{11=>nil}, 11, "s:+l", false], [{19=>nil}, 19, "s:+l", false], [{21=>nil}, 21, "s:+l", false], [{28=>nil}, 28, "s:+l", false], [{29=>nil}, 29, "s:+l", false], [{29=>nil, 38=>:enemy}, 38, "s:+l", true], [{29=>nil, 38=>nil}, 38, "s:+l", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "s:+l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{30=>nil}, 30, "s:+l", false]], 21=>[[{12=>:enemy}, 12, "s:+l", true], [{20=>:enemy}, 20, "s:+l", true], [{22=>:enemy}, 22, "s:+l", true], [{29=>:enemy}, 29, "s:+l", true], [{30=>:enemy}, 30, "s:+l", true], [{31=>:enemy}, 31, "s:+l", true], [{12=>nil}, 12, "s:+l", false], [{20=>nil}, 20, "s:+l", false], [{22=>nil}, 22, "s:+l", false], [{29=>nil}, 29, "s:+l", false], [{30=>nil}, 30, "s:+l", false], [{30=>nil, 39=>:enemy}, 39, "s:+l", true], [{30=>nil, 39=>nil}, 39, "s:+l", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "s:+l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{31=>nil}, 31, "s:+l", false]], 22=>[[{13=>:enemy}, 13, "s:+l", true], [{21=>:enemy}, 21, "s:+l", true], [{23=>:enemy}, 23, "s:+l", true], [{30=>:enemy}, 30, "s:+l", true], [{31=>:enemy}, 31, "s:+l", true], [{32=>:enemy}, 32, "s:+l", true], [{13=>nil}, 13, "s:+l", false], [{21=>nil}, 21, "s:+l", false], [{23=>nil}, 23, "s:+l", false], [{30=>nil}, 30, "s:+l", false], [{31=>nil}, 31, "s:+l", false], [{31=>nil, 40=>:enemy}, 40, "s:+l", true], [{31=>nil, 40=>nil}, 40, "s:+l", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "s:+l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{32=>nil}, 32, "s:+l", false]], 23=>[[{14=>:enemy}, 14, "s:+l", true], [{22=>:enemy}, 22, "s:+l", true], [{24=>:enemy}, 24, "s:+l", true], [{31=>:enemy}, 31, "s:+l", true], [{32=>:enemy}, 32, "s:+l", true], [{33=>:enemy}, 33, "s:+l", true], [{14=>nil}, 14, "s:+l", false], [{22=>nil}, 22, "s:+l", false], [{24=>nil}, 24, "s:+l", false], [{31=>nil}, 31, "s:+l", false], [{32=>nil}, 32, "s:+l", false], [{32=>nil, 41=>:enemy}, 41, "s:+l", true], [{32=>nil, 41=>nil}, 41, "s:+l", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "s:+l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{33=>nil}, 33, "s:+l", false]], 24=>[[{15=>:enemy}, 15, "s:+l", true], [{23=>:enemy}, 23, "s:+l", true], [{25=>:enemy}, 25, "s:+l", true], [{32=>:enemy}, 32, "s:+l", true], [{33=>:enemy}, 33, "s:+l", true], [{34=>:enemy}, 34, "s:+l", true], [{15=>nil}, 15, "s:+l", false], [{23=>nil}, 23, "s:+l", false], [{25=>nil}, 25, "s:+l", false], [{32=>nil}, 32, "s:+l", false], [{33=>nil}, 33, "s:+l", false], [{33=>nil, 42=>:enemy}, 42, "s:+l", true], [{33=>nil, 42=>nil}, 42, "s:+l", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "s:+l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{34=>nil}, 34, "s:+l", false]], 25=>[[{16=>:enemy}, 16, "s:+l", true], [{24=>:enemy}, 24, "s:+l", true], [{26=>:enemy}, 26, "s:+l", true], [{33=>:enemy}, 33, "s:+l", true], [{34=>:enemy}, 34, "s:+l", true], [{35=>:enemy}, 35, "s:+l", true], [{16=>nil}, 16, "s:+l", false], [{24=>nil}, 24, "s:+l", false], [{26=>nil}, 26, "s:+l", false], [{33=>nil}, 33, "s:+l", false], [{34=>nil}, 34, "s:+l", false], [{34=>nil, 43=>:enemy}, 43, "s:+l", true], [{34=>nil, 43=>nil}, 43, "s:+l", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "s:+l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{35=>nil}, 35, "s:+l", false]], 26=>[[{17=>:enemy}, 17, "s:+l", true], [{25=>:enemy}, 25, "s:+l", true], [{34=>:enemy}, 34, "s:+l", true], [{35=>:enemy}, 35, "s:+l", true], [{17=>nil}, 17, "s:+l", false], [{25=>nil}, 25, "s:+l", false], [{34=>nil}, 34, "s:+l", false], [{35=>nil}, 35, "s:+l", false], [{35=>nil, 44=>:enemy}, 44, "s:+l", true], [{35=>nil, 44=>nil}, 44, "s:+l", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "s:+l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 27=>[[{18=>:enemy}, 18, "s:+l", true], [{28=>:enemy}, 28, "s:+l", true], [{36=>:enemy}, 36, "s:+l", true], [{37=>:enemy}, 37, "s:+l", true], [{18=>nil}, 18, "s:+l", false], [{28=>nil}, 28, "s:+l", false], [{36=>nil}, 36, "s:+l", false], [{36=>nil, 45=>:enemy}, 45, "s:+l", true], [{36=>nil, 45=>nil}, 45, "s:+l", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{37=>nil}, 37, "s:+l", false]], 28=>[[{19=>:enemy}, 19, "s:+l", true], [{27=>:enemy}, 27, "s:+l", true], [{29=>:enemy}, 29, "s:+l", true], [{36=>:enemy}, 36, "s:+l", true], [{37=>:enemy}, 37, "s:+l", true], [{38=>:enemy}, 38, "s:+l", true], [{19=>nil}, 19, "s:+l", false], [{27=>nil}, 27, "s:+l", false], [{29=>nil}, 29, "s:+l", false], [{36=>nil}, 36, "s:+l", false], [{37=>nil}, 37, "s:+l", false], [{37=>nil, 46=>:enemy}, 46, "s:+l", true], [{37=>nil, 46=>nil}, 46, "s:+l", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{38=>nil}, 38, "s:+l", false]], 29=>[[{20=>:enemy}, 20, "s:+l", true], [{28=>:enemy}, 28, "s:+l", true], [{30=>:enemy}, 30, "s:+l", true], [{37=>:enemy}, 37, "s:+l", true], [{38=>:enemy}, 38, "s:+l", true], [{39=>:enemy}, 39, "s:+l", true], [{20=>nil}, 20, "s:+l", false], [{28=>nil}, 28, "s:+l", false], [{30=>nil}, 30, "s:+l", false], [{37=>nil}, 37, "s:+l", false], [{38=>nil}, 38, "s:+l", false], [{38=>nil, 47=>:enemy}, 47, "s:+l", true], [{38=>nil, 47=>nil}, 47, "s:+l", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{39=>nil}, 39, "s:+l", false]], 30=>[[{21=>:enemy}, 21, "s:+l", true], [{29=>:enemy}, 29, "s:+l", true], [{31=>:enemy}, 31, "s:+l", true], [{38=>:enemy}, 38, "s:+l", true], [{39=>:enemy}, 39, "s:+l", true], [{40=>:enemy}, 40, "s:+l", true], [{21=>nil}, 21, "s:+l", false], [{29=>nil}, 29, "s:+l", false], [{31=>nil}, 31, "s:+l", false], [{38=>nil}, 38, "s:+l", false], [{39=>nil}, 39, "s:+l", false], [{39=>nil, 48=>:enemy}, 48, "s:+l", true], [{39=>nil, 48=>nil}, 48, "s:+l", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{40=>nil}, 40, "s:+l", false]], 31=>[[{22=>:enemy}, 22, "s:+l", true], [{30=>:enemy}, 30, "s:+l", true], [{32=>:enemy}, 32, "s:+l", true], [{39=>:enemy}, 39, "s:+l", true], [{40=>:enemy}, 40, "s:+l", true], [{41=>:enemy}, 41, "s:+l", true], [{22=>nil}, 22, "s:+l", false], [{30=>nil}, 30, "s:+l", false], [{32=>nil}, 32, "s:+l", false], [{39=>nil}, 39, "s:+l", false], [{40=>nil}, 40, "s:+l", false], [{40=>nil, 49=>:enemy}, 49, "s:+l", true], [{40=>nil, 49=>nil}, 49, "s:+l", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{41=>nil}, 41, "s:+l", false]], 32=>[[{23=>:enemy}, 23, "s:+l", true], [{31=>:enemy}, 31, "s:+l", true], [{33=>:enemy}, 33, "s:+l", true], [{40=>:enemy}, 40, "s:+l", true], [{41=>:enemy}, 41, "s:+l", true], [{42=>:enemy}, 42, "s:+l", true], [{23=>nil}, 23, "s:+l", false], [{31=>nil}, 31, "s:+l", false], [{33=>nil}, 33, "s:+l", false], [{40=>nil}, 40, "s:+l", false], [{41=>nil}, 41, "s:+l", false], [{41=>nil, 50=>:enemy}, 50, "s:+l", true], [{41=>nil, 50=>nil}, 50, "s:+l", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{42=>nil}, 42, "s:+l", false]], 33=>[[{24=>:enemy}, 24, "s:+l", true], [{32=>:enemy}, 32, "s:+l", true], [{34=>:enemy}, 34, "s:+l", true], [{41=>:enemy}, 41, "s:+l", true], [{42=>:enemy}, 42, "s:+l", true], [{43=>:enemy}, 43, "s:+l", true], [{24=>nil}, 24, "s:+l", false], [{32=>nil}, 32, "s:+l", false], [{34=>nil}, 34, "s:+l", false], [{41=>nil}, 41, "s:+l", false], [{42=>nil}, 42, "s:+l", false], [{42=>nil, 51=>:enemy}, 51, "s:+l", true], [{42=>nil, 51=>nil}, 51, "s:+l", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{43=>nil}, 43, "s:+l", false]], 34=>[[{25=>:enemy}, 25, "s:+l", true], [{33=>:enemy}, 33, "s:+l", true], [{35=>:enemy}, 35, "s:+l", true], [{42=>:enemy}, 42, "s:+l", true], [{43=>:enemy}, 43, "s:+l", true], [{44=>:enemy}, 44, "s:+l", true], [{25=>nil}, 25, "s:+l", false], [{33=>nil}, 33, "s:+l", false], [{35=>nil}, 35, "s:+l", false], [{42=>nil}, 42, "s:+l", false], [{43=>nil}, 43, "s:+l", false], [{43=>nil, 52=>:enemy}, 52, "s:+l", true], [{43=>nil, 52=>nil}, 52, "s:+l", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{44=>nil}, 44, "s:+l", false]], 35=>[[{26=>:enemy}, 26, "s:+l", true], [{34=>:enemy}, 34, "s:+l", true], [{43=>:enemy}, 43, "s:+l", true], [{44=>:enemy}, 44, "s:+l", true], [{26=>nil}, 26, "s:+l", false], [{34=>nil}, 34, "s:+l", false], [{43=>nil}, 43, "s:+l", false], [{44=>nil}, 44, "s:+l", false], [{44=>nil, 53=>:enemy}, 53, "s:+l", true], [{44=>nil, 53=>nil}, 53, "s:+l", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 36=>[[{27=>:enemy}, 27, "s:+l", true], [{37=>:enemy}, 37, "s:+l", true], [{45=>:enemy}, 45, "s:+l", true], [{46=>:enemy}, 46, "s:+l", true], [{27=>nil}, 27, "s:+l", false], [{37=>nil}, 37, "s:+l", false], [{45=>nil}, 45, "s:+l", false], [{45=>nil, 54=>:enemy}, 54, "s:+l", true], [{45=>nil, 54=>nil}, 54, "s:+l", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{46=>nil}, 46, "s:+l", false]], 37=>[[{28=>:enemy}, 28, "s:+l", true], [{36=>:enemy}, 36, "s:+l", true], [{38=>:enemy}, 38, "s:+l", true], [{45=>:enemy}, 45, "s:+l", true], [{46=>:enemy}, 46, "s:+l", true], [{47=>:enemy}, 47, "s:+l", true], [{28=>nil}, 28, "s:+l", false], [{36=>nil}, 36, "s:+l", false], [{38=>nil}, 38, "s:+l", false], [{45=>nil}, 45, "s:+l", false], [{46=>nil}, 46, "s:+l", false], [{46=>nil, 55=>:enemy}, 55, "s:+l", true], [{46=>nil, 55=>nil}, 55, "s:+l", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{47=>nil}, 47, "s:+l", false]], 38=>[[{29=>:enemy}, 29, "s:+l", true], [{37=>:enemy}, 37, "s:+l", true], [{39=>:enemy}, 39, "s:+l", true], [{46=>:enemy}, 46, "s:+l", true], [{47=>:enemy}, 47, "s:+l", true], [{48=>:enemy}, 48, "s:+l", true], [{29=>nil}, 29, "s:+l", false], [{37=>nil}, 37, "s:+l", false], [{39=>nil}, 39, "s:+l", false], [{46=>nil}, 46, "s:+l", false], [{47=>nil}, 47, "s:+l", false], [{47=>nil, 56=>:enemy}, 56, "s:+l", true], [{47=>nil, 56=>nil}, 56, "s:+l", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{48=>nil}, 48, "s:+l", false]], 39=>[[{30=>:enemy}, 30, "s:+l", true], [{38=>:enemy}, 38, "s:+l", true], [{40=>:enemy}, 40, "s:+l", true], [{47=>:enemy}, 47, "s:+l", true], [{48=>:enemy}, 48, "s:+l", true], [{49=>:enemy}, 49, "s:+l", true], [{30=>nil}, 30, "s:+l", false], [{38=>nil}, 38, "s:+l", false], [{40=>nil}, 40, "s:+l", false], [{47=>nil}, 47, "s:+l", false], [{48=>nil}, 48, "s:+l", false], [{48=>nil, 57=>:enemy}, 57, "s:+l", true], [{48=>nil, 57=>nil}, 57, "s:+l", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{49=>nil}, 49, "s:+l", false]], 40=>[[{31=>:enemy}, 31, "s:+l", true], [{39=>:enemy}, 39, "s:+l", true], [{41=>:enemy}, 41, "s:+l", true], [{48=>:enemy}, 48, "s:+l", true], [{49=>:enemy}, 49, "s:+l", true], [{50=>:enemy}, 50, "s:+l", true], [{31=>nil}, 31, "s:+l", false], [{39=>nil}, 39, "s:+l", false], [{41=>nil}, 41, "s:+l", false], [{48=>nil}, 48, "s:+l", false], [{49=>nil}, 49, "s:+l", false], [{49=>nil, 58=>:enemy}, 58, "s:+l", true], [{49=>nil, 58=>nil}, 58, "s:+l", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{50=>nil}, 50, "s:+l", false]], 41=>[[{32=>:enemy}, 32, "s:+l", true], [{40=>:enemy}, 40, "s:+l", true], [{42=>:enemy}, 42, "s:+l", true], [{49=>:enemy}, 49, "s:+l", true], [{50=>:enemy}, 50, "s:+l", true], [{51=>:enemy}, 51, "s:+l", true], [{32=>nil}, 32, "s:+l", false], [{40=>nil}, 40, "s:+l", false], [{42=>nil}, 42, "s:+l", false], [{49=>nil}, 49, "s:+l", false], [{50=>nil}, 50, "s:+l", false], [{50=>nil, 59=>:enemy}, 59, "s:+l", true], [{50=>nil, 59=>nil}, 59, "s:+l", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{51=>nil}, 51, "s:+l", false]], 42=>[[{33=>:enemy}, 33, "s:+l", true], [{41=>:enemy}, 41, "s:+l", true], [{43=>:enemy}, 43, "s:+l", true], [{50=>:enemy}, 50, "s:+l", true], [{51=>:enemy}, 51, "s:+l", true], [{52=>:enemy}, 52, "s:+l", true], [{33=>nil}, 33, "s:+l", false], [{41=>nil}, 41, "s:+l", false], [{43=>nil}, 43, "s:+l", false], [{50=>nil}, 50, "s:+l", false], [{51=>nil}, 51, "s:+l", false], [{51=>nil, 60=>:enemy}, 60, "s:+l", true], [{51=>nil, 60=>nil}, 60, "s:+l", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{52=>nil}, 52, "s:+l", false]], 43=>[[{34=>:enemy}, 34, "s:+l", true], [{42=>:enemy}, 42, "s:+l", true], [{44=>:enemy}, 44, "s:+l", true], [{51=>:enemy}, 51, "s:+l", true], [{52=>:enemy}, 52, "s:+l", true], [{53=>:enemy}, 53, "s:+l", true], [{34=>nil}, 34, "s:+l", false], [{42=>nil}, 42, "s:+l", false], [{44=>nil}, 44, "s:+l", false], [{51=>nil}, 51, "s:+l", false], [{52=>nil}, 52, "s:+l", false], [{52=>nil, 61=>:enemy}, 61, "s:+l", true], [{52=>nil, 61=>nil}, 61, "s:+l", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{53=>nil}, 53, "s:+l", false]], 44=>[[{35=>:enemy}, 35, "s:+l", true], [{43=>:enemy}, 43, "s:+l", true], [{52=>:enemy}, 52, "s:+l", true], [{53=>:enemy}, 53, "s:+l", true], [{35=>nil}, 35, "s:+l", false], [{43=>nil}, 43, "s:+l", false], [{52=>nil}, 52, "s:+l", false], [{53=>nil}, 53, "s:+l", false], [{53=>nil, 62=>:enemy}, 62, "s:+l", true], [{53=>nil, 62=>nil}, 62, "s:+l", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 45=>[[{36=>:enemy}, 36, "s:+l", true], [{46=>:enemy}, 46, "s:+l", true], [{54=>:enemy}, 54, "s:+l", true], [{55=>:enemy}, 55, "s:+l", true], [{36=>nil}, 36, "s:+l", false], [{46=>nil}, 46, "s:+l", false], [{54=>nil}, 54, "s:+l", false], [{54=>nil, 63=>:enemy}, 63, "s:+l", true], [{54=>nil, 63=>nil}, 63, "s:+l", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false], [{55=>nil}, 55, "s:+l", false]], 46=>[[{37=>:enemy}, 37, "s:+l", true], [{45=>:enemy}, 45, "s:+l", true], [{47=>:enemy}, 47, "s:+l", true], [{54=>:enemy}, 54, "s:+l", true], [{55=>:enemy}, 55, "s:+l", true], [{56=>:enemy}, 56, "s:+l", true], [{37=>nil}, 37, "s:+l", false], [{45=>nil}, 45, "s:+l", false], [{47=>nil}, 47, "s:+l", false], [{54=>nil}, 54, "s:+l", false], [{55=>nil}, 55, "s:+l", false], [{55=>nil, 64=>:enemy}, 64, "s:+l", true], [{55=>nil, 64=>nil}, 64, "s:+l", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false], [{56=>nil}, 56, "s:+l", false]], 47=>[[{38=>:enemy}, 38, "s:+l", true], [{46=>:enemy}, 46, "s:+l", true], [{48=>:enemy}, 48, "s:+l", true], [{55=>:enemy}, 55, "s:+l", true], [{56=>:enemy}, 56, "s:+l", true], [{57=>:enemy}, 57, "s:+l", true], [{38=>nil}, 38, "s:+l", false], [{46=>nil}, 46, "s:+l", false], [{48=>nil}, 48, "s:+l", false], [{55=>nil}, 55, "s:+l", false], [{56=>nil}, 56, "s:+l", false], [{56=>nil, 65=>:enemy}, 65, "s:+l", true], [{56=>nil, 65=>nil}, 65, "s:+l", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false], [{57=>nil}, 57, "s:+l", false]], 48=>[[{39=>:enemy}, 39, "s:+l", true], [{47=>:enemy}, 47, "s:+l", true], [{49=>:enemy}, 49, "s:+l", true], [{56=>:enemy}, 56, "s:+l", true], [{57=>:enemy}, 57, "s:+l", true], [{58=>:enemy}, 58, "s:+l", true], [{39=>nil}, 39, "s:+l", false], [{47=>nil}, 47, "s:+l", false], [{49=>nil}, 49, "s:+l", false], [{56=>nil}, 56, "s:+l", false], [{57=>nil}, 57, "s:+l", false], [{57=>nil, 66=>:enemy}, 66, "s:+l", true], [{57=>nil, 66=>nil}, 66, "s:+l", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false], [{58=>nil}, 58, "s:+l", false]], 49=>[[{40=>:enemy}, 40, "s:+l", true], [{48=>:enemy}, 48, "s:+l", true], [{50=>:enemy}, 50, "s:+l", true], [{57=>:enemy}, 57, "s:+l", true], [{58=>:enemy}, 58, "s:+l", true], [{59=>:enemy}, 59, "s:+l", true], [{40=>nil}, 40, "s:+l", false], [{48=>nil}, 48, "s:+l", false], [{50=>nil}, 50, "s:+l", false], [{57=>nil}, 57, "s:+l", false], [{58=>nil}, 58, "s:+l", false], [{58=>nil, 67=>:enemy}, 67, "s:+l", true], [{58=>nil, 67=>nil}, 67, "s:+l", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false], [{59=>nil}, 59, "s:+l", false]], 50=>[[{41=>:enemy}, 41, "s:+l", true], [{49=>:enemy}, 49, "s:+l", true], [{51=>:enemy}, 51, "s:+l", true], [{58=>:enemy}, 58, "s:+l", true], [{59=>:enemy}, 59, "s:+l", true], [{60=>:enemy}, 60, "s:+l", true], [{41=>nil}, 41, "s:+l", false], [{49=>nil}, 49, "s:+l", false], [{51=>nil}, 51, "s:+l", false], [{58=>nil}, 58, "s:+l", false], [{59=>nil}, 59, "s:+l", false], [{59=>nil, 68=>:enemy}, 68, "s:+l", true], [{59=>nil, 68=>nil}, 68, "s:+l", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false], [{60=>nil}, 60, "s:+l", false]], 51=>[[{42=>:enemy}, 42, "s:+l", true], [{50=>:enemy}, 50, "s:+l", true], [{52=>:enemy}, 52, "s:+l", true], [{59=>:enemy}, 59, "s:+l", true], [{60=>:enemy}, 60, "s:+l", true], [{61=>:enemy}, 61, "s:+l", true], [{42=>nil}, 42, "s:+l", false], [{50=>nil}, 50, "s:+l", false], [{52=>nil}, 52, "s:+l", false], [{59=>nil}, 59, "s:+l", false], [{60=>nil}, 60, "s:+l", false], [{60=>nil, 69=>:enemy}, 69, "s:+l", true], [{60=>nil, 69=>nil}, 69, "s:+l", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false], [{61=>nil}, 61, "s:+l", false]], 52=>[[{43=>:enemy}, 43, "s:+l", true], [{51=>:enemy}, 51, "s:+l", true], [{53=>:enemy}, 53, "s:+l", true], [{60=>:enemy}, 60, "s:+l", true], [{61=>:enemy}, 61, "s:+l", true], [{62=>:enemy}, 62, "s:+l", true], [{43=>nil}, 43, "s:+l", false], [{51=>nil}, 51, "s:+l", false], [{53=>nil}, 53, "s:+l", false], [{60=>nil}, 60, "s:+l", false], [{61=>nil}, 61, "s:+l", false], [{61=>nil, 70=>:enemy}, 70, "s:+l", true], [{61=>nil, 70=>nil}, 70, "s:+l", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false], [{62=>nil}, 62, "s:+l", false]], 53=>[[{44=>:enemy}, 44, "s:+l", true], [{52=>:enemy}, 52, "s:+l", true], [{61=>:enemy}, 61, "s:+l", true], [{62=>:enemy}, 62, "s:+l", true], [{44=>nil}, 44, "s:+l", false], [{52=>nil}, 52, "s:+l", false], [{61=>nil}, 61, "s:+l", false], [{62=>nil}, 62, "s:+l", false], [{62=>nil, 71=>:enemy}, 71, "s:+l", true], [{62=>nil, 71=>nil}, 71, "s:+l", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 54=>[[{45=>:enemy}, 45, "s:+l", true], [{55=>:enemy}, 55, "s:+l", true], [{63=>:enemy}, 63, "s:+l", true], [{64=>:enemy}, 64, "s:+l", true], [{45=>nil}, 45, "s:+l", false], [{55=>nil}, 55, "s:+l", false], [{63=>nil}, 63, "s:+l", false], [{63=>nil, 72=>:enemy}, 72, "s:+l", true], [{63=>nil, 72=>nil}, 72, "s:+l", false], [{64=>nil}, 64, "s:+l", false]], 55=>[[{46=>:enemy}, 46, "s:+l", true], [{54=>:enemy}, 54, "s:+l", true], [{56=>:enemy}, 56, "s:+l", true], [{63=>:enemy}, 63, "s:+l", true], [{64=>:enemy}, 64, "s:+l", true], [{65=>:enemy}, 65, "s:+l", true], [{46=>nil}, 46, "s:+l", false], [{54=>nil}, 54, "s:+l", false], [{56=>nil}, 56, "s:+l", false], [{63=>nil}, 63, "s:+l", false], [{64=>nil}, 64, "s:+l", false], [{64=>nil, 73=>:enemy}, 73, "s:+l", true], [{64=>nil, 73=>nil}, 73, "s:+l", false], [{65=>nil}, 65, "s:+l", false]], 56=>[[{47=>:enemy}, 47, "s:+l", true], [{55=>:enemy}, 55, "s:+l", true], [{57=>:enemy}, 57, "s:+l", true], [{64=>:enemy}, 64, "s:+l", true], [{65=>:enemy}, 65, "s:+l", true], [{66=>:enemy}, 66, "s:+l", true], [{47=>nil}, 47, "s:+l", false], [{55=>nil}, 55, "s:+l", false], [{57=>nil}, 57, "s:+l", false], [{64=>nil}, 64, "s:+l", false], [{65=>nil}, 65, "s:+l", false], [{65=>nil, 74=>:enemy}, 74, "s:+l", true], [{65=>nil, 74=>nil}, 74, "s:+l", false], [{66=>nil}, 66, "s:+l", false]], 57=>[[{48=>:enemy}, 48, "s:+l", true], [{56=>:enemy}, 56, "s:+l", true], [{58=>:enemy}, 58, "s:+l", true], [{65=>:enemy}, 65, "s:+l", true], [{66=>:enemy}, 66, "s:+l", true], [{67=>:enemy}, 67, "s:+l", true], [{48=>nil}, 48, "s:+l", false], [{56=>nil}, 56, "s:+l", false], [{58=>nil}, 58, "s:+l", false], [{65=>nil}, 65, "s:+l", false], [{66=>nil}, 66, "s:+l", false], [{66=>nil, 75=>:enemy}, 75, "s:+l", true], [{66=>nil, 75=>nil}, 75, "s:+l", false], [{67=>nil}, 67, "s:+l", false]], 58=>[[{49=>:enemy}, 49, "s:+l", true], [{57=>:enemy}, 57, "s:+l", true], [{59=>:enemy}, 59, "s:+l", true], [{66=>:enemy}, 66, "s:+l", true], [{67=>:enemy}, 67, "s:+l", true], [{68=>:enemy}, 68, "s:+l", true], [{49=>nil}, 49, "s:+l", false], [{57=>nil}, 57, "s:+l", false], [{59=>nil}, 59, "s:+l", false], [{66=>nil}, 66, "s:+l", false], [{67=>nil}, 67, "s:+l", false], [{67=>nil, 76=>:enemy}, 76, "s:+l", true], [{67=>nil, 76=>nil}, 76, "s:+l", false], [{68=>nil}, 68, "s:+l", false]], 59=>[[{50=>:enemy}, 50, "s:+l", true], [{58=>:enemy}, 58, "s:+l", true], [{60=>:enemy}, 60, "s:+l", true], [{67=>:enemy}, 67, "s:+l", true], [{68=>:enemy}, 68, "s:+l", true], [{69=>:enemy}, 69, "s:+l", true], [{50=>nil}, 50, "s:+l", false], [{58=>nil}, 58, "s:+l", false], [{60=>nil}, 60, "s:+l", false], [{67=>nil}, 67, "s:+l", false], [{68=>nil}, 68, "s:+l", false], [{68=>nil, 77=>:enemy}, 77, "s:+l", true], [{68=>nil, 77=>nil}, 77, "s:+l", false], [{69=>nil}, 69, "s:+l", false]], 60=>[[{51=>:enemy}, 51, "s:+l", true], [{59=>:enemy}, 59, "s:+l", true], [{61=>:enemy}, 61, "s:+l", true], [{68=>:enemy}, 68, "s:+l", true], [{69=>:enemy}, 69, "s:+l", true], [{70=>:enemy}, 70, "s:+l", true], [{51=>nil}, 51, "s:+l", false], [{59=>nil}, 59, "s:+l", false], [{61=>nil}, 61, "s:+l", false], [{68=>nil}, 68, "s:+l", false], [{69=>nil}, 69, "s:+l", false], [{69=>nil, 78=>:enemy}, 78, "s:+l", true], [{69=>nil, 78=>nil}, 78, "s:+l", false], [{70=>nil}, 70, "s:+l", false]], 61=>[[{52=>:enemy}, 52, "s:+l", true], [{60=>:enemy}, 60, "s:+l", true], [{62=>:enemy}, 62, "s:+l", true], [{69=>:enemy}, 69, "s:+l", true], [{70=>:enemy}, 70, "s:+l", true], [{71=>:enemy}, 71, "s:+l", true], [{52=>nil}, 52, "s:+l", false], [{60=>nil}, 60, "s:+l", false], [{62=>nil}, 62, "s:+l", false], [{69=>nil}, 69, "s:+l", false], [{70=>nil}, 70, "s:+l", false], [{70=>nil, 79=>:enemy}, 79, "s:+l", true], [{70=>nil, 79=>nil}, 79, "s:+l", false], [{71=>nil}, 71, "s:+l", false]], 62=>[[{53=>:enemy}, 53, "s:+l", true], [{61=>:enemy}, 61, "s:+l", true], [{70=>:enemy}, 70, "s:+l", true], [{71=>:enemy}, 71, "s:+l", true], [{53=>nil}, 53, "s:+l", false], [{61=>nil}, 61, "s:+l", false], [{70=>nil}, 70, "s:+l", false], [{71=>nil}, 71, "s:+l", false], [{71=>nil, 80=>:enemy}, 80, "s:+l", true], [{71=>nil, 80=>nil}, 80, "s:+l", false]], 63=>[[{54=>:enemy}, 54, "s:+l", true], [{64=>:enemy}, 64, "s:+l", true], [{72=>:enemy}, 72, "s:+l", true], [{73=>:enemy}, 73, "s:+l", true], [{54=>nil}, 54, "s:+l", false], [{64=>nil}, 64, "s:+l", false], [{72=>nil}, 72, "s:+l", false], [{73=>nil}, 73, "s:+l", false]], 64=>[[{55=>:enemy}, 55, "s:+l", true], [{63=>:enemy}, 63, "s:+l", true], [{65=>:enemy}, 65, "s:+l", true], [{72=>:enemy}, 72, "s:+l", true], [{73=>:enemy}, 73, "s:+l", true], [{74=>:enemy}, 74, "s:+l", true], [{55=>nil}, 55, "s:+l", false], [{63=>nil}, 63, "s:+l", false], [{65=>nil}, 65, "s:+l", false], [{72=>nil}, 72, "s:+l", false], [{73=>nil}, 73, "s:+l", false], [{74=>nil}, 74, "s:+l", false]], 65=>[[{56=>:enemy}, 56, "s:+l", true], [{64=>:enemy}, 64, "s:+l", true], [{66=>:enemy}, 66, "s:+l", true], [{73=>:enemy}, 73, "s:+l", true], [{74=>:enemy}, 74, "s:+l", true], [{75=>:enemy}, 75, "s:+l", true], [{56=>nil}, 56, "s:+l", false], [{64=>nil}, 64, "s:+l", false], [{66=>nil}, 66, "s:+l", false], [{73=>nil}, 73, "s:+l", false], [{74=>nil}, 74, "s:+l", false], [{75=>nil}, 75, "s:+l", false]], 66=>[[{57=>:enemy}, 57, "s:+l", true], [{65=>:enemy}, 65, "s:+l", true], [{67=>:enemy}, 67, "s:+l", true], [{74=>:enemy}, 74, "s:+l", true], [{75=>:enemy}, 75, "s:+l", true], [{76=>:enemy}, 76, "s:+l", true], [{57=>nil}, 57, "s:+l", false], [{65=>nil}, 65, "s:+l", false], [{67=>nil}, 67, "s:+l", false], [{74=>nil}, 74, "s:+l", false], [{75=>nil}, 75, "s:+l", false], [{76=>nil}, 76, "s:+l", false]], 67=>[[{58=>:enemy}, 58, "s:+l", true], [{66=>:enemy}, 66, "s:+l", true], [{68=>:enemy}, 68, "s:+l", true], [{75=>:enemy}, 75, "s:+l", true], [{76=>:enemy}, 76, "s:+l", true], [{77=>:enemy}, 77, "s:+l", true], [{58=>nil}, 58, "s:+l", false], [{66=>nil}, 66, "s:+l", false], [{68=>nil}, 68, "s:+l", false], [{75=>nil}, 75, "s:+l", false], [{76=>nil}, 76, "s:+l", false], [{77=>nil}, 77, "s:+l", false]], 68=>[[{59=>:enemy}, 59, "s:+l", true], [{67=>:enemy}, 67, "s:+l", true], [{69=>:enemy}, 69, "s:+l", true], [{76=>:enemy}, 76, "s:+l", true], [{77=>:enemy}, 77, "s:+l", true], [{78=>:enemy}, 78, "s:+l", true], [{59=>nil}, 59, "s:+l", false], [{67=>nil}, 67, "s:+l", false], [{69=>nil}, 69, "s:+l", false], [{76=>nil}, 76, "s:+l", false], [{77=>nil}, 77, "s:+l", false], [{78=>nil}, 78, "s:+l", false]], 69=>[[{60=>:enemy}, 60, "s:+l", true], [{68=>:enemy}, 68, "s:+l", true], [{70=>:enemy}, 70, "s:+l", true], [{77=>:enemy}, 77, "s:+l", true], [{78=>:enemy}, 78, "s:+l", true], [{79=>:enemy}, 79, "s:+l", true], [{60=>nil}, 60, "s:+l", false], [{68=>nil}, 68, "s:+l", false], [{70=>nil}, 70, "s:+l", false], [{77=>nil}, 77, "s:+l", false], [{78=>nil}, 78, "s:+l", false], [{79=>nil}, 79, "s:+l", false]], 70=>[[{61=>:enemy}, 61, "s:+l", true], [{69=>:enemy}, 69, "s:+l", true], [{71=>:enemy}, 71, "s:+l", true], [{78=>:enemy}, 78, "s:+l", true], [{79=>:enemy}, 79, "s:+l", true], [{80=>:enemy}, 80, "s:+l", true], [{61=>nil}, 61, "s:+l", false], [{69=>nil}, 69, "s:+l", false], [{71=>nil}, 71, "s:+l", false], [{78=>nil}, 78, "s:+l", false], [{79=>nil}, 79, "s:+l", false], [{80=>nil}, 80, "s:+l", false]], 71=>[[{62=>:enemy}, 62, "s:+l", true], [{70=>:enemy}, 70, "s:+l", true], [{79=>:enemy}, 79, "s:+l", true], [{80=>:enemy}, 80, "s:+l", true], [{62=>nil}, 62, "s:+l", false], [{70=>nil}, 70, "s:+l", false], [{79=>nil}, 79, "s:+l", false], [{80=>nil}, 80, "s:+l", false]], 72=>[[{63=>:enemy}, 63, "s:+l", true], [{73=>:enemy}, 73, "s:+l", true], [{63=>nil}, 63, "s:+l", false], [{73=>nil}, 73, "s:+l", false]], 73=>[[{64=>:enemy}, 64, "s:+l", true], [{72=>:enemy}, 72, "s:+l", true], [{74=>:enemy}, 74, "s:+l", true], [{64=>nil}, 64, "s:+l", false], [{72=>nil}, 72, "s:+l", false], [{74=>nil}, 74, "s:+l", false]], 74=>[[{65=>:enemy}, 65, "s:+l", true], [{73=>:enemy}, 73, "s:+l", true], [{75=>:enemy}, 75, "s:+l", true], [{65=>nil}, 65, "s:+l", false], [{73=>nil}, 73, "s:+l", false], [{75=>nil}, 75, "s:+l", false]], 75=>[[{66=>:enemy}, 66, "s:+l", true], [{74=>:enemy}, 74, "s:+l", true], [{76=>:enemy}, 76, "s:+l", true], [{66=>nil}, 66, "s:+l", false], [{74=>nil}, 74, "s:+l", false], [{76=>nil}, 76, "s:+l", false]], 76=>[[{67=>:enemy}, 67, "s:+l", true], [{75=>:enemy}, 75, "s:+l", true], [{77=>:enemy}, 77, "s:+l", true], [{67=>nil}, 67, "s:+l", false], [{75=>nil}, 75, "s:+l", false], [{77=>nil}, 77, "s:+l", false]], 77=>[[{68=>:enemy}, 68, "s:+l", true], [{76=>:enemy}, 76, "s:+l", true], [{78=>:enemy}, 78, "s:+l", true], [{68=>nil}, 68, "s:+l", false], [{76=>nil}, 76, "s:+l", false], [{78=>nil}, 78, "s:+l", false]], 78=>[[{69=>:enemy}, 69, "s:+l", true], [{77=>:enemy}, 77, "s:+l", true], [{79=>:enemy}, 79, "s:+l", true], [{69=>nil}, 69, "s:+l", false], [{77=>nil}, 77, "s:+l", false], [{79=>nil}, 79, "s:+l", false]], 79=>[[{70=>:enemy}, 70, "s:+l", true], [{78=>:enemy}, 78, "s:+l", true], [{80=>:enemy}, 80, "s:+l", true], [{70=>nil}, 70, "s:+l", false], [{78=>nil}, 78, "s:+l", false], [{80=>nil}, 80, "s:+l", false]], 80=>[[{71=>:enemy}, 71, "s:+l", true], [{79=>:enemy}, 79, "s:+l", true], [{71=>nil}, 71, "s:+l", false], [{79=>nil}, 79, "s:+l", false]], nil=>[]}, "s:+n"=>{0=>[[{1=>:enemy}, 1, "s:+n", true], [{9=>:enemy}, 9, "s:+n", true], [{10=>:enemy}, 10, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{1=>nil}, 1, "s:+n", false], [{9=>nil}, 9, "s:+n", false], [{10=>nil}, 10, "s:+n", false], [{19=>nil}, 19, "s:+n", false]], 1=>[[{0=>:enemy}, 0, "s:+n", true], [{2=>:enemy}, 2, "s:+n", true], [{9=>:enemy}, 9, "s:+n", true], [{10=>:enemy}, 10, "s:+n", true], [{11=>:enemy}, 11, "s:+n", true], [{18=>:enemy}, 18, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{0=>nil}, 0, "s:+n", false], [{2=>nil}, 2, "s:+n", false], [{9=>nil}, 9, "s:+n", false], [{10=>nil}, 10, "s:+n", false], [{11=>nil}, 11, "s:+n", false], [{18=>nil}, 18, "s:+n", false], [{20=>nil}, 20, "s:+n", false]], 2=>[[{1=>:enemy}, 1, "s:+n", true], [{3=>:enemy}, 3, "s:+n", true], [{10=>:enemy}, 10, "s:+n", true], [{11=>:enemy}, 11, "s:+n", true], [{12=>:enemy}, 12, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{1=>nil}, 1, "s:+n", false], [{3=>nil}, 3, "s:+n", false], [{10=>nil}, 10, "s:+n", false], [{11=>nil}, 11, "s:+n", false], [{12=>nil}, 12, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{21=>nil}, 21, "s:+n", false]], 3=>[[{2=>:enemy}, 2, "s:+n", true], [{4=>:enemy}, 4, "s:+n", true], [{11=>:enemy}, 11, "s:+n", true], [{12=>:enemy}, 12, "s:+n", true], [{13=>:enemy}, 13, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{2=>nil}, 2, "s:+n", false], [{4=>nil}, 4, "s:+n", false], [{11=>nil}, 11, "s:+n", false], [{12=>nil}, 12, "s:+n", false], [{13=>nil}, 13, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{22=>nil}, 22, "s:+n", false]], 4=>[[{3=>:enemy}, 3, "s:+n", true], [{5=>:enemy}, 5, "s:+n", true], [{12=>:enemy}, 12, "s:+n", true], [{13=>:enemy}, 13, "s:+n", true], [{14=>:enemy}, 14, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{3=>nil}, 3, "s:+n", false], [{5=>nil}, 5, "s:+n", false], [{12=>nil}, 12, "s:+n", false], [{13=>nil}, 13, "s:+n", false], [{14=>nil}, 14, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{23=>nil}, 23, "s:+n", false]], 5=>[[{4=>:enemy}, 4, "s:+n", true], [{6=>:enemy}, 6, "s:+n", true], [{13=>:enemy}, 13, "s:+n", true], [{14=>:enemy}, 14, "s:+n", true], [{15=>:enemy}, 15, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{4=>nil}, 4, "s:+n", false], [{6=>nil}, 6, "s:+n", false], [{13=>nil}, 13, "s:+n", false], [{14=>nil}, 14, "s:+n", false], [{15=>nil}, 15, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{24=>nil}, 24, "s:+n", false]], 6=>[[{5=>:enemy}, 5, "s:+n", true], [{7=>:enemy}, 7, "s:+n", true], [{14=>:enemy}, 14, "s:+n", true], [{15=>:enemy}, 15, "s:+n", true], [{16=>:enemy}, 16, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{5=>nil}, 5, "s:+n", false], [{7=>nil}, 7, "s:+n", false], [{14=>nil}, 14, "s:+n", false], [{15=>nil}, 15, "s:+n", false], [{16=>nil}, 16, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{25=>nil}, 25, "s:+n", false]], 7=>[[{6=>:enemy}, 6, "s:+n", true], [{8=>:enemy}, 8, "s:+n", true], [{15=>:enemy}, 15, "s:+n", true], [{16=>:enemy}, 16, "s:+n", true], [{17=>:enemy}, 17, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{26=>:enemy}, 26, "s:+n", true], [{6=>nil}, 6, "s:+n", false], [{8=>nil}, 8, "s:+n", false], [{15=>nil}, 15, "s:+n", false], [{16=>nil}, 16, "s:+n", false], [{17=>nil}, 17, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{26=>nil}, 26, "s:+n", false]], 8=>[[{7=>:enemy}, 7, "s:+n", true], [{16=>:enemy}, 16, "s:+n", true], [{17=>:enemy}, 17, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{7=>nil}, 7, "s:+n", false], [{16=>nil}, 16, "s:+n", false], [{17=>nil}, 17, "s:+n", false], [{25=>nil}, 25, "s:+n", false]], 9=>[[{0=>:enemy}, 0, "s:+n", true], [{10=>:enemy}, 10, "s:+n", true], [{18=>:enemy}, 18, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{0=>nil}, 0, "s:+n", false], [{10=>nil}, 10, "s:+n", false], [{18=>nil}, 18, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{28=>nil}, 28, "s:+n", false]], 10=>[[{1=>:enemy}, 1, "s:+n", true], [{9=>:enemy}, 9, "s:+n", true], [{11=>:enemy}, 11, "s:+n", true], [{18=>:enemy}, 18, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{27=>:enemy}, 27, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{1=>nil}, 1, "s:+n", false], [{9=>nil}, 9, "s:+n", false], [{11=>nil}, 11, "s:+n", false], [{18=>nil}, 18, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{27=>nil}, 27, "s:+n", false], [{29=>nil}, 29, "s:+n", false]], 11=>[[{2=>:enemy}, 2, "s:+n", true], [{10=>:enemy}, 10, "s:+n", true], [{12=>:enemy}, 12, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{2=>nil}, 2, "s:+n", false], [{10=>nil}, 10, "s:+n", false], [{12=>nil}, 12, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{30=>nil}, 30, "s:+n", false]], 12=>[[{3=>:enemy}, 3, "s:+n", true], [{11=>:enemy}, 11, "s:+n", true], [{13=>:enemy}, 13, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{3=>nil}, 3, "s:+n", false], [{11=>nil}, 11, "s:+n", false], [{13=>nil}, 13, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{31=>nil}, 31, "s:+n", false]], 13=>[[{4=>:enemy}, 4, "s:+n", true], [{12=>:enemy}, 12, "s:+n", true], [{14=>:enemy}, 14, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{4=>nil}, 4, "s:+n", false], [{12=>nil}, 12, "s:+n", false], [{14=>nil}, 14, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{32=>nil}, 32, "s:+n", false]], 14=>[[{5=>:enemy}, 5, "s:+n", true], [{13=>:enemy}, 13, "s:+n", true], [{15=>:enemy}, 15, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{5=>nil}, 5, "s:+n", false], [{13=>nil}, 13, "s:+n", false], [{15=>nil}, 15, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{33=>nil}, 33, "s:+n", false]], 15=>[[{6=>:enemy}, 6, "s:+n", true], [{14=>:enemy}, 14, "s:+n", true], [{16=>:enemy}, 16, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{6=>nil}, 6, "s:+n", false], [{14=>nil}, 14, "s:+n", false], [{16=>nil}, 16, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{25=>nil}, 25, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{34=>nil}, 34, "s:+n", false]], 16=>[[{7=>:enemy}, 7, "s:+n", true], [{15=>:enemy}, 15, "s:+n", true], [{17=>:enemy}, 17, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{26=>:enemy}, 26, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{35=>:enemy}, 35, "s:+n", true], [{7=>nil}, 7, "s:+n", false], [{15=>nil}, 15, "s:+n", false], [{17=>nil}, 17, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{25=>nil}, 25, "s:+n", false], [{26=>nil}, 26, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{35=>nil}, 35, "s:+n", false]], 17=>[[{8=>:enemy}, 8, "s:+n", true], [{16=>:enemy}, 16, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{26=>:enemy}, 26, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{8=>nil}, 8, "s:+n", false], [{16=>nil}, 16, "s:+n", false], [{25=>nil}, 25, "s:+n", false], [{26=>nil}, 26, "s:+n", false], [{34=>nil}, 34, "s:+n", false]], 18=>[[{9=>:enemy}, 9, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{27=>:enemy}, 27, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{9=>nil}, 9, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{27=>nil}, 27, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{37=>nil}, 37, "s:+n", false]], 19=>[[{10=>:enemy}, 10, "s:+n", true], [{18=>:enemy}, 18, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{27=>:enemy}, 27, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{36=>:enemy}, 36, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{10=>nil}, 10, "s:+n", false], [{18=>nil}, 18, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{27=>nil}, 27, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{36=>nil}, 36, "s:+n", false], [{38=>nil}, 38, "s:+n", false]], 20=>[[{11=>:enemy}, 11, "s:+n", true], [{19=>:enemy}, 19, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{11=>nil}, 11, "s:+n", false], [{19=>nil}, 19, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{39=>nil}, 39, "s:+n", false]], 21=>[[{12=>:enemy}, 12, "s:+n", true], [{20=>:enemy}, 20, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{12=>nil}, 12, "s:+n", false], [{20=>nil}, 20, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{40=>nil}, 40, "s:+n", false]], 22=>[[{13=>:enemy}, 13, "s:+n", true], [{21=>:enemy}, 21, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{13=>nil}, 13, "s:+n", false], [{21=>nil}, 21, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{41=>nil}, 41, "s:+n", false]], 23=>[[{14=>:enemy}, 14, "s:+n", true], [{22=>:enemy}, 22, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{14=>nil}, 14, "s:+n", false], [{22=>nil}, 22, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{42=>nil}, 42, "s:+n", false]], 24=>[[{15=>:enemy}, 15, "s:+n", true], [{23=>:enemy}, 23, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{15=>nil}, 15, "s:+n", false], [{23=>nil}, 23, "s:+n", false], [{25=>nil}, 25, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{34=>nil}, 34, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{43=>nil}, 43, "s:+n", false]], 25=>[[{16=>:enemy}, 16, "s:+n", true], [{24=>:enemy}, 24, "s:+n", true], [{26=>:enemy}, 26, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{35=>:enemy}, 35, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{44=>:enemy}, 44, "s:+n", true], [{16=>nil}, 16, "s:+n", false], [{24=>nil}, 24, "s:+n", false], [{26=>nil}, 26, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{34=>nil}, 34, "s:+n", false], [{35=>nil}, 35, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{44=>nil}, 44, "s:+n", false]], 26=>[[{17=>:enemy}, 17, "s:+n", true], [{25=>:enemy}, 25, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{35=>:enemy}, 35, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{17=>nil}, 17, "s:+n", false], [{25=>nil}, 25, "s:+n", false], [{34=>nil}, 34, "s:+n", false], [{35=>nil}, 35, "s:+n", false], [{43=>nil}, 43, "s:+n", false]], 27=>[[{18=>:enemy}, 18, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{36=>:enemy}, 36, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{18=>nil}, 18, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{36=>nil}, 36, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{46=>nil}, 46, "s:+n", false]], 28=>[[{19=>:enemy}, 19, "s:+n", true], [{27=>:enemy}, 27, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{36=>:enemy}, 36, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{45=>:enemy}, 45, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{19=>nil}, 19, "s:+n", false], [{27=>nil}, 27, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{36=>nil}, 36, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{45=>nil}, 45, "s:+n", false], [{47=>nil}, 47, "s:+n", false]], 29=>[[{20=>:enemy}, 20, "s:+n", true], [{28=>:enemy}, 28, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{20=>nil}, 20, "s:+n", false], [{28=>nil}, 28, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{48=>nil}, 48, "s:+n", false]], 30=>[[{21=>:enemy}, 21, "s:+n", true], [{29=>:enemy}, 29, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{21=>nil}, 21, "s:+n", false], [{29=>nil}, 29, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{49=>nil}, 49, "s:+n", false]], 31=>[[{22=>:enemy}, 22, "s:+n", true], [{30=>:enemy}, 30, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{22=>nil}, 22, "s:+n", false], [{30=>nil}, 30, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{50=>nil}, 50, "s:+n", false]], 32=>[[{23=>:enemy}, 23, "s:+n", true], [{31=>:enemy}, 31, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{23=>nil}, 23, "s:+n", false], [{31=>nil}, 31, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{51=>nil}, 51, "s:+n", false]], 33=>[[{24=>:enemy}, 24, "s:+n", true], [{32=>:enemy}, 32, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{24=>nil}, 24, "s:+n", false], [{32=>nil}, 32, "s:+n", false], [{34=>nil}, 34, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{43=>nil}, 43, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{52=>nil}, 52, "s:+n", false]], 34=>[[{25=>:enemy}, 25, "s:+n", true], [{33=>:enemy}, 33, "s:+n", true], [{35=>:enemy}, 35, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{44=>:enemy}, 44, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{53=>:enemy}, 53, "s:+n", true], [{25=>nil}, 25, "s:+n", false], [{33=>nil}, 33, "s:+n", false], [{35=>nil}, 35, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{43=>nil}, 43, "s:+n", false], [{44=>nil}, 44, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{53=>nil}, 53, "s:+n", false]], 35=>[[{26=>:enemy}, 26, "s:+n", true], [{34=>:enemy}, 34, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{44=>:enemy}, 44, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{26=>nil}, 26, "s:+n", false], [{34=>nil}, 34, "s:+n", false], [{43=>nil}, 43, "s:+n", false], [{44=>nil}, 44, "s:+n", false], [{52=>nil}, 52, "s:+n", false]], 36=>[[{27=>:enemy}, 27, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{45=>:enemy}, 45, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{27=>nil}, 27, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{45=>nil}, 45, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{55=>nil}, 55, "s:+n", false]], 37=>[[{28=>:enemy}, 28, "s:+n", true], [{36=>:enemy}, 36, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{45=>:enemy}, 45, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{54=>:enemy}, 54, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{28=>nil}, 28, "s:+n", false], [{36=>nil}, 36, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{45=>nil}, 45, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{54=>nil}, 54, "s:+n", false], [{56=>nil}, 56, "s:+n", false]], 38=>[[{29=>:enemy}, 29, "s:+n", true], [{37=>:enemy}, 37, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{29=>nil}, 29, "s:+n", false], [{37=>nil}, 37, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{57=>nil}, 57, "s:+n", false]], 39=>[[{30=>:enemy}, 30, "s:+n", true], [{38=>:enemy}, 38, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{30=>nil}, 30, "s:+n", false], [{38=>nil}, 38, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{58=>nil}, 58, "s:+n", false]], 40=>[[{31=>:enemy}, 31, "s:+n", true], [{39=>:enemy}, 39, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{31=>nil}, 31, "s:+n", false], [{39=>nil}, 39, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{59=>nil}, 59, "s:+n", false]], 41=>[[{32=>:enemy}, 32, "s:+n", true], [{40=>:enemy}, 40, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{32=>nil}, 32, "s:+n", false], [{40=>nil}, 40, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{60=>nil}, 60, "s:+n", false]], 42=>[[{33=>:enemy}, 33, "s:+n", true], [{41=>:enemy}, 41, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{33=>nil}, 33, "s:+n", false], [{41=>nil}, 41, "s:+n", false], [{43=>nil}, 43, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{52=>nil}, 52, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{61=>nil}, 61, "s:+n", false]], 43=>[[{34=>:enemy}, 34, "s:+n", true], [{42=>:enemy}, 42, "s:+n", true], [{44=>:enemy}, 44, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{53=>:enemy}, 53, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{62=>:enemy}, 62, "s:+n", true], [{34=>nil}, 34, "s:+n", false], [{42=>nil}, 42, "s:+n", false], [{44=>nil}, 44, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{52=>nil}, 52, "s:+n", false], [{53=>nil}, 53, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{62=>nil}, 62, "s:+n", false]], 44=>[[{35=>:enemy}, 35, "s:+n", true], [{43=>:enemy}, 43, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{53=>:enemy}, 53, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{35=>nil}, 35, "s:+n", false], [{43=>nil}, 43, "s:+n", false], [{52=>nil}, 52, "s:+n", false], [{53=>nil}, 53, "s:+n", false], [{61=>nil}, 61, "s:+n", false]], 45=>[[{36=>:enemy}, 36, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{54=>:enemy}, 54, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{36=>nil}, 36, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{54=>nil}, 54, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{64=>nil}, 64, "s:+n", false]], 46=>[[{37=>:enemy}, 37, "s:+n", true], [{45=>:enemy}, 45, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{54=>:enemy}, 54, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{63=>:enemy}, 63, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{37=>nil}, 37, "s:+n", false], [{45=>nil}, 45, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{54=>nil}, 54, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{63=>nil}, 63, "s:+n", false], [{65=>nil}, 65, "s:+n", false]], 47=>[[{38=>:enemy}, 38, "s:+n", true], [{46=>:enemy}, 46, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{38=>nil}, 38, "s:+n", false], [{46=>nil}, 46, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{66=>nil}, 66, "s:+n", false]], 48=>[[{39=>:enemy}, 39, "s:+n", true], [{47=>:enemy}, 47, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{39=>nil}, 39, "s:+n", false], [{47=>nil}, 47, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{67=>nil}, 67, "s:+n", false]], 49=>[[{40=>:enemy}, 40, "s:+n", true], [{48=>:enemy}, 48, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{40=>nil}, 40, "s:+n", false], [{48=>nil}, 48, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{68=>nil}, 68, "s:+n", false]], 50=>[[{41=>:enemy}, 41, "s:+n", true], [{49=>:enemy}, 49, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{41=>nil}, 41, "s:+n", false], [{49=>nil}, 49, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{69=>nil}, 69, "s:+n", false]], 51=>[[{42=>:enemy}, 42, "s:+n", true], [{50=>:enemy}, 50, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{42=>nil}, 42, "s:+n", false], [{50=>nil}, 50, "s:+n", false], [{52=>nil}, 52, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{61=>nil}, 61, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{70=>nil}, 70, "s:+n", false]], 52=>[[{43=>:enemy}, 43, "s:+n", true], [{51=>:enemy}, 51, "s:+n", true], [{53=>:enemy}, 53, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{62=>:enemy}, 62, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{71=>:enemy}, 71, "s:+n", true], [{43=>nil}, 43, "s:+n", false], [{51=>nil}, 51, "s:+n", false], [{53=>nil}, 53, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{61=>nil}, 61, "s:+n", false], [{62=>nil}, 62, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{71=>nil}, 71, "s:+n", false]], 53=>[[{44=>:enemy}, 44, "s:+n", true], [{52=>:enemy}, 52, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{62=>:enemy}, 62, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{44=>nil}, 44, "s:+n", false], [{52=>nil}, 52, "s:+n", false], [{61=>nil}, 61, "s:+n", false], [{62=>nil}, 62, "s:+n", false], [{70=>nil}, 70, "s:+n", false]], 54=>[[{45=>:enemy}, 45, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{63=>:enemy}, 63, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{45=>nil}, 45, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{63=>nil}, 63, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{73=>nil}, 73, "s:+n", false]], 55=>[[{46=>:enemy}, 46, "s:+n", true], [{54=>:enemy}, 54, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{63=>:enemy}, 63, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{72=>:enemy}, 72, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{46=>nil}, 46, "s:+n", false], [{54=>nil}, 54, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{63=>nil}, 63, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{72=>nil}, 72, "s:+n", false], [{74=>nil}, 74, "s:+n", false]], 56=>[[{47=>:enemy}, 47, "s:+n", true], [{55=>:enemy}, 55, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{47=>nil}, 47, "s:+n", false], [{55=>nil}, 55, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{73=>nil}, 73, "s:+n", false], [{75=>nil}, 75, "s:+n", false]], 57=>[[{48=>:enemy}, 48, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{48=>nil}, 48, "s:+n", false], [{56=>nil}, 56, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{74=>nil}, 74, "s:+n", false], [{76=>nil}, 76, "s:+n", false]], 58=>[[{49=>:enemy}, 49, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{49=>nil}, 49, "s:+n", false], [{57=>nil}, 57, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{75=>nil}, 75, "s:+n", false], [{77=>nil}, 77, "s:+n", false]], 59=>[[{50=>:enemy}, 50, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{50=>nil}, 50, "s:+n", false], [{58=>nil}, 58, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{76=>nil}, 76, "s:+n", false], [{78=>nil}, 78, "s:+n", false]], 60=>[[{51=>:enemy}, 51, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{51=>nil}, 51, "s:+n", false], [{59=>nil}, 59, "s:+n", false], [{61=>nil}, 61, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{70=>nil}, 70, "s:+n", false], [{77=>nil}, 77, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], 61=>[[{52=>:enemy}, 52, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{62=>:enemy}, 62, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{71=>:enemy}, 71, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{80=>:enemy}, 80, "s:+n", true], [{52=>nil}, 52, "s:+n", false], [{60=>nil}, 60, "s:+n", false], [{62=>nil}, 62, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{70=>nil}, 70, "s:+n", false], [{71=>nil}, 71, "s:+n", false], [{78=>nil}, 78, "s:+n", false], [{80=>nil}, 80, "s:+n", false]], 62=>[[{53=>:enemy}, 53, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{71=>:enemy}, 71, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{53=>nil}, 53, "s:+n", false], [{61=>nil}, 61, "s:+n", false], [{70=>nil}, 70, "s:+n", false], [{71=>nil}, 71, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], 63=>[[{54=>:enemy}, 54, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{72=>:enemy}, 72, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{54=>nil}, 54, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{72=>nil}, 72, "s:+n", false], [{73=>nil}, 73, "s:+n", false]], 64=>[[{55=>:enemy}, 55, "s:+n", true], [{63=>:enemy}, 63, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{72=>:enemy}, 72, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{55=>nil}, 55, "s:+n", false], [{63=>nil}, 63, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{72=>nil}, 72, "s:+n", false], [{73=>nil}, 73, "s:+n", false], [{74=>nil}, 74, "s:+n", false]], 65=>[[{56=>:enemy}, 56, "s:+n", true], [{64=>:enemy}, 64, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{56=>nil}, 56, "s:+n", false], [{64=>nil}, 64, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{73=>nil}, 73, "s:+n", false], [{74=>nil}, 74, "s:+n", false], [{75=>nil}, 75, "s:+n", false]], 66=>[[{57=>:enemy}, 57, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{57=>nil}, 57, "s:+n", false], [{65=>nil}, 65, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{74=>nil}, 74, "s:+n", false], [{75=>nil}, 75, "s:+n", false], [{76=>nil}, 76, "s:+n", false]], 67=>[[{58=>:enemy}, 58, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{58=>nil}, 58, "s:+n", false], [{66=>nil}, 66, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{75=>nil}, 75, "s:+n", false], [{76=>nil}, 76, "s:+n", false], [{77=>nil}, 77, "s:+n", false]], 68=>[[{59=>:enemy}, 59, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{59=>nil}, 59, "s:+n", false], [{67=>nil}, 67, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{76=>nil}, 76, "s:+n", false], [{77=>nil}, 77, "s:+n", false], [{78=>nil}, 78, "s:+n", false]], 69=>[[{60=>:enemy}, 60, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{60=>nil}, 60, "s:+n", false], [{68=>nil}, 68, "s:+n", false], [{70=>nil}, 70, "s:+n", false], [{77=>nil}, 77, "s:+n", false], [{78=>nil}, 78, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], 70=>[[{61=>:enemy}, 61, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{71=>:enemy}, 71, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{80=>:enemy}, 80, "s:+n", true], [{61=>nil}, 61, "s:+n", false], [{69=>nil}, 69, "s:+n", false], [{71=>nil}, 71, "s:+n", false], [{78=>nil}, 78, "s:+n", false], [{79=>nil}, 79, "s:+n", false], [{80=>nil}, 80, "s:+n", false]], 71=>[[{62=>:enemy}, 62, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{80=>:enemy}, 80, "s:+n", true], [{62=>nil}, 62, "s:+n", false], [{70=>nil}, 70, "s:+n", false], [{79=>nil}, 79, "s:+n", false], [{80=>nil}, 80, "s:+n", false]], 72=>[[{63=>:enemy}, 63, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{63=>nil}, 63, "s:+n", false], [{73=>nil}, 73, "s:+n", false]], 73=>[[{64=>:enemy}, 64, "s:+n", true], [{72=>:enemy}, 72, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{64=>nil}, 64, "s:+n", false], [{72=>nil}, 72, "s:+n", false], [{74=>nil}, 74, "s:+n", false]], 74=>[[{65=>:enemy}, 65, "s:+n", true], [{73=>:enemy}, 73, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{65=>nil}, 65, "s:+n", false], [{73=>nil}, 73, "s:+n", false], [{75=>nil}, 75, "s:+n", false]], 75=>[[{66=>:enemy}, 66, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{66=>nil}, 66, "s:+n", false], [{74=>nil}, 74, "s:+n", false], [{76=>nil}, 76, "s:+n", false]], 76=>[[{67=>:enemy}, 67, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{67=>nil}, 67, "s:+n", false], [{75=>nil}, 75, "s:+n", false], [{77=>nil}, 77, "s:+n", false]], 77=>[[{68=>:enemy}, 68, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{68=>nil}, 68, "s:+n", false], [{76=>nil}, 76, "s:+n", false], [{78=>nil}, 78, "s:+n", false]], 78=>[[{69=>:enemy}, 69, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{69=>nil}, 69, "s:+n", false], [{77=>nil}, 77, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], 79=>[[{70=>:enemy}, 70, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{80=>:enemy}, 80, "s:+n", true], [{70=>nil}, 70, "s:+n", false], [{78=>nil}, 78, "s:+n", false], [{80=>nil}, 80, "s:+n", false]], 80=>[[{71=>:enemy}, 71, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{71=>nil}, 71, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], nil=>[]}, "s:+p"=>{0=>[[{1=>:enemy}, 1, "s:+p", true], [{9=>:enemy}, 9, "s:+p", true], [{10=>:enemy}, 10, "s:+p", true], [{1=>nil}, 1, "s:+p", false], [{9=>nil}, 9, "s:+p", false], [{10=>nil}, 10, "s:+p", false]], 1=>[[{0=>:enemy}, 0, "s:+p", true], [{2=>:enemy}, 2, "s:+p", true], [{9=>:enemy}, 9, "s:+p", true], [{10=>:enemy}, 10, "s:+p", true], [{11=>:enemy}, 11, "s:+p", true], [{0=>nil}, 0, "s:+p", false], [{2=>nil}, 2, "s:+p", false], [{9=>nil}, 9, "s:+p", false], [{10=>nil}, 10, "s:+p", false], [{11=>nil}, 11, "s:+p", false]], 2=>[[{1=>:enemy}, 1, "s:+p", true], [{3=>:enemy}, 3, "s:+p", true], [{10=>:enemy}, 10, "s:+p", true], [{11=>:enemy}, 11, "s:+p", true], [{12=>:enemy}, 12, "s:+p", true], [{1=>nil}, 1, "s:+p", false], [{3=>nil}, 3, "s:+p", false], [{10=>nil}, 10, "s:+p", false], [{11=>nil}, 11, "s:+p", false], [{12=>nil}, 12, "s:+p", false]], 3=>[[{2=>:enemy}, 2, "s:+p", true], [{4=>:enemy}, 4, "s:+p", true], [{11=>:enemy}, 11, "s:+p", true], [{12=>:enemy}, 12, "s:+p", true], [{13=>:enemy}, 13, "s:+p", true], [{2=>nil}, 2, "s:+p", false], [{4=>nil}, 4, "s:+p", false], [{11=>nil}, 11, "s:+p", false], [{12=>nil}, 12, "s:+p", false], [{13=>nil}, 13, "s:+p", false]], 4=>[[{3=>:enemy}, 3, "s:+p", true], [{5=>:enemy}, 5, "s:+p", true], [{12=>:enemy}, 12, "s:+p", true], [{13=>:enemy}, 13, "s:+p", true], [{14=>:enemy}, 14, "s:+p", true], [{3=>nil}, 3, "s:+p", false], [{5=>nil}, 5, "s:+p", false], [{12=>nil}, 12, "s:+p", false], [{13=>nil}, 13, "s:+p", false], [{14=>nil}, 14, "s:+p", false]], 5=>[[{4=>:enemy}, 4, "s:+p", true], [{6=>:enemy}, 6, "s:+p", true], [{13=>:enemy}, 13, "s:+p", true], [{14=>:enemy}, 14, "s:+p", true], [{15=>:enemy}, 15, "s:+p", true], [{4=>nil}, 4, "s:+p", false], [{6=>nil}, 6, "s:+p", false], [{13=>nil}, 13, "s:+p", false], [{14=>nil}, 14, "s:+p", false], [{15=>nil}, 15, "s:+p", false]], 6=>[[{5=>:enemy}, 5, "s:+p", true], [{7=>:enemy}, 7, "s:+p", true], [{14=>:enemy}, 14, "s:+p", true], [{15=>:enemy}, 15, "s:+p", true], [{16=>:enemy}, 16, "s:+p", true], [{5=>nil}, 5, "s:+p", false], [{7=>nil}, 7, "s:+p", false], [{14=>nil}, 14, "s:+p", false], [{15=>nil}, 15, "s:+p", false], [{16=>nil}, 16, "s:+p", false]], 7=>[[{6=>:enemy}, 6, "s:+p", true], [{8=>:enemy}, 8, "s:+p", true], [{15=>:enemy}, 15, "s:+p", true], [{16=>:enemy}, 16, "s:+p", true], [{17=>:enemy}, 17, "s:+p", true], [{6=>nil}, 6, "s:+p", false], [{8=>nil}, 8, "s:+p", false], [{15=>nil}, 15, "s:+p", false], [{16=>nil}, 16, "s:+p", false], [{17=>nil}, 17, "s:+p", false]], 8=>[[{7=>:enemy}, 7, "s:+p", true], [{16=>:enemy}, 16, "s:+p", true], [{17=>:enemy}, 17, "s:+p", true], [{7=>nil}, 7, "s:+p", false], [{16=>nil}, 16, "s:+p", false], [{17=>nil}, 17, "s:+p", false]], 9=>[[{0=>:enemy}, 0, "s:+p", true], [{10=>:enemy}, 10, "s:+p", true], [{18=>:enemy}, 18, "s:+p", true], [{19=>:enemy}, 19, "s:+p", true], [{0=>nil}, 0, "s:+p", false], [{10=>nil}, 10, "s:+p", false], [{18=>nil}, 18, "s:+p", false], [{19=>nil}, 19, "s:+p", false]], 10=>[[{1=>:enemy}, 1, "s:+p", true], [{9=>:enemy}, 9, "s:+p", true], [{11=>:enemy}, 11, "s:+p", true], [{18=>:enemy}, 18, "s:+p", true], [{19=>:enemy}, 19, "s:+p", true], [{20=>:enemy}, 20, "s:+p", true], [{1=>nil}, 1, "s:+p", false], [{9=>nil}, 9, "s:+p", false], [{11=>nil}, 11, "s:+p", false], [{18=>nil}, 18, "s:+p", false], [{19=>nil}, 19, "s:+p", false], [{20=>nil}, 20, "s:+p", false]], 11=>[[{2=>:enemy}, 2, "s:+p", true], [{10=>:enemy}, 10, "s:+p", true], [{12=>:enemy}, 12, "s:+p", true], [{19=>:enemy}, 19, "s:+p", true], [{20=>:enemy}, 20, "s:+p", true], [{21=>:enemy}, 21, "s:+p", true], [{2=>nil}, 2, "s:+p", false], [{10=>nil}, 10, "s:+p", false], [{12=>nil}, 12, "s:+p", false], [{19=>nil}, 19, "s:+p", false], [{20=>nil}, 20, "s:+p", false], [{21=>nil}, 21, "s:+p", false]], 12=>[[{3=>:enemy}, 3, "s:+p", true], [{11=>:enemy}, 11, "s:+p", true], [{13=>:enemy}, 13, "s:+p", true], [{20=>:enemy}, 20, "s:+p", true], [{21=>:enemy}, 21, "s:+p", true], [{22=>:enemy}, 22, "s:+p", true], [{3=>nil}, 3, "s:+p", false], [{11=>nil}, 11, "s:+p", false], [{13=>nil}, 13, "s:+p", false], [{20=>nil}, 20, "s:+p", false], [{21=>nil}, 21, "s:+p", false], [{22=>nil}, 22, "s:+p", false]], 13=>[[{4=>:enemy}, 4, "s:+p", true], [{12=>:enemy}, 12, "s:+p", true], [{14=>:enemy}, 14, "s:+p", true], [{21=>:enemy}, 21, "s:+p", true], [{22=>:enemy}, 22, "s:+p", true], [{23=>:enemy}, 23, "s:+p", true], [{4=>nil}, 4, "s:+p", false], [{12=>nil}, 12, "s:+p", false], [{14=>nil}, 14, "s:+p", false], [{21=>nil}, 21, "s:+p", false], [{22=>nil}, 22, "s:+p", false], [{23=>nil}, 23, "s:+p", false]], 14=>[[{5=>:enemy}, 5, "s:+p", true], [{13=>:enemy}, 13, "s:+p", true], [{15=>:enemy}, 15, "s:+p", true], [{22=>:enemy}, 22, "s:+p", true], [{23=>:enemy}, 23, "s:+p", true], [{24=>:enemy}, 24, "s:+p", true], [{5=>nil}, 5, "s:+p", false], [{13=>nil}, 13, "s:+p", false], [{15=>nil}, 15, "s:+p", false], [{22=>nil}, 22, "s:+p", false], [{23=>nil}, 23, "s:+p", false], [{24=>nil}, 24, "s:+p", false]], 15=>[[{6=>:enemy}, 6, "s:+p", true], [{14=>:enemy}, 14, "s:+p", true], [{16=>:enemy}, 16, "s:+p", true], [{23=>:enemy}, 23, "s:+p", true], [{24=>:enemy}, 24, "s:+p", true], [{25=>:enemy}, 25, "s:+p", true], [{6=>nil}, 6, "s:+p", false], [{14=>nil}, 14, "s:+p", false], [{16=>nil}, 16, "s:+p", false], [{23=>nil}, 23, "s:+p", false], [{24=>nil}, 24, "s:+p", false], [{25=>nil}, 25, "s:+p", false]], 16=>[[{7=>:enemy}, 7, "s:+p", true], [{15=>:enemy}, 15, "s:+p", true], [{17=>:enemy}, 17, "s:+p", true], [{24=>:enemy}, 24, "s:+p", true], [{25=>:enemy}, 25, "s:+p", true], [{26=>:enemy}, 26, "s:+p", true], [{7=>nil}, 7, "s:+p", false], [{15=>nil}, 15, "s:+p", false], [{17=>nil}, 17, "s:+p", false], [{24=>nil}, 24, "s:+p", false], [{25=>nil}, 25, "s:+p", false], [{26=>nil}, 26, "s:+p", false]], 17=>[[{8=>:enemy}, 8, "s:+p", true], [{16=>:enemy}, 16, "s:+p", true], [{25=>:enemy}, 25, "s:+p", true], [{26=>:enemy}, 26, "s:+p", true], [{8=>nil}, 8, "s:+p", false], [{16=>nil}, 16, "s:+p", false], [{25=>nil}, 25, "s:+p", false], [{26=>nil}, 26, "s:+p", false]], 18=>[[{9=>:enemy}, 9, "s:+p", true], [{19=>:enemy}, 19, "s:+p", true], [{27=>:enemy}, 27, "s:+p", true], [{28=>:enemy}, 28, "s:+p", true], [{9=>nil}, 9, "s:+p", false], [{19=>nil}, 19, "s:+p", false], [{27=>nil}, 27, "s:+p", false], [{28=>nil}, 28, "s:+p", false]], 19=>[[{10=>:enemy}, 10, "s:+p", true], [{18=>:enemy}, 18, "s:+p", true], [{20=>:enemy}, 20, "s:+p", true], [{27=>:enemy}, 27, "s:+p", true], [{28=>:enemy}, 28, "s:+p", true], [{29=>:enemy}, 29, "s:+p", true], [{10=>nil}, 10, "s:+p", false], [{18=>nil}, 18, "s:+p", false], [{20=>nil}, 20, "s:+p", false], [{27=>nil}, 27, "s:+p", false], [{28=>nil}, 28, "s:+p", false], [{29=>nil}, 29, "s:+p", false]], 20=>[[{11=>:enemy}, 11, "s:+p", true], [{19=>:enemy}, 19, "s:+p", true], [{21=>:enemy}, 21, "s:+p", true], [{28=>:enemy}, 28, "s:+p", true], [{29=>:enemy}, 29, "s:+p", true], [{30=>:enemy}, 30, "s:+p", true], [{11=>nil}, 11, "s:+p", false], [{19=>nil}, 19, "s:+p", false], [{21=>nil}, 21, "s:+p", false], [{28=>nil}, 28, "s:+p", false], [{29=>nil}, 29, "s:+p", false], [{30=>nil}, 30, "s:+p", false]], 21=>[[{12=>:enemy}, 12, "s:+p", true], [{20=>:enemy}, 20, "s:+p", true], [{22=>:enemy}, 22, "s:+p", true], [{29=>:enemy}, 29, "s:+p", true], [{30=>:enemy}, 30, "s:+p", true], [{31=>:enemy}, 31, "s:+p", true], [{12=>nil}, 12, "s:+p", false], [{20=>nil}, 20, "s:+p", false], [{22=>nil}, 22, "s:+p", false], [{29=>nil}, 29, "s:+p", false], [{30=>nil}, 30, "s:+p", false], [{31=>nil}, 31, "s:+p", false]], 22=>[[{13=>:enemy}, 13, "s:+p", true], [{21=>:enemy}, 21, "s:+p", true], [{23=>:enemy}, 23, "s:+p", true], [{30=>:enemy}, 30, "s:+p", true], [{31=>:enemy}, 31, "s:+p", true], [{32=>:enemy}, 32, "s:+p", true], [{13=>nil}, 13, "s:+p", false], [{21=>nil}, 21, "s:+p", false], [{23=>nil}, 23, "s:+p", false], [{30=>nil}, 30, "s:+p", false], [{31=>nil}, 31, "s:+p", false], [{32=>nil}, 32, "s:+p", false]], 23=>[[{14=>:enemy}, 14, "s:+p", true], [{22=>:enemy}, 22, "s:+p", true], [{24=>:enemy}, 24, "s:+p", true], [{31=>:enemy}, 31, "s:+p", true], [{32=>:enemy}, 32, "s:+p", true], [{33=>:enemy}, 33, "s:+p", true], [{14=>nil}, 14, "s:+p", false], [{22=>nil}, 22, "s:+p", false], [{24=>nil}, 24, "s:+p", false], [{31=>nil}, 31, "s:+p", false], [{32=>nil}, 32, "s:+p", false], [{33=>nil}, 33, "s:+p", false]], 24=>[[{15=>:enemy}, 15, "s:+p", true], [{23=>:enemy}, 23, "s:+p", true], [{25=>:enemy}, 25, "s:+p", true], [{32=>:enemy}, 32, "s:+p", true], [{33=>:enemy}, 33, "s:+p", true], [{34=>:enemy}, 34, "s:+p", true], [{15=>nil}, 15, "s:+p", false], [{23=>nil}, 23, "s:+p", false], [{25=>nil}, 25, "s:+p", false], [{32=>nil}, 32, "s:+p", false], [{33=>nil}, 33, "s:+p", false], [{34=>nil}, 34, "s:+p", false]], 25=>[[{16=>:enemy}, 16, "s:+p", true], [{24=>:enemy}, 24, "s:+p", true], [{26=>:enemy}, 26, "s:+p", true], [{33=>:enemy}, 33, "s:+p", true], [{34=>:enemy}, 34, "s:+p", true], [{35=>:enemy}, 35, "s:+p", true], [{16=>nil}, 16, "s:+p", false], [{24=>nil}, 24, "s:+p", false], [{26=>nil}, 26, "s:+p", false], [{33=>nil}, 33, "s:+p", false], [{34=>nil}, 34, "s:+p", false], [{35=>nil}, 35, "s:+p", false]], 26=>[[{17=>:enemy}, 17, "s:+p", true], [{25=>:enemy}, 25, "s:+p", true], [{34=>:enemy}, 34, "s:+p", true], [{35=>:enemy}, 35, "s:+p", true], [{17=>nil}, 17, "s:+p", false], [{25=>nil}, 25, "s:+p", false], [{34=>nil}, 34, "s:+p", false], [{35=>nil}, 35, "s:+p", false]], 27=>[[{18=>:enemy}, 18, "s:+p", true], [{28=>:enemy}, 28, "s:+p", true], [{36=>:enemy}, 36, "s:+p", true], [{37=>:enemy}, 37, "s:+p", true], [{18=>nil}, 18, "s:+p", false], [{28=>nil}, 28, "s:+p", false], [{36=>nil}, 36, "s:+p", false], [{37=>nil}, 37, "s:+p", false]], 28=>[[{19=>:enemy}, 19, "s:+p", true], [{27=>:enemy}, 27, "s:+p", true], [{29=>:enemy}, 29, "s:+p", true], [{36=>:enemy}, 36, "s:+p", true], [{37=>:enemy}, 37, "s:+p", true], [{38=>:enemy}, 38, "s:+p", true], [{19=>nil}, 19, "s:+p", false], [{27=>nil}, 27, "s:+p", false], [{29=>nil}, 29, "s:+p", false], [{36=>nil}, 36, "s:+p", false], [{37=>nil}, 37, "s:+p", false], [{38=>nil}, 38, "s:+p", false]], 29=>[[{20=>:enemy}, 20, "s:+p", true], [{28=>:enemy}, 28, "s:+p", true], [{30=>:enemy}, 30, "s:+p", true], [{37=>:enemy}, 37, "s:+p", true], [{38=>:enemy}, 38, "s:+p", true], [{39=>:enemy}, 39, "s:+p", true], [{20=>nil}, 20, "s:+p", false], [{28=>nil}, 28, "s:+p", false], [{30=>nil}, 30, "s:+p", false], [{37=>nil}, 37, "s:+p", false], [{38=>nil}, 38, "s:+p", false], [{39=>nil}, 39, "s:+p", false]], 30=>[[{21=>:enemy}, 21, "s:+p", true], [{29=>:enemy}, 29, "s:+p", true], [{31=>:enemy}, 31, "s:+p", true], [{38=>:enemy}, 38, "s:+p", true], [{39=>:enemy}, 39, "s:+p", true], [{40=>:enemy}, 40, "s:+p", true], [{21=>nil}, 21, "s:+p", false], [{29=>nil}, 29, "s:+p", false], [{31=>nil}, 31, "s:+p", false], [{38=>nil}, 38, "s:+p", false], [{39=>nil}, 39, "s:+p", false], [{40=>nil}, 40, "s:+p", false]], 31=>[[{22=>:enemy}, 22, "s:+p", true], [{30=>:enemy}, 30, "s:+p", true], [{32=>:enemy}, 32, "s:+p", true], [{39=>:enemy}, 39, "s:+p", true], [{40=>:enemy}, 40, "s:+p", true], [{41=>:enemy}, 41, "s:+p", true], [{22=>nil}, 22, "s:+p", false], [{30=>nil}, 30, "s:+p", false], [{32=>nil}, 32, "s:+p", false], [{39=>nil}, 39, "s:+p", false], [{40=>nil}, 40, "s:+p", false], [{41=>nil}, 41, "s:+p", false]], 32=>[[{23=>:enemy}, 23, "s:+p", true], [{31=>:enemy}, 31, "s:+p", true], [{33=>:enemy}, 33, "s:+p", true], [{40=>:enemy}, 40, "s:+p", true], [{41=>:enemy}, 41, "s:+p", true], [{42=>:enemy}, 42, "s:+p", true], [{23=>nil}, 23, "s:+p", false], [{31=>nil}, 31, "s:+p", false], [{33=>nil}, 33, "s:+p", false], [{40=>nil}, 40, "s:+p", false], [{41=>nil}, 41, "s:+p", false], [{42=>nil}, 42, "s:+p", false]], 33=>[[{24=>:enemy}, 24, "s:+p", true], [{32=>:enemy}, 32, "s:+p", true], [{34=>:enemy}, 34, "s:+p", true], [{41=>:enemy}, 41, "s:+p", true], [{42=>:enemy}, 42, "s:+p", true], [{43=>:enemy}, 43, "s:+p", true], [{24=>nil}, 24, "s:+p", false], [{32=>nil}, 32, "s:+p", false], [{34=>nil}, 34, "s:+p", false], [{41=>nil}, 41, "s:+p", false], [{42=>nil}, 42, "s:+p", false], [{43=>nil}, 43, "s:+p", false]], 34=>[[{25=>:enemy}, 25, "s:+p", true], [{33=>:enemy}, 33, "s:+p", true], [{35=>:enemy}, 35, "s:+p", true], [{42=>:enemy}, 42, "s:+p", true], [{43=>:enemy}, 43, "s:+p", true], [{44=>:enemy}, 44, "s:+p", true], [{25=>nil}, 25, "s:+p", false], [{33=>nil}, 33, "s:+p", false], [{35=>nil}, 35, "s:+p", false], [{42=>nil}, 42, "s:+p", false], [{43=>nil}, 43, "s:+p", false], [{44=>nil}, 44, "s:+p", false]], 35=>[[{26=>:enemy}, 26, "s:+p", true], [{34=>:enemy}, 34, "s:+p", true], [{43=>:enemy}, 43, "s:+p", true], [{44=>:enemy}, 44, "s:+p", true], [{26=>nil}, 26, "s:+p", false], [{34=>nil}, 34, "s:+p", false], [{43=>nil}, 43, "s:+p", false], [{44=>nil}, 44, "s:+p", false]], 36=>[[{27=>:enemy}, 27, "s:+p", true], [{37=>:enemy}, 37, "s:+p", true], [{45=>:enemy}, 45, "s:+p", true], [{46=>:enemy}, 46, "s:+p", true], [{27=>nil}, 27, "s:+p", false], [{37=>nil}, 37, "s:+p", false], [{45=>nil}, 45, "s:+p", false], [{46=>nil}, 46, "s:+p", false]], 37=>[[{28=>:enemy}, 28, "s:+p", true], [{36=>:enemy}, 36, "s:+p", true], [{38=>:enemy}, 38, "s:+p", true], [{45=>:enemy}, 45, "s:+p", true], [{46=>:enemy}, 46, "s:+p", true], [{47=>:enemy}, 47, "s:+p", true], [{28=>nil}, 28, "s:+p", false], [{36=>nil}, 36, "s:+p", false], [{38=>nil}, 38, "s:+p", false], [{45=>nil}, 45, "s:+p", false], [{46=>nil}, 46, "s:+p", false], [{47=>nil}, 47, "s:+p", false]], 38=>[[{29=>:enemy}, 29, "s:+p", true], [{37=>:enemy}, 37, "s:+p", true], [{39=>:enemy}, 39, "s:+p", true], [{46=>:enemy}, 46, "s:+p", true], [{47=>:enemy}, 47, "s:+p", true], [{48=>:enemy}, 48, "s:+p", true], [{29=>nil}, 29, "s:+p", false], [{37=>nil}, 37, "s:+p", false], [{39=>nil}, 39, "s:+p", false], [{46=>nil}, 46, "s:+p", false], [{47=>nil}, 47, "s:+p", false], [{48=>nil}, 48, "s:+p", false]], 39=>[[{30=>:enemy}, 30, "s:+p", true], [{38=>:enemy}, 38, "s:+p", true], [{40=>:enemy}, 40, "s:+p", true], [{47=>:enemy}, 47, "s:+p", true], [{48=>:enemy}, 48, "s:+p", true], [{49=>:enemy}, 49, "s:+p", true], [{30=>nil}, 30, "s:+p", false], [{38=>nil}, 38, "s:+p", false], [{40=>nil}, 40, "s:+p", false], [{47=>nil}, 47, "s:+p", false], [{48=>nil}, 48, "s:+p", false], [{49=>nil}, 49, "s:+p", false]], 40=>[[{31=>:enemy}, 31, "s:+p", true], [{39=>:enemy}, 39, "s:+p", true], [{41=>:enemy}, 41, "s:+p", true], [{48=>:enemy}, 48, "s:+p", true], [{49=>:enemy}, 49, "s:+p", true], [{50=>:enemy}, 50, "s:+p", true], [{31=>nil}, 31, "s:+p", false], [{39=>nil}, 39, "s:+p", false], [{41=>nil}, 41, "s:+p", false], [{48=>nil}, 48, "s:+p", false], [{49=>nil}, 49, "s:+p", false], [{50=>nil}, 50, "s:+p", false]], 41=>[[{32=>:enemy}, 32, "s:+p", true], [{40=>:enemy}, 40, "s:+p", true], [{42=>:enemy}, 42, "s:+p", true], [{49=>:enemy}, 49, "s:+p", true], [{50=>:enemy}, 50, "s:+p", true], [{51=>:enemy}, 51, "s:+p", true], [{32=>nil}, 32, "s:+p", false], [{40=>nil}, 40, "s:+p", false], [{42=>nil}, 42, "s:+p", false], [{49=>nil}, 49, "s:+p", false], [{50=>nil}, 50, "s:+p", false], [{51=>nil}, 51, "s:+p", false]], 42=>[[{33=>:enemy}, 33, "s:+p", true], [{41=>:enemy}, 41, "s:+p", true], [{43=>:enemy}, 43, "s:+p", true], [{50=>:enemy}, 50, "s:+p", true], [{51=>:enemy}, 51, "s:+p", true], [{52=>:enemy}, 52, "s:+p", true], [{33=>nil}, 33, "s:+p", false], [{41=>nil}, 41, "s:+p", false], [{43=>nil}, 43, "s:+p", false], [{50=>nil}, 50, "s:+p", false], [{51=>nil}, 51, "s:+p", false], [{52=>nil}, 52, "s:+p", false]], 43=>[[{34=>:enemy}, 34, "s:+p", true], [{42=>:enemy}, 42, "s:+p", true], [{44=>:enemy}, 44, "s:+p", true], [{51=>:enemy}, 51, "s:+p", true], [{52=>:enemy}, 52, "s:+p", true], [{53=>:enemy}, 53, "s:+p", true], [{34=>nil}, 34, "s:+p", false], [{42=>nil}, 42, "s:+p", false], [{44=>nil}, 44, "s:+p", false], [{51=>nil}, 51, "s:+p", false], [{52=>nil}, 52, "s:+p", false], [{53=>nil}, 53, "s:+p", false]], 44=>[[{35=>:enemy}, 35, "s:+p", true], [{43=>:enemy}, 43, "s:+p", true], [{52=>:enemy}, 52, "s:+p", true], [{53=>:enemy}, 53, "s:+p", true], [{35=>nil}, 35, "s:+p", false], [{43=>nil}, 43, "s:+p", false], [{52=>nil}, 52, "s:+p", false], [{53=>nil}, 53, "s:+p", false]], 45=>[[{36=>:enemy}, 36, "s:+p", true], [{46=>:enemy}, 46, "s:+p", true], [{54=>:enemy}, 54, "s:+p", true], [{55=>:enemy}, 55, "s:+p", true], [{36=>nil}, 36, "s:+p", false], [{46=>nil}, 46, "s:+p", false], [{54=>nil}, 54, "s:+p", false], [{55=>nil}, 55, "s:+p", false]], 46=>[[{37=>:enemy}, 37, "s:+p", true], [{45=>:enemy}, 45, "s:+p", true], [{47=>:enemy}, 47, "s:+p", true], [{54=>:enemy}, 54, "s:+p", true], [{55=>:enemy}, 55, "s:+p", true], [{56=>:enemy}, 56, "s:+p", true], [{37=>nil}, 37, "s:+p", false], [{45=>nil}, 45, "s:+p", false], [{47=>nil}, 47, "s:+p", false], [{54=>nil}, 54, "s:+p", false], [{55=>nil}, 55, "s:+p", false], [{56=>nil}, 56, "s:+p", false]], 47=>[[{38=>:enemy}, 38, "s:+p", true], [{46=>:enemy}, 46, "s:+p", true], [{48=>:enemy}, 48, "s:+p", true], [{55=>:enemy}, 55, "s:+p", true], [{56=>:enemy}, 56, "s:+p", true], [{57=>:enemy}, 57, "s:+p", true], [{38=>nil}, 38, "s:+p", false], [{46=>nil}, 46, "s:+p", false], [{48=>nil}, 48, "s:+p", false], [{55=>nil}, 55, "s:+p", false], [{56=>nil}, 56, "s:+p", false], [{57=>nil}, 57, "s:+p", false]], 48=>[[{39=>:enemy}, 39, "s:+p", true], [{47=>:enemy}, 47, "s:+p", true], [{49=>:enemy}, 49, "s:+p", true], [{56=>:enemy}, 56, "s:+p", true], [{57=>:enemy}, 57, "s:+p", true], [{58=>:enemy}, 58, "s:+p", true], [{39=>nil}, 39, "s:+p", false], [{47=>nil}, 47, "s:+p", false], [{49=>nil}, 49, "s:+p", false], [{56=>nil}, 56, "s:+p", false], [{57=>nil}, 57, "s:+p", false], [{58=>nil}, 58, "s:+p", false]], 49=>[[{40=>:enemy}, 40, "s:+p", true], [{48=>:enemy}, 48, "s:+p", true], [{50=>:enemy}, 50, "s:+p", true], [{57=>:enemy}, 57, "s:+p", true], [{58=>:enemy}, 58, "s:+p", true], [{59=>:enemy}, 59, "s:+p", true], [{40=>nil}, 40, "s:+p", false], [{48=>nil}, 48, "s:+p", false], [{50=>nil}, 50, "s:+p", false], [{57=>nil}, 57, "s:+p", false], [{58=>nil}, 58, "s:+p", false], [{59=>nil}, 59, "s:+p", false]], 50=>[[{41=>:enemy}, 41, "s:+p", true], [{49=>:enemy}, 49, "s:+p", true], [{51=>:enemy}, 51, "s:+p", true], [{58=>:enemy}, 58, "s:+p", true], [{59=>:enemy}, 59, "s:+p", true], [{60=>:enemy}, 60, "s:+p", true], [{41=>nil}, 41, "s:+p", false], [{49=>nil}, 49, "s:+p", false], [{51=>nil}, 51, "s:+p", false], [{58=>nil}, 58, "s:+p", false], [{59=>nil}, 59, "s:+p", false], [{60=>nil}, 60, "s:+p", false]], 51=>[[{42=>:enemy}, 42, "s:+p", true], [{50=>:enemy}, 50, "s:+p", true], [{52=>:enemy}, 52, "s:+p", true], [{59=>:enemy}, 59, "s:+p", true], [{60=>:enemy}, 60, "s:+p", true], [{61=>:enemy}, 61, "s:+p", true], [{42=>nil}, 42, "s:+p", false], [{50=>nil}, 50, "s:+p", false], [{52=>nil}, 52, "s:+p", false], [{59=>nil}, 59, "s:+p", false], [{60=>nil}, 60, "s:+p", false], [{61=>nil}, 61, "s:+p", false]], 52=>[[{43=>:enemy}, 43, "s:+p", true], [{51=>:enemy}, 51, "s:+p", true], [{53=>:enemy}, 53, "s:+p", true], [{60=>:enemy}, 60, "s:+p", true], [{61=>:enemy}, 61, "s:+p", true], [{62=>:enemy}, 62, "s:+p", true], [{43=>nil}, 43, "s:+p", false], [{51=>nil}, 51, "s:+p", false], [{53=>nil}, 53, "s:+p", false], [{60=>nil}, 60, "s:+p", false], [{61=>nil}, 61, "s:+p", false], [{62=>nil}, 62, "s:+p", false]], 53=>[[{44=>:enemy}, 44, "s:+p", true], [{52=>:enemy}, 52, "s:+p", true], [{61=>:enemy}, 61, "s:+p", true], [{62=>:enemy}, 62, "s:+p", true], [{44=>nil}, 44, "s:+p", false], [{52=>nil}, 52, "s:+p", false], [{61=>nil}, 61, "s:+p", false], [{62=>nil}, 62, "s:+p", false]], 54=>[[{45=>:enemy}, 45, "s:+p", true], [{55=>:enemy}, 55, "s:+p", true], [{63=>:enemy}, 63, "s:+p", true], [{64=>:enemy}, 64, "s:+p", true], [{45=>nil}, 45, "s:+p", false], [{55=>nil}, 55, "s:+p", false], [{63=>nil}, 63, "s:+p", false], [{64=>nil}, 64, "s:+p", false]], 55=>[[{46=>:enemy}, 46, "s:+p", true], [{54=>:enemy}, 54, "s:+p", true], [{56=>:enemy}, 56, "s:+p", true], [{63=>:enemy}, 63, "s:+p", true], [{64=>:enemy}, 64, "s:+p", true], [{65=>:enemy}, 65, "s:+p", true], [{46=>nil}, 46, "s:+p", false], [{54=>nil}, 54, "s:+p", false], [{56=>nil}, 56, "s:+p", false], [{63=>nil}, 63, "s:+p", false], [{64=>nil}, 64, "s:+p", false], [{65=>nil}, 65, "s:+p", false]], 56=>[[{47=>:enemy}, 47, "s:+p", true], [{55=>:enemy}, 55, "s:+p", true], [{57=>:enemy}, 57, "s:+p", true], [{64=>:enemy}, 64, "s:+p", true], [{65=>:enemy}, 65, "s:+p", true], [{66=>:enemy}, 66, "s:+p", true], [{47=>nil}, 47, "s:+p", false], [{55=>nil}, 55, "s:+p", false], [{57=>nil}, 57, "s:+p", false], [{64=>nil}, 64, "s:+p", false], [{65=>nil}, 65, "s:+p", false], [{66=>nil}, 66, "s:+p", false]], 57=>[[{48=>:enemy}, 48, "s:+p", true], [{56=>:enemy}, 56, "s:+p", true], [{58=>:enemy}, 58, "s:+p", true], [{65=>:enemy}, 65, "s:+p", true], [{66=>:enemy}, 66, "s:+p", true], [{67=>:enemy}, 67, "s:+p", true], [{48=>nil}, 48, "s:+p", false], [{56=>nil}, 56, "s:+p", false], [{58=>nil}, 58, "s:+p", false], [{65=>nil}, 65, "s:+p", false], [{66=>nil}, 66, "s:+p", false], [{67=>nil}, 67, "s:+p", false]], 58=>[[{49=>:enemy}, 49, "s:+p", true], [{57=>:enemy}, 57, "s:+p", true], [{59=>:enemy}, 59, "s:+p", true], [{66=>:enemy}, 66, "s:+p", true], [{67=>:enemy}, 67, "s:+p", true], [{68=>:enemy}, 68, "s:+p", true], [{49=>nil}, 49, "s:+p", false], [{57=>nil}, 57, "s:+p", false], [{59=>nil}, 59, "s:+p", false], [{66=>nil}, 66, "s:+p", false], [{67=>nil}, 67, "s:+p", false], [{68=>nil}, 68, "s:+p", false]], 59=>[[{50=>:enemy}, 50, "s:+p", true], [{58=>:enemy}, 58, "s:+p", true], [{60=>:enemy}, 60, "s:+p", true], [{67=>:enemy}, 67, "s:+p", true], [{68=>:enemy}, 68, "s:+p", true], [{69=>:enemy}, 69, "s:+p", true], [{50=>nil}, 50, "s:+p", false], [{58=>nil}, 58, "s:+p", false], [{60=>nil}, 60, "s:+p", false], [{67=>nil}, 67, "s:+p", false], [{68=>nil}, 68, "s:+p", false], [{69=>nil}, 69, "s:+p", false]], 60=>[[{51=>:enemy}, 51, "s:+p", true], [{59=>:enemy}, 59, "s:+p", true], [{61=>:enemy}, 61, "s:+p", true], [{68=>:enemy}, 68, "s:+p", true], [{69=>:enemy}, 69, "s:+p", true], [{70=>:enemy}, 70, "s:+p", true], [{51=>nil}, 51, "s:+p", false], [{59=>nil}, 59, "s:+p", false], [{61=>nil}, 61, "s:+p", false], [{68=>nil}, 68, "s:+p", false], [{69=>nil}, 69, "s:+p", false], [{70=>nil}, 70, "s:+p", false]], 61=>[[{52=>:enemy}, 52, "s:+p", true], [{60=>:enemy}, 60, "s:+p", true], [{62=>:enemy}, 62, "s:+p", true], [{69=>:enemy}, 69, "s:+p", true], [{70=>:enemy}, 70, "s:+p", true], [{71=>:enemy}, 71, "s:+p", true], [{52=>nil}, 52, "s:+p", false], [{60=>nil}, 60, "s:+p", false], [{62=>nil}, 62, "s:+p", false], [{69=>nil}, 69, "s:+p", false], [{70=>nil}, 70, "s:+p", false], [{71=>nil}, 71, "s:+p", false]], 62=>[[{53=>:enemy}, 53, "s:+p", true], [{61=>:enemy}, 61, "s:+p", true], [{70=>:enemy}, 70, "s:+p", true], [{71=>:enemy}, 71, "s:+p", true], [{53=>nil}, 53, "s:+p", false], [{61=>nil}, 61, "s:+p", false], [{70=>nil}, 70, "s:+p", false], [{71=>nil}, 71, "s:+p", false]], 63=>[[{54=>:enemy}, 54, "s:+p", true], [{64=>:enemy}, 64, "s:+p", true], [{72=>:enemy}, 72, "s:+p", true], [{73=>:enemy}, 73, "s:+p", true], [{54=>nil}, 54, "s:+p", false], [{64=>nil}, 64, "s:+p", false], [{72=>nil}, 72, "s:+p", false], [{73=>nil}, 73, "s:+p", false]], 64=>[[{55=>:enemy}, 55, "s:+p", true], [{63=>:enemy}, 63, "s:+p", true], [{65=>:enemy}, 65, "s:+p", true], [{72=>:enemy}, 72, "s:+p", true], [{73=>:enemy}, 73, "s:+p", true], [{74=>:enemy}, 74, "s:+p", true], [{55=>nil}, 55, "s:+p", false], [{63=>nil}, 63, "s:+p", false], [{65=>nil}, 65, "s:+p", false], [{72=>nil}, 72, "s:+p", false], [{73=>nil}, 73, "s:+p", false], [{74=>nil}, 74, "s:+p", false]], 65=>[[{56=>:enemy}, 56, "s:+p", true], [{64=>:enemy}, 64, "s:+p", true], [{66=>:enemy}, 66, "s:+p", true], [{73=>:enemy}, 73, "s:+p", true], [{74=>:enemy}, 74, "s:+p", true], [{75=>:enemy}, 75, "s:+p", true], [{56=>nil}, 56, "s:+p", false], [{64=>nil}, 64, "s:+p", false], [{66=>nil}, 66, "s:+p", false], [{73=>nil}, 73, "s:+p", false], [{74=>nil}, 74, "s:+p", false], [{75=>nil}, 75, "s:+p", false]], 66=>[[{57=>:enemy}, 57, "s:+p", true], [{65=>:enemy}, 65, "s:+p", true], [{67=>:enemy}, 67, "s:+p", true], [{74=>:enemy}, 74, "s:+p", true], [{75=>:enemy}, 75, "s:+p", true], [{76=>:enemy}, 76, "s:+p", true], [{57=>nil}, 57, "s:+p", false], [{65=>nil}, 65, "s:+p", false], [{67=>nil}, 67, "s:+p", false], [{74=>nil}, 74, "s:+p", false], [{75=>nil}, 75, "s:+p", false], [{76=>nil}, 76, "s:+p", false]], 67=>[[{58=>:enemy}, 58, "s:+p", true], [{66=>:enemy}, 66, "s:+p", true], [{68=>:enemy}, 68, "s:+p", true], [{75=>:enemy}, 75, "s:+p", true], [{76=>:enemy}, 76, "s:+p", true], [{77=>:enemy}, 77, "s:+p", true], [{58=>nil}, 58, "s:+p", false], [{66=>nil}, 66, "s:+p", false], [{68=>nil}, 68, "s:+p", false], [{75=>nil}, 75, "s:+p", false], [{76=>nil}, 76, "s:+p", false], [{77=>nil}, 77, "s:+p", false]], 68=>[[{59=>:enemy}, 59, "s:+p", true], [{67=>:enemy}, 67, "s:+p", true], [{69=>:enemy}, 69, "s:+p", true], [{76=>:enemy}, 76, "s:+p", true], [{77=>:enemy}, 77, "s:+p", true], [{78=>:enemy}, 78, "s:+p", true], [{59=>nil}, 59, "s:+p", false], [{67=>nil}, 67, "s:+p", false], [{69=>nil}, 69, "s:+p", false], [{76=>nil}, 76, "s:+p", false], [{77=>nil}, 77, "s:+p", false], [{78=>nil}, 78, "s:+p", false]], 69=>[[{60=>:enemy}, 60, "s:+p", true], [{68=>:enemy}, 68, "s:+p", true], [{70=>:enemy}, 70, "s:+p", true], [{77=>:enemy}, 77, "s:+p", true], [{78=>:enemy}, 78, "s:+p", true], [{79=>:enemy}, 79, "s:+p", true], [{60=>nil}, 60, "s:+p", false], [{68=>nil}, 68, "s:+p", false], [{70=>nil}, 70, "s:+p", false], [{77=>nil}, 77, "s:+p", false], [{78=>nil}, 78, "s:+p", false], [{79=>nil}, 79, "s:+p", false]], 70=>[[{61=>:enemy}, 61, "s:+p", true], [{69=>:enemy}, 69, "s:+p", true], [{71=>:enemy}, 71, "s:+p", true], [{78=>:enemy}, 78, "s:+p", true], [{79=>:enemy}, 79, "s:+p", true], [{80=>:enemy}, 80, "s:+p", true], [{61=>nil}, 61, "s:+p", false], [{69=>nil}, 69, "s:+p", false], [{71=>nil}, 71, "s:+p", false], [{78=>nil}, 78, "s:+p", false], [{79=>nil}, 79, "s:+p", false], [{80=>nil}, 80, "s:+p", false]], 71=>[[{62=>:enemy}, 62, "s:+p", true], [{70=>:enemy}, 70, "s:+p", true], [{79=>:enemy}, 79, "s:+p", true], [{80=>:enemy}, 80, "s:+p", true], [{62=>nil}, 62, "s:+p", false], [{70=>nil}, 70, "s:+p", false], [{79=>nil}, 79, "s:+p", false], [{80=>nil}, 80, "s:+p", false]], 72=>[[{63=>:enemy}, 63, "s:+p", true], [{73=>:enemy}, 73, "s:+p", true], [{63=>nil}, 63, "s:+p", false], [{73=>nil}, 73, "s:+p", false]], 73=>[[{64=>:enemy}, 64, "s:+p", true], [{72=>:enemy}, 72, "s:+p", true], [{74=>:enemy}, 74, "s:+p", true], [{64=>nil}, 64, "s:+p", false], [{72=>nil}, 72, "s:+p", false], [{74=>nil}, 74, "s:+p", false]], 74=>[[{65=>:enemy}, 65, "s:+p", true], [{73=>:enemy}, 73, "s:+p", true], [{75=>:enemy}, 75, "s:+p", true], [{65=>nil}, 65, "s:+p", false], [{73=>nil}, 73, "s:+p", false], [{75=>nil}, 75, "s:+p", false]], 75=>[[{66=>:enemy}, 66, "s:+p", true], [{74=>:enemy}, 74, "s:+p", true], [{76=>:enemy}, 76, "s:+p", true], [{66=>nil}, 66, "s:+p", false], [{74=>nil}, 74, "s:+p", false], [{76=>nil}, 76, "s:+p", false]], 76=>[[{67=>:enemy}, 67, "s:+p", true], [{75=>:enemy}, 75, "s:+p", true], [{77=>:enemy}, 77, "s:+p", true], [{67=>nil}, 67, "s:+p", false], [{75=>nil}, 75, "s:+p", false], [{77=>nil}, 77, "s:+p", false]], 77=>[[{68=>:enemy}, 68, "s:+p", true], [{76=>:enemy}, 76, "s:+p", true], [{78=>:enemy}, 78, "s:+p", true], [{68=>nil}, 68, "s:+p", false], [{76=>nil}, 76, "s:+p", false], [{78=>nil}, 78, "s:+p", false]], 78=>[[{69=>:enemy}, 69, "s:+p", true], [{77=>:enemy}, 77, "s:+p", true], [{79=>:enemy}, 79, "s:+p", true], [{69=>nil}, 69, "s:+p", false], [{77=>nil}, 77, "s:+p", false], [{79=>nil}, 79, "s:+p", false]], 79=>[[{70=>:enemy}, 70, "s:+p", true], [{78=>:enemy}, 78, "s:+p", true], [{80=>:enemy}, 80, "s:+p", true], [{70=>nil}, 70, "s:+p", false], [{78=>nil}, 78, "s:+p", false], [{80=>nil}, 80, "s:+p", false]], 80=>[[{71=>:enemy}, 71, "s:+p", true], [{79=>:enemy}, 79, "s:+p", true], [{71=>nil}, 71, "s:+p", false], [{79=>nil}, 79, "s:+p", false]], nil=>[]}, "s:+r"=>{0=>[[{1=>:enemy}, 1, "s:+r", true], [{9=>:enemy}, 9, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{1=>nil}, 1, "s:+r", false], [{1=>nil, 2=>:enemy}, 2, "s:+r", true], [{1=>nil, 2=>nil}, 2, "s:+r", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "s:+r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "s:+r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "s:+r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:+r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:+r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{9=>nil}, 9, "s:+r", false], [{9=>nil, 18=>:enemy}, 18, "s:+r", true], [{9=>nil, 18=>nil}, 18, "s:+r", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{10=>nil}, 10, "s:+r", false]], 1=>[[{0=>:enemy}, 0, "s:+r", true], [{2=>:enemy}, 2, "s:+r", true], [{9=>:enemy}, 9, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{0=>nil}, 0, "s:+r", false], [{2=>nil}, 2, "s:+r", false], [{2=>nil, 3=>:enemy}, 3, "s:+r", true], [{2=>nil, 3=>nil}, 3, "s:+r", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "s:+r", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "s:+r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "s:+r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "s:+r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:+r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:+r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:+r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:+r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{9=>nil}, 9, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{10=>nil, 19=>:enemy}, 19, "s:+r", true], [{10=>nil, 19=>nil}, 19, "s:+r", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{11=>nil}, 11, "s:+r", false]], 2=>[[{1=>:enemy}, 1, "s:+r", true], [{3=>:enemy}, 3, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{1=>nil}, 1, "s:+r", false], [{1=>nil, 0=>:enemy}, 0, "s:+r", true], [{1=>nil, 0=>nil}, 0, "s:+r", false], [{3=>nil}, 3, "s:+r", false], [{3=>nil, 4=>:enemy}, 4, "s:+r", true], [{3=>nil, 4=>nil}, 4, "s:+r", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "s:+r", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "s:+r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:+r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:+r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:+r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:+r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{11=>nil, 20=>:enemy}, 20, "s:+r", true], [{11=>nil, 20=>nil}, 20, "s:+r", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{12=>nil}, 12, "s:+r", false]], 3=>[[{2=>:enemy}, 2, "s:+r", true], [{4=>:enemy}, 4, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{2=>nil}, 2, "s:+r", false], [{2=>nil, 1=>:enemy}, 1, "s:+r", true], [{2=>nil, 1=>nil}, 1, "s:+r", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{4=>nil}, 4, "s:+r", false], [{4=>nil, 5=>:enemy}, 5, "s:+r", true], [{4=>nil, 5=>nil}, 5, "s:+r", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "s:+r", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "s:+r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:+r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:+r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{12=>nil, 21=>:enemy}, 21, "s:+r", true], [{12=>nil, 21=>nil}, 21, "s:+r", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{13=>nil}, 13, "s:+r", false]], 4=>[[{3=>:enemy}, 3, "s:+r", true], [{5=>:enemy}, 5, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{3=>nil}, 3, "s:+r", false], [{3=>nil, 2=>:enemy}, 2, "s:+r", true], [{3=>nil, 2=>nil}, 2, "s:+r", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "s:+r", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "s:+r", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{5=>nil}, 5, "s:+r", false], [{5=>nil, 6=>:enemy}, 6, "s:+r", true], [{5=>nil, 6=>nil}, 6, "s:+r", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "s:+r", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "s:+r", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{13=>nil, 22=>:enemy}, 22, "s:+r", true], [{13=>nil, 22=>nil}, 22, "s:+r", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{14=>nil}, 14, "s:+r", false]], 5=>[[{4=>:enemy}, 4, "s:+r", true], [{6=>:enemy}, 6, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{4=>nil}, 4, "s:+r", false], [{4=>nil, 3=>:enemy}, 3, "s:+r", true], [{4=>nil, 3=>nil}, 3, "s:+r", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "s:+r", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "s:+r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:+r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:+r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{6=>nil}, 6, "s:+r", false], [{6=>nil, 7=>:enemy}, 7, "s:+r", true], [{6=>nil, 7=>nil}, 7, "s:+r", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "s:+r", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{14=>nil, 23=>:enemy}, 23, "s:+r", true], [{14=>nil, 23=>nil}, 23, "s:+r", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{15=>nil}, 15, "s:+r", false]], 6=>[[{5=>:enemy}, 5, "s:+r", true], [{7=>:enemy}, 7, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{5=>nil}, 5, "s:+r", false], [{5=>nil, 4=>:enemy}, 4, "s:+r", true], [{5=>nil, 4=>nil}, 4, "s:+r", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "s:+r", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "s:+r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:+r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:+r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:+r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:+r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{7=>nil}, 7, "s:+r", false], [{7=>nil, 8=>:enemy}, 8, "s:+r", true], [{7=>nil, 8=>nil}, 8, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{15=>nil, 24=>:enemy}, 24, "s:+r", true], [{15=>nil, 24=>nil}, 24, "s:+r", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{16=>nil}, 16, "s:+r", false]], 7=>[[{6=>:enemy}, 6, "s:+r", true], [{8=>:enemy}, 8, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{17=>:enemy}, 17, "s:+r", true], [{6=>nil}, 6, "s:+r", false], [{6=>nil, 5=>:enemy}, 5, "s:+r", true], [{6=>nil, 5=>nil}, 5, "s:+r", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "s:+r", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "s:+r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "s:+r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "s:+r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:+r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:+r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:+r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:+r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{8=>nil}, 8, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{16=>nil, 25=>:enemy}, 25, "s:+r", true], [{16=>nil, 25=>nil}, 25, "s:+r", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{17=>nil}, 17, "s:+r", false]], 8=>[[{7=>:enemy}, 7, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{17=>:enemy}, 17, "s:+r", true], [{7=>nil}, 7, "s:+r", false], [{7=>nil, 6=>:enemy}, 6, "s:+r", true], [{7=>nil, 6=>nil}, 6, "s:+r", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "s:+r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "s:+r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "s:+r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:+r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:+r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:+r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{17=>nil}, 17, "s:+r", false], [{17=>nil, 26=>:enemy}, 26, "s:+r", true], [{17=>nil, 26=>nil}, 26, "s:+r", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 9=>[[{0=>:enemy}, 0, "s:+r", true], [{1=>:enemy}, 1, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{18=>:enemy}, 18, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{0=>nil}, 0, "s:+r", false], [{1=>nil}, 1, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{10=>nil, 11=>:enemy}, 11, "s:+r", true], [{10=>nil, 11=>nil}, 11, "s:+r", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "s:+r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "s:+r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "s:+r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:+r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:+r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{18=>nil}, 18, "s:+r", false], [{18=>nil, 27=>:enemy}, 27, "s:+r", true], [{18=>nil, 27=>nil}, 27, "s:+r", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{19=>nil}, 19, "s:+r", false]], 10=>[[{0=>:enemy}, 0, "s:+r", true], [{1=>:enemy}, 1, "s:+r", true], [{2=>:enemy}, 2, "s:+r", true], [{9=>:enemy}, 9, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{18=>:enemy}, 18, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{0=>nil}, 0, "s:+r", false], [{1=>nil}, 1, "s:+r", false], [{2=>nil}, 2, "s:+r", false], [{9=>nil}, 9, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{11=>nil, 12=>:enemy}, 12, "s:+r", true], [{11=>nil, 12=>nil}, 12, "s:+r", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "s:+r", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "s:+r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "s:+r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "s:+r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:+r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:+r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:+r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:+r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{18=>nil}, 18, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{19=>nil, 28=>:enemy}, 28, "s:+r", true], [{19=>nil, 28=>nil}, 28, "s:+r", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{20=>nil}, 20, "s:+r", false]], 11=>[[{1=>:enemy}, 1, "s:+r", true], [{2=>:enemy}, 2, "s:+r", true], [{3=>:enemy}, 3, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{1=>nil}, 1, "s:+r", false], [{2=>nil}, 2, "s:+r", false], [{3=>nil}, 3, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{10=>nil, 9=>:enemy}, 9, "s:+r", true], [{10=>nil, 9=>nil}, 9, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{12=>nil, 13=>:enemy}, 13, "s:+r", true], [{12=>nil, 13=>nil}, 13, "s:+r", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "s:+r", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "s:+r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:+r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:+r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:+r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:+r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{20=>nil, 29=>:enemy}, 29, "s:+r", true], [{20=>nil, 29=>nil}, 29, "s:+r", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{21=>nil}, 21, "s:+r", false]], 12=>[[{2=>:enemy}, 2, "s:+r", true], [{3=>:enemy}, 3, "s:+r", true], [{4=>:enemy}, 4, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{2=>nil}, 2, "s:+r", false], [{3=>nil}, 3, "s:+r", false], [{4=>nil}, 4, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{11=>nil, 10=>:enemy}, 10, "s:+r", true], [{11=>nil, 10=>nil}, 10, "s:+r", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{13=>nil, 14=>:enemy}, 14, "s:+r", true], [{13=>nil, 14=>nil}, 14, "s:+r", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "s:+r", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "s:+r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:+r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:+r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{21=>nil, 30=>:enemy}, 30, "s:+r", true], [{21=>nil, 30=>nil}, 30, "s:+r", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{22=>nil}, 22, "s:+r", false]], 13=>[[{3=>:enemy}, 3, "s:+r", true], [{4=>:enemy}, 4, "s:+r", true], [{5=>:enemy}, 5, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{3=>nil}, 3, "s:+r", false], [{4=>nil}, 4, "s:+r", false], [{5=>nil}, 5, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{12=>nil, 11=>:enemy}, 11, "s:+r", true], [{12=>nil, 11=>nil}, 11, "s:+r", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "s:+r", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "s:+r", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{14=>nil, 15=>:enemy}, 15, "s:+r", true], [{14=>nil, 15=>nil}, 15, "s:+r", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "s:+r", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "s:+r", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{22=>nil, 31=>:enemy}, 31, "s:+r", true], [{22=>nil, 31=>nil}, 31, "s:+r", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{23=>nil}, 23, "s:+r", false]], 14=>[[{4=>:enemy}, 4, "s:+r", true], [{5=>:enemy}, 5, "s:+r", true], [{6=>:enemy}, 6, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{4=>nil}, 4, "s:+r", false], [{5=>nil}, 5, "s:+r", false], [{6=>nil}, 6, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{13=>nil, 12=>:enemy}, 12, "s:+r", true], [{13=>nil, 12=>nil}, 12, "s:+r", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "s:+r", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "s:+r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:+r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:+r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{15=>nil, 16=>:enemy}, 16, "s:+r", true], [{15=>nil, 16=>nil}, 16, "s:+r", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "s:+r", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{23=>nil, 32=>:enemy}, 32, "s:+r", true], [{23=>nil, 32=>nil}, 32, "s:+r", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{24=>nil}, 24, "s:+r", false]], 15=>[[{5=>:enemy}, 5, "s:+r", true], [{6=>:enemy}, 6, "s:+r", true], [{7=>:enemy}, 7, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{5=>nil}, 5, "s:+r", false], [{6=>nil}, 6, "s:+r", false], [{7=>nil}, 7, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{14=>nil, 13=>:enemy}, 13, "s:+r", true], [{14=>nil, 13=>nil}, 13, "s:+r", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "s:+r", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "s:+r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:+r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:+r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:+r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:+r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{16=>nil, 17=>:enemy}, 17, "s:+r", true], [{16=>nil, 17=>nil}, 17, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{24=>nil, 33=>:enemy}, 33, "s:+r", true], [{24=>nil, 33=>nil}, 33, "s:+r", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{25=>nil}, 25, "s:+r", false]], 16=>[[{6=>:enemy}, 6, "s:+r", true], [{7=>:enemy}, 7, "s:+r", true], [{8=>:enemy}, 8, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{17=>:enemy}, 17, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{26=>:enemy}, 26, "s:+r", true], [{6=>nil}, 6, "s:+r", false], [{7=>nil}, 7, "s:+r", false], [{8=>nil}, 8, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{15=>nil, 14=>:enemy}, 14, "s:+r", true], [{15=>nil, 14=>nil}, 14, "s:+r", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "s:+r", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "s:+r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "s:+r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "s:+r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:+r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:+r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:+r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:+r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{17=>nil}, 17, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{25=>nil, 34=>:enemy}, 34, "s:+r", true], [{25=>nil, 34=>nil}, 34, "s:+r", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{26=>nil}, 26, "s:+r", false]], 17=>[[{7=>:enemy}, 7, "s:+r", true], [{8=>:enemy}, 8, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{26=>:enemy}, 26, "s:+r", true], [{7=>nil}, 7, "s:+r", false], [{8=>nil}, 8, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{16=>nil, 15=>:enemy}, 15, "s:+r", true], [{16=>nil, 15=>nil}, 15, "s:+r", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "s:+r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "s:+r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "s:+r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:+r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:+r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:+r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{26=>nil}, 26, "s:+r", false], [{26=>nil, 35=>:enemy}, 35, "s:+r", true], [{26=>nil, 35=>nil}, 35, "s:+r", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 18=>[[{9=>:enemy}, 9, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{27=>:enemy}, 27, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{9=>nil}, 9, "s:+r", false], [{9=>nil, 0=>:enemy}, 0, "s:+r", true], [{9=>nil, 0=>nil}, 0, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{19=>nil, 20=>:enemy}, 20, "s:+r", true], [{19=>nil, 20=>nil}, 20, "s:+r", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "s:+r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "s:+r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "s:+r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:+r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:+r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{27=>nil}, 27, "s:+r", false], [{27=>nil, 36=>:enemy}, 36, "s:+r", true], [{27=>nil, 36=>nil}, 36, "s:+r", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "s:+r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{28=>nil}, 28, "s:+r", false]], 19=>[[{9=>:enemy}, 9, "s:+r", true], [{10=>:enemy}, 10, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{18=>:enemy}, 18, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{27=>:enemy}, 27, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{9=>nil}, 9, "s:+r", false], [{10=>nil}, 10, "s:+r", false], [{10=>nil, 1=>:enemy}, 1, "s:+r", true], [{10=>nil, 1=>nil}, 1, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{18=>nil}, 18, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{20=>nil, 21=>:enemy}, 21, "s:+r", true], [{20=>nil, 21=>nil}, 21, "s:+r", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "s:+r", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "s:+r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "s:+r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "s:+r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:+r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:+r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:+r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:+r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{27=>nil}, 27, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{28=>nil, 37=>:enemy}, 37, "s:+r", true], [{28=>nil, 37=>nil}, 37, "s:+r", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "s:+r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{29=>nil}, 29, "s:+r", false]], 20=>[[{10=>:enemy}, 10, "s:+r", true], [{11=>:enemy}, 11, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{10=>nil}, 10, "s:+r", false], [{11=>nil}, 11, "s:+r", false], [{11=>nil, 2=>:enemy}, 2, "s:+r", true], [{11=>nil, 2=>nil}, 2, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{19=>nil, 18=>:enemy}, 18, "s:+r", true], [{19=>nil, 18=>nil}, 18, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{21=>nil, 22=>:enemy}, 22, "s:+r", true], [{21=>nil, 22=>nil}, 22, "s:+r", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "s:+r", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "s:+r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:+r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:+r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:+r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:+r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{29=>nil, 38=>:enemy}, 38, "s:+r", true], [{29=>nil, 38=>nil}, 38, "s:+r", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "s:+r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{30=>nil}, 30, "s:+r", false]], 21=>[[{11=>:enemy}, 11, "s:+r", true], [{12=>:enemy}, 12, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{11=>nil}, 11, "s:+r", false], [{12=>nil}, 12, "s:+r", false], [{12=>nil, 3=>:enemy}, 3, "s:+r", true], [{12=>nil, 3=>nil}, 3, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{20=>nil, 19=>:enemy}, 19, "s:+r", true], [{20=>nil, 19=>nil}, 19, "s:+r", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{22=>nil, 23=>:enemy}, 23, "s:+r", true], [{22=>nil, 23=>nil}, 23, "s:+r", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "s:+r", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "s:+r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:+r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:+r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{30=>nil, 39=>:enemy}, 39, "s:+r", true], [{30=>nil, 39=>nil}, 39, "s:+r", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "s:+r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{31=>nil}, 31, "s:+r", false]], 22=>[[{12=>:enemy}, 12, "s:+r", true], [{13=>:enemy}, 13, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{12=>nil}, 12, "s:+r", false], [{13=>nil}, 13, "s:+r", false], [{13=>nil, 4=>:enemy}, 4, "s:+r", true], [{13=>nil, 4=>nil}, 4, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{21=>nil, 20=>:enemy}, 20, "s:+r", true], [{21=>nil, 20=>nil}, 20, "s:+r", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "s:+r", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "s:+r", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{23=>nil, 24=>:enemy}, 24, "s:+r", true], [{23=>nil, 24=>nil}, 24, "s:+r", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "s:+r", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "s:+r", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{31=>nil, 40=>:enemy}, 40, "s:+r", true], [{31=>nil, 40=>nil}, 40, "s:+r", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "s:+r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{32=>nil}, 32, "s:+r", false]], 23=>[[{13=>:enemy}, 13, "s:+r", true], [{14=>:enemy}, 14, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{13=>nil}, 13, "s:+r", false], [{14=>nil}, 14, "s:+r", false], [{14=>nil, 5=>:enemy}, 5, "s:+r", true], [{14=>nil, 5=>nil}, 5, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{22=>nil, 21=>:enemy}, 21, "s:+r", true], [{22=>nil, 21=>nil}, 21, "s:+r", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "s:+r", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "s:+r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:+r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:+r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{24=>nil, 25=>:enemy}, 25, "s:+r", true], [{24=>nil, 25=>nil}, 25, "s:+r", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "s:+r", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{32=>nil, 41=>:enemy}, 41, "s:+r", true], [{32=>nil, 41=>nil}, 41, "s:+r", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "s:+r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{33=>nil}, 33, "s:+r", false]], 24=>[[{14=>:enemy}, 14, "s:+r", true], [{15=>:enemy}, 15, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{14=>nil}, 14, "s:+r", false], [{15=>nil}, 15, "s:+r", false], [{15=>nil, 6=>:enemy}, 6, "s:+r", true], [{15=>nil, 6=>nil}, 6, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{23=>nil, 22=>:enemy}, 22, "s:+r", true], [{23=>nil, 22=>nil}, 22, "s:+r", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "s:+r", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "s:+r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:+r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:+r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:+r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:+r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{25=>nil, 26=>:enemy}, 26, "s:+r", true], [{25=>nil, 26=>nil}, 26, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{33=>nil, 42=>:enemy}, 42, "s:+r", true], [{33=>nil, 42=>nil}, 42, "s:+r", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "s:+r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{34=>nil}, 34, "s:+r", false]], 25=>[[{15=>:enemy}, 15, "s:+r", true], [{16=>:enemy}, 16, "s:+r", true], [{17=>:enemy}, 17, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{26=>:enemy}, 26, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{35=>:enemy}, 35, "s:+r", true], [{15=>nil}, 15, "s:+r", false], [{16=>nil}, 16, "s:+r", false], [{16=>nil, 7=>:enemy}, 7, "s:+r", true], [{16=>nil, 7=>nil}, 7, "s:+r", false], [{17=>nil}, 17, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{24=>nil, 23=>:enemy}, 23, "s:+r", true], [{24=>nil, 23=>nil}, 23, "s:+r", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "s:+r", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "s:+r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "s:+r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "s:+r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:+r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:+r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:+r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:+r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{26=>nil}, 26, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{34=>nil, 43=>:enemy}, 43, "s:+r", true], [{34=>nil, 43=>nil}, 43, "s:+r", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "s:+r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{35=>nil}, 35, "s:+r", false]], 26=>[[{16=>:enemy}, 16, "s:+r", true], [{17=>:enemy}, 17, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{35=>:enemy}, 35, "s:+r", true], [{16=>nil}, 16, "s:+r", false], [{17=>nil}, 17, "s:+r", false], [{17=>nil, 8=>:enemy}, 8, "s:+r", true], [{17=>nil, 8=>nil}, 8, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{25=>nil, 24=>:enemy}, 24, "s:+r", true], [{25=>nil, 24=>nil}, 24, "s:+r", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "s:+r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "s:+r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "s:+r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:+r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:+r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:+r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{35=>nil}, 35, "s:+r", false], [{35=>nil, 44=>:enemy}, 44, "s:+r", true], [{35=>nil, 44=>nil}, 44, "s:+r", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "s:+r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 27=>[[{18=>:enemy}, 18, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{36=>:enemy}, 36, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{18=>nil}, 18, "s:+r", false], [{18=>nil, 9=>:enemy}, 9, "s:+r", true], [{18=>nil, 9=>nil}, 9, "s:+r", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{28=>nil, 29=>:enemy}, 29, "s:+r", true], [{28=>nil, 29=>nil}, 29, "s:+r", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "s:+r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "s:+r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "s:+r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:+r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:+r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{36=>nil}, 36, "s:+r", false], [{36=>nil, 45=>:enemy}, 45, "s:+r", true], [{36=>nil, 45=>nil}, 45, "s:+r", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{37=>nil}, 37, "s:+r", false]], 28=>[[{18=>:enemy}, 18, "s:+r", true], [{19=>:enemy}, 19, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{27=>:enemy}, 27, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{36=>:enemy}, 36, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{18=>nil}, 18, "s:+r", false], [{19=>nil}, 19, "s:+r", false], [{19=>nil, 10=>:enemy}, 10, "s:+r", true], [{19=>nil, 10=>nil}, 10, "s:+r", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{27=>nil}, 27, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{29=>nil, 30=>:enemy}, 30, "s:+r", true], [{29=>nil, 30=>nil}, 30, "s:+r", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "s:+r", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "s:+r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "s:+r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "s:+r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:+r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:+r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:+r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:+r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{36=>nil}, 36, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{37=>nil, 46=>:enemy}, 46, "s:+r", true], [{37=>nil, 46=>nil}, 46, "s:+r", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{38=>nil}, 38, "s:+r", false]], 29=>[[{19=>:enemy}, 19, "s:+r", true], [{20=>:enemy}, 20, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{19=>nil}, 19, "s:+r", false], [{20=>nil}, 20, "s:+r", false], [{20=>nil, 11=>:enemy}, 11, "s:+r", true], [{20=>nil, 11=>nil}, 11, "s:+r", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{28=>nil, 27=>:enemy}, 27, "s:+r", true], [{28=>nil, 27=>nil}, 27, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{30=>nil, 31=>:enemy}, 31, "s:+r", true], [{30=>nil, 31=>nil}, 31, "s:+r", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "s:+r", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "s:+r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:+r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:+r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:+r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:+r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{38=>nil, 47=>:enemy}, 47, "s:+r", true], [{38=>nil, 47=>nil}, 47, "s:+r", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{39=>nil}, 39, "s:+r", false]], 30=>[[{20=>:enemy}, 20, "s:+r", true], [{21=>:enemy}, 21, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{20=>nil}, 20, "s:+r", false], [{21=>nil}, 21, "s:+r", false], [{21=>nil, 12=>:enemy}, 12, "s:+r", true], [{21=>nil, 12=>nil}, 12, "s:+r", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{29=>nil, 28=>:enemy}, 28, "s:+r", true], [{29=>nil, 28=>nil}, 28, "s:+r", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{31=>nil, 32=>:enemy}, 32, "s:+r", true], [{31=>nil, 32=>nil}, 32, "s:+r", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "s:+r", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "s:+r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:+r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:+r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{39=>nil, 48=>:enemy}, 48, "s:+r", true], [{39=>nil, 48=>nil}, 48, "s:+r", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{40=>nil}, 40, "s:+r", false]], 31=>[[{21=>:enemy}, 21, "s:+r", true], [{22=>:enemy}, 22, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{21=>nil}, 21, "s:+r", false], [{22=>nil}, 22, "s:+r", false], [{22=>nil, 13=>:enemy}, 13, "s:+r", true], [{22=>nil, 13=>nil}, 13, "s:+r", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{30=>nil, 29=>:enemy}, 29, "s:+r", true], [{30=>nil, 29=>nil}, 29, "s:+r", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "s:+r", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "s:+r", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{32=>nil, 33=>:enemy}, 33, "s:+r", true], [{32=>nil, 33=>nil}, 33, "s:+r", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "s:+r", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "s:+r", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{40=>nil, 49=>:enemy}, 49, "s:+r", true], [{40=>nil, 49=>nil}, 49, "s:+r", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{41=>nil}, 41, "s:+r", false]], 32=>[[{22=>:enemy}, 22, "s:+r", true], [{23=>:enemy}, 23, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{22=>nil}, 22, "s:+r", false], [{23=>nil}, 23, "s:+r", false], [{23=>nil, 14=>:enemy}, 14, "s:+r", true], [{23=>nil, 14=>nil}, 14, "s:+r", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{31=>nil, 30=>:enemy}, 30, "s:+r", true], [{31=>nil, 30=>nil}, 30, "s:+r", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "s:+r", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "s:+r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:+r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:+r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{33=>nil, 34=>:enemy}, 34, "s:+r", true], [{33=>nil, 34=>nil}, 34, "s:+r", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "s:+r", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{41=>nil, 50=>:enemy}, 50, "s:+r", true], [{41=>nil, 50=>nil}, 50, "s:+r", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{42=>nil}, 42, "s:+r", false]], 33=>[[{23=>:enemy}, 23, "s:+r", true], [{24=>:enemy}, 24, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{23=>nil}, 23, "s:+r", false], [{24=>nil}, 24, "s:+r", false], [{24=>nil, 15=>:enemy}, 15, "s:+r", true], [{24=>nil, 15=>nil}, 15, "s:+r", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{32=>nil, 31=>:enemy}, 31, "s:+r", true], [{32=>nil, 31=>nil}, 31, "s:+r", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "s:+r", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "s:+r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:+r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:+r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:+r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:+r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{34=>nil, 35=>:enemy}, 35, "s:+r", true], [{34=>nil, 35=>nil}, 35, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{42=>nil, 51=>:enemy}, 51, "s:+r", true], [{42=>nil, 51=>nil}, 51, "s:+r", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{43=>nil}, 43, "s:+r", false]], 34=>[[{24=>:enemy}, 24, "s:+r", true], [{25=>:enemy}, 25, "s:+r", true], [{26=>:enemy}, 26, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{35=>:enemy}, 35, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{44=>:enemy}, 44, "s:+r", true], [{24=>nil}, 24, "s:+r", false], [{25=>nil}, 25, "s:+r", false], [{25=>nil, 16=>:enemy}, 16, "s:+r", true], [{25=>nil, 16=>nil}, 16, "s:+r", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{26=>nil}, 26, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{33=>nil, 32=>:enemy}, 32, "s:+r", true], [{33=>nil, 32=>nil}, 32, "s:+r", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "s:+r", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "s:+r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "s:+r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "s:+r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:+r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:+r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:+r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:+r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{35=>nil}, 35, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{43=>nil, 52=>:enemy}, 52, "s:+r", true], [{43=>nil, 52=>nil}, 52, "s:+r", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{44=>nil}, 44, "s:+r", false]], 35=>[[{25=>:enemy}, 25, "s:+r", true], [{26=>:enemy}, 26, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{44=>:enemy}, 44, "s:+r", true], [{25=>nil}, 25, "s:+r", false], [{26=>nil}, 26, "s:+r", false], [{26=>nil, 17=>:enemy}, 17, "s:+r", true], [{26=>nil, 17=>nil}, 17, "s:+r", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{34=>nil, 33=>:enemy}, 33, "s:+r", true], [{34=>nil, 33=>nil}, 33, "s:+r", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "s:+r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "s:+r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "s:+r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:+r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:+r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:+r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{44=>nil}, 44, "s:+r", false], [{44=>nil, 53=>:enemy}, 53, "s:+r", true], [{44=>nil, 53=>nil}, 53, "s:+r", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 36=>[[{27=>:enemy}, 27, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{45=>:enemy}, 45, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{27=>nil}, 27, "s:+r", false], [{27=>nil, 18=>:enemy}, 18, "s:+r", true], [{27=>nil, 18=>nil}, 18, "s:+r", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{37=>nil, 38=>:enemy}, 38, "s:+r", true], [{37=>nil, 38=>nil}, 38, "s:+r", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "s:+r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "s:+r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "s:+r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:+r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:+r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{45=>nil}, 45, "s:+r", false], [{45=>nil, 54=>:enemy}, 54, "s:+r", true], [{45=>nil, 54=>nil}, 54, "s:+r", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{46=>nil}, 46, "s:+r", false]], 37=>[[{27=>:enemy}, 27, "s:+r", true], [{28=>:enemy}, 28, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{36=>:enemy}, 36, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{45=>:enemy}, 45, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{27=>nil}, 27, "s:+r", false], [{28=>nil}, 28, "s:+r", false], [{28=>nil, 19=>:enemy}, 19, "s:+r", true], [{28=>nil, 19=>nil}, 19, "s:+r", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{36=>nil}, 36, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{38=>nil, 39=>:enemy}, 39, "s:+r", true], [{38=>nil, 39=>nil}, 39, "s:+r", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "s:+r", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "s:+r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "s:+r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "s:+r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:+r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:+r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:+r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:+r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{45=>nil}, 45, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{46=>nil, 55=>:enemy}, 55, "s:+r", true], [{46=>nil, 55=>nil}, 55, "s:+r", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{47=>nil}, 47, "s:+r", false]], 38=>[[{28=>:enemy}, 28, "s:+r", true], [{29=>:enemy}, 29, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{28=>nil}, 28, "s:+r", false], [{29=>nil}, 29, "s:+r", false], [{29=>nil, 20=>:enemy}, 20, "s:+r", true], [{29=>nil, 20=>nil}, 20, "s:+r", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{37=>nil, 36=>:enemy}, 36, "s:+r", true], [{37=>nil, 36=>nil}, 36, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{39=>nil, 40=>:enemy}, 40, "s:+r", true], [{39=>nil, 40=>nil}, 40, "s:+r", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "s:+r", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "s:+r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:+r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:+r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:+r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:+r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{47=>nil, 56=>:enemy}, 56, "s:+r", true], [{47=>nil, 56=>nil}, 56, "s:+r", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{48=>nil}, 48, "s:+r", false]], 39=>[[{29=>:enemy}, 29, "s:+r", true], [{30=>:enemy}, 30, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{29=>nil}, 29, "s:+r", false], [{30=>nil}, 30, "s:+r", false], [{30=>nil, 21=>:enemy}, 21, "s:+r", true], [{30=>nil, 21=>nil}, 21, "s:+r", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{38=>nil, 37=>:enemy}, 37, "s:+r", true], [{38=>nil, 37=>nil}, 37, "s:+r", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{40=>nil, 41=>:enemy}, 41, "s:+r", true], [{40=>nil, 41=>nil}, 41, "s:+r", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "s:+r", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "s:+r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:+r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:+r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{48=>nil, 57=>:enemy}, 57, "s:+r", true], [{48=>nil, 57=>nil}, 57, "s:+r", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{49=>nil}, 49, "s:+r", false]], 40=>[[{30=>:enemy}, 30, "s:+r", true], [{31=>:enemy}, 31, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{30=>nil}, 30, "s:+r", false], [{31=>nil}, 31, "s:+r", false], [{31=>nil, 22=>:enemy}, 22, "s:+r", true], [{31=>nil, 22=>nil}, 22, "s:+r", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{39=>nil, 38=>:enemy}, 38, "s:+r", true], [{39=>nil, 38=>nil}, 38, "s:+r", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "s:+r", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "s:+r", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{41=>nil, 42=>:enemy}, 42, "s:+r", true], [{41=>nil, 42=>nil}, 42, "s:+r", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "s:+r", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "s:+r", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{49=>nil, 58=>:enemy}, 58, "s:+r", true], [{49=>nil, 58=>nil}, 58, "s:+r", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{50=>nil}, 50, "s:+r", false]], 41=>[[{31=>:enemy}, 31, "s:+r", true], [{32=>:enemy}, 32, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{31=>nil}, 31, "s:+r", false], [{32=>nil}, 32, "s:+r", false], [{32=>nil, 23=>:enemy}, 23, "s:+r", true], [{32=>nil, 23=>nil}, 23, "s:+r", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{40=>nil, 39=>:enemy}, 39, "s:+r", true], [{40=>nil, 39=>nil}, 39, "s:+r", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "s:+r", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "s:+r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:+r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:+r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{42=>nil, 43=>:enemy}, 43, "s:+r", true], [{42=>nil, 43=>nil}, 43, "s:+r", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "s:+r", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{50=>nil, 59=>:enemy}, 59, "s:+r", true], [{50=>nil, 59=>nil}, 59, "s:+r", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{51=>nil}, 51, "s:+r", false]], 42=>[[{32=>:enemy}, 32, "s:+r", true], [{33=>:enemy}, 33, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{32=>nil}, 32, "s:+r", false], [{33=>nil}, 33, "s:+r", false], [{33=>nil, 24=>:enemy}, 24, "s:+r", true], [{33=>nil, 24=>nil}, 24, "s:+r", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{41=>nil, 40=>:enemy}, 40, "s:+r", true], [{41=>nil, 40=>nil}, 40, "s:+r", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "s:+r", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "s:+r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:+r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:+r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:+r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:+r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{43=>nil, 44=>:enemy}, 44, "s:+r", true], [{43=>nil, 44=>nil}, 44, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{51=>nil, 60=>:enemy}, 60, "s:+r", true], [{51=>nil, 60=>nil}, 60, "s:+r", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{52=>nil}, 52, "s:+r", false]], 43=>[[{33=>:enemy}, 33, "s:+r", true], [{34=>:enemy}, 34, "s:+r", true], [{35=>:enemy}, 35, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{44=>:enemy}, 44, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{53=>:enemy}, 53, "s:+r", true], [{33=>nil}, 33, "s:+r", false], [{34=>nil}, 34, "s:+r", false], [{34=>nil, 25=>:enemy}, 25, "s:+r", true], [{34=>nil, 25=>nil}, 25, "s:+r", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{35=>nil}, 35, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{42=>nil, 41=>:enemy}, 41, "s:+r", true], [{42=>nil, 41=>nil}, 41, "s:+r", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "s:+r", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "s:+r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "s:+r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "s:+r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:+r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:+r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:+r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:+r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{44=>nil}, 44, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{52=>nil, 61=>:enemy}, 61, "s:+r", true], [{52=>nil, 61=>nil}, 61, "s:+r", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{53=>nil}, 53, "s:+r", false]], 44=>[[{34=>:enemy}, 34, "s:+r", true], [{35=>:enemy}, 35, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{53=>:enemy}, 53, "s:+r", true], [{34=>nil}, 34, "s:+r", false], [{35=>nil}, 35, "s:+r", false], [{35=>nil, 26=>:enemy}, 26, "s:+r", true], [{35=>nil, 26=>nil}, 26, "s:+r", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{43=>nil, 42=>:enemy}, 42, "s:+r", true], [{43=>nil, 42=>nil}, 42, "s:+r", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "s:+r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "s:+r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "s:+r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:+r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:+r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:+r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{53=>nil}, 53, "s:+r", false], [{53=>nil, 62=>:enemy}, 62, "s:+r", true], [{53=>nil, 62=>nil}, 62, "s:+r", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 45=>[[{36=>:enemy}, 36, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{54=>:enemy}, 54, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{36=>nil}, 36, "s:+r", false], [{36=>nil, 27=>:enemy}, 27, "s:+r", true], [{36=>nil, 27=>nil}, 27, "s:+r", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{46=>nil, 47=>:enemy}, 47, "s:+r", true], [{46=>nil, 47=>nil}, 47, "s:+r", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "s:+r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "s:+r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "s:+r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:+r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:+r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{54=>nil}, 54, "s:+r", false], [{54=>nil, 63=>:enemy}, 63, "s:+r", true], [{54=>nil, 63=>nil}, 63, "s:+r", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false], [{55=>nil}, 55, "s:+r", false]], 46=>[[{36=>:enemy}, 36, "s:+r", true], [{37=>:enemy}, 37, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{45=>:enemy}, 45, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{54=>:enemy}, 54, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{36=>nil}, 36, "s:+r", false], [{37=>nil}, 37, "s:+r", false], [{37=>nil, 28=>:enemy}, 28, "s:+r", true], [{37=>nil, 28=>nil}, 28, "s:+r", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{45=>nil}, 45, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{47=>nil, 48=>:enemy}, 48, "s:+r", true], [{47=>nil, 48=>nil}, 48, "s:+r", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "s:+r", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "s:+r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "s:+r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "s:+r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:+r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:+r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:+r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:+r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{54=>nil}, 54, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 64=>:enemy}, 64, "s:+r", true], [{55=>nil, 64=>nil}, 64, "s:+r", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false], [{56=>nil}, 56, "s:+r", false]], 47=>[[{37=>:enemy}, 37, "s:+r", true], [{38=>:enemy}, 38, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{37=>nil}, 37, "s:+r", false], [{38=>nil}, 38, "s:+r", false], [{38=>nil, 29=>:enemy}, 29, "s:+r", true], [{38=>nil, 29=>nil}, 29, "s:+r", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{46=>nil, 45=>:enemy}, 45, "s:+r", true], [{46=>nil, 45=>nil}, 45, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{48=>nil, 49=>:enemy}, 49, "s:+r", true], [{48=>nil, 49=>nil}, 49, "s:+r", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "s:+r", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "s:+r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:+r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:+r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:+r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:+r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 65=>:enemy}, 65, "s:+r", true], [{56=>nil, 65=>nil}, 65, "s:+r", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false], [{57=>nil}, 57, "s:+r", false]], 48=>[[{38=>:enemy}, 38, "s:+r", true], [{39=>:enemy}, 39, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{38=>nil}, 38, "s:+r", false], [{39=>nil}, 39, "s:+r", false], [{39=>nil, 30=>:enemy}, 30, "s:+r", true], [{39=>nil, 30=>nil}, 30, "s:+r", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{47=>nil, 46=>:enemy}, 46, "s:+r", true], [{47=>nil, 46=>nil}, 46, "s:+r", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{49=>nil, 50=>:enemy}, 50, "s:+r", true], [{49=>nil, 50=>nil}, 50, "s:+r", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "s:+r", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "s:+r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:+r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:+r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 66=>:enemy}, 66, "s:+r", true], [{57=>nil, 66=>nil}, 66, "s:+r", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false], [{58=>nil}, 58, "s:+r", false]], 49=>[[{39=>:enemy}, 39, "s:+r", true], [{40=>:enemy}, 40, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{39=>nil}, 39, "s:+r", false], [{40=>nil}, 40, "s:+r", false], [{40=>nil, 31=>:enemy}, 31, "s:+r", true], [{40=>nil, 31=>nil}, 31, "s:+r", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{48=>nil, 47=>:enemy}, 47, "s:+r", true], [{48=>nil, 47=>nil}, 47, "s:+r", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "s:+r", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "s:+r", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{50=>nil, 51=>:enemy}, 51, "s:+r", true], [{50=>nil, 51=>nil}, 51, "s:+r", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "s:+r", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "s:+r", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 67=>:enemy}, 67, "s:+r", true], [{58=>nil, 67=>nil}, 67, "s:+r", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false], [{59=>nil}, 59, "s:+r", false]], 50=>[[{40=>:enemy}, 40, "s:+r", true], [{41=>:enemy}, 41, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{40=>nil}, 40, "s:+r", false], [{41=>nil}, 41, "s:+r", false], [{41=>nil, 32=>:enemy}, 32, "s:+r", true], [{41=>nil, 32=>nil}, 32, "s:+r", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{49=>nil, 48=>:enemy}, 48, "s:+r", true], [{49=>nil, 48=>nil}, 48, "s:+r", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "s:+r", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "s:+r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:+r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:+r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{51=>nil, 52=>:enemy}, 52, "s:+r", true], [{51=>nil, 52=>nil}, 52, "s:+r", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "s:+r", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 68=>:enemy}, 68, "s:+r", true], [{59=>nil, 68=>nil}, 68, "s:+r", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false], [{60=>nil}, 60, "s:+r", false]], 51=>[[{41=>:enemy}, 41, "s:+r", true], [{42=>:enemy}, 42, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{41=>nil}, 41, "s:+r", false], [{42=>nil}, 42, "s:+r", false], [{42=>nil, 33=>:enemy}, 33, "s:+r", true], [{42=>nil, 33=>nil}, 33, "s:+r", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{50=>nil, 49=>:enemy}, 49, "s:+r", true], [{50=>nil, 49=>nil}, 49, "s:+r", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "s:+r", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "s:+r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:+r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:+r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:+r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:+r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{52=>nil, 53=>:enemy}, 53, "s:+r", true], [{52=>nil, 53=>nil}, 53, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 69=>:enemy}, 69, "s:+r", true], [{60=>nil, 69=>nil}, 69, "s:+r", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false], [{61=>nil}, 61, "s:+r", false]], 52=>[[{42=>:enemy}, 42, "s:+r", true], [{43=>:enemy}, 43, "s:+r", true], [{44=>:enemy}, 44, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{53=>:enemy}, 53, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{42=>nil}, 42, "s:+r", false], [{43=>nil}, 43, "s:+r", false], [{43=>nil, 34=>:enemy}, 34, "s:+r", true], [{43=>nil, 34=>nil}, 34, "s:+r", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{44=>nil}, 44, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{51=>nil, 50=>:enemy}, 50, "s:+r", true], [{51=>nil, 50=>nil}, 50, "s:+r", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "s:+r", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "s:+r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "s:+r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "s:+r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:+r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:+r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:+r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:+r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{53=>nil}, 53, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 70=>:enemy}, 70, "s:+r", true], [{61=>nil, 70=>nil}, 70, "s:+r", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false], [{62=>nil}, 62, "s:+r", false]], 53=>[[{43=>:enemy}, 43, "s:+r", true], [{44=>:enemy}, 44, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{43=>nil}, 43, "s:+r", false], [{44=>nil}, 44, "s:+r", false], [{44=>nil, 35=>:enemy}, 35, "s:+r", true], [{44=>nil, 35=>nil}, 35, "s:+r", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{52=>nil, 51=>:enemy}, 51, "s:+r", true], [{52=>nil, 51=>nil}, 51, "s:+r", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "s:+r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "s:+r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "s:+r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:+r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:+r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:+r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{62=>nil}, 62, "s:+r", false], [{62=>nil, 71=>:enemy}, 71, "s:+r", true], [{62=>nil, 71=>nil}, 71, "s:+r", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 54=>[[{45=>:enemy}, 45, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{63=>:enemy}, 63, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{45=>nil}, 45, "s:+r", false], [{45=>nil, 36=>:enemy}, 36, "s:+r", true], [{45=>nil, 36=>nil}, 36, "s:+r", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 56=>:enemy}, 56, "s:+r", true], [{55=>nil, 56=>nil}, 56, "s:+r", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{63=>nil}, 63, "s:+r", false], [{63=>nil, 72=>:enemy}, 72, "s:+r", true], [{63=>nil, 72=>nil}, 72, "s:+r", false], [{64=>nil}, 64, "s:+r", false]], 55=>[[{45=>:enemy}, 45, "s:+r", true], [{46=>:enemy}, 46, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{54=>:enemy}, 54, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{63=>:enemy}, 63, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{45=>nil}, 45, "s:+r", false], [{46=>nil}, 46, "s:+r", false], [{46=>nil, 37=>:enemy}, 37, "s:+r", true], [{46=>nil, 37=>nil}, 37, "s:+r", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{54=>nil}, 54, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 57=>:enemy}, 57, "s:+r", true], [{56=>nil, 57=>nil}, 57, "s:+r", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{63=>nil}, 63, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 73=>:enemy}, 73, "s:+r", true], [{64=>nil, 73=>nil}, 73, "s:+r", false], [{65=>nil}, 65, "s:+r", false]], 56=>[[{46=>:enemy}, 46, "s:+r", true], [{47=>:enemy}, 47, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{46=>nil}, 46, "s:+r", false], [{47=>nil}, 47, "s:+r", false], [{47=>nil, 38=>:enemy}, 38, "s:+r", true], [{47=>nil, 38=>nil}, 38, "s:+r", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 54=>:enemy}, 54, "s:+r", true], [{55=>nil, 54=>nil}, 54, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 58=>:enemy}, 58, "s:+r", true], [{57=>nil, 58=>nil}, 58, "s:+r", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 74=>:enemy}, 74, "s:+r", true], [{65=>nil, 74=>nil}, 74, "s:+r", false], [{66=>nil}, 66, "s:+r", false]], 57=>[[{47=>:enemy}, 47, "s:+r", true], [{48=>:enemy}, 48, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{47=>nil}, 47, "s:+r", false], [{48=>nil}, 48, "s:+r", false], [{48=>nil, 39=>:enemy}, 39, "s:+r", true], [{48=>nil, 39=>nil}, 39, "s:+r", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 55=>:enemy}, 55, "s:+r", true], [{56=>nil, 55=>nil}, 55, "s:+r", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 59=>:enemy}, 59, "s:+r", true], [{58=>nil, 59=>nil}, 59, "s:+r", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 75=>:enemy}, 75, "s:+r", true], [{66=>nil, 75=>nil}, 75, "s:+r", false], [{67=>nil}, 67, "s:+r", false]], 58=>[[{48=>:enemy}, 48, "s:+r", true], [{49=>:enemy}, 49, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{48=>nil}, 48, "s:+r", false], [{49=>nil}, 49, "s:+r", false], [{49=>nil, 40=>:enemy}, 40, "s:+r", true], [{49=>nil, 40=>nil}, 40, "s:+r", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 56=>:enemy}, 56, "s:+r", true], [{57=>nil, 56=>nil}, 56, "s:+r", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 60=>:enemy}, 60, "s:+r", true], [{59=>nil, 60=>nil}, 60, "s:+r", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 76=>:enemy}, 76, "s:+r", true], [{67=>nil, 76=>nil}, 76, "s:+r", false], [{68=>nil}, 68, "s:+r", false]], 59=>[[{49=>:enemy}, 49, "s:+r", true], [{50=>:enemy}, 50, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{49=>nil}, 49, "s:+r", false], [{50=>nil}, 50, "s:+r", false], [{50=>nil, 41=>:enemy}, 41, "s:+r", true], [{50=>nil, 41=>nil}, 41, "s:+r", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 57=>:enemy}, 57, "s:+r", true], [{58=>nil, 57=>nil}, 57, "s:+r", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 61=>:enemy}, 61, "s:+r", true], [{60=>nil, 61=>nil}, 61, "s:+r", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 77=>:enemy}, 77, "s:+r", true], [{68=>nil, 77=>nil}, 77, "s:+r", false], [{69=>nil}, 69, "s:+r", false]], 60=>[[{50=>:enemy}, 50, "s:+r", true], [{51=>:enemy}, 51, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{50=>nil}, 50, "s:+r", false], [{51=>nil}, 51, "s:+r", false], [{51=>nil, 42=>:enemy}, 42, "s:+r", true], [{51=>nil, 42=>nil}, 42, "s:+r", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 58=>:enemy}, 58, "s:+r", true], [{59=>nil, 58=>nil}, 58, "s:+r", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 62=>:enemy}, 62, "s:+r", true], [{61=>nil, 62=>nil}, 62, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 78=>:enemy}, 78, "s:+r", true], [{69=>nil, 78=>nil}, 78, "s:+r", false], [{70=>nil}, 70, "s:+r", false]], 61=>[[{51=>:enemy}, 51, "s:+r", true], [{52=>:enemy}, 52, "s:+r", true], [{53=>:enemy}, 53, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{51=>nil}, 51, "s:+r", false], [{52=>nil}, 52, "s:+r", false], [{52=>nil, 43=>:enemy}, 43, "s:+r", true], [{52=>nil, 43=>nil}, 43, "s:+r", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{53=>nil}, 53, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 59=>:enemy}, 59, "s:+r", true], [{60=>nil, 59=>nil}, 59, "s:+r", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{62=>nil}, 62, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 79=>:enemy}, 79, "s:+r", true], [{70=>nil, 79=>nil}, 79, "s:+r", false], [{71=>nil}, 71, "s:+r", false]], 62=>[[{52=>:enemy}, 52, "s:+r", true], [{53=>:enemy}, 53, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{52=>nil}, 52, "s:+r", false], [{53=>nil}, 53, "s:+r", false], [{53=>nil, 44=>:enemy}, 44, "s:+r", true], [{53=>nil, 44=>nil}, 44, "s:+r", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 60=>:enemy}, 60, "s:+r", true], [{61=>nil, 60=>nil}, 60, "s:+r", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{71=>nil, 80=>:enemy}, 80, "s:+r", true], [{71=>nil, 80=>nil}, 80, "s:+r", false]], 63=>[[{54=>:enemy}, 54, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{72=>:enemy}, 72, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{54=>nil}, 54, "s:+r", false], [{54=>nil, 45=>:enemy}, 45, "s:+r", true], [{54=>nil, 45=>nil}, 45, "s:+r", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 65=>:enemy}, 65, "s:+r", true], [{64=>nil, 65=>nil}, 65, "s:+r", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{72=>nil}, 72, "s:+r", false], [{73=>nil}, 73, "s:+r", false]], 64=>[[{54=>:enemy}, 54, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{63=>:enemy}, 63, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{72=>:enemy}, 72, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{54=>nil}, 54, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 46=>:enemy}, 46, "s:+r", true], [{55=>nil, 46=>nil}, 46, "s:+r", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{63=>nil}, 63, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 66=>:enemy}, 66, "s:+r", true], [{65=>nil, 66=>nil}, 66, "s:+r", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{72=>nil}, 72, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{74=>nil}, 74, "s:+r", false]], 65=>[[{55=>:enemy}, 55, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{55=>nil}, 55, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 47=>:enemy}, 47, "s:+r", true], [{56=>nil, 47=>nil}, 47, "s:+r", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 63=>:enemy}, 63, "s:+r", true], [{64=>nil, 63=>nil}, 63, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 67=>:enemy}, 67, "s:+r", true], [{66=>nil, 67=>nil}, 67, "s:+r", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{75=>nil}, 75, "s:+r", false]], 66=>[[{56=>:enemy}, 56, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{56=>nil}, 56, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 48=>:enemy}, 48, "s:+r", true], [{57=>nil, 48=>nil}, 48, "s:+r", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 64=>:enemy}, 64, "s:+r", true], [{65=>nil, 64=>nil}, 64, "s:+r", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 68=>:enemy}, 68, "s:+r", true], [{67=>nil, 68=>nil}, 68, "s:+r", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{76=>nil}, 76, "s:+r", false]], 67=>[[{57=>:enemy}, 57, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{57=>nil}, 57, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 49=>:enemy}, 49, "s:+r", true], [{58=>nil, 49=>nil}, 49, "s:+r", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 65=>:enemy}, 65, "s:+r", true], [{66=>nil, 65=>nil}, 65, "s:+r", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 69=>:enemy}, 69, "s:+r", true], [{68=>nil, 69=>nil}, 69, "s:+r", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{77=>nil}, 77, "s:+r", false]], 68=>[[{58=>:enemy}, 58, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{58=>nil}, 58, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 50=>:enemy}, 50, "s:+r", true], [{59=>nil, 50=>nil}, 50, "s:+r", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 66=>:enemy}, 66, "s:+r", true], [{67=>nil, 66=>nil}, 66, "s:+r", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 70=>:enemy}, 70, "s:+r", true], [{69=>nil, 70=>nil}, 70, "s:+r", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{78=>nil}, 78, "s:+r", false]], 69=>[[{59=>:enemy}, 59, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{59=>nil}, 59, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 51=>:enemy}, 51, "s:+r", true], [{60=>nil, 51=>nil}, 51, "s:+r", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 67=>:enemy}, 67, "s:+r", true], [{68=>nil, 67=>nil}, 67, "s:+r", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 71=>:enemy}, 71, "s:+r", true], [{70=>nil, 71=>nil}, 71, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{79=>nil}, 79, "s:+r", false]], 70=>[[{60=>:enemy}, 60, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{80=>:enemy}, 80, "s:+r", true], [{60=>nil}, 60, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 52=>:enemy}, 52, "s:+r", true], [{61=>nil, 52=>nil}, 52, "s:+r", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{62=>nil}, 62, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 68=>:enemy}, 68, "s:+r", true], [{69=>nil, 68=>nil}, 68, "s:+r", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{80=>nil}, 80, "s:+r", false]], 71=>[[{61=>:enemy}, 61, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{80=>:enemy}, 80, "s:+r", true], [{61=>nil}, 61, "s:+r", false], [{62=>nil}, 62, "s:+r", false], [{62=>nil, 53=>:enemy}, 53, "s:+r", true], [{62=>nil, 53=>nil}, 53, "s:+r", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 69=>:enemy}, 69, "s:+r", true], [{70=>nil, 69=>nil}, 69, "s:+r", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{80=>nil}, 80, "s:+r", false]], 72=>[[{63=>:enemy}, 63, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{63=>nil}, 63, "s:+r", false], [{63=>nil, 54=>:enemy}, 54, "s:+r", true], [{63=>nil, 54=>nil}, 54, "s:+r", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{73=>nil, 74=>:enemy}, 74, "s:+r", true], [{73=>nil, 74=>nil}, 74, "s:+r", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 73=>[[{63=>:enemy}, 63, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{72=>:enemy}, 72, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{63=>nil}, 63, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 55=>:enemy}, 55, "s:+r", true], [{64=>nil, 55=>nil}, 55, "s:+r", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{72=>nil}, 72, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{74=>nil, 75=>:enemy}, 75, "s:+r", true], [{74=>nil, 75=>nil}, 75, "s:+r", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 74=>[[{64=>:enemy}, 64, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{64=>nil}, 64, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 56=>:enemy}, 56, "s:+r", true], [{65=>nil, 56=>nil}, 56, "s:+r", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{73=>nil, 72=>:enemy}, 72, "s:+r", true], [{73=>nil, 72=>nil}, 72, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{75=>nil, 76=>:enemy}, 76, "s:+r", true], [{75=>nil, 76=>nil}, 76, "s:+r", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 75=>[[{65=>:enemy}, 65, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{65=>nil}, 65, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 57=>:enemy}, 57, "s:+r", true], [{66=>nil, 57=>nil}, 57, "s:+r", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{74=>nil, 73=>:enemy}, 73, "s:+r", true], [{74=>nil, 73=>nil}, 73, "s:+r", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{76=>nil, 77=>:enemy}, 77, "s:+r", true], [{76=>nil, 77=>nil}, 77, "s:+r", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 76=>[[{66=>:enemy}, 66, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{66=>nil}, 66, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 58=>:enemy}, 58, "s:+r", true], [{67=>nil, 58=>nil}, 58, "s:+r", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{75=>nil, 74=>:enemy}, 74, "s:+r", true], [{75=>nil, 74=>nil}, 74, "s:+r", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{77=>nil, 78=>:enemy}, 78, "s:+r", true], [{77=>nil, 78=>nil}, 78, "s:+r", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 77=>[[{67=>:enemy}, 67, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{67=>nil}, 67, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 59=>:enemy}, 59, "s:+r", true], [{68=>nil, 59=>nil}, 59, "s:+r", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{76=>nil, 75=>:enemy}, 75, "s:+r", true], [{76=>nil, 75=>nil}, 75, "s:+r", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{78=>nil, 79=>:enemy}, 79, "s:+r", true], [{78=>nil, 79=>nil}, 79, "s:+r", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 78=>[[{68=>:enemy}, 68, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{68=>nil}, 68, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 60=>:enemy}, 60, "s:+r", true], [{69=>nil, 60=>nil}, 60, "s:+r", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{77=>nil, 76=>:enemy}, 76, "s:+r", true], [{77=>nil, 76=>nil}, 76, "s:+r", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{79=>nil, 80=>:enemy}, 80, "s:+r", true], [{79=>nil, 80=>nil}, 80, "s:+r", false]], 79=>[[{69=>:enemy}, 69, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{80=>:enemy}, 80, "s:+r", true], [{69=>nil}, 69, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 61=>:enemy}, 61, "s:+r", true], [{70=>nil, 61=>nil}, 61, "s:+r", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{78=>nil, 77=>:enemy}, 77, "s:+r", true], [{78=>nil, 77=>nil}, 77, "s:+r", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{80=>nil}, 80, "s:+r", false]], 80=>[[{70=>:enemy}, 70, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{70=>nil}, 70, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{71=>nil, 62=>:enemy}, 62, "s:+r", true], [{71=>nil, 62=>nil}, 62, "s:+r", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{79=>nil, 78=>:enemy}, 78, "s:+r", true], [{79=>nil, 78=>nil}, 78, "s:+r", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false]], nil=>[]}, "s:+s"=>{0=>[[{1=>:enemy}, 1, "s:+s", true], [{9=>:enemy}, 9, "s:+s", true], [{10=>:enemy}, 10, "s:+s", true], [{1=>nil}, 1, "s:+s", false], [{9=>nil}, 9, "s:+s", false], [{10=>nil}, 10, "s:+s", false]], 1=>[[{0=>:enemy}, 0, "s:+s", true], [{2=>:enemy}, 2, "s:+s", true], [{9=>:enemy}, 9, "s:+s", true], [{10=>:enemy}, 10, "s:+s", true], [{11=>:enemy}, 11, "s:+s", true], [{0=>nil}, 0, "s:+s", false], [{2=>nil}, 2, "s:+s", false], [{9=>nil}, 9, "s:+s", false], [{10=>nil}, 10, "s:+s", false], [{11=>nil}, 11, "s:+s", false]], 2=>[[{1=>:enemy}, 1, "s:+s", true], [{3=>:enemy}, 3, "s:+s", true], [{10=>:enemy}, 10, "s:+s", true], [{11=>:enemy}, 11, "s:+s", true], [{12=>:enemy}, 12, "s:+s", true], [{1=>nil}, 1, "s:+s", false], [{3=>nil}, 3, "s:+s", false], [{10=>nil}, 10, "s:+s", false], [{11=>nil}, 11, "s:+s", false], [{12=>nil}, 12, "s:+s", false]], 3=>[[{2=>:enemy}, 2, "s:+s", true], [{4=>:enemy}, 4, "s:+s", true], [{11=>:enemy}, 11, "s:+s", true], [{12=>:enemy}, 12, "s:+s", true], [{13=>:enemy}, 13, "s:+s", true], [{2=>nil}, 2, "s:+s", false], [{4=>nil}, 4, "s:+s", false], [{11=>nil}, 11, "s:+s", false], [{12=>nil}, 12, "s:+s", false], [{13=>nil}, 13, "s:+s", false]], 4=>[[{3=>:enemy}, 3, "s:+s", true], [{5=>:enemy}, 5, "s:+s", true], [{12=>:enemy}, 12, "s:+s", true], [{13=>:enemy}, 13, "s:+s", true], [{14=>:enemy}, 14, "s:+s", true], [{3=>nil}, 3, "s:+s", false], [{5=>nil}, 5, "s:+s", false], [{12=>nil}, 12, "s:+s", false], [{13=>nil}, 13, "s:+s", false], [{14=>nil}, 14, "s:+s", false]], 5=>[[{4=>:enemy}, 4, "s:+s", true], [{6=>:enemy}, 6, "s:+s", true], [{13=>:enemy}, 13, "s:+s", true], [{14=>:enemy}, 14, "s:+s", true], [{15=>:enemy}, 15, "s:+s", true], [{4=>nil}, 4, "s:+s", false], [{6=>nil}, 6, "s:+s", false], [{13=>nil}, 13, "s:+s", false], [{14=>nil}, 14, "s:+s", false], [{15=>nil}, 15, "s:+s", false]], 6=>[[{5=>:enemy}, 5, "s:+s", true], [{7=>:enemy}, 7, "s:+s", true], [{14=>:enemy}, 14, "s:+s", true], [{15=>:enemy}, 15, "s:+s", true], [{16=>:enemy}, 16, "s:+s", true], [{5=>nil}, 5, "s:+s", false], [{7=>nil}, 7, "s:+s", false], [{14=>nil}, 14, "s:+s", false], [{15=>nil}, 15, "s:+s", false], [{16=>nil}, 16, "s:+s", false]], 7=>[[{6=>:enemy}, 6, "s:+s", true], [{8=>:enemy}, 8, "s:+s", true], [{15=>:enemy}, 15, "s:+s", true], [{16=>:enemy}, 16, "s:+s", true], [{17=>:enemy}, 17, "s:+s", true], [{6=>nil}, 6, "s:+s", false], [{8=>nil}, 8, "s:+s", false], [{15=>nil}, 15, "s:+s", false], [{16=>nil}, 16, "s:+s", false], [{17=>nil}, 17, "s:+s", false]], 8=>[[{7=>:enemy}, 7, "s:+s", true], [{16=>:enemy}, 16, "s:+s", true], [{17=>:enemy}, 17, "s:+s", true], [{7=>nil}, 7, "s:+s", false], [{16=>nil}, 16, "s:+s", false], [{17=>nil}, 17, "s:+s", false]], 9=>[[{0=>:enemy}, 0, "s:+s", true], [{10=>:enemy}, 10, "s:+s", true], [{18=>:enemy}, 18, "s:+s", true], [{19=>:enemy}, 19, "s:+s", true], [{0=>nil}, 0, "s:+s", false], [{10=>nil}, 10, "s:+s", false], [{18=>nil}, 18, "s:+s", false], [{19=>nil}, 19, "s:+s", false]], 10=>[[{1=>:enemy}, 1, "s:+s", true], [{9=>:enemy}, 9, "s:+s", true], [{11=>:enemy}, 11, "s:+s", true], [{18=>:enemy}, 18, "s:+s", true], [{19=>:enemy}, 19, "s:+s", true], [{20=>:enemy}, 20, "s:+s", true], [{1=>nil}, 1, "s:+s", false], [{9=>nil}, 9, "s:+s", false], [{11=>nil}, 11, "s:+s", false], [{18=>nil}, 18, "s:+s", false], [{19=>nil}, 19, "s:+s", false], [{20=>nil}, 20, "s:+s", false]], 11=>[[{2=>:enemy}, 2, "s:+s", true], [{10=>:enemy}, 10, "s:+s", true], [{12=>:enemy}, 12, "s:+s", true], [{19=>:enemy}, 19, "s:+s", true], [{20=>:enemy}, 20, "s:+s", true], [{21=>:enemy}, 21, "s:+s", true], [{2=>nil}, 2, "s:+s", false], [{10=>nil}, 10, "s:+s", false], [{12=>nil}, 12, "s:+s", false], [{19=>nil}, 19, "s:+s", false], [{20=>nil}, 20, "s:+s", false], [{21=>nil}, 21, "s:+s", false]], 12=>[[{3=>:enemy}, 3, "s:+s", true], [{11=>:enemy}, 11, "s:+s", true], [{13=>:enemy}, 13, "s:+s", true], [{20=>:enemy}, 20, "s:+s", true], [{21=>:enemy}, 21, "s:+s", true], [{22=>:enemy}, 22, "s:+s", true], [{3=>nil}, 3, "s:+s", false], [{11=>nil}, 11, "s:+s", false], [{13=>nil}, 13, "s:+s", false], [{20=>nil}, 20, "s:+s", false], [{21=>nil}, 21, "s:+s", false], [{22=>nil}, 22, "s:+s", false]], 13=>[[{4=>:enemy}, 4, "s:+s", true], [{12=>:enemy}, 12, "s:+s", true], [{14=>:enemy}, 14, "s:+s", true], [{21=>:enemy}, 21, "s:+s", true], [{22=>:enemy}, 22, "s:+s", true], [{23=>:enemy}, 23, "s:+s", true], [{4=>nil}, 4, "s:+s", false], [{12=>nil}, 12, "s:+s", false], [{14=>nil}, 14, "s:+s", false], [{21=>nil}, 21, "s:+s", false], [{22=>nil}, 22, "s:+s", false], [{23=>nil}, 23, "s:+s", false]], 14=>[[{5=>:enemy}, 5, "s:+s", true], [{13=>:enemy}, 13, "s:+s", true], [{15=>:enemy}, 15, "s:+s", true], [{22=>:enemy}, 22, "s:+s", true], [{23=>:enemy}, 23, "s:+s", true], [{24=>:enemy}, 24, "s:+s", true], [{5=>nil}, 5, "s:+s", false], [{13=>nil}, 13, "s:+s", false], [{15=>nil}, 15, "s:+s", false], [{22=>nil}, 22, "s:+s", false], [{23=>nil}, 23, "s:+s", false], [{24=>nil}, 24, "s:+s", false]], 15=>[[{6=>:enemy}, 6, "s:+s", true], [{14=>:enemy}, 14, "s:+s", true], [{16=>:enemy}, 16, "s:+s", true], [{23=>:enemy}, 23, "s:+s", true], [{24=>:enemy}, 24, "s:+s", true], [{25=>:enemy}, 25, "s:+s", true], [{6=>nil}, 6, "s:+s", false], [{14=>nil}, 14, "s:+s", false], [{16=>nil}, 16, "s:+s", false], [{23=>nil}, 23, "s:+s", false], [{24=>nil}, 24, "s:+s", false], [{25=>nil}, 25, "s:+s", false]], 16=>[[{7=>:enemy}, 7, "s:+s", true], [{15=>:enemy}, 15, "s:+s", true], [{17=>:enemy}, 17, "s:+s", true], [{24=>:enemy}, 24, "s:+s", true], [{25=>:enemy}, 25, "s:+s", true], [{26=>:enemy}, 26, "s:+s", true], [{7=>nil}, 7, "s:+s", false], [{15=>nil}, 15, "s:+s", false], [{17=>nil}, 17, "s:+s", false], [{24=>nil}, 24, "s:+s", false], [{25=>nil}, 25, "s:+s", false], [{26=>nil}, 26, "s:+s", false]], 17=>[[{8=>:enemy}, 8, "s:+s", true], [{16=>:enemy}, 16, "s:+s", true], [{25=>:enemy}, 25, "s:+s", true], [{26=>:enemy}, 26, "s:+s", true], [{8=>nil}, 8, "s:+s", false], [{16=>nil}, 16, "s:+s", false], [{25=>nil}, 25, "s:+s", false], [{26=>nil}, 26, "s:+s", false]], 18=>[[{9=>:enemy}, 9, "s:+s", true], [{19=>:enemy}, 19, "s:+s", true], [{27=>:enemy}, 27, "s:+s", true], [{28=>:enemy}, 28, "s:+s", true], [{9=>nil}, 9, "s:+s", false], [{19=>nil}, 19, "s:+s", false], [{27=>nil}, 27, "s:+s", false], [{28=>nil}, 28, "s:+s", false]], 19=>[[{10=>:enemy}, 10, "s:+s", true], [{18=>:enemy}, 18, "s:+s", true], [{20=>:enemy}, 20, "s:+s", true], [{27=>:enemy}, 27, "s:+s", true], [{28=>:enemy}, 28, "s:+s", true], [{29=>:enemy}, 29, "s:+s", true], [{10=>nil}, 10, "s:+s", false], [{18=>nil}, 18, "s:+s", false], [{20=>nil}, 20, "s:+s", false], [{27=>nil}, 27, "s:+s", false], [{28=>nil}, 28, "s:+s", false], [{29=>nil}, 29, "s:+s", false]], 20=>[[{11=>:enemy}, 11, "s:+s", true], [{19=>:enemy}, 19, "s:+s", true], [{21=>:enemy}, 21, "s:+s", true], [{28=>:enemy}, 28, "s:+s", true], [{29=>:enemy}, 29, "s:+s", true], [{30=>:enemy}, 30, "s:+s", true], [{11=>nil}, 11, "s:+s", false], [{19=>nil}, 19, "s:+s", false], [{21=>nil}, 21, "s:+s", false], [{28=>nil}, 28, "s:+s", false], [{29=>nil}, 29, "s:+s", false], [{30=>nil}, 30, "s:+s", false]], 21=>[[{12=>:enemy}, 12, "s:+s", true], [{20=>:enemy}, 20, "s:+s", true], [{22=>:enemy}, 22, "s:+s", true], [{29=>:enemy}, 29, "s:+s", true], [{30=>:enemy}, 30, "s:+s", true], [{31=>:enemy}, 31, "s:+s", true], [{12=>nil}, 12, "s:+s", false], [{20=>nil}, 20, "s:+s", false], [{22=>nil}, 22, "s:+s", false], [{29=>nil}, 29, "s:+s", false], [{30=>nil}, 30, "s:+s", false], [{31=>nil}, 31, "s:+s", false]], 22=>[[{13=>:enemy}, 13, "s:+s", true], [{21=>:enemy}, 21, "s:+s", true], [{23=>:enemy}, 23, "s:+s", true], [{30=>:enemy}, 30, "s:+s", true], [{31=>:enemy}, 31, "s:+s", true], [{32=>:enemy}, 32, "s:+s", true], [{13=>nil}, 13, "s:+s", false], [{21=>nil}, 21, "s:+s", false], [{23=>nil}, 23, "s:+s", false], [{30=>nil}, 30, "s:+s", false], [{31=>nil}, 31, "s:+s", false], [{32=>nil}, 32, "s:+s", false]], 23=>[[{14=>:enemy}, 14, "s:+s", true], [{22=>:enemy}, 22, "s:+s", true], [{24=>:enemy}, 24, "s:+s", true], [{31=>:enemy}, 31, "s:+s", true], [{32=>:enemy}, 32, "s:+s", true], [{33=>:enemy}, 33, "s:+s", true], [{14=>nil}, 14, "s:+s", false], [{22=>nil}, 22, "s:+s", false], [{24=>nil}, 24, "s:+s", false], [{31=>nil}, 31, "s:+s", false], [{32=>nil}, 32, "s:+s", false], [{33=>nil}, 33, "s:+s", false]], 24=>[[{15=>:enemy}, 15, "s:+s", true], [{23=>:enemy}, 23, "s:+s", true], [{25=>:enemy}, 25, "s:+s", true], [{32=>:enemy}, 32, "s:+s", true], [{33=>:enemy}, 33, "s:+s", true], [{34=>:enemy}, 34, "s:+s", true], [{15=>nil}, 15, "s:+s", false], [{23=>nil}, 23, "s:+s", false], [{25=>nil}, 25, "s:+s", false], [{32=>nil}, 32, "s:+s", false], [{33=>nil}, 33, "s:+s", false], [{34=>nil}, 34, "s:+s", false]], 25=>[[{16=>:enemy}, 16, "s:+s", true], [{24=>:enemy}, 24, "s:+s", true], [{26=>:enemy}, 26, "s:+s", true], [{33=>:enemy}, 33, "s:+s", true], [{34=>:enemy}, 34, "s:+s", true], [{35=>:enemy}, 35, "s:+s", true], [{16=>nil}, 16, "s:+s", false], [{24=>nil}, 24, "s:+s", false], [{26=>nil}, 26, "s:+s", false], [{33=>nil}, 33, "s:+s", false], [{34=>nil}, 34, "s:+s", false], [{35=>nil}, 35, "s:+s", false]], 26=>[[{17=>:enemy}, 17, "s:+s", true], [{25=>:enemy}, 25, "s:+s", true], [{34=>:enemy}, 34, "s:+s", true], [{35=>:enemy}, 35, "s:+s", true], [{17=>nil}, 17, "s:+s", false], [{25=>nil}, 25, "s:+s", false], [{34=>nil}, 34, "s:+s", false], [{35=>nil}, 35, "s:+s", false]], 27=>[[{18=>:enemy}, 18, "s:+s", true], [{28=>:enemy}, 28, "s:+s", true], [{36=>:enemy}, 36, "s:+s", true], [{37=>:enemy}, 37, "s:+s", true], [{18=>nil}, 18, "s:+s", false], [{28=>nil}, 28, "s:+s", false], [{36=>nil}, 36, "s:+s", false], [{37=>nil}, 37, "s:+s", false]], 28=>[[{19=>:enemy}, 19, "s:+s", true], [{27=>:enemy}, 27, "s:+s", true], [{29=>:enemy}, 29, "s:+s", true], [{36=>:enemy}, 36, "s:+s", true], [{37=>:enemy}, 37, "s:+s", true], [{38=>:enemy}, 38, "s:+s", true], [{19=>nil}, 19, "s:+s", false], [{27=>nil}, 27, "s:+s", false], [{29=>nil}, 29, "s:+s", false], [{36=>nil}, 36, "s:+s", false], [{37=>nil}, 37, "s:+s", false], [{38=>nil}, 38, "s:+s", false]], 29=>[[{20=>:enemy}, 20, "s:+s", true], [{28=>:enemy}, 28, "s:+s", true], [{30=>:enemy}, 30, "s:+s", true], [{37=>:enemy}, 37, "s:+s", true], [{38=>:enemy}, 38, "s:+s", true], [{39=>:enemy}, 39, "s:+s", true], [{20=>nil}, 20, "s:+s", false], [{28=>nil}, 28, "s:+s", false], [{30=>nil}, 30, "s:+s", false], [{37=>nil}, 37, "s:+s", false], [{38=>nil}, 38, "s:+s", false], [{39=>nil}, 39, "s:+s", false]], 30=>[[{21=>:enemy}, 21, "s:+s", true], [{29=>:enemy}, 29, "s:+s", true], [{31=>:enemy}, 31, "s:+s", true], [{38=>:enemy}, 38, "s:+s", true], [{39=>:enemy}, 39, "s:+s", true], [{40=>:enemy}, 40, "s:+s", true], [{21=>nil}, 21, "s:+s", false], [{29=>nil}, 29, "s:+s", false], [{31=>nil}, 31, "s:+s", false], [{38=>nil}, 38, "s:+s", false], [{39=>nil}, 39, "s:+s", false], [{40=>nil}, 40, "s:+s", false]], 31=>[[{22=>:enemy}, 22, "s:+s", true], [{30=>:enemy}, 30, "s:+s", true], [{32=>:enemy}, 32, "s:+s", true], [{39=>:enemy}, 39, "s:+s", true], [{40=>:enemy}, 40, "s:+s", true], [{41=>:enemy}, 41, "s:+s", true], [{22=>nil}, 22, "s:+s", false], [{30=>nil}, 30, "s:+s", false], [{32=>nil}, 32, "s:+s", false], [{39=>nil}, 39, "s:+s", false], [{40=>nil}, 40, "s:+s", false], [{41=>nil}, 41, "s:+s", false]], 32=>[[{23=>:enemy}, 23, "s:+s", true], [{31=>:enemy}, 31, "s:+s", true], [{33=>:enemy}, 33, "s:+s", true], [{40=>:enemy}, 40, "s:+s", true], [{41=>:enemy}, 41, "s:+s", true], [{42=>:enemy}, 42, "s:+s", true], [{23=>nil}, 23, "s:+s", false], [{31=>nil}, 31, "s:+s", false], [{33=>nil}, 33, "s:+s", false], [{40=>nil}, 40, "s:+s", false], [{41=>nil}, 41, "s:+s", false], [{42=>nil}, 42, "s:+s", false]], 33=>[[{24=>:enemy}, 24, "s:+s", true], [{32=>:enemy}, 32, "s:+s", true], [{34=>:enemy}, 34, "s:+s", true], [{41=>:enemy}, 41, "s:+s", true], [{42=>:enemy}, 42, "s:+s", true], [{43=>:enemy}, 43, "s:+s", true], [{24=>nil}, 24, "s:+s", false], [{32=>nil}, 32, "s:+s", false], [{34=>nil}, 34, "s:+s", false], [{41=>nil}, 41, "s:+s", false], [{42=>nil}, 42, "s:+s", false], [{43=>nil}, 43, "s:+s", false]], 34=>[[{25=>:enemy}, 25, "s:+s", true], [{33=>:enemy}, 33, "s:+s", true], [{35=>:enemy}, 35, "s:+s", true], [{42=>:enemy}, 42, "s:+s", true], [{43=>:enemy}, 43, "s:+s", true], [{44=>:enemy}, 44, "s:+s", true], [{25=>nil}, 25, "s:+s", false], [{33=>nil}, 33, "s:+s", false], [{35=>nil}, 35, "s:+s", false], [{42=>nil}, 42, "s:+s", false], [{43=>nil}, 43, "s:+s", false], [{44=>nil}, 44, "s:+s", false]], 35=>[[{26=>:enemy}, 26, "s:+s", true], [{34=>:enemy}, 34, "s:+s", true], [{43=>:enemy}, 43, "s:+s", true], [{44=>:enemy}, 44, "s:+s", true], [{26=>nil}, 26, "s:+s", false], [{34=>nil}, 34, "s:+s", false], [{43=>nil}, 43, "s:+s", false], [{44=>nil}, 44, "s:+s", false]], 36=>[[{27=>:enemy}, 27, "s:+s", true], [{37=>:enemy}, 37, "s:+s", true], [{45=>:enemy}, 45, "s:+s", true], [{46=>:enemy}, 46, "s:+s", true], [{27=>nil}, 27, "s:+s", false], [{37=>nil}, 37, "s:+s", false], [{45=>nil}, 45, "s:+s", false], [{46=>nil}, 46, "s:+s", false]], 37=>[[{28=>:enemy}, 28, "s:+s", true], [{36=>:enemy}, 36, "s:+s", true], [{38=>:enemy}, 38, "s:+s", true], [{45=>:enemy}, 45, "s:+s", true], [{46=>:enemy}, 46, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{28=>nil}, 28, "s:+s", false], [{36=>nil}, 36, "s:+s", false], [{38=>nil}, 38, "s:+s", false], [{45=>nil}, 45, "s:+s", false], [{46=>nil}, 46, "s:+s", false], [{47=>nil}, 47, "s:+s", false]], 38=>[[{29=>:enemy}, 29, "s:+s", true], [{37=>:enemy}, 37, "s:+s", true], [{39=>:enemy}, 39, "s:+s", true], [{46=>:enemy}, 46, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{29=>nil}, 29, "s:+s", false], [{37=>nil}, 37, "s:+s", false], [{39=>nil}, 39, "s:+s", false], [{46=>nil}, 46, "s:+s", false], [{47=>nil}, 47, "s:+s", false], [{48=>nil}, 48, "s:+s", false]], 39=>[[{30=>:enemy}, 30, "s:+s", true], [{38=>:enemy}, 38, "s:+s", true], [{40=>:enemy}, 40, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{30=>nil}, 30, "s:+s", false], [{38=>nil}, 38, "s:+s", false], [{40=>nil}, 40, "s:+s", false], [{47=>nil}, 47, "s:+s", false], [{48=>nil}, 48, "s:+s", false], [{49=>nil}, 49, "s:+s", false]], 40=>[[{31=>:enemy}, 31, "s:+s", true], [{39=>:enemy}, 39, "s:+s", true], [{41=>:enemy}, 41, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{31=>nil}, 31, "s:+s", false], [{39=>nil}, 39, "s:+s", false], [{41=>nil}, 41, "s:+s", false], [{48=>nil}, 48, "s:+s", false], [{49=>nil}, 49, "s:+s", false], [{50=>nil}, 50, "s:+s", false]], 41=>[[{32=>:enemy}, 32, "s:+s", true], [{40=>:enemy}, 40, "s:+s", true], [{42=>:enemy}, 42, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{32=>nil}, 32, "s:+s", false], [{40=>nil}, 40, "s:+s", false], [{42=>nil}, 42, "s:+s", false], [{49=>nil}, 49, "s:+s", false], [{50=>nil}, 50, "s:+s", false], [{51=>nil}, 51, "s:+s", false]], 42=>[[{33=>:enemy}, 33, "s:+s", true], [{41=>:enemy}, 41, "s:+s", true], [{43=>:enemy}, 43, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{33=>nil}, 33, "s:+s", false], [{41=>nil}, 41, "s:+s", false], [{43=>nil}, 43, "s:+s", false], [{50=>nil}, 50, "s:+s", false], [{51=>nil}, 51, "s:+s", false], [{52=>nil}, 52, "s:+s", false]], 43=>[[{34=>:enemy}, 34, "s:+s", true], [{42=>:enemy}, 42, "s:+s", true], [{44=>:enemy}, 44, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{53=>:enemy}, 53, "s:+s", true], [{34=>nil}, 34, "s:+s", false], [{42=>nil}, 42, "s:+s", false], [{44=>nil}, 44, "s:+s", false], [{51=>nil}, 51, "s:+s", false], [{52=>nil}, 52, "s:+s", false], [{53=>nil}, 53, "s:+s", false]], 44=>[[{35=>:enemy}, 35, "s:+s", true], [{43=>:enemy}, 43, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{53=>:enemy}, 53, "s:+s", true], [{35=>nil}, 35, "s:+s", false], [{43=>nil}, 43, "s:+s", false], [{52=>nil}, 52, "s:+s", false], [{53=>nil}, 53, "s:+s", false]], 45=>[[{36=>:enemy}, 36, "s:+s", true], [{46=>:enemy}, 46, "s:+s", true], [{54=>:enemy}, 54, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{36=>nil}, 36, "s:+s", false], [{46=>nil}, 46, "s:+s", false], [{54=>nil}, 54, "s:+s", false], [{55=>nil}, 55, "s:+s", false]], 46=>[[{37=>:enemy}, 37, "s:+s", true], [{45=>:enemy}, 45, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{54=>:enemy}, 54, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{37=>nil}, 37, "s:+s", false], [{45=>nil}, 45, "s:+s", false], [{47=>nil}, 47, "s:+s", false], [{54=>nil}, 54, "s:+s", false], [{55=>nil}, 55, "s:+s", false], [{56=>nil}, 56, "s:+s", false]], 47=>[[{38=>:enemy}, 38, "s:+s", true], [{46=>:enemy}, 46, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{38=>nil}, 38, "s:+s", false], [{46=>nil}, 46, "s:+s", false], [{48=>nil}, 48, "s:+s", false], [{55=>nil}, 55, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{57=>nil}, 57, "s:+s", false]], 48=>[[{39=>:enemy}, 39, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{39=>nil}, 39, "s:+s", false], [{47=>nil}, 47, "s:+s", false], [{49=>nil}, 49, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{58=>nil}, 58, "s:+s", false]], 49=>[[{40=>:enemy}, 40, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{40=>nil}, 40, "s:+s", false], [{48=>nil}, 48, "s:+s", false], [{50=>nil}, 50, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{59=>nil}, 59, "s:+s", false]], 50=>[[{41=>:enemy}, 41, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{41=>nil}, 41, "s:+s", false], [{49=>nil}, 49, "s:+s", false], [{51=>nil}, 51, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{60=>nil}, 60, "s:+s", false]], 51=>[[{42=>:enemy}, 42, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{42=>nil}, 42, "s:+s", false], [{50=>nil}, 50, "s:+s", false], [{52=>nil}, 52, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{61=>nil}, 61, "s:+s", false]], 52=>[[{43=>:enemy}, 43, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{53=>:enemy}, 53, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{43=>nil}, 43, "s:+s", false], [{51=>nil}, 51, "s:+s", false], [{53=>nil}, 53, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{62=>nil}, 62, "s:+s", false]], 53=>[[{44=>:enemy}, 44, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{44=>nil}, 44, "s:+s", false], [{52=>nil}, 52, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{62=>nil}, 62, "s:+s", false]], 54=>[[{45=>:enemy}, 45, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{63=>:enemy}, 63, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{45=>nil}, 45, "s:+s", false], [{55=>nil}, 55, "s:+s", false], [{63=>nil}, 63, "s:+s", false], [{64=>nil}, 64, "s:+s", false]], 55=>[[{46=>:enemy}, 46, "s:+s", true], [{54=>:enemy}, 54, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{63=>:enemy}, 63, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{46=>nil}, 46, "s:+s", false], [{54=>nil}, 54, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{63=>nil}, 63, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{65=>nil}, 65, "s:+s", false]], 56=>[[{47=>:enemy}, 47, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{47=>nil}, 47, "s:+s", false], [{55=>nil}, 55, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{66=>nil}, 66, "s:+s", false]], 57=>[[{48=>:enemy}, 48, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{48=>nil}, 48, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{67=>nil}, 67, "s:+s", false]], 58=>[[{49=>:enemy}, 49, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{49=>nil}, 49, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{68=>nil}, 68, "s:+s", false]], 59=>[[{50=>:enemy}, 50, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{50=>nil}, 50, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{69=>nil}, 69, "s:+s", false]], 60=>[[{51=>:enemy}, 51, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{51=>nil}, 51, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{70=>nil}, 70, "s:+s", false]], 61=>[[{52=>:enemy}, 52, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{52=>nil}, 52, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{62=>nil}, 62, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{71=>nil}, 71, "s:+s", false]], 62=>[[{53=>:enemy}, 53, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{53=>nil}, 53, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{71=>nil}, 71, "s:+s", false]], 63=>[[{54=>:enemy}, 54, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{72=>:enemy}, 72, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{54=>nil}, 54, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{72=>nil}, 72, "s:+s", false], [{73=>nil}, 73, "s:+s", false]], 64=>[[{55=>:enemy}, 55, "s:+s", true], [{63=>:enemy}, 63, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{72=>:enemy}, 72, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{55=>nil}, 55, "s:+s", false], [{63=>nil}, 63, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{72=>nil}, 72, "s:+s", false], [{73=>nil}, 73, "s:+s", false], [{74=>nil}, 74, "s:+s", false]], 65=>[[{56=>:enemy}, 56, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{56=>nil}, 56, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{73=>nil}, 73, "s:+s", false], [{74=>nil}, 74, "s:+s", false], [{75=>nil}, 75, "s:+s", false]], 66=>[[{57=>:enemy}, 57, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{57=>nil}, 57, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{74=>nil}, 74, "s:+s", false], [{75=>nil}, 75, "s:+s", false], [{76=>nil}, 76, "s:+s", false]], 67=>[[{58=>:enemy}, 58, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{58=>nil}, 58, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{75=>nil}, 75, "s:+s", false], [{76=>nil}, 76, "s:+s", false], [{77=>nil}, 77, "s:+s", false]], 68=>[[{59=>:enemy}, 59, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{59=>nil}, 59, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{76=>nil}, 76, "s:+s", false], [{77=>nil}, 77, "s:+s", false], [{78=>nil}, 78, "s:+s", false]], 69=>[[{60=>:enemy}, 60, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{60=>nil}, 60, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{77=>nil}, 77, "s:+s", false], [{78=>nil}, 78, "s:+s", false], [{79=>nil}, 79, "s:+s", false]], 70=>[[{61=>:enemy}, 61, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{80=>:enemy}, 80, "s:+s", true], [{61=>nil}, 61, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{71=>nil}, 71, "s:+s", false], [{78=>nil}, 78, "s:+s", false], [{79=>nil}, 79, "s:+s", false], [{80=>nil}, 80, "s:+s", false]], 71=>[[{62=>:enemy}, 62, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{80=>:enemy}, 80, "s:+s", true], [{62=>nil}, 62, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{79=>nil}, 79, "s:+s", false], [{80=>nil}, 80, "s:+s", false]], 72=>[[{63=>:enemy}, 63, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{63=>nil}, 63, "s:+s", false], [{73=>nil}, 73, "s:+s", false]], 73=>[[{64=>:enemy}, 64, "s:+s", true], [{72=>:enemy}, 72, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{64=>nil}, 64, "s:+s", false], [{72=>nil}, 72, "s:+s", false], [{74=>nil}, 74, "s:+s", false]], 74=>[[{65=>:enemy}, 65, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{65=>nil}, 65, "s:+s", false], [{73=>nil}, 73, "s:+s", false], [{75=>nil}, 75, "s:+s", false]], 75=>[[{66=>:enemy}, 66, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{66=>nil}, 66, "s:+s", false], [{74=>nil}, 74, "s:+s", false], [{76=>nil}, 76, "s:+s", false]], 76=>[[{67=>:enemy}, 67, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{67=>nil}, 67, "s:+s", false], [{75=>nil}, 75, "s:+s", false], [{77=>nil}, 77, "s:+s", false]], 77=>[[{68=>:enemy}, 68, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{68=>nil}, 68, "s:+s", false], [{76=>nil}, 76, "s:+s", false], [{78=>nil}, 78, "s:+s", false]], 78=>[[{69=>:enemy}, 69, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{69=>nil}, 69, "s:+s", false], [{77=>nil}, 77, "s:+s", false], [{79=>nil}, 79, "s:+s", false]], 79=>[[{70=>:enemy}, 70, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{80=>:enemy}, 80, "s:+s", true], [{70=>nil}, 70, "s:+s", false], [{78=>nil}, 78, "s:+s", false], [{80=>nil}, 80, "s:+s", false]], 80=>[[{71=>:enemy}, 71, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{71=>nil}, 71, "s:+s", false], [{79=>nil}, 79, "s:+s", false]], nil=>[]}, "s:-k"=>{0=>[[{1=>:enemy}, 1, "s:-k", true], [{9=>:enemy}, 9, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{1=>nil}, 1, "s:-k", false], [{9=>nil}, 9, "s:-k", false], [{10=>nil}, 10, "s:-k", false]], 1=>[[{0=>:enemy}, 0, "s:-k", true], [{2=>:enemy}, 2, "s:-k", true], [{9=>:enemy}, 9, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{0=>nil}, 0, "s:-k", false], [{2=>nil}, 2, "s:-k", false], [{9=>nil}, 9, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{11=>nil}, 11, "s:-k", false]], 2=>[[{1=>:enemy}, 1, "s:-k", true], [{3=>:enemy}, 3, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{1=>nil}, 1, "s:-k", false], [{3=>nil}, 3, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{12=>nil}, 12, "s:-k", false]], 3=>[[{2=>:enemy}, 2, "s:-k", true], [{4=>:enemy}, 4, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{2=>nil}, 2, "s:-k", false], [{4=>nil}, 4, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{13=>nil}, 13, "s:-k", false]], 4=>[[{3=>:enemy}, 3, "s:-k", true], [{5=>:enemy}, 5, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{3=>nil}, 3, "s:-k", false], [{5=>nil}, 5, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{14=>nil}, 14, "s:-k", false]], 5=>[[{4=>:enemy}, 4, "s:-k", true], [{6=>:enemy}, 6, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{4=>nil}, 4, "s:-k", false], [{6=>nil}, 6, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{15=>nil}, 15, "s:-k", false]], 6=>[[{5=>:enemy}, 5, "s:-k", true], [{7=>:enemy}, 7, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{5=>nil}, 5, "s:-k", false], [{7=>nil}, 7, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{16=>nil}, 16, "s:-k", false]], 7=>[[{6=>:enemy}, 6, "s:-k", true], [{8=>:enemy}, 8, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{17=>:enemy}, 17, "s:-k", true], [{6=>nil}, 6, "s:-k", false], [{8=>nil}, 8, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{17=>nil}, 17, "s:-k", false]], 8=>[[{7=>:enemy}, 7, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{17=>:enemy}, 17, "s:-k", true], [{7=>nil}, 7, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{17=>nil}, 17, "s:-k", false]], 9=>[[{0=>:enemy}, 0, "s:-k", true], [{1=>:enemy}, 1, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{18=>:enemy}, 18, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{0=>nil}, 0, "s:-k", false], [{1=>nil}, 1, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{18=>nil}, 18, "s:-k", false], [{19=>nil}, 19, "s:-k", false]], 10=>[[{0=>:enemy}, 0, "s:-k", true], [{1=>:enemy}, 1, "s:-k", true], [{2=>:enemy}, 2, "s:-k", true], [{9=>:enemy}, 9, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{18=>:enemy}, 18, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{0=>nil}, 0, "s:-k", false], [{1=>nil}, 1, "s:-k", false], [{2=>nil}, 2, "s:-k", false], [{9=>nil}, 9, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{18=>nil}, 18, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{20=>nil}, 20, "s:-k", false]], 11=>[[{1=>:enemy}, 1, "s:-k", true], [{2=>:enemy}, 2, "s:-k", true], [{3=>:enemy}, 3, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{1=>nil}, 1, "s:-k", false], [{2=>nil}, 2, "s:-k", false], [{3=>nil}, 3, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{21=>nil}, 21, "s:-k", false]], 12=>[[{2=>:enemy}, 2, "s:-k", true], [{3=>:enemy}, 3, "s:-k", true], [{4=>:enemy}, 4, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{2=>nil}, 2, "s:-k", false], [{3=>nil}, 3, "s:-k", false], [{4=>nil}, 4, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{22=>nil}, 22, "s:-k", false]], 13=>[[{3=>:enemy}, 3, "s:-k", true], [{4=>:enemy}, 4, "s:-k", true], [{5=>:enemy}, 5, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{3=>nil}, 3, "s:-k", false], [{4=>nil}, 4, "s:-k", false], [{5=>nil}, 5, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{23=>nil}, 23, "s:-k", false]], 14=>[[{4=>:enemy}, 4, "s:-k", true], [{5=>:enemy}, 5, "s:-k", true], [{6=>:enemy}, 6, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{4=>nil}, 4, "s:-k", false], [{5=>nil}, 5, "s:-k", false], [{6=>nil}, 6, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{24=>nil}, 24, "s:-k", false]], 15=>[[{5=>:enemy}, 5, "s:-k", true], [{6=>:enemy}, 6, "s:-k", true], [{7=>:enemy}, 7, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{5=>nil}, 5, "s:-k", false], [{6=>nil}, 6, "s:-k", false], [{7=>nil}, 7, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{25=>nil}, 25, "s:-k", false]], 16=>[[{6=>:enemy}, 6, "s:-k", true], [{7=>:enemy}, 7, "s:-k", true], [{8=>:enemy}, 8, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{17=>:enemy}, 17, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{26=>:enemy}, 26, "s:-k", true], [{6=>nil}, 6, "s:-k", false], [{7=>nil}, 7, "s:-k", false], [{8=>nil}, 8, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{17=>nil}, 17, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{26=>nil}, 26, "s:-k", false]], 17=>[[{7=>:enemy}, 7, "s:-k", true], [{8=>:enemy}, 8, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{26=>:enemy}, 26, "s:-k", true], [{7=>nil}, 7, "s:-k", false], [{8=>nil}, 8, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{26=>nil}, 26, "s:-k", false]], 18=>[[{9=>:enemy}, 9, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{27=>:enemy}, 27, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{9=>nil}, 9, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{27=>nil}, 27, "s:-k", false], [{28=>nil}, 28, "s:-k", false]], 19=>[[{9=>:enemy}, 9, "s:-k", true], [{10=>:enemy}, 10, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{18=>:enemy}, 18, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{27=>:enemy}, 27, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{9=>nil}, 9, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{18=>nil}, 18, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{27=>nil}, 27, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{29=>nil}, 29, "s:-k", false]], 20=>[[{10=>:enemy}, 10, "s:-k", true], [{11=>:enemy}, 11, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{10=>nil}, 10, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{30=>nil}, 30, "s:-k", false]], 21=>[[{11=>:enemy}, 11, "s:-k", true], [{12=>:enemy}, 12, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{11=>nil}, 11, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{31=>nil}, 31, "s:-k", false]], 22=>[[{12=>:enemy}, 12, "s:-k", true], [{13=>:enemy}, 13, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{12=>nil}, 12, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{32=>nil}, 32, "s:-k", false]], 23=>[[{13=>:enemy}, 13, "s:-k", true], [{14=>:enemy}, 14, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{13=>nil}, 13, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{33=>nil}, 33, "s:-k", false]], 24=>[[{14=>:enemy}, 14, "s:-k", true], [{15=>:enemy}, 15, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{14=>nil}, 14, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{34=>nil}, 34, "s:-k", false]], 25=>[[{15=>:enemy}, 15, "s:-k", true], [{16=>:enemy}, 16, "s:-k", true], [{17=>:enemy}, 17, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{26=>:enemy}, 26, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{35=>:enemy}, 35, "s:-k", true], [{15=>nil}, 15, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{17=>nil}, 17, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{26=>nil}, 26, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{35=>nil}, 35, "s:-k", false]], 26=>[[{16=>:enemy}, 16, "s:-k", true], [{17=>:enemy}, 17, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{35=>:enemy}, 35, "s:-k", true], [{16=>nil}, 16, "s:-k", false], [{17=>nil}, 17, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{35=>nil}, 35, "s:-k", false]], 27=>[[{18=>:enemy}, 18, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{36=>:enemy}, 36, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{18=>nil}, 18, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{36=>nil}, 36, "s:-k", false], [{37=>nil}, 37, "s:-k", false]], 28=>[[{18=>:enemy}, 18, "s:-k", true], [{19=>:enemy}, 19, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{27=>:enemy}, 27, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{36=>:enemy}, 36, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{18=>nil}, 18, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{27=>nil}, 27, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{36=>nil}, 36, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{38=>nil}, 38, "s:-k", false]], 29=>[[{19=>:enemy}, 19, "s:-k", true], [{20=>:enemy}, 20, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{19=>nil}, 19, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{39=>nil}, 39, "s:-k", false]], 30=>[[{20=>:enemy}, 20, "s:-k", true], [{21=>:enemy}, 21, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{20=>nil}, 20, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{40=>nil}, 40, "s:-k", false]], 31=>[[{21=>:enemy}, 21, "s:-k", true], [{22=>:enemy}, 22, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{21=>nil}, 21, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{41=>nil}, 41, "s:-k", false]], 32=>[[{22=>:enemy}, 22, "s:-k", true], [{23=>:enemy}, 23, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{22=>nil}, 22, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{42=>nil}, 42, "s:-k", false]], 33=>[[{23=>:enemy}, 23, "s:-k", true], [{24=>:enemy}, 24, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{23=>nil}, 23, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{43=>nil}, 43, "s:-k", false]], 34=>[[{24=>:enemy}, 24, "s:-k", true], [{25=>:enemy}, 25, "s:-k", true], [{26=>:enemy}, 26, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{35=>:enemy}, 35, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{44=>:enemy}, 44, "s:-k", true], [{24=>nil}, 24, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{26=>nil}, 26, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{35=>nil}, 35, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{44=>nil}, 44, "s:-k", false]], 35=>[[{25=>:enemy}, 25, "s:-k", true], [{26=>:enemy}, 26, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{44=>:enemy}, 44, "s:-k", true], [{25=>nil}, 25, "s:-k", false], [{26=>nil}, 26, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{44=>nil}, 44, "s:-k", false]], 36=>[[{27=>:enemy}, 27, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{45=>:enemy}, 45, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{27=>nil}, 27, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{45=>nil}, 45, "s:-k", false], [{46=>nil}, 46, "s:-k", false]], 37=>[[{27=>:enemy}, 27, "s:-k", true], [{28=>:enemy}, 28, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{36=>:enemy}, 36, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{45=>:enemy}, 45, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{27=>nil}, 27, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{36=>nil}, 36, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{45=>nil}, 45, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{47=>nil}, 47, "s:-k", false]], 38=>[[{28=>:enemy}, 28, "s:-k", true], [{29=>:enemy}, 29, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{28=>nil}, 28, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{48=>nil}, 48, "s:-k", false]], 39=>[[{29=>:enemy}, 29, "s:-k", true], [{30=>:enemy}, 30, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{29=>nil}, 29, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{49=>nil}, 49, "s:-k", false]], 40=>[[{30=>:enemy}, 30, "s:-k", true], [{31=>:enemy}, 31, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{30=>nil}, 30, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{50=>nil}, 50, "s:-k", false]], 41=>[[{31=>:enemy}, 31, "s:-k", true], [{32=>:enemy}, 32, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{31=>nil}, 31, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{51=>nil}, 51, "s:-k", false]], 42=>[[{32=>:enemy}, 32, "s:-k", true], [{33=>:enemy}, 33, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{32=>nil}, 32, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{52=>nil}, 52, "s:-k", false]], 43=>[[{33=>:enemy}, 33, "s:-k", true], [{34=>:enemy}, 34, "s:-k", true], [{35=>:enemy}, 35, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{44=>:enemy}, 44, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{53=>:enemy}, 53, "s:-k", true], [{33=>nil}, 33, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{35=>nil}, 35, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{44=>nil}, 44, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{53=>nil}, 53, "s:-k", false]], 44=>[[{34=>:enemy}, 34, "s:-k", true], [{35=>:enemy}, 35, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{53=>:enemy}, 53, "s:-k", true], [{34=>nil}, 34, "s:-k", false], [{35=>nil}, 35, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{53=>nil}, 53, "s:-k", false]], 45=>[[{36=>:enemy}, 36, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{54=>:enemy}, 54, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{36=>nil}, 36, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{54=>nil}, 54, "s:-k", false], [{55=>nil}, 55, "s:-k", false]], 46=>[[{36=>:enemy}, 36, "s:-k", true], [{37=>:enemy}, 37, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{45=>:enemy}, 45, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{54=>:enemy}, 54, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{36=>nil}, 36, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{45=>nil}, 45, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{54=>nil}, 54, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{56=>nil}, 56, "s:-k", false]], 47=>[[{37=>:enemy}, 37, "s:-k", true], [{38=>:enemy}, 38, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{37=>nil}, 37, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{57=>nil}, 57, "s:-k", false]], 48=>[[{38=>:enemy}, 38, "s:-k", true], [{39=>:enemy}, 39, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{38=>nil}, 38, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{58=>nil}, 58, "s:-k", false]], 49=>[[{39=>:enemy}, 39, "s:-k", true], [{40=>:enemy}, 40, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{39=>nil}, 39, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{59=>nil}, 59, "s:-k", false]], 50=>[[{40=>:enemy}, 40, "s:-k", true], [{41=>:enemy}, 41, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{40=>nil}, 40, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{60=>nil}, 60, "s:-k", false]], 51=>[[{41=>:enemy}, 41, "s:-k", true], [{42=>:enemy}, 42, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{41=>nil}, 41, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{61=>nil}, 61, "s:-k", false]], 52=>[[{42=>:enemy}, 42, "s:-k", true], [{43=>:enemy}, 43, "s:-k", true], [{44=>:enemy}, 44, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{53=>:enemy}, 53, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{62=>:enemy}, 62, "s:-k", true], [{42=>nil}, 42, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{44=>nil}, 44, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{53=>nil}, 53, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{62=>nil}, 62, "s:-k", false]], 53=>[[{43=>:enemy}, 43, "s:-k", true], [{44=>:enemy}, 44, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{62=>:enemy}, 62, "s:-k", true], [{43=>nil}, 43, "s:-k", false], [{44=>nil}, 44, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{62=>nil}, 62, "s:-k", false]], 54=>[[{45=>:enemy}, 45, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{63=>:enemy}, 63, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{45=>nil}, 45, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{63=>nil}, 63, "s:-k", false], [{64=>nil}, 64, "s:-k", false]], 55=>[[{45=>:enemy}, 45, "s:-k", true], [{46=>:enemy}, 46, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{54=>:enemy}, 54, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{63=>:enemy}, 63, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{45=>nil}, 45, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{54=>nil}, 54, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{63=>nil}, 63, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{65=>nil}, 65, "s:-k", false]], 56=>[[{46=>:enemy}, 46, "s:-k", true], [{47=>:enemy}, 47, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{46=>nil}, 46, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{66=>nil}, 66, "s:-k", false]], 57=>[[{47=>:enemy}, 47, "s:-k", true], [{48=>:enemy}, 48, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{47=>nil}, 47, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{67=>nil}, 67, "s:-k", false]], 58=>[[{48=>:enemy}, 48, "s:-k", true], [{49=>:enemy}, 49, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{48=>nil}, 48, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{68=>nil}, 68, "s:-k", false]], 59=>[[{49=>:enemy}, 49, "s:-k", true], [{50=>:enemy}, 50, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{49=>nil}, 49, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{69=>nil}, 69, "s:-k", false]], 60=>[[{50=>:enemy}, 50, "s:-k", true], [{51=>:enemy}, 51, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{50=>nil}, 50, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{70=>nil}, 70, "s:-k", false]], 61=>[[{51=>:enemy}, 51, "s:-k", true], [{52=>:enemy}, 52, "s:-k", true], [{53=>:enemy}, 53, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{62=>:enemy}, 62, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{71=>:enemy}, 71, "s:-k", true], [{51=>nil}, 51, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{53=>nil}, 53, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{62=>nil}, 62, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{71=>nil}, 71, "s:-k", false]], 62=>[[{52=>:enemy}, 52, "s:-k", true], [{53=>:enemy}, 53, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{71=>:enemy}, 71, "s:-k", true], [{52=>nil}, 52, "s:-k", false], [{53=>nil}, 53, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{71=>nil}, 71, "s:-k", false]], 63=>[[{54=>:enemy}, 54, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{72=>:enemy}, 72, "s:-k", true], [{73=>:enemy}, 73, "s:-k", true], [{54=>nil}, 54, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{72=>nil}, 72, "s:-k", false], [{73=>nil}, 73, "s:-k", false]], 64=>[[{54=>:enemy}, 54, "s:-k", true], [{55=>:enemy}, 55, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{63=>:enemy}, 63, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{72=>:enemy}, 72, "s:-k", true], [{73=>:enemy}, 73, "s:-k", true], [{74=>:enemy}, 74, "s:-k", true], [{54=>nil}, 54, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{63=>nil}, 63, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{72=>nil}, 72, "s:-k", false], [{73=>nil}, 73, "s:-k", false], [{74=>nil}, 74, "s:-k", false]], 65=>[[{55=>:enemy}, 55, "s:-k", true], [{56=>:enemy}, 56, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{73=>:enemy}, 73, "s:-k", true], [{74=>:enemy}, 74, "s:-k", true], [{75=>:enemy}, 75, "s:-k", true], [{55=>nil}, 55, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{73=>nil}, 73, "s:-k", false], [{74=>nil}, 74, "s:-k", false], [{75=>nil}, 75, "s:-k", false]], 66=>[[{56=>:enemy}, 56, "s:-k", true], [{57=>:enemy}, 57, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{74=>:enemy}, 74, "s:-k", true], [{75=>:enemy}, 75, "s:-k", true], [{76=>:enemy}, 76, "s:-k", true], [{56=>nil}, 56, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{74=>nil}, 74, "s:-k", false], [{75=>nil}, 75, "s:-k", false], [{76=>nil}, 76, "s:-k", false]], 67=>[[{57=>:enemy}, 57, "s:-k", true], [{58=>:enemy}, 58, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{75=>:enemy}, 75, "s:-k", true], [{76=>:enemy}, 76, "s:-k", true], [{77=>:enemy}, 77, "s:-k", true], [{57=>nil}, 57, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{75=>nil}, 75, "s:-k", false], [{76=>nil}, 76, "s:-k", false], [{77=>nil}, 77, "s:-k", false]], 68=>[[{58=>:enemy}, 58, "s:-k", true], [{59=>:enemy}, 59, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{76=>:enemy}, 76, "s:-k", true], [{77=>:enemy}, 77, "s:-k", true], [{78=>:enemy}, 78, "s:-k", true], [{58=>nil}, 58, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{76=>nil}, 76, "s:-k", false], [{77=>nil}, 77, "s:-k", false], [{78=>nil}, 78, "s:-k", false]], 69=>[[{59=>:enemy}, 59, "s:-k", true], [{60=>:enemy}, 60, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{77=>:enemy}, 77, "s:-k", true], [{78=>:enemy}, 78, "s:-k", true], [{79=>:enemy}, 79, "s:-k", true], [{59=>nil}, 59, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{77=>nil}, 77, "s:-k", false], [{78=>nil}, 78, "s:-k", false], [{79=>nil}, 79, "s:-k", false]], 70=>[[{60=>:enemy}, 60, "s:-k", true], [{61=>:enemy}, 61, "s:-k", true], [{62=>:enemy}, 62, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{71=>:enemy}, 71, "s:-k", true], [{78=>:enemy}, 78, "s:-k", true], [{79=>:enemy}, 79, "s:-k", true], [{80=>:enemy}, 80, "s:-k", true], [{60=>nil}, 60, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{62=>nil}, 62, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{71=>nil}, 71, "s:-k", false], [{78=>nil}, 78, "s:-k", false], [{79=>nil}, 79, "s:-k", false], [{80=>nil}, 80, "s:-k", false]], 71=>[[{61=>:enemy}, 61, "s:-k", true], [{62=>:enemy}, 62, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{79=>:enemy}, 79, "s:-k", true], [{80=>:enemy}, 80, "s:-k", true], [{61=>nil}, 61, "s:-k", false], [{62=>nil}, 62, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{79=>nil}, 79, "s:-k", false], [{80=>nil}, 80, "s:-k", false]], 72=>[[{63=>:enemy}, 63, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{73=>:enemy}, 73, "s:-k", true], [{63=>nil}, 63, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{73=>nil}, 73, "s:-k", false]], 73=>[[{63=>:enemy}, 63, "s:-k", true], [{64=>:enemy}, 64, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{72=>:enemy}, 72, "s:-k", true], [{74=>:enemy}, 74, "s:-k", true], [{63=>nil}, 63, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{72=>nil}, 72, "s:-k", false], [{74=>nil}, 74, "s:-k", false]], 74=>[[{64=>:enemy}, 64, "s:-k", true], [{65=>:enemy}, 65, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{73=>:enemy}, 73, "s:-k", true], [{75=>:enemy}, 75, "s:-k", true], [{64=>nil}, 64, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{73=>nil}, 73, "s:-k", false], [{75=>nil}, 75, "s:-k", false]], 75=>[[{65=>:enemy}, 65, "s:-k", true], [{66=>:enemy}, 66, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{74=>:enemy}, 74, "s:-k", true], [{76=>:enemy}, 76, "s:-k", true], [{65=>nil}, 65, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{74=>nil}, 74, "s:-k", false], [{76=>nil}, 76, "s:-k", false]], 76=>[[{66=>:enemy}, 66, "s:-k", true], [{67=>:enemy}, 67, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{75=>:enemy}, 75, "s:-k", true], [{77=>:enemy}, 77, "s:-k", true], [{66=>nil}, 66, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{75=>nil}, 75, "s:-k", false], [{77=>nil}, 77, "s:-k", false]], 77=>[[{67=>:enemy}, 67, "s:-k", true], [{68=>:enemy}, 68, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{76=>:enemy}, 76, "s:-k", true], [{78=>:enemy}, 78, "s:-k", true], [{67=>nil}, 67, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{76=>nil}, 76, "s:-k", false], [{78=>nil}, 78, "s:-k", false]], 78=>[[{68=>:enemy}, 68, "s:-k", true], [{69=>:enemy}, 69, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{77=>:enemy}, 77, "s:-k", true], [{79=>:enemy}, 79, "s:-k", true], [{68=>nil}, 68, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{77=>nil}, 77, "s:-k", false], [{79=>nil}, 79, "s:-k", false]], 79=>[[{69=>:enemy}, 69, "s:-k", true], [{70=>:enemy}, 70, "s:-k", true], [{71=>:enemy}, 71, "s:-k", true], [{78=>:enemy}, 78, "s:-k", true], [{80=>:enemy}, 80, "s:-k", true], [{69=>nil}, 69, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{71=>nil}, 71, "s:-k", false], [{78=>nil}, 78, "s:-k", false], [{80=>nil}, 80, "s:-k", false]], 80=>[[{70=>:enemy}, 70, "s:-k", true], [{71=>:enemy}, 71, "s:-k", true], [{79=>:enemy}, 79, "s:-k", true], [{70=>nil}, 70, "s:-k", false], [{71=>nil}, 71, "s:-k", false], [{79=>nil}, 79, "s:-k", false]], nil=>[[{0=>nil}, 0, "s:-k", false], [{1=>nil}, 1, "s:-k", false], [{2=>nil}, 2, "s:-k", false], [{3=>nil}, 3, "s:-k", false], [{4=>nil}, 4, "s:-k", false], [{5=>nil}, 5, "s:-k", false], [{6=>nil}, 6, "s:-k", false], [{7=>nil}, 7, "s:-k", false], [{8=>nil}, 8, "s:-k", false], [{9=>nil}, 9, "s:-k", false], [{10=>nil}, 10, "s:-k", false], [{11=>nil}, 11, "s:-k", false], [{12=>nil}, 12, "s:-k", false], [{13=>nil}, 13, "s:-k", false], [{14=>nil}, 14, "s:-k", false], [{15=>nil}, 15, "s:-k", false], [{16=>nil}, 16, "s:-k", false], [{17=>nil}, 17, "s:-k", false], [{18=>nil}, 18, "s:-k", false], [{19=>nil}, 19, "s:-k", false], [{20=>nil}, 20, "s:-k", false], [{21=>nil}, 21, "s:-k", false], [{22=>nil}, 22, "s:-k", false], [{23=>nil}, 23, "s:-k", false], [{24=>nil}, 24, "s:-k", false], [{25=>nil}, 25, "s:-k", false], [{26=>nil}, 26, "s:-k", false], [{27=>nil}, 27, "s:-k", false], [{28=>nil}, 28, "s:-k", false], [{29=>nil}, 29, "s:-k", false], [{30=>nil}, 30, "s:-k", false], [{31=>nil}, 31, "s:-k", false], [{32=>nil}, 32, "s:-k", false], [{33=>nil}, 33, "s:-k", false], [{34=>nil}, 34, "s:-k", false], [{35=>nil}, 35, "s:-k", false], [{36=>nil}, 36, "s:-k", false], [{37=>nil}, 37, "s:-k", false], [{38=>nil}, 38, "s:-k", false], [{39=>nil}, 39, "s:-k", false], [{40=>nil}, 40, "s:-k", false], [{41=>nil}, 41, "s:-k", false], [{42=>nil}, 42, "s:-k", false], [{43=>nil}, 43, "s:-k", false], [{44=>nil}, 44, "s:-k", false], [{45=>nil}, 45, "s:-k", false], [{46=>nil}, 46, "s:-k", false], [{47=>nil}, 47, "s:-k", false], [{48=>nil}, 48, "s:-k", false], [{49=>nil}, 49, "s:-k", false], [{50=>nil}, 50, "s:-k", false], [{51=>nil}, 51, "s:-k", false], [{52=>nil}, 52, "s:-k", false], [{53=>nil}, 53, "s:-k", false], [{54=>nil}, 54, "s:-k", false], [{55=>nil}, 55, "s:-k", false], [{56=>nil}, 56, "s:-k", false], [{57=>nil}, 57, "s:-k", false], [{58=>nil}, 58, "s:-k", false], [{59=>nil}, 59, "s:-k", false], [{60=>nil}, 60, "s:-k", false], [{61=>nil}, 61, "s:-k", false], [{62=>nil}, 62, "s:-k", false], [{63=>nil}, 63, "s:-k", false], [{64=>nil}, 64, "s:-k", false], [{65=>nil}, 65, "s:-k", false], [{66=>nil}, 66, "s:-k", false], [{67=>nil}, 67, "s:-k", false], [{68=>nil}, 68, "s:-k", false], [{69=>nil}, 69, "s:-k", false], [{70=>nil}, 70, "s:-k", false], [{71=>nil}, 71, "s:-k", false], [{72=>nil}, 72, "s:-k", false], [{73=>nil}, 73, "s:-k", false], [{74=>nil}, 74, "s:-k", false], [{75=>nil}, 75, "s:-k", false], [{76=>nil}, 76, "s:-k", false], [{77=>nil}, 77, "s:-k", false], [{78=>nil}, 78, "s:-k", false], [{79=>nil}, 79, "s:-k", false], [{80=>nil}, 80, "s:-k", false]]}, "s:b"=>{0=>[[{10=>:enemy}, 10, "s:b", true], [{10=>nil}, 10, "s:b", false], [{10=>nil, 20=>:enemy}, 20, "s:b", true], [{10=>nil, 20=>nil}, 20, "s:b", false], [{10=>nil, 20=>nil, 30=>:enemy}, 30, "s:b", true], [{10=>nil, 20=>nil, 30=>nil}, 30, "s:b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>:enemy}, 40, "s:b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil}, 40, "s:b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "s:b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "s:b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{10=>nil, 20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 1=>[[{9=>:enemy}, 9, "s:b", true], [{11=>:enemy}, 11, "s:b", true], [{9=>nil}, 9, "s:b", false], [{11=>nil}, 11, "s:b", false], [{11=>nil, 21=>:enemy}, 21, "s:b", true], [{11=>nil, 21=>nil}, 21, "s:b", false], [{11=>nil, 21=>nil, 31=>:enemy}, 31, "s:b", true], [{11=>nil, 21=>nil, 31=>nil}, 31, "s:b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>:enemy}, 41, "s:b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil}, 41, "s:b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "s:b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "s:b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{11=>nil, 21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 2=>[[{10=>:enemy}, 10, "s:b", true], [{12=>:enemy}, 12, "s:b", true], [{10=>nil}, 10, "s:b", false], [{10=>nil, 18=>:enemy}, 18, "s:b", true], [{10=>nil, 18=>nil}, 18, "s:b", false], [{12=>nil}, 12, "s:b", false], [{12=>nil, 22=>:enemy}, 22, "s:b", true], [{12=>nil, 22=>nil}, 22, "s:b", false], [{12=>nil, 22=>nil, 32=>:enemy}, 32, "s:b", true], [{12=>nil, 22=>nil, 32=>nil}, 32, "s:b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>:enemy}, 42, "s:b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil}, 42, "s:b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "s:b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "s:b", false], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{12=>nil, 22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 3=>[[{11=>:enemy}, 11, "s:b", true], [{13=>:enemy}, 13, "s:b", true], [{11=>nil}, 11, "s:b", false], [{11=>nil, 19=>:enemy}, 19, "s:b", true], [{11=>nil, 19=>nil}, 19, "s:b", false], [{11=>nil, 19=>nil, 27=>:enemy}, 27, "s:b", true], [{11=>nil, 19=>nil, 27=>nil}, 27, "s:b", false], [{13=>nil}, 13, "s:b", false], [{13=>nil, 23=>:enemy}, 23, "s:b", true], [{13=>nil, 23=>nil}, 23, "s:b", false], [{13=>nil, 23=>nil, 33=>:enemy}, 33, "s:b", true], [{13=>nil, 23=>nil, 33=>nil}, 33, "s:b", false], [{13=>nil, 23=>nil, 33=>nil, 43=>:enemy}, 43, "s:b", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil}, 43, "s:b", false], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "s:b", true], [{13=>nil, 23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "s:b", false]], 4=>[[{12=>:enemy}, 12, "s:b", true], [{14=>:enemy}, 14, "s:b", true], [{12=>nil}, 12, "s:b", false], [{12=>nil, 20=>:enemy}, 20, "s:b", true], [{12=>nil, 20=>nil}, 20, "s:b", false], [{12=>nil, 20=>nil, 28=>:enemy}, 28, "s:b", true], [{12=>nil, 20=>nil, 28=>nil}, 28, "s:b", false], [{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, 36, "s:b", true], [{12=>nil, 20=>nil, 28=>nil, 36=>nil}, 36, "s:b", false], [{14=>nil}, 14, "s:b", false], [{14=>nil, 24=>:enemy}, 24, "s:b", true], [{14=>nil, 24=>nil}, 24, "s:b", false], [{14=>nil, 24=>nil, 34=>:enemy}, 34, "s:b", true], [{14=>nil, 24=>nil, 34=>nil}, 34, "s:b", false], [{14=>nil, 24=>nil, 34=>nil, 44=>:enemy}, 44, "s:b", true], [{14=>nil, 24=>nil, 34=>nil, 44=>nil}, 44, "s:b", false]], 5=>[[{13=>:enemy}, 13, "s:b", true], [{15=>:enemy}, 15, "s:b", true], [{13=>nil}, 13, "s:b", false], [{13=>nil, 21=>:enemy}, 21, "s:b", true], [{13=>nil, 21=>nil}, 21, "s:b", false], [{13=>nil, 21=>nil, 29=>:enemy}, 29, "s:b", true], [{13=>nil, 21=>nil, 29=>nil}, 29, "s:b", false], [{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, 37, "s:b", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil}, 37, "s:b", false], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "s:b", true], [{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "s:b", false], [{15=>nil}, 15, "s:b", false], [{15=>nil, 25=>:enemy}, 25, "s:b", true], [{15=>nil, 25=>nil}, 25, "s:b", false], [{15=>nil, 25=>nil, 35=>:enemy}, 35, "s:b", true], [{15=>nil, 25=>nil, 35=>nil}, 35, "s:b", false]], 6=>[[{14=>:enemy}, 14, "s:b", true], [{16=>:enemy}, 16, "s:b", true], [{14=>nil}, 14, "s:b", false], [{14=>nil, 22=>:enemy}, 22, "s:b", true], [{14=>nil, 22=>nil}, 22, "s:b", false], [{14=>nil, 22=>nil, 30=>:enemy}, 30, "s:b", true], [{14=>nil, 22=>nil, 30=>nil}, 30, "s:b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, 38, "s:b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil}, 38, "s:b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "s:b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "s:b", false], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{16=>nil}, 16, "s:b", false], [{16=>nil, 26=>:enemy}, 26, "s:b", true], [{16=>nil, 26=>nil}, 26, "s:b", false]], 7=>[[{15=>:enemy}, 15, "s:b", true], [{17=>:enemy}, 17, "s:b", true], [{15=>nil}, 15, "s:b", false], [{15=>nil, 23=>:enemy}, 23, "s:b", true], [{15=>nil, 23=>nil}, 23, "s:b", false], [{15=>nil, 23=>nil, 31=>:enemy}, 31, "s:b", true], [{15=>nil, 23=>nil, 31=>nil}, 31, "s:b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, 39, "s:b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil}, 39, "s:b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "s:b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "s:b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{17=>nil}, 17, "s:b", false]], 8=>[[{16=>:enemy}, 16, "s:b", true], [{16=>nil}, 16, "s:b", false], [{16=>nil, 24=>:enemy}, 24, "s:b", true], [{16=>nil, 24=>nil}, 24, "s:b", false], [{16=>nil, 24=>nil, 32=>:enemy}, 32, "s:b", true], [{16=>nil, 24=>nil, 32=>nil}, 32, "s:b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, 40, "s:b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil}, 40, "s:b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "s:b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "s:b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false]], 9=>[[{1=>:enemy}, 1, "s:b", true], [{19=>:enemy}, 19, "s:b", true], [{1=>nil}, 1, "s:b", false], [{19=>nil}, 19, "s:b", false], [{19=>nil, 29=>:enemy}, 29, "s:b", true], [{19=>nil, 29=>nil}, 29, "s:b", false], [{19=>nil, 29=>nil, 39=>:enemy}, 39, "s:b", true], [{19=>nil, 29=>nil, 39=>nil}, 39, "s:b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>:enemy}, 49, "s:b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil}, 49, "s:b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{19=>nil, 29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 10=>[[{0=>:enemy}, 0, "s:b", true], [{2=>:enemy}, 2, "s:b", true], [{18=>:enemy}, 18, "s:b", true], [{20=>:enemy}, 20, "s:b", true], [{0=>nil}, 0, "s:b", false], [{2=>nil}, 2, "s:b", false], [{18=>nil}, 18, "s:b", false], [{20=>nil}, 20, "s:b", false], [{20=>nil, 30=>:enemy}, 30, "s:b", true], [{20=>nil, 30=>nil}, 30, "s:b", false], [{20=>nil, 30=>nil, 40=>:enemy}, 40, "s:b", true], [{20=>nil, 30=>nil, 40=>nil}, 40, "s:b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>:enemy}, 50, "s:b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil}, 50, "s:b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{20=>nil, 30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 11=>[[{1=>:enemy}, 1, "s:b", true], [{3=>:enemy}, 3, "s:b", true], [{19=>:enemy}, 19, "s:b", true], [{21=>:enemy}, 21, "s:b", true], [{1=>nil}, 1, "s:b", false], [{3=>nil}, 3, "s:b", false], [{19=>nil}, 19, "s:b", false], [{19=>nil, 27=>:enemy}, 27, "s:b", true], [{19=>nil, 27=>nil}, 27, "s:b", false], [{21=>nil}, 21, "s:b", false], [{21=>nil, 31=>:enemy}, 31, "s:b", true], [{21=>nil, 31=>nil}, 31, "s:b", false], [{21=>nil, 31=>nil, 41=>:enemy}, 41, "s:b", true], [{21=>nil, 31=>nil, 41=>nil}, 41, "s:b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>:enemy}, 51, "s:b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil}, 51, "s:b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{21=>nil, 31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 12=>[[{2=>:enemy}, 2, "s:b", true], [{4=>:enemy}, 4, "s:b", true], [{20=>:enemy}, 20, "s:b", true], [{22=>:enemy}, 22, "s:b", true], [{2=>nil}, 2, "s:b", false], [{4=>nil}, 4, "s:b", false], [{20=>nil}, 20, "s:b", false], [{20=>nil, 28=>:enemy}, 28, "s:b", true], [{20=>nil, 28=>nil}, 28, "s:b", false], [{20=>nil, 28=>nil, 36=>:enemy}, 36, "s:b", true], [{20=>nil, 28=>nil, 36=>nil}, 36, "s:b", false], [{22=>nil}, 22, "s:b", false], [{22=>nil, 32=>:enemy}, 32, "s:b", true], [{22=>nil, 32=>nil}, 32, "s:b", false], [{22=>nil, 32=>nil, 42=>:enemy}, 42, "s:b", true], [{22=>nil, 32=>nil, 42=>nil}, 42, "s:b", false], [{22=>nil, 32=>nil, 42=>nil, 52=>:enemy}, 52, "s:b", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil}, 52, "s:b", false], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{22=>nil, 32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 13=>[[{3=>:enemy}, 3, "s:b", true], [{5=>:enemy}, 5, "s:b", true], [{21=>:enemy}, 21, "s:b", true], [{23=>:enemy}, 23, "s:b", true], [{3=>nil}, 3, "s:b", false], [{5=>nil}, 5, "s:b", false], [{21=>nil}, 21, "s:b", false], [{21=>nil, 29=>:enemy}, 29, "s:b", true], [{21=>nil, 29=>nil}, 29, "s:b", false], [{21=>nil, 29=>nil, 37=>:enemy}, 37, "s:b", true], [{21=>nil, 29=>nil, 37=>nil}, 37, "s:b", false], [{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, 45, "s:b", true], [{21=>nil, 29=>nil, 37=>nil, 45=>nil}, 45, "s:b", false], [{23=>nil}, 23, "s:b", false], [{23=>nil, 33=>:enemy}, 33, "s:b", true], [{23=>nil, 33=>nil}, 33, "s:b", false], [{23=>nil, 33=>nil, 43=>:enemy}, 43, "s:b", true], [{23=>nil, 33=>nil, 43=>nil}, 43, "s:b", false], [{23=>nil, 33=>nil, 43=>nil, 53=>:enemy}, 53, "s:b", true], [{23=>nil, 33=>nil, 43=>nil, 53=>nil}, 53, "s:b", false]], 14=>[[{4=>:enemy}, 4, "s:b", true], [{6=>:enemy}, 6, "s:b", true], [{22=>:enemy}, 22, "s:b", true], [{24=>:enemy}, 24, "s:b", true], [{4=>nil}, 4, "s:b", false], [{6=>nil}, 6, "s:b", false], [{22=>nil}, 22, "s:b", false], [{22=>nil, 30=>:enemy}, 30, "s:b", true], [{22=>nil, 30=>nil}, 30, "s:b", false], [{22=>nil, 30=>nil, 38=>:enemy}, 38, "s:b", true], [{22=>nil, 30=>nil, 38=>nil}, 38, "s:b", false], [{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, 46, "s:b", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil}, 46, "s:b", false], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{24=>nil}, 24, "s:b", false], [{24=>nil, 34=>:enemy}, 34, "s:b", true], [{24=>nil, 34=>nil}, 34, "s:b", false], [{24=>nil, 34=>nil, 44=>:enemy}, 44, "s:b", true], [{24=>nil, 34=>nil, 44=>nil}, 44, "s:b", false]], 15=>[[{5=>:enemy}, 5, "s:b", true], [{7=>:enemy}, 7, "s:b", true], [{23=>:enemy}, 23, "s:b", true], [{25=>:enemy}, 25, "s:b", true], [{5=>nil}, 5, "s:b", false], [{7=>nil}, 7, "s:b", false], [{23=>nil}, 23, "s:b", false], [{23=>nil, 31=>:enemy}, 31, "s:b", true], [{23=>nil, 31=>nil}, 31, "s:b", false], [{23=>nil, 31=>nil, 39=>:enemy}, 39, "s:b", true], [{23=>nil, 31=>nil, 39=>nil}, 39, "s:b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, 47, "s:b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil}, 47, "s:b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{25=>nil}, 25, "s:b", false], [{25=>nil, 35=>:enemy}, 35, "s:b", true], [{25=>nil, 35=>nil}, 35, "s:b", false]], 16=>[[{6=>:enemy}, 6, "s:b", true], [{8=>:enemy}, 8, "s:b", true], [{24=>:enemy}, 24, "s:b", true], [{26=>:enemy}, 26, "s:b", true], [{6=>nil}, 6, "s:b", false], [{8=>nil}, 8, "s:b", false], [{24=>nil}, 24, "s:b", false], [{24=>nil, 32=>:enemy}, 32, "s:b", true], [{24=>nil, 32=>nil}, 32, "s:b", false], [{24=>nil, 32=>nil, 40=>:enemy}, 40, "s:b", true], [{24=>nil, 32=>nil, 40=>nil}, 40, "s:b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, 48, "s:b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil}, 48, "s:b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{26=>nil}, 26, "s:b", false]], 17=>[[{7=>:enemy}, 7, "s:b", true], [{25=>:enemy}, 25, "s:b", true], [{7=>nil}, 7, "s:b", false], [{25=>nil}, 25, "s:b", false], [{25=>nil, 33=>:enemy}, 33, "s:b", true], [{25=>nil, 33=>nil}, 33, "s:b", false], [{25=>nil, 33=>nil, 41=>:enemy}, 41, "s:b", true], [{25=>nil, 33=>nil, 41=>nil}, 41, "s:b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, 49, "s:b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil}, 49, "s:b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false]], 18=>[[{10=>:enemy}, 10, "s:b", true], [{28=>:enemy}, 28, "s:b", true], [{10=>nil}, 10, "s:b", false], [{10=>nil, 2=>:enemy}, 2, "s:b", true], [{10=>nil, 2=>nil}, 2, "s:b", false], [{28=>nil}, 28, "s:b", false], [{28=>nil, 38=>:enemy}, 38, "s:b", true], [{28=>nil, 38=>nil}, 38, "s:b", false], [{28=>nil, 38=>nil, 48=>:enemy}, 48, "s:b", true], [{28=>nil, 38=>nil, 48=>nil}, 48, "s:b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>:enemy}, 58, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil}, 58, "s:+b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{28=>nil, 38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 19=>[[{9=>:enemy}, 9, "s:b", true], [{11=>:enemy}, 11, "s:b", true], [{27=>:enemy}, 27, "s:b", true], [{29=>:enemy}, 29, "s:b", true], [{9=>nil}, 9, "s:b", false], [{11=>nil}, 11, "s:b", false], [{11=>nil, 3=>:enemy}, 3, "s:b", true], [{11=>nil, 3=>nil}, 3, "s:b", false], [{27=>nil}, 27, "s:b", false], [{29=>nil}, 29, "s:b", false], [{29=>nil, 39=>:enemy}, 39, "s:b", true], [{29=>nil, 39=>nil}, 39, "s:b", false], [{29=>nil, 39=>nil, 49=>:enemy}, 49, "s:b", true], [{29=>nil, 39=>nil, 49=>nil}, 49, "s:b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{29=>nil, 39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 20=>[[{10=>:enemy}, 10, "s:b", true], [{12=>:enemy}, 12, "s:b", true], [{28=>:enemy}, 28, "s:b", true], [{30=>:enemy}, 30, "s:b", true], [{10=>nil}, 10, "s:b", false], [{10=>nil, 0=>:enemy}, 0, "s:b", true], [{10=>nil, 0=>nil}, 0, "s:b", false], [{12=>nil}, 12, "s:b", false], [{12=>nil, 4=>:enemy}, 4, "s:b", true], [{12=>nil, 4=>nil}, 4, "s:b", false], [{28=>nil}, 28, "s:b", false], [{28=>nil, 36=>:enemy}, 36, "s:b", true], [{28=>nil, 36=>nil}, 36, "s:b", false], [{30=>nil}, 30, "s:b", false], [{30=>nil, 40=>:enemy}, 40, "s:b", true], [{30=>nil, 40=>nil}, 40, "s:b", false], [{30=>nil, 40=>nil, 50=>:enemy}, 50, "s:b", true], [{30=>nil, 40=>nil, 50=>nil}, 50, "s:b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{30=>nil, 40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 21=>[[{11=>:enemy}, 11, "s:b", true], [{13=>:enemy}, 13, "s:b", true], [{29=>:enemy}, 29, "s:b", true], [{31=>:enemy}, 31, "s:b", true], [{11=>nil}, 11, "s:b", false], [{11=>nil, 1=>:enemy}, 1, "s:b", true], [{11=>nil, 1=>nil}, 1, "s:b", false], [{13=>nil}, 13, "s:b", false], [{13=>nil, 5=>:enemy}, 5, "s:b", true], [{13=>nil, 5=>nil}, 5, "s:b", false], [{29=>nil}, 29, "s:b", false], [{29=>nil, 37=>:enemy}, 37, "s:b", true], [{29=>nil, 37=>nil}, 37, "s:b", false], [{29=>nil, 37=>nil, 45=>:enemy}, 45, "s:b", true], [{29=>nil, 37=>nil, 45=>nil}, 45, "s:b", false], [{31=>nil}, 31, "s:b", false], [{31=>nil, 41=>:enemy}, 41, "s:b", true], [{31=>nil, 41=>nil}, 41, "s:b", false], [{31=>nil, 41=>nil, 51=>:enemy}, 51, "s:b", true], [{31=>nil, 41=>nil, 51=>nil}, 51, "s:b", false], [{31=>nil, 41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{31=>nil, 41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 22=>[[{12=>:enemy}, 12, "s:b", true], [{14=>:enemy}, 14, "s:b", true], [{30=>:enemy}, 30, "s:b", true], [{32=>:enemy}, 32, "s:b", true], [{12=>nil}, 12, "s:b", false], [{12=>nil, 2=>:enemy}, 2, "s:b", true], [{12=>nil, 2=>nil}, 2, "s:b", false], [{14=>nil}, 14, "s:b", false], [{14=>nil, 6=>:enemy}, 6, "s:b", true], [{14=>nil, 6=>nil}, 6, "s:b", false], [{30=>nil}, 30, "s:b", false], [{30=>nil, 38=>:enemy}, 38, "s:b", true], [{30=>nil, 38=>nil}, 38, "s:b", false], [{30=>nil, 38=>nil, 46=>:enemy}, 46, "s:b", true], [{30=>nil, 38=>nil, 46=>nil}, 46, "s:b", false], [{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{30=>nil, 38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{32=>nil}, 32, "s:b", false], [{32=>nil, 42=>:enemy}, 42, "s:b", true], [{32=>nil, 42=>nil}, 42, "s:b", false], [{32=>nil, 42=>nil, 52=>:enemy}, 52, "s:b", true], [{32=>nil, 42=>nil, 52=>nil}, 52, "s:b", false], [{32=>nil, 42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{32=>nil, 42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 23=>[[{13=>:enemy}, 13, "s:b", true], [{15=>:enemy}, 15, "s:b", true], [{31=>:enemy}, 31, "s:b", true], [{33=>:enemy}, 33, "s:b", true], [{13=>nil}, 13, "s:b", false], [{13=>nil, 3=>:enemy}, 3, "s:b", true], [{13=>nil, 3=>nil}, 3, "s:b", false], [{15=>nil}, 15, "s:b", false], [{15=>nil, 7=>:enemy}, 7, "s:b", true], [{15=>nil, 7=>nil}, 7, "s:b", false], [{31=>nil}, 31, "s:b", false], [{31=>nil, 39=>:enemy}, 39, "s:b", true], [{31=>nil, 39=>nil}, 39, "s:b", false], [{31=>nil, 39=>nil, 47=>:enemy}, 47, "s:b", true], [{31=>nil, 39=>nil, 47=>nil}, 47, "s:b", false], [{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{33=>nil}, 33, "s:b", false], [{33=>nil, 43=>:enemy}, 43, "s:b", true], [{33=>nil, 43=>nil}, 43, "s:b", false], [{33=>nil, 43=>nil, 53=>:enemy}, 53, "s:b", true], [{33=>nil, 43=>nil, 53=>nil}, 53, "s:b", false]], 24=>[[{14=>:enemy}, 14, "s:b", true], [{16=>:enemy}, 16, "s:b", true], [{32=>:enemy}, 32, "s:b", true], [{34=>:enemy}, 34, "s:b", true], [{14=>nil}, 14, "s:b", false], [{14=>nil, 4=>:enemy}, 4, "s:b", true], [{14=>nil, 4=>nil}, 4, "s:b", false], [{16=>nil}, 16, "s:b", false], [{16=>nil, 8=>:enemy}, 8, "s:b", true], [{16=>nil, 8=>nil}, 8, "s:b", false], [{32=>nil}, 32, "s:b", false], [{32=>nil, 40=>:enemy}, 40, "s:b", true], [{32=>nil, 40=>nil}, 40, "s:b", false], [{32=>nil, 40=>nil, 48=>:enemy}, 48, "s:b", true], [{32=>nil, 40=>nil, 48=>nil}, 48, "s:b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{32=>nil, 40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{34=>nil}, 34, "s:b", false], [{34=>nil, 44=>:enemy}, 44, "s:b", true], [{34=>nil, 44=>nil}, 44, "s:b", false]], 25=>[[{15=>:enemy}, 15, "s:b", true], [{17=>:enemy}, 17, "s:b", true], [{33=>:enemy}, 33, "s:b", true], [{35=>:enemy}, 35, "s:b", true], [{15=>nil}, 15, "s:b", false], [{15=>nil, 5=>:enemy}, 5, "s:b", true], [{15=>nil, 5=>nil}, 5, "s:b", false], [{17=>nil}, 17, "s:b", false], [{33=>nil}, 33, "s:b", false], [{33=>nil, 41=>:enemy}, 41, "s:b", true], [{33=>nil, 41=>nil}, 41, "s:b", false], [{33=>nil, 41=>nil, 49=>:enemy}, 49, "s:b", true], [{33=>nil, 41=>nil, 49=>nil}, 49, "s:b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{33=>nil, 41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{35=>nil}, 35, "s:b", false]], 26=>[[{16=>:enemy}, 16, "s:b", true], [{34=>:enemy}, 34, "s:b", true], [{16=>nil}, 16, "s:b", false], [{16=>nil, 6=>:enemy}, 6, "s:b", true], [{16=>nil, 6=>nil}, 6, "s:b", false], [{34=>nil}, 34, "s:b", false], [{34=>nil, 42=>:enemy}, 42, "s:b", true], [{34=>nil, 42=>nil}, 42, "s:b", false], [{34=>nil, 42=>nil, 50=>:enemy}, 50, "s:b", true], [{34=>nil, 42=>nil, 50=>nil}, 50, "s:b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, 58, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil}, 58, "s:+b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{34=>nil, 42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false]], 27=>[[{19=>:enemy}, 19, "s:b", true], [{37=>:enemy}, 37, "s:b", true], [{19=>nil}, 19, "s:b", false], [{19=>nil, 11=>:enemy}, 11, "s:b", true], [{19=>nil, 11=>nil}, 11, "s:b", false], [{19=>nil, 11=>nil, 3=>:enemy}, 3, "s:b", true], [{19=>nil, 11=>nil, 3=>nil}, 3, "s:b", false], [{37=>nil}, 37, "s:b", false], [{37=>nil, 47=>:enemy}, 47, "s:b", true], [{37=>nil, 47=>nil}, 47, "s:b", false], [{37=>nil, 47=>nil, 57=>:enemy}, 57, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil}, 57, "s:+b", false], [{37=>nil, 47=>nil, 57=>nil, 67=>:enemy}, 67, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil}, 67, "s:+b", false], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{37=>nil, 47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 28=>[[{18=>:enemy}, 18, "s:b", true], [{20=>:enemy}, 20, "s:b", true], [{36=>:enemy}, 36, "s:b", true], [{38=>:enemy}, 38, "s:b", true], [{18=>nil}, 18, "s:b", false], [{20=>nil}, 20, "s:b", false], [{20=>nil, 12=>:enemy}, 12, "s:b", true], [{20=>nil, 12=>nil}, 12, "s:b", false], [{20=>nil, 12=>nil, 4=>:enemy}, 4, "s:b", true], [{20=>nil, 12=>nil, 4=>nil}, 4, "s:b", false], [{36=>nil}, 36, "s:b", false], [{38=>nil}, 38, "s:b", false], [{38=>nil, 48=>:enemy}, 48, "s:b", true], [{38=>nil, 48=>nil}, 48, "s:b", false], [{38=>nil, 48=>nil, 58=>:enemy}, 58, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil}, 58, "s:+b", false], [{38=>nil, 48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{38=>nil, 48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 29=>[[{19=>:enemy}, 19, "s:b", true], [{21=>:enemy}, 21, "s:b", true], [{37=>:enemy}, 37, "s:b", true], [{39=>:enemy}, 39, "s:b", true], [{19=>nil}, 19, "s:b", false], [{19=>nil, 9=>:enemy}, 9, "s:b", true], [{19=>nil, 9=>nil}, 9, "s:b", false], [{21=>nil}, 21, "s:b", false], [{21=>nil, 13=>:enemy}, 13, "s:b", true], [{21=>nil, 13=>nil}, 13, "s:b", false], [{21=>nil, 13=>nil, 5=>:enemy}, 5, "s:b", true], [{21=>nil, 13=>nil, 5=>nil}, 5, "s:b", false], [{37=>nil}, 37, "s:b", false], [{37=>nil, 45=>:enemy}, 45, "s:b", true], [{37=>nil, 45=>nil}, 45, "s:b", false], [{39=>nil}, 39, "s:b", false], [{39=>nil, 49=>:enemy}, 49, "s:b", true], [{39=>nil, 49=>nil}, 49, "s:b", false], [{39=>nil, 49=>nil, 59=>:enemy}, 59, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil}, 59, "s:+b", false], [{39=>nil, 49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{39=>nil, 49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 30=>[[{20=>:enemy}, 20, "s:b", true], [{22=>:enemy}, 22, "s:b", true], [{38=>:enemy}, 38, "s:b", true], [{40=>:enemy}, 40, "s:b", true], [{20=>nil}, 20, "s:b", false], [{20=>nil, 10=>:enemy}, 10, "s:b", true], [{20=>nil, 10=>nil}, 10, "s:b", false], [{20=>nil, 10=>nil, 0=>:enemy}, 0, "s:b", true], [{20=>nil, 10=>nil, 0=>nil}, 0, "s:b", false], [{22=>nil}, 22, "s:b", false], [{22=>nil, 14=>:enemy}, 14, "s:b", true], [{22=>nil, 14=>nil}, 14, "s:b", false], [{22=>nil, 14=>nil, 6=>:enemy}, 6, "s:b", true], [{22=>nil, 14=>nil, 6=>nil}, 6, "s:b", false], [{38=>nil}, 38, "s:b", false], [{38=>nil, 46=>:enemy}, 46, "s:b", true], [{38=>nil, 46=>nil}, 46, "s:b", false], [{38=>nil, 46=>nil, 54=>:enemy}, 54, "s:+b", true], [{38=>nil, 46=>nil, 54=>nil}, 54, "s:+b", false], [{40=>nil}, 40, "s:b", false], [{40=>nil, 50=>:enemy}, 50, "s:b", true], [{40=>nil, 50=>nil}, 50, "s:b", false], [{40=>nil, 50=>nil, 60=>:enemy}, 60, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil}, 60, "s:+b", false], [{40=>nil, 50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{40=>nil, 50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 31=>[[{21=>:enemy}, 21, "s:b", true], [{23=>:enemy}, 23, "s:b", true], [{39=>:enemy}, 39, "s:b", true], [{41=>:enemy}, 41, "s:b", true], [{21=>nil}, 21, "s:b", false], [{21=>nil, 11=>:enemy}, 11, "s:b", true], [{21=>nil, 11=>nil}, 11, "s:b", false], [{21=>nil, 11=>nil, 1=>:enemy}, 1, "s:b", true], [{21=>nil, 11=>nil, 1=>nil}, 1, "s:b", false], [{23=>nil}, 23, "s:b", false], [{23=>nil, 15=>:enemy}, 15, "s:b", true], [{23=>nil, 15=>nil}, 15, "s:b", false], [{23=>nil, 15=>nil, 7=>:enemy}, 7, "s:b", true], [{23=>nil, 15=>nil, 7=>nil}, 7, "s:b", false], [{39=>nil}, 39, "s:b", false], [{39=>nil, 47=>:enemy}, 47, "s:b", true], [{39=>nil, 47=>nil}, 47, "s:b", false], [{39=>nil, 47=>nil, 55=>:enemy}, 55, "s:+b", true], [{39=>nil, 47=>nil, 55=>nil}, 55, "s:+b", false], [{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{39=>nil, 47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{41=>nil}, 41, "s:b", false], [{41=>nil, 51=>:enemy}, 51, "s:b", true], [{41=>nil, 51=>nil}, 51, "s:b", false], [{41=>nil, 51=>nil, 61=>:enemy}, 61, "s:+b", true], [{41=>nil, 51=>nil, 61=>nil}, 61, "s:+b", false], [{41=>nil, 51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{41=>nil, 51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 32=>[[{22=>:enemy}, 22, "s:b", true], [{24=>:enemy}, 24, "s:b", true], [{40=>:enemy}, 40, "s:b", true], [{42=>:enemy}, 42, "s:b", true], [{22=>nil}, 22, "s:b", false], [{22=>nil, 12=>:enemy}, 12, "s:b", true], [{22=>nil, 12=>nil}, 12, "s:b", false], [{22=>nil, 12=>nil, 2=>:enemy}, 2, "s:b", true], [{22=>nil, 12=>nil, 2=>nil}, 2, "s:b", false], [{24=>nil}, 24, "s:b", false], [{24=>nil, 16=>:enemy}, 16, "s:b", true], [{24=>nil, 16=>nil}, 16, "s:b", false], [{24=>nil, 16=>nil, 8=>:enemy}, 8, "s:b", true], [{24=>nil, 16=>nil, 8=>nil}, 8, "s:b", false], [{40=>nil}, 40, "s:b", false], [{40=>nil, 48=>:enemy}, 48, "s:b", true], [{40=>nil, 48=>nil}, 48, "s:b", false], [{40=>nil, 48=>nil, 56=>:enemy}, 56, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil}, 56, "s:+b", false], [{40=>nil, 48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{40=>nil, 48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{42=>nil}, 42, "s:b", false], [{42=>nil, 52=>:enemy}, 52, "s:b", true], [{42=>nil, 52=>nil}, 52, "s:b", false], [{42=>nil, 52=>nil, 62=>:enemy}, 62, "s:+b", true], [{42=>nil, 52=>nil, 62=>nil}, 62, "s:+b", false]], 33=>[[{23=>:enemy}, 23, "s:b", true], [{25=>:enemy}, 25, "s:b", true], [{41=>:enemy}, 41, "s:b", true], [{43=>:enemy}, 43, "s:b", true], [{23=>nil}, 23, "s:b", false], [{23=>nil, 13=>:enemy}, 13, "s:b", true], [{23=>nil, 13=>nil}, 13, "s:b", false], [{23=>nil, 13=>nil, 3=>:enemy}, 3, "s:b", true], [{23=>nil, 13=>nil, 3=>nil}, 3, "s:b", false], [{25=>nil}, 25, "s:b", false], [{25=>nil, 17=>:enemy}, 17, "s:b", true], [{25=>nil, 17=>nil}, 17, "s:b", false], [{41=>nil}, 41, "s:b", false], [{41=>nil, 49=>:enemy}, 49, "s:b", true], [{41=>nil, 49=>nil}, 49, "s:b", false], [{41=>nil, 49=>nil, 57=>:enemy}, 57, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil}, 57, "s:+b", false], [{41=>nil, 49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{41=>nil, 49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{43=>nil}, 43, "s:b", false], [{43=>nil, 53=>:enemy}, 53, "s:b", true], [{43=>nil, 53=>nil}, 53, "s:b", false]], 34=>[[{24=>:enemy}, 24, "s:b", true], [{26=>:enemy}, 26, "s:b", true], [{42=>:enemy}, 42, "s:b", true], [{44=>:enemy}, 44, "s:b", true], [{24=>nil}, 24, "s:b", false], [{24=>nil, 14=>:enemy}, 14, "s:b", true], [{24=>nil, 14=>nil}, 14, "s:b", false], [{24=>nil, 14=>nil, 4=>:enemy}, 4, "s:b", true], [{24=>nil, 14=>nil, 4=>nil}, 4, "s:b", false], [{26=>nil}, 26, "s:b", false], [{42=>nil}, 42, "s:b", false], [{42=>nil, 50=>:enemy}, 50, "s:b", true], [{42=>nil, 50=>nil}, 50, "s:b", false], [{42=>nil, 50=>nil, 58=>:enemy}, 58, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil}, 58, "s:+b", false], [{42=>nil, 50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{42=>nil, 50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{44=>nil}, 44, "s:b", false]], 35=>[[{25=>:enemy}, 25, "s:b", true], [{43=>:enemy}, 43, "s:b", true], [{25=>nil}, 25, "s:b", false], [{25=>nil, 15=>:enemy}, 15, "s:b", true], [{25=>nil, 15=>nil}, 15, "s:b", false], [{25=>nil, 15=>nil, 5=>:enemy}, 5, "s:b", true], [{25=>nil, 15=>nil, 5=>nil}, 5, "s:b", false], [{43=>nil}, 43, "s:b", false], [{43=>nil, 51=>:enemy}, 51, "s:b", true], [{43=>nil, 51=>nil}, 51, "s:b", false], [{43=>nil, 51=>nil, 59=>:enemy}, 59, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil}, 59, "s:+b", false], [{43=>nil, 51=>nil, 59=>nil, 67=>:enemy}, 67, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil}, 67, "s:+b", false], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{43=>nil, 51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false]], 36=>[[{28=>:enemy}, 28, "s:b", true], [{46=>:enemy}, 46, "s:b", true], [{28=>nil}, 28, "s:b", false], [{28=>nil, 20=>:enemy}, 20, "s:b", true], [{28=>nil, 20=>nil}, 20, "s:b", false], [{28=>nil, 20=>nil, 12=>:enemy}, 12, "s:b", true], [{28=>nil, 20=>nil, 12=>nil}, 12, "s:b", false], [{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, 4, "s:b", true], [{28=>nil, 20=>nil, 12=>nil, 4=>nil}, 4, "s:b", false], [{46=>nil}, 46, "s:b", false], [{46=>nil, 56=>:enemy}, 56, "s:+b", true], [{46=>nil, 56=>nil}, 56, "s:+b", false], [{46=>nil, 56=>nil, 66=>:enemy}, 66, "s:+b", true], [{46=>nil, 56=>nil, 66=>nil}, 66, "s:+b", false], [{46=>nil, 56=>nil, 66=>nil, 76=>:enemy}, 76, "s:+b", true], [{46=>nil, 56=>nil, 66=>nil, 76=>nil}, 76, "s:+b", false]], 37=>[[{27=>:enemy}, 27, "s:b", true], [{29=>:enemy}, 29, "s:b", true], [{45=>:enemy}, 45, "s:b", true], [{47=>:enemy}, 47, "s:b", true], [{27=>nil}, 27, "s:b", false], [{29=>nil}, 29, "s:b", false], [{29=>nil, 21=>:enemy}, 21, "s:b", true], [{29=>nil, 21=>nil}, 21, "s:b", false], [{29=>nil, 21=>nil, 13=>:enemy}, 13, "s:b", true], [{29=>nil, 21=>nil, 13=>nil}, 13, "s:b", false], [{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "s:b", true], [{29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "s:b", false], [{45=>nil}, 45, "s:b", false], [{47=>nil}, 47, "s:b", false], [{47=>nil, 57=>:enemy}, 57, "s:+b", true], [{47=>nil, 57=>nil}, 57, "s:+b", false], [{47=>nil, 57=>nil, 67=>:enemy}, 67, "s:+b", true], [{47=>nil, 57=>nil, 67=>nil}, 67, "s:+b", false], [{47=>nil, 57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{47=>nil, 57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 38=>[[{28=>:enemy}, 28, "s:b", true], [{30=>:enemy}, 30, "s:b", true], [{46=>:enemy}, 46, "s:b", true], [{48=>:enemy}, 48, "s:b", true], [{28=>nil}, 28, "s:b", false], [{28=>nil, 18=>:enemy}, 18, "s:b", true], [{28=>nil, 18=>nil}, 18, "s:b", false], [{30=>nil}, 30, "s:b", false], [{30=>nil, 22=>:enemy}, 22, "s:b", true], [{30=>nil, 22=>nil}, 22, "s:b", false], [{30=>nil, 22=>nil, 14=>:enemy}, 14, "s:b", true], [{30=>nil, 22=>nil, 14=>nil}, 14, "s:b", false], [{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:b", true], [{30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:b", false], [{46=>nil}, 46, "s:b", false], [{46=>nil, 54=>:enemy}, 54, "s:+b", true], [{46=>nil, 54=>nil}, 54, "s:+b", false], [{48=>nil}, 48, "s:b", false], [{48=>nil, 58=>:enemy}, 58, "s:+b", true], [{48=>nil, 58=>nil}, 58, "s:+b", false], [{48=>nil, 58=>nil, 68=>:enemy}, 68, "s:+b", true], [{48=>nil, 58=>nil, 68=>nil}, 68, "s:+b", false], [{48=>nil, 58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{48=>nil, 58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 39=>[[{29=>:enemy}, 29, "s:b", true], [{31=>:enemy}, 31, "s:b", true], [{47=>:enemy}, 47, "s:b", true], [{49=>:enemy}, 49, "s:b", true], [{29=>nil}, 29, "s:b", false], [{29=>nil, 19=>:enemy}, 19, "s:b", true], [{29=>nil, 19=>nil}, 19, "s:b", false], [{29=>nil, 19=>nil, 9=>:enemy}, 9, "s:b", true], [{29=>nil, 19=>nil, 9=>nil}, 9, "s:b", false], [{31=>nil}, 31, "s:b", false], [{31=>nil, 23=>:enemy}, 23, "s:b", true], [{31=>nil, 23=>nil}, 23, "s:b", false], [{31=>nil, 23=>nil, 15=>:enemy}, 15, "s:b", true], [{31=>nil, 23=>nil, 15=>nil}, 15, "s:b", false], [{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:b", true], [{31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:b", false], [{47=>nil}, 47, "s:b", false], [{47=>nil, 55=>:enemy}, 55, "s:+b", true], [{47=>nil, 55=>nil}, 55, "s:+b", false], [{47=>nil, 55=>nil, 63=>:enemy}, 63, "s:+b", true], [{47=>nil, 55=>nil, 63=>nil}, 63, "s:+b", false], [{49=>nil}, 49, "s:b", false], [{49=>nil, 59=>:enemy}, 59, "s:+b", true], [{49=>nil, 59=>nil}, 59, "s:+b", false], [{49=>nil, 59=>nil, 69=>:enemy}, 69, "s:+b", true], [{49=>nil, 59=>nil, 69=>nil}, 69, "s:+b", false], [{49=>nil, 59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{49=>nil, 59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 40=>[[{30=>:enemy}, 30, "s:b", true], [{32=>:enemy}, 32, "s:b", true], [{48=>:enemy}, 48, "s:b", true], [{50=>:enemy}, 50, "s:b", true], [{30=>nil}, 30, "s:b", false], [{30=>nil, 20=>:enemy}, 20, "s:b", true], [{30=>nil, 20=>nil}, 20, "s:b", false], [{30=>nil, 20=>nil, 10=>:enemy}, 10, "s:b", true], [{30=>nil, 20=>nil, 10=>nil}, 10, "s:b", false], [{30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:b", true], [{30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:b", false], [{32=>nil}, 32, "s:b", false], [{32=>nil, 24=>:enemy}, 24, "s:b", true], [{32=>nil, 24=>nil}, 24, "s:b", false], [{32=>nil, 24=>nil, 16=>:enemy}, 16, "s:b", true], [{32=>nil, 24=>nil, 16=>nil}, 16, "s:b", false], [{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:b", true], [{32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:b", false], [{48=>nil}, 48, "s:b", false], [{48=>nil, 56=>:enemy}, 56, "s:+b", true], [{48=>nil, 56=>nil}, 56, "s:+b", false], [{48=>nil, 56=>nil, 64=>:enemy}, 64, "s:+b", true], [{48=>nil, 56=>nil, 64=>nil}, 64, "s:+b", false], [{48=>nil, 56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{48=>nil, 56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{50=>nil}, 50, "s:b", false], [{50=>nil, 60=>:enemy}, 60, "s:+b", true], [{50=>nil, 60=>nil}, 60, "s:+b", false], [{50=>nil, 60=>nil, 70=>:enemy}, 70, "s:+b", true], [{50=>nil, 60=>nil, 70=>nil}, 70, "s:+b", false], [{50=>nil, 60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{50=>nil, 60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 41=>[[{31=>:enemy}, 31, "s:b", true], [{33=>:enemy}, 33, "s:b", true], [{49=>:enemy}, 49, "s:b", true], [{51=>:enemy}, 51, "s:b", true], [{31=>nil}, 31, "s:b", false], [{31=>nil, 21=>:enemy}, 21, "s:b", true], [{31=>nil, 21=>nil}, 21, "s:b", false], [{31=>nil, 21=>nil, 11=>:enemy}, 11, "s:b", true], [{31=>nil, 21=>nil, 11=>nil}, 11, "s:b", false], [{31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:b", true], [{31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:b", false], [{33=>nil}, 33, "s:b", false], [{33=>nil, 25=>:enemy}, 25, "s:b", true], [{33=>nil, 25=>nil}, 25, "s:b", false], [{33=>nil, 25=>nil, 17=>:enemy}, 17, "s:b", true], [{33=>nil, 25=>nil, 17=>nil}, 17, "s:b", false], [{49=>nil}, 49, "s:b", false], [{49=>nil, 57=>:enemy}, 57, "s:+b", true], [{49=>nil, 57=>nil}, 57, "s:+b", false], [{49=>nil, 57=>nil, 65=>:enemy}, 65, "s:+b", true], [{49=>nil, 57=>nil, 65=>nil}, 65, "s:+b", false], [{49=>nil, 57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{49=>nil, 57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{51=>nil}, 51, "s:b", false], [{51=>nil, 61=>:enemy}, 61, "s:+b", true], [{51=>nil, 61=>nil}, 61, "s:+b", false], [{51=>nil, 61=>nil, 71=>:enemy}, 71, "s:+b", true], [{51=>nil, 61=>nil, 71=>nil}, 71, "s:+b", false]], 42=>[[{32=>:enemy}, 32, "s:b", true], [{34=>:enemy}, 34, "s:b", true], [{50=>:enemy}, 50, "s:b", true], [{52=>:enemy}, 52, "s:b", true], [{32=>nil}, 32, "s:b", false], [{32=>nil, 22=>:enemy}, 22, "s:b", true], [{32=>nil, 22=>nil}, 22, "s:b", false], [{32=>nil, 22=>nil, 12=>:enemy}, 12, "s:b", true], [{32=>nil, 22=>nil, 12=>nil}, 12, "s:b", false], [{32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:b", true], [{32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:b", false], [{34=>nil}, 34, "s:b", false], [{34=>nil, 26=>:enemy}, 26, "s:b", true], [{34=>nil, 26=>nil}, 26, "s:b", false], [{50=>nil}, 50, "s:b", false], [{50=>nil, 58=>:enemy}, 58, "s:+b", true], [{50=>nil, 58=>nil}, 58, "s:+b", false], [{50=>nil, 58=>nil, 66=>:enemy}, 66, "s:+b", true], [{50=>nil, 58=>nil, 66=>nil}, 66, "s:+b", false], [{50=>nil, 58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{50=>nil, 58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{52=>nil}, 52, "s:b", false], [{52=>nil, 62=>:enemy}, 62, "s:+b", true], [{52=>nil, 62=>nil}, 62, "s:+b", false]], 43=>[[{33=>:enemy}, 33, "s:b", true], [{35=>:enemy}, 35, "s:b", true], [{51=>:enemy}, 51, "s:b", true], [{53=>:enemy}, 53, "s:b", true], [{33=>nil}, 33, "s:b", false], [{33=>nil, 23=>:enemy}, 23, "s:b", true], [{33=>nil, 23=>nil}, 23, "s:b", false], [{33=>nil, 23=>nil, 13=>:enemy}, 13, "s:b", true], [{33=>nil, 23=>nil, 13=>nil}, 13, "s:b", false], [{33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "s:b", true], [{33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "s:b", false], [{35=>nil}, 35, "s:b", false], [{51=>nil}, 51, "s:b", false], [{51=>nil, 59=>:enemy}, 59, "s:+b", true], [{51=>nil, 59=>nil}, 59, "s:+b", false], [{51=>nil, 59=>nil, 67=>:enemy}, 67, "s:+b", true], [{51=>nil, 59=>nil, 67=>nil}, 67, "s:+b", false], [{51=>nil, 59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{51=>nil, 59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false], [{53=>nil}, 53, "s:b", false]], 44=>[[{34=>:enemy}, 34, "s:b", true], [{52=>:enemy}, 52, "s:b", true], [{34=>nil}, 34, "s:b", false], [{34=>nil, 24=>:enemy}, 24, "s:b", true], [{34=>nil, 24=>nil}, 24, "s:b", false], [{34=>nil, 24=>nil, 14=>:enemy}, 14, "s:b", true], [{34=>nil, 24=>nil, 14=>nil}, 14, "s:b", false], [{34=>nil, 24=>nil, 14=>nil, 4=>:enemy}, 4, "s:b", true], [{34=>nil, 24=>nil, 14=>nil, 4=>nil}, 4, "s:b", false], [{52=>nil}, 52, "s:b", false], [{52=>nil, 60=>:enemy}, 60, "s:+b", true], [{52=>nil, 60=>nil}, 60, "s:+b", false], [{52=>nil, 60=>nil, 68=>:enemy}, 68, "s:+b", true], [{52=>nil, 60=>nil, 68=>nil}, 68, "s:+b", false], [{52=>nil, 60=>nil, 68=>nil, 76=>:enemy}, 76, "s:+b", true], [{52=>nil, 60=>nil, 68=>nil, 76=>nil}, 76, "s:+b", false]], 45=>[[{37=>:enemy}, 37, "s:b", true], [{55=>:enemy}, 55, "s:+b", true], [{37=>nil}, 37, "s:b", false], [{37=>nil, 29=>:enemy}, 29, "s:b", true], [{37=>nil, 29=>nil}, 29, "s:b", false], [{37=>nil, 29=>nil, 21=>:enemy}, 21, "s:b", true], [{37=>nil, 29=>nil, 21=>nil}, 21, "s:b", false], [{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, 13, "s:b", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil}, 13, "s:b", false], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, 5, "s:b", true], [{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}, 5, "s:b", false], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 65=>:enemy}, 65, "s:+b", true], [{55=>nil, 65=>nil}, 65, "s:+b", false], [{55=>nil, 65=>nil, 75=>:enemy}, 75, "s:+b", true], [{55=>nil, 65=>nil, 75=>nil}, 75, "s:+b", false]], 46=>[[{36=>:enemy}, 36, "s:b", true], [{38=>:enemy}, 38, "s:b", true], [{54=>:enemy}, 54, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{36=>nil}, 36, "s:b", false], [{38=>nil}, 38, "s:b", false], [{38=>nil, 30=>:enemy}, 30, "s:b", true], [{38=>nil, 30=>nil}, 30, "s:b", false], [{38=>nil, 30=>nil, 22=>:enemy}, 22, "s:b", true], [{38=>nil, 30=>nil, 22=>nil}, 22, "s:b", false], [{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "s:b", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "s:b", false], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:b", true], [{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:b", false], [{54=>nil}, 54, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 66=>:enemy}, 66, "s:+b", true], [{56=>nil, 66=>nil}, 66, "s:+b", false], [{56=>nil, 66=>nil, 76=>:enemy}, 76, "s:+b", true], [{56=>nil, 66=>nil, 76=>nil}, 76, "s:+b", false]], 47=>[[{37=>:enemy}, 37, "s:b", true], [{39=>:enemy}, 39, "s:b", true], [{55=>:enemy}, 55, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{37=>nil}, 37, "s:b", false], [{37=>nil, 27=>:enemy}, 27, "s:b", true], [{37=>nil, 27=>nil}, 27, "s:b", false], [{39=>nil}, 39, "s:b", false], [{39=>nil, 31=>:enemy}, 31, "s:b", true], [{39=>nil, 31=>nil}, 31, "s:b", false], [{39=>nil, 31=>nil, 23=>:enemy}, 23, "s:b", true], [{39=>nil, 31=>nil, 23=>nil}, 23, "s:b", false], [{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:b", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:b", false], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:b", true], [{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:b", false], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 63=>:enemy}, 63, "s:+b", true], [{55=>nil, 63=>nil}, 63, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 67=>:enemy}, 67, "s:+b", true], [{57=>nil, 67=>nil}, 67, "s:+b", false], [{57=>nil, 67=>nil, 77=>:enemy}, 77, "s:+b", true], [{57=>nil, 67=>nil, 77=>nil}, 77, "s:+b", false]], 48=>[[{38=>:enemy}, 38, "s:b", true], [{40=>:enemy}, 40, "s:b", true], [{56=>:enemy}, 56, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{38=>nil}, 38, "s:b", false], [{38=>nil, 28=>:enemy}, 28, "s:b", true], [{38=>nil, 28=>nil}, 28, "s:b", false], [{38=>nil, 28=>nil, 18=>:enemy}, 18, "s:b", true], [{38=>nil, 28=>nil, 18=>nil}, 18, "s:b", false], [{40=>nil}, 40, "s:b", false], [{40=>nil, 32=>:enemy}, 32, "s:b", true], [{40=>nil, 32=>nil}, 32, "s:b", false], [{40=>nil, 32=>nil, 24=>:enemy}, 24, "s:b", true], [{40=>nil, 32=>nil, 24=>nil}, 24, "s:b", false], [{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:b", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:b", false], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:b", true], [{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 64=>:enemy}, 64, "s:+b", true], [{56=>nil, 64=>nil}, 64, "s:+b", false], [{56=>nil, 64=>nil, 72=>:enemy}, 72, "s:+b", true], [{56=>nil, 64=>nil, 72=>nil}, 72, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 68=>:enemy}, 68, "s:+b", true], [{58=>nil, 68=>nil}, 68, "s:+b", false], [{58=>nil, 68=>nil, 78=>:enemy}, 78, "s:+b", true], [{58=>nil, 68=>nil, 78=>nil}, 78, "s:+b", false]], 49=>[[{39=>:enemy}, 39, "s:b", true], [{41=>:enemy}, 41, "s:b", true], [{57=>:enemy}, 57, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{39=>nil}, 39, "s:b", false], [{39=>nil, 29=>:enemy}, 29, "s:b", true], [{39=>nil, 29=>nil}, 29, "s:b", false], [{39=>nil, 29=>nil, 19=>:enemy}, 19, "s:b", true], [{39=>nil, 29=>nil, 19=>nil}, 19, "s:b", false], [{39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:b", true], [{39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:b", false], [{41=>nil}, 41, "s:b", false], [{41=>nil, 33=>:enemy}, 33, "s:b", true], [{41=>nil, 33=>nil}, 33, "s:b", false], [{41=>nil, 33=>nil, 25=>:enemy}, 25, "s:b", true], [{41=>nil, 33=>nil, 25=>nil}, 25, "s:b", false], [{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:b", true], [{41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 65=>:enemy}, 65, "s:+b", true], [{57=>nil, 65=>nil}, 65, "s:+b", false], [{57=>nil, 65=>nil, 73=>:enemy}, 73, "s:+b", true], [{57=>nil, 65=>nil, 73=>nil}, 73, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 69=>:enemy}, 69, "s:+b", true], [{59=>nil, 69=>nil}, 69, "s:+b", false], [{59=>nil, 69=>nil, 79=>:enemy}, 79, "s:+b", true], [{59=>nil, 69=>nil, 79=>nil}, 79, "s:+b", false]], 50=>[[{40=>:enemy}, 40, "s:b", true], [{42=>:enemy}, 42, "s:b", true], [{58=>:enemy}, 58, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{40=>nil}, 40, "s:b", false], [{40=>nil, 30=>:enemy}, 30, "s:b", true], [{40=>nil, 30=>nil}, 30, "s:b", false], [{40=>nil, 30=>nil, 20=>:enemy}, 20, "s:b", true], [{40=>nil, 30=>nil, 20=>nil}, 20, "s:b", false], [{40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:b", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:b", false], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:b", true], [{40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:b", false], [{42=>nil}, 42, "s:b", false], [{42=>nil, 34=>:enemy}, 34, "s:b", true], [{42=>nil, 34=>nil}, 34, "s:b", false], [{42=>nil, 34=>nil, 26=>:enemy}, 26, "s:b", true], [{42=>nil, 34=>nil, 26=>nil}, 26, "s:b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 66=>:enemy}, 66, "s:+b", true], [{58=>nil, 66=>nil}, 66, "s:+b", false], [{58=>nil, 66=>nil, 74=>:enemy}, 74, "s:+b", true], [{58=>nil, 66=>nil, 74=>nil}, 74, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 70=>:enemy}, 70, "s:+b", true], [{60=>nil, 70=>nil}, 70, "s:+b", false], [{60=>nil, 70=>nil, 80=>:enemy}, 80, "s:+b", true], [{60=>nil, 70=>nil, 80=>nil}, 80, "s:+b", false]], 51=>[[{41=>:enemy}, 41, "s:b", true], [{43=>:enemy}, 43, "s:b", true], [{59=>:enemy}, 59, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{41=>nil}, 41, "s:b", false], [{41=>nil, 31=>:enemy}, 31, "s:b", true], [{41=>nil, 31=>nil}, 31, "s:b", false], [{41=>nil, 31=>nil, 21=>:enemy}, 21, "s:b", true], [{41=>nil, 31=>nil, 21=>nil}, 21, "s:b", false], [{41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:b", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:b", false], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:b", true], [{41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:b", false], [{43=>nil}, 43, "s:b", false], [{43=>nil, 35=>:enemy}, 35, "s:b", true], [{43=>nil, 35=>nil}, 35, "s:b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 67=>:enemy}, 67, "s:+b", true], [{59=>nil, 67=>nil}, 67, "s:+b", false], [{59=>nil, 67=>nil, 75=>:enemy}, 75, "s:+b", true], [{59=>nil, 67=>nil, 75=>nil}, 75, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 71=>:enemy}, 71, "s:+b", true], [{61=>nil, 71=>nil}, 71, "s:+b", false]], 52=>[[{42=>:enemy}, 42, "s:b", true], [{44=>:enemy}, 44, "s:b", true], [{60=>:enemy}, 60, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{42=>nil}, 42, "s:b", false], [{42=>nil, 32=>:enemy}, 32, "s:b", true], [{42=>nil, 32=>nil}, 32, "s:b", false], [{42=>nil, 32=>nil, 22=>:enemy}, 22, "s:b", true], [{42=>nil, 32=>nil, 22=>nil}, 22, "s:b", false], [{42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "s:b", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "s:b", false], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:b", true], [{42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:b", false], [{44=>nil}, 44, "s:b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 68=>:enemy}, 68, "s:+b", true], [{60=>nil, 68=>nil}, 68, "s:+b", false], [{60=>nil, 68=>nil, 76=>:enemy}, 76, "s:+b", true], [{60=>nil, 68=>nil, 76=>nil}, 76, "s:+b", false], [{62=>nil}, 62, "s:+b", false]], 53=>[[{43=>:enemy}, 43, "s:b", true], [{61=>:enemy}, 61, "s:+b", true], [{43=>nil}, 43, "s:b", false], [{43=>nil, 33=>:enemy}, 33, "s:b", true], [{43=>nil, 33=>nil}, 33, "s:b", false], [{43=>nil, 33=>nil, 23=>:enemy}, 23, "s:b", true], [{43=>nil, 33=>nil, 23=>nil}, 23, "s:b", false], [{43=>nil, 33=>nil, 23=>nil, 13=>:enemy}, 13, "s:b", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil}, 13, "s:b", false], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>:enemy}, 3, "s:b", true], [{43=>nil, 33=>nil, 23=>nil, 13=>nil, 3=>nil}, 3, "s:b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 69=>:enemy}, 69, "s:+b", true], [{61=>nil, 69=>nil}, 69, "s:+b", false], [{61=>nil, 69=>nil, 77=>:enemy}, 77, "s:+b", true], [{61=>nil, 69=>nil, 77=>nil}, 77, "s:+b", false]], 54=>[[{46=>:enemy}, 46, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 38=>:enemy}, 38, "s:+b", true], [{46=>nil, 38=>nil}, 38, "s:+b", false], [{46=>nil, 38=>nil, 30=>:enemy}, 30, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil}, 30, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, 22, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil}, 22, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, 14, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}, 14, "s:+b", false], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, 6, "s:+b", true], [{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}, 6, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 74=>:enemy}, 74, "s:+b", true], [{64=>nil, 74=>nil}, 74, "s:+b", false]], 55=>[[{45=>:enemy}, 45, "s:+b", true], [{47=>:enemy}, 47, "s:+b", true], [{63=>:enemy}, 63, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{45=>nil}, 45, "s:+b", false], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 39=>:enemy}, 39, "s:+b", true], [{47=>nil, 39=>nil}, 39, "s:+b", false], [{47=>nil, 39=>nil, 31=>:enemy}, 31, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil}, 31, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{63=>nil}, 63, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 75=>:enemy}, 75, "s:+b", true], [{65=>nil, 75=>nil}, 75, "s:+b", false]], 56=>[[{46=>:enemy}, 46, "s:+b", true], [{48=>:enemy}, 48, "s:+b", true], [{64=>:enemy}, 64, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{46=>nil}, 46, "s:+b", false], [{46=>nil, 36=>:enemy}, 36, "s:+b", true], [{46=>nil, 36=>nil}, 36, "s:+b", false], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 40=>:enemy}, 40, "s:+b", true], [{48=>nil, 40=>nil}, 40, "s:+b", false], [{48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 72=>:enemy}, 72, "s:+b", true], [{64=>nil, 72=>nil}, 72, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 76=>:enemy}, 76, "s:+b", true], [{66=>nil, 76=>nil}, 76, "s:+b", false]], 57=>[[{47=>:enemy}, 47, "s:+b", true], [{49=>:enemy}, 49, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{47=>nil}, 47, "s:+b", false], [{47=>nil, 37=>:enemy}, 37, "s:+b", true], [{47=>nil, 37=>nil}, 37, "s:+b", false], [{47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 41=>:enemy}, 41, "s:+b", true], [{49=>nil, 41=>nil}, 41, "s:+b", false], [{49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 73=>:enemy}, 73, "s:+b", true], [{65=>nil, 73=>nil}, 73, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 77=>:enemy}, 77, "s:+b", true], [{67=>nil, 77=>nil}, 77, "s:+b", false]], 58=>[[{48=>:enemy}, 48, "s:+b", true], [{50=>:enemy}, 50, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{48=>nil}, 48, "s:+b", false], [{48=>nil, 38=>:enemy}, 38, "s:+b", true], [{48=>nil, 38=>nil}, 38, "s:+b", false], [{48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 42=>:enemy}, 42, "s:+b", true], [{50=>nil, 42=>nil}, 42, "s:+b", false], [{50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 74=>:enemy}, 74, "s:+b", true], [{66=>nil, 74=>nil}, 74, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 78=>:enemy}, 78, "s:+b", true], [{68=>nil, 78=>nil}, 78, "s:+b", false]], 59=>[[{49=>:enemy}, 49, "s:+b", true], [{51=>:enemy}, 51, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{49=>nil}, 49, "s:+b", false], [{49=>nil, 39=>:enemy}, 39, "s:+b", true], [{49=>nil, 39=>nil}, 39, "s:+b", false], [{49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 43=>:enemy}, 43, "s:+b", true], [{51=>nil, 43=>nil}, 43, "s:+b", false], [{51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 75=>:enemy}, 75, "s:+b", true], [{67=>nil, 75=>nil}, 75, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 79=>:enemy}, 79, "s:+b", true], [{69=>nil, 79=>nil}, 79, "s:+b", false]], 60=>[[{50=>:enemy}, 50, "s:+b", true], [{52=>:enemy}, 52, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{50=>nil}, 50, "s:+b", false], [{50=>nil, 40=>:enemy}, 40, "s:+b", true], [{50=>nil, 40=>nil}, 40, "s:+b", false], [{50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 44=>:enemy}, 44, "s:+b", true], [{52=>nil, 44=>nil}, 44, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 76=>:enemy}, 76, "s:+b", true], [{68=>nil, 76=>nil}, 76, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 80=>:enemy}, 80, "s:+b", true], [{70=>nil, 80=>nil}, 80, "s:+b", false]], 61=>[[{51=>:enemy}, 51, "s:+b", true], [{53=>:enemy}, 53, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{51=>nil}, 51, "s:+b", false], [{51=>nil, 41=>:enemy}, 41, "s:+b", true], [{51=>nil, 41=>nil}, 41, "s:+b", false], [{51=>nil, 41=>nil, 31=>:enemy}, 31, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil}, 31, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{53=>nil}, 53, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 77=>:enemy}, 77, "s:+b", true], [{69=>nil, 77=>nil}, 77, "s:+b", false], [{71=>nil}, 71, "s:+b", false]], 62=>[[{52=>:enemy}, 52, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{52=>nil}, 52, "s:+b", false], [{52=>nil, 42=>:enemy}, 42, "s:+b", true], [{52=>nil, 42=>nil}, 42, "s:+b", false], [{52=>nil, 42=>nil, 32=>:enemy}, 32, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil}, 32, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>:enemy}, 22, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil}, 22, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>:enemy}, 12, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil}, 12, "s:+b", false], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>:enemy}, 2, "s:+b", true], [{52=>nil, 42=>nil, 32=>nil, 22=>nil, 12=>nil, 2=>nil}, 2, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 78=>:enemy}, 78, "s:+b", true], [{70=>nil, 78=>nil}, 78, "s:+b", false]], 63=>[[{55=>:enemy}, 55, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 47=>:enemy}, 47, "s:+b", true], [{55=>nil, 47=>nil}, 47, "s:+b", false], [{55=>nil, 47=>nil, 39=>:enemy}, 39, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil}, 39, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, 31, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil}, 31, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, 23, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}, 23, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, 15, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}, 15, "s:+b", false], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, 7, "s:+b", true], [{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}, 7, "s:+b", false], [{73=>nil}, 73, "s:+b", false]], 64=>[[{54=>:enemy}, 54, "s:+b", true], [{56=>:enemy}, 56, "s:+b", true], [{72=>:enemy}, 72, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{54=>nil}, 54, "s:+b", false], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 48=>:enemy}, 48, "s:+b", true], [{56=>nil, 48=>nil}, 48, "s:+b", false], [{56=>nil, 48=>nil, 40=>:enemy}, 40, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil}, 40, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false], [{72=>nil}, 72, "s:+b", false], [{74=>nil}, 74, "s:+b", false]], 65=>[[{55=>:enemy}, 55, "s:+b", true], [{57=>:enemy}, 57, "s:+b", true], [{73=>:enemy}, 73, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{55=>nil}, 55, "s:+b", false], [{55=>nil, 45=>:enemy}, 45, "s:+b", true], [{55=>nil, 45=>nil}, 45, "s:+b", false], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 49=>:enemy}, 49, "s:+b", true], [{57=>nil, 49=>nil}, 49, "s:+b", false], [{57=>nil, 49=>nil, 41=>:enemy}, 41, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil}, 41, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false], [{73=>nil}, 73, "s:+b", false], [{75=>nil}, 75, "s:+b", false]], 66=>[[{56=>:enemy}, 56, "s:+b", true], [{58=>:enemy}, 58, "s:+b", true], [{74=>:enemy}, 74, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{56=>nil}, 56, "s:+b", false], [{56=>nil, 46=>:enemy}, 46, "s:+b", true], [{56=>nil, 46=>nil}, 46, "s:+b", false], [{56=>nil, 46=>nil, 36=>:enemy}, 36, "s:+b", true], [{56=>nil, 46=>nil, 36=>nil}, 36, "s:+b", false], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 50=>:enemy}, 50, "s:+b", true], [{58=>nil, 50=>nil}, 50, "s:+b", false], [{58=>nil, 50=>nil, 42=>:enemy}, 42, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil}, 42, "s:+b", false], [{58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false], [{74=>nil}, 74, "s:+b", false], [{76=>nil}, 76, "s:+b", false]], 67=>[[{57=>:enemy}, 57, "s:+b", true], [{59=>:enemy}, 59, "s:+b", true], [{75=>:enemy}, 75, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{57=>nil}, 57, "s:+b", false], [{57=>nil, 47=>:enemy}, 47, "s:+b", true], [{57=>nil, 47=>nil}, 47, "s:+b", false], [{57=>nil, 47=>nil, 37=>:enemy}, 37, "s:+b", true], [{57=>nil, 47=>nil, 37=>nil}, 37, "s:+b", false], [{57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 51=>:enemy}, 51, "s:+b", true], [{59=>nil, 51=>nil}, 51, "s:+b", false], [{59=>nil, 51=>nil, 43=>:enemy}, 43, "s:+b", true], [{59=>nil, 51=>nil, 43=>nil}, 43, "s:+b", false], [{59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false], [{75=>nil}, 75, "s:+b", false], [{77=>nil}, 77, "s:+b", false]], 68=>[[{58=>:enemy}, 58, "s:+b", true], [{60=>:enemy}, 60, "s:+b", true], [{76=>:enemy}, 76, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{58=>nil}, 58, "s:+b", false], [{58=>nil, 48=>:enemy}, 48, "s:+b", true], [{58=>nil, 48=>nil}, 48, "s:+b", false], [{58=>nil, 48=>nil, 38=>:enemy}, 38, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil}, 38, "s:+b", false], [{58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 52=>:enemy}, 52, "s:+b", true], [{60=>nil, 52=>nil}, 52, "s:+b", false], [{60=>nil, 52=>nil, 44=>:enemy}, 44, "s:+b", true], [{60=>nil, 52=>nil, 44=>nil}, 44, "s:+b", false], [{76=>nil}, 76, "s:+b", false], [{78=>nil}, 78, "s:+b", false]], 69=>[[{59=>:enemy}, 59, "s:+b", true], [{61=>:enemy}, 61, "s:+b", true], [{77=>:enemy}, 77, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{59=>nil}, 59, "s:+b", false], [{59=>nil, 49=>:enemy}, 49, "s:+b", true], [{59=>nil, 49=>nil}, 49, "s:+b", false], [{59=>nil, 49=>nil, 39=>:enemy}, 39, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil}, 39, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 53=>:enemy}, 53, "s:+b", true], [{61=>nil, 53=>nil}, 53, "s:+b", false], [{77=>nil}, 77, "s:+b", false], [{79=>nil}, 79, "s:+b", false]], 70=>[[{60=>:enemy}, 60, "s:+b", true], [{62=>:enemy}, 62, "s:+b", true], [{78=>:enemy}, 78, "s:+b", true], [{80=>:enemy}, 80, "s:+b", true], [{60=>nil}, 60, "s:+b", false], [{60=>nil, 50=>:enemy}, 50, "s:+b", true], [{60=>nil, 50=>nil}, 50, "s:+b", false], [{60=>nil, 50=>nil, 40=>:enemy}, 40, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil}, 40, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false], [{62=>nil}, 62, "s:+b", false], [{78=>nil}, 78, "s:+b", false], [{80=>nil}, 80, "s:+b", false]], 71=>[[{61=>:enemy}, 61, "s:+b", true], [{79=>:enemy}, 79, "s:+b", true], [{61=>nil}, 61, "s:+b", false], [{61=>nil, 51=>:enemy}, 51, "s:+b", true], [{61=>nil, 51=>nil}, 51, "s:+b", false], [{61=>nil, 51=>nil, 41=>:enemy}, 41, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil}, 41, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>:enemy}, 31, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil}, 31, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>:enemy}, 21, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil}, 21, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>:enemy}, 11, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil}, 11, "s:+b", false], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>:enemy}, 1, "s:+b", true], [{61=>nil, 51=>nil, 41=>nil, 31=>nil, 21=>nil, 11=>nil, 1=>nil}, 1, "s:+b", false], [{79=>nil}, 79, "s:+b", false]], 72=>[[{64=>:enemy}, 64, "s:+b", true], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 56=>:enemy}, 56, "s:+b", true], [{64=>nil, 56=>nil}, 56, "s:+b", false], [{64=>nil, 56=>nil, 48=>:enemy}, 48, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil}, 48, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>:enemy}, 40, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil}, 40, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>:enemy}, 32, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil}, 32, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, 24, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil}, 24, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, 16, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}, 16, "s:+b", false], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, 8, "s:+b", true], [{64=>nil, 56=>nil, 48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}, 8, "s:+b", false]], 73=>[[{63=>:enemy}, 63, "s:+b", true], [{65=>:enemy}, 65, "s:+b", true], [{63=>nil}, 63, "s:+b", false], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 57=>:enemy}, 57, "s:+b", true], [{65=>nil, 57=>nil}, 57, "s:+b", false], [{65=>nil, 57=>nil, 49=>:enemy}, 49, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil}, 49, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>:enemy}, 41, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil}, 41, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>:enemy}, 33, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil}, 33, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, 25, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil}, 25, "s:+b", false], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, 17, "s:+b", true], [{65=>nil, 57=>nil, 49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}, 17, "s:+b", false]], 74=>[[{64=>:enemy}, 64, "s:+b", true], [{66=>:enemy}, 66, "s:+b", true], [{64=>nil}, 64, "s:+b", false], [{64=>nil, 54=>:enemy}, 54, "s:+b", true], [{64=>nil, 54=>nil}, 54, "s:+b", false], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 58=>:enemy}, 58, "s:+b", true], [{66=>nil, 58=>nil}, 58, "s:+b", false], [{66=>nil, 58=>nil, 50=>:enemy}, 50, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil}, 50, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>:enemy}, 42, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil}, 42, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>:enemy}, 34, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil}, 34, "s:+b", false], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, 26, "s:+b", true], [{66=>nil, 58=>nil, 50=>nil, 42=>nil, 34=>nil, 26=>nil}, 26, "s:+b", false]], 75=>[[{65=>:enemy}, 65, "s:+b", true], [{67=>:enemy}, 67, "s:+b", true], [{65=>nil}, 65, "s:+b", false], [{65=>nil, 55=>:enemy}, 55, "s:+b", true], [{65=>nil, 55=>nil}, 55, "s:+b", false], [{65=>nil, 55=>nil, 45=>:enemy}, 45, "s:+b", true], [{65=>nil, 55=>nil, 45=>nil}, 45, "s:+b", false], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 59=>:enemy}, 59, "s:+b", true], [{67=>nil, 59=>nil}, 59, "s:+b", false], [{67=>nil, 59=>nil, 51=>:enemy}, 51, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil}, 51, "s:+b", false], [{67=>nil, 59=>nil, 51=>nil, 43=>:enemy}, 43, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil}, 43, "s:+b", false], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>:enemy}, 35, "s:+b", true], [{67=>nil, 59=>nil, 51=>nil, 43=>nil, 35=>nil}, 35, "s:+b", false]], 76=>[[{66=>:enemy}, 66, "s:+b", true], [{68=>:enemy}, 68, "s:+b", true], [{66=>nil}, 66, "s:+b", false], [{66=>nil, 56=>:enemy}, 56, "s:+b", true], [{66=>nil, 56=>nil}, 56, "s:+b", false], [{66=>nil, 56=>nil, 46=>:enemy}, 46, "s:+b", true], [{66=>nil, 56=>nil, 46=>nil}, 46, "s:+b", false], [{66=>nil, 56=>nil, 46=>nil, 36=>:enemy}, 36, "s:+b", true], [{66=>nil, 56=>nil, 46=>nil, 36=>nil}, 36, "s:+b", false], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 60=>:enemy}, 60, "s:+b", true], [{68=>nil, 60=>nil}, 60, "s:+b", false], [{68=>nil, 60=>nil, 52=>:enemy}, 52, "s:+b", true], [{68=>nil, 60=>nil, 52=>nil}, 52, "s:+b", false], [{68=>nil, 60=>nil, 52=>nil, 44=>:enemy}, 44, "s:+b", true], [{68=>nil, 60=>nil, 52=>nil, 44=>nil}, 44, "s:+b", false]], 77=>[[{67=>:enemy}, 67, "s:+b", true], [{69=>:enemy}, 69, "s:+b", true], [{67=>nil}, 67, "s:+b", false], [{67=>nil, 57=>:enemy}, 57, "s:+b", true], [{67=>nil, 57=>nil}, 57, "s:+b", false], [{67=>nil, 57=>nil, 47=>:enemy}, 47, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil}, 47, "s:+b", false], [{67=>nil, 57=>nil, 47=>nil, 37=>:enemy}, 37, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil}, 37, "s:+b", false], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>:enemy}, 27, "s:+b", true], [{67=>nil, 57=>nil, 47=>nil, 37=>nil, 27=>nil}, 27, "s:+b", false], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 61=>:enemy}, 61, "s:+b", true], [{69=>nil, 61=>nil}, 61, "s:+b", false], [{69=>nil, 61=>nil, 53=>:enemy}, 53, "s:+b", true], [{69=>nil, 61=>nil, 53=>nil}, 53, "s:+b", false]], 78=>[[{68=>:enemy}, 68, "s:+b", true], [{70=>:enemy}, 70, "s:+b", true], [{68=>nil}, 68, "s:+b", false], [{68=>nil, 58=>:enemy}, 58, "s:+b", true], [{68=>nil, 58=>nil}, 58, "s:+b", false], [{68=>nil, 58=>nil, 48=>:enemy}, 48, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil}, 48, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>:enemy}, 38, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil}, 38, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>:enemy}, 28, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil}, 28, "s:+b", false], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>:enemy}, 18, "s:+b", true], [{68=>nil, 58=>nil, 48=>nil, 38=>nil, 28=>nil, 18=>nil}, 18, "s:+b", false], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 62=>:enemy}, 62, "s:+b", true], [{70=>nil, 62=>nil}, 62, "s:+b", false]], 79=>[[{69=>:enemy}, 69, "s:+b", true], [{71=>:enemy}, 71, "s:+b", true], [{69=>nil}, 69, "s:+b", false], [{69=>nil, 59=>:enemy}, 59, "s:+b", true], [{69=>nil, 59=>nil}, 59, "s:+b", false], [{69=>nil, 59=>nil, 49=>:enemy}, 49, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil}, 49, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>:enemy}, 39, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil}, 39, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>:enemy}, 29, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil}, 29, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>:enemy}, 19, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil}, 19, "s:+b", false], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>:enemy}, 9, "s:+b", true], [{69=>nil, 59=>nil, 49=>nil, 39=>nil, 29=>nil, 19=>nil, 9=>nil}, 9, "s:+b", false], [{71=>nil}, 71, "s:+b", false]], 80=>[[{70=>:enemy}, 70, "s:+b", true], [{70=>nil}, 70, "s:+b", false], [{70=>nil, 60=>:enemy}, 60, "s:+b", true], [{70=>nil, 60=>nil}, 60, "s:+b", false], [{70=>nil, 60=>nil, 50=>:enemy}, 50, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil}, 50, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>:enemy}, 40, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil}, 40, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>:enemy}, 30, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil}, 30, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>:enemy}, 20, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil}, 20, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>:enemy}, 10, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil}, 10, "s:+b", false], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>:enemy}, 0, "s:+b", true], [{70=>nil, 60=>nil, 50=>nil, 40=>nil, 30=>nil, 20=>nil, 10=>nil, 0=>nil}, 0, "s:+b", false]], nil=>[[{0=>nil}, 0, "s:b", false], [{1=>nil}, 1, "s:b", false], [{2=>nil}, 2, "s:b", false], [{3=>nil}, 3, "s:b", false], [{4=>nil}, 4, "s:b", false], [{5=>nil}, 5, "s:b", false], [{6=>nil}, 6, "s:b", false], [{7=>nil}, 7, "s:b", false], [{8=>nil}, 8, "s:b", false], [{9=>nil}, 9, "s:b", false], [{10=>nil}, 10, "s:b", false], [{11=>nil}, 11, "s:b", false], [{12=>nil}, 12, "s:b", false], [{13=>nil}, 13, "s:b", false], [{14=>nil}, 14, "s:b", false], [{15=>nil}, 15, "s:b", false], [{16=>nil}, 16, "s:b", false], [{17=>nil}, 17, "s:b", false], [{18=>nil}, 18, "s:b", false], [{19=>nil}, 19, "s:b", false], [{20=>nil}, 20, "s:b", false], [{21=>nil}, 21, "s:b", false], [{22=>nil}, 22, "s:b", false], [{23=>nil}, 23, "s:b", false], [{24=>nil}, 24, "s:b", false], [{25=>nil}, 25, "s:b", false], [{26=>nil}, 26, "s:b", false], [{27=>nil}, 27, "s:b", false], [{28=>nil}, 28, "s:b", false], [{29=>nil}, 29, "s:b", false], [{30=>nil}, 30, "s:b", false], [{31=>nil}, 31, "s:b", false], [{32=>nil}, 32, "s:b", false], [{33=>nil}, 33, "s:b", false], [{34=>nil}, 34, "s:b", false], [{35=>nil}, 35, "s:b", false], [{36=>nil}, 36, "s:b", false], [{37=>nil}, 37, "s:b", false], [{38=>nil}, 38, "s:b", false], [{39=>nil}, 39, "s:b", false], [{40=>nil}, 40, "s:b", false], [{41=>nil}, 41, "s:b", false], [{42=>nil}, 42, "s:b", false], [{43=>nil}, 43, "s:b", false], [{44=>nil}, 44, "s:b", false], [{45=>nil}, 45, "s:b", false], [{46=>nil}, 46, "s:b", false], [{47=>nil}, 47, "s:b", false], [{48=>nil}, 48, "s:b", false], [{49=>nil}, 49, "s:b", false], [{50=>nil}, 50, "s:b", false], [{51=>nil}, 51, "s:b", false], [{52=>nil}, 52, "s:b", false], [{53=>nil}, 53, "s:b", false], [{54=>nil}, 54, "s:b", false], [{55=>nil}, 55, "s:b", false], [{56=>nil}, 56, "s:b", false], [{57=>nil}, 57, "s:b", false], [{58=>nil}, 58, "s:b", false], [{59=>nil}, 59, "s:b", false], [{60=>nil}, 60, "s:b", false], [{61=>nil}, 61, "s:b", false], [{62=>nil}, 62, "s:b", false], [{63=>nil}, 63, "s:b", false], [{64=>nil}, 64, "s:b", false], [{65=>nil}, 65, "s:b", false], [{66=>nil}, 66, "s:b", false], [{67=>nil}, 67, "s:b", false], [{68=>nil}, 68, "s:b", false], [{69=>nil}, 69, "s:b", false], [{70=>nil}, 70, "s:b", false], [{71=>nil}, 71, "s:b", false], [{72=>nil}, 72, "s:b", false], [{73=>nil}, 73, "s:b", false], [{74=>nil}, 74, "s:b", false], [{75=>nil}, 75, "s:b", false], [{76=>nil}, 76, "s:b", false], [{77=>nil}, 77, "s:b", false], [{78=>nil}, 78, "s:b", false], [{79=>nil}, 79, "s:b", false], [{80=>nil}, 80, "s:b", false]]}, "s:g"=>{0=>[[{1=>:enemy}, 1, "s:g", true], [{9=>:enemy}, 9, "s:g", true], [{10=>:enemy}, 10, "s:g", true], [{1=>nil}, 1, "s:g", false], [{9=>nil}, 9, "s:g", false], [{10=>nil}, 10, "s:g", false]], 1=>[[{0=>:enemy}, 0, "s:g", true], [{2=>:enemy}, 2, "s:g", true], [{9=>:enemy}, 9, "s:g", true], [{10=>:enemy}, 10, "s:g", true], [{11=>:enemy}, 11, "s:g", true], [{0=>nil}, 0, "s:g", false], [{2=>nil}, 2, "s:g", false], [{9=>nil}, 9, "s:g", false], [{10=>nil}, 10, "s:g", false], [{11=>nil}, 11, "s:g", false]], 2=>[[{1=>:enemy}, 1, "s:g", true], [{3=>:enemy}, 3, "s:g", true], [{10=>:enemy}, 10, "s:g", true], [{11=>:enemy}, 11, "s:g", true], [{12=>:enemy}, 12, "s:g", true], [{1=>nil}, 1, "s:g", false], [{3=>nil}, 3, "s:g", false], [{10=>nil}, 10, "s:g", false], [{11=>nil}, 11, "s:g", false], [{12=>nil}, 12, "s:g", false]], 3=>[[{2=>:enemy}, 2, "s:g", true], [{4=>:enemy}, 4, "s:g", true], [{11=>:enemy}, 11, "s:g", true], [{12=>:enemy}, 12, "s:g", true], [{13=>:enemy}, 13, "s:g", true], [{2=>nil}, 2, "s:g", false], [{4=>nil}, 4, "s:g", false], [{11=>nil}, 11, "s:g", false], [{12=>nil}, 12, "s:g", false], [{13=>nil}, 13, "s:g", false]], 4=>[[{3=>:enemy}, 3, "s:g", true], [{5=>:enemy}, 5, "s:g", true], [{12=>:enemy}, 12, "s:g", true], [{13=>:enemy}, 13, "s:g", true], [{14=>:enemy}, 14, "s:g", true], [{3=>nil}, 3, "s:g", false], [{5=>nil}, 5, "s:g", false], [{12=>nil}, 12, "s:g", false], [{13=>nil}, 13, "s:g", false], [{14=>nil}, 14, "s:g", false]], 5=>[[{4=>:enemy}, 4, "s:g", true], [{6=>:enemy}, 6, "s:g", true], [{13=>:enemy}, 13, "s:g", true], [{14=>:enemy}, 14, "s:g", true], [{15=>:enemy}, 15, "s:g", true], [{4=>nil}, 4, "s:g", false], [{6=>nil}, 6, "s:g", false], [{13=>nil}, 13, "s:g", false], [{14=>nil}, 14, "s:g", false], [{15=>nil}, 15, "s:g", false]], 6=>[[{5=>:enemy}, 5, "s:g", true], [{7=>:enemy}, 7, "s:g", true], [{14=>:enemy}, 14, "s:g", true], [{15=>:enemy}, 15, "s:g", true], [{16=>:enemy}, 16, "s:g", true], [{5=>nil}, 5, "s:g", false], [{7=>nil}, 7, "s:g", false], [{14=>nil}, 14, "s:g", false], [{15=>nil}, 15, "s:g", false], [{16=>nil}, 16, "s:g", false]], 7=>[[{6=>:enemy}, 6, "s:g", true], [{8=>:enemy}, 8, "s:g", true], [{15=>:enemy}, 15, "s:g", true], [{16=>:enemy}, 16, "s:g", true], [{17=>:enemy}, 17, "s:g", true], [{6=>nil}, 6, "s:g", false], [{8=>nil}, 8, "s:g", false], [{15=>nil}, 15, "s:g", false], [{16=>nil}, 16, "s:g", false], [{17=>nil}, 17, "s:g", false]], 8=>[[{7=>:enemy}, 7, "s:g", true], [{16=>:enemy}, 16, "s:g", true], [{17=>:enemy}, 17, "s:g", true], [{7=>nil}, 7, "s:g", false], [{16=>nil}, 16, "s:g", false], [{17=>nil}, 17, "s:g", false]], 9=>[[{0=>:enemy}, 0, "s:g", true], [{10=>:enemy}, 10, "s:g", true], [{18=>:enemy}, 18, "s:g", true], [{19=>:enemy}, 19, "s:g", true], [{0=>nil}, 0, "s:g", false], [{10=>nil}, 10, "s:g", false], [{18=>nil}, 18, "s:g", false], [{19=>nil}, 19, "s:g", false]], 10=>[[{1=>:enemy}, 1, "s:g", true], [{9=>:enemy}, 9, "s:g", true], [{11=>:enemy}, 11, "s:g", true], [{18=>:enemy}, 18, "s:g", true], [{19=>:enemy}, 19, "s:g", true], [{20=>:enemy}, 20, "s:g", true], [{1=>nil}, 1, "s:g", false], [{9=>nil}, 9, "s:g", false], [{11=>nil}, 11, "s:g", false], [{18=>nil}, 18, "s:g", false], [{19=>nil}, 19, "s:g", false], [{20=>nil}, 20, "s:g", false]], 11=>[[{2=>:enemy}, 2, "s:g", true], [{10=>:enemy}, 10, "s:g", true], [{12=>:enemy}, 12, "s:g", true], [{19=>:enemy}, 19, "s:g", true], [{20=>:enemy}, 20, "s:g", true], [{21=>:enemy}, 21, "s:g", true], [{2=>nil}, 2, "s:g", false], [{10=>nil}, 10, "s:g", false], [{12=>nil}, 12, "s:g", false], [{19=>nil}, 19, "s:g", false], [{20=>nil}, 20, "s:g", false], [{21=>nil}, 21, "s:g", false]], 12=>[[{3=>:enemy}, 3, "s:g", true], [{11=>:enemy}, 11, "s:g", true], [{13=>:enemy}, 13, "s:g", true], [{20=>:enemy}, 20, "s:g", true], [{21=>:enemy}, 21, "s:g", true], [{22=>:enemy}, 22, "s:g", true], [{3=>nil}, 3, "s:g", false], [{11=>nil}, 11, "s:g", false], [{13=>nil}, 13, "s:g", false], [{20=>nil}, 20, "s:g", false], [{21=>nil}, 21, "s:g", false], [{22=>nil}, 22, "s:g", false]], 13=>[[{4=>:enemy}, 4, "s:g", true], [{12=>:enemy}, 12, "s:g", true], [{14=>:enemy}, 14, "s:g", true], [{21=>:enemy}, 21, "s:g", true], [{22=>:enemy}, 22, "s:g", true], [{23=>:enemy}, 23, "s:g", true], [{4=>nil}, 4, "s:g", false], [{12=>nil}, 12, "s:g", false], [{14=>nil}, 14, "s:g", false], [{21=>nil}, 21, "s:g", false], [{22=>nil}, 22, "s:g", false], [{23=>nil}, 23, "s:g", false]], 14=>[[{5=>:enemy}, 5, "s:g", true], [{13=>:enemy}, 13, "s:g", true], [{15=>:enemy}, 15, "s:g", true], [{22=>:enemy}, 22, "s:g", true], [{23=>:enemy}, 23, "s:g", true], [{24=>:enemy}, 24, "s:g", true], [{5=>nil}, 5, "s:g", false], [{13=>nil}, 13, "s:g", false], [{15=>nil}, 15, "s:g", false], [{22=>nil}, 22, "s:g", false], [{23=>nil}, 23, "s:g", false], [{24=>nil}, 24, "s:g", false]], 15=>[[{6=>:enemy}, 6, "s:g", true], [{14=>:enemy}, 14, "s:g", true], [{16=>:enemy}, 16, "s:g", true], [{23=>:enemy}, 23, "s:g", true], [{24=>:enemy}, 24, "s:g", true], [{25=>:enemy}, 25, "s:g", true], [{6=>nil}, 6, "s:g", false], [{14=>nil}, 14, "s:g", false], [{16=>nil}, 16, "s:g", false], [{23=>nil}, 23, "s:g", false], [{24=>nil}, 24, "s:g", false], [{25=>nil}, 25, "s:g", false]], 16=>[[{7=>:enemy}, 7, "s:g", true], [{15=>:enemy}, 15, "s:g", true], [{17=>:enemy}, 17, "s:g", true], [{24=>:enemy}, 24, "s:g", true], [{25=>:enemy}, 25, "s:g", true], [{26=>:enemy}, 26, "s:g", true], [{7=>nil}, 7, "s:g", false], [{15=>nil}, 15, "s:g", false], [{17=>nil}, 17, "s:g", false], [{24=>nil}, 24, "s:g", false], [{25=>nil}, 25, "s:g", false], [{26=>nil}, 26, "s:g", false]], 17=>[[{8=>:enemy}, 8, "s:g", true], [{16=>:enemy}, 16, "s:g", true], [{25=>:enemy}, 25, "s:g", true], [{26=>:enemy}, 26, "s:g", true], [{8=>nil}, 8, "s:g", false], [{16=>nil}, 16, "s:g", false], [{25=>nil}, 25, "s:g", false], [{26=>nil}, 26, "s:g", false]], 18=>[[{9=>:enemy}, 9, "s:g", true], [{19=>:enemy}, 19, "s:g", true], [{27=>:enemy}, 27, "s:g", true], [{28=>:enemy}, 28, "s:g", true], [{9=>nil}, 9, "s:g", false], [{19=>nil}, 19, "s:g", false], [{27=>nil}, 27, "s:g", false], [{28=>nil}, 28, "s:g", false]], 19=>[[{10=>:enemy}, 10, "s:g", true], [{18=>:enemy}, 18, "s:g", true], [{20=>:enemy}, 20, "s:g", true], [{27=>:enemy}, 27, "s:g", true], [{28=>:enemy}, 28, "s:g", true], [{29=>:enemy}, 29, "s:g", true], [{10=>nil}, 10, "s:g", false], [{18=>nil}, 18, "s:g", false], [{20=>nil}, 20, "s:g", false], [{27=>nil}, 27, "s:g", false], [{28=>nil}, 28, "s:g", false], [{29=>nil}, 29, "s:g", false]], 20=>[[{11=>:enemy}, 11, "s:g", true], [{19=>:enemy}, 19, "s:g", true], [{21=>:enemy}, 21, "s:g", true], [{28=>:enemy}, 28, "s:g", true], [{29=>:enemy}, 29, "s:g", true], [{30=>:enemy}, 30, "s:g", true], [{11=>nil}, 11, "s:g", false], [{19=>nil}, 19, "s:g", false], [{21=>nil}, 21, "s:g", false], [{28=>nil}, 28, "s:g", false], [{29=>nil}, 29, "s:g", false], [{30=>nil}, 30, "s:g", false]], 21=>[[{12=>:enemy}, 12, "s:g", true], [{20=>:enemy}, 20, "s:g", true], [{22=>:enemy}, 22, "s:g", true], [{29=>:enemy}, 29, "s:g", true], [{30=>:enemy}, 30, "s:g", true], [{31=>:enemy}, 31, "s:g", true], [{12=>nil}, 12, "s:g", false], [{20=>nil}, 20, "s:g", false], [{22=>nil}, 22, "s:g", false], [{29=>nil}, 29, "s:g", false], [{30=>nil}, 30, "s:g", false], [{31=>nil}, 31, "s:g", false]], 22=>[[{13=>:enemy}, 13, "s:g", true], [{21=>:enemy}, 21, "s:g", true], [{23=>:enemy}, 23, "s:g", true], [{30=>:enemy}, 30, "s:g", true], [{31=>:enemy}, 31, "s:g", true], [{32=>:enemy}, 32, "s:g", true], [{13=>nil}, 13, "s:g", false], [{21=>nil}, 21, "s:g", false], [{23=>nil}, 23, "s:g", false], [{30=>nil}, 30, "s:g", false], [{31=>nil}, 31, "s:g", false], [{32=>nil}, 32, "s:g", false]], 23=>[[{14=>:enemy}, 14, "s:g", true], [{22=>:enemy}, 22, "s:g", true], [{24=>:enemy}, 24, "s:g", true], [{31=>:enemy}, 31, "s:g", true], [{32=>:enemy}, 32, "s:g", true], [{33=>:enemy}, 33, "s:g", true], [{14=>nil}, 14, "s:g", false], [{22=>nil}, 22, "s:g", false], [{24=>nil}, 24, "s:g", false], [{31=>nil}, 31, "s:g", false], [{32=>nil}, 32, "s:g", false], [{33=>nil}, 33, "s:g", false]], 24=>[[{15=>:enemy}, 15, "s:g", true], [{23=>:enemy}, 23, "s:g", true], [{25=>:enemy}, 25, "s:g", true], [{32=>:enemy}, 32, "s:g", true], [{33=>:enemy}, 33, "s:g", true], [{34=>:enemy}, 34, "s:g", true], [{15=>nil}, 15, "s:g", false], [{23=>nil}, 23, "s:g", false], [{25=>nil}, 25, "s:g", false], [{32=>nil}, 32, "s:g", false], [{33=>nil}, 33, "s:g", false], [{34=>nil}, 34, "s:g", false]], 25=>[[{16=>:enemy}, 16, "s:g", true], [{24=>:enemy}, 24, "s:g", true], [{26=>:enemy}, 26, "s:g", true], [{33=>:enemy}, 33, "s:g", true], [{34=>:enemy}, 34, "s:g", true], [{35=>:enemy}, 35, "s:g", true], [{16=>nil}, 16, "s:g", false], [{24=>nil}, 24, "s:g", false], [{26=>nil}, 26, "s:g", false], [{33=>nil}, 33, "s:g", false], [{34=>nil}, 34, "s:g", false], [{35=>nil}, 35, "s:g", false]], 26=>[[{17=>:enemy}, 17, "s:g", true], [{25=>:enemy}, 25, "s:g", true], [{34=>:enemy}, 34, "s:g", true], [{35=>:enemy}, 35, "s:g", true], [{17=>nil}, 17, "s:g", false], [{25=>nil}, 25, "s:g", false], [{34=>nil}, 34, "s:g", false], [{35=>nil}, 35, "s:g", false]], 27=>[[{18=>:enemy}, 18, "s:g", true], [{28=>:enemy}, 28, "s:g", true], [{36=>:enemy}, 36, "s:g", true], [{37=>:enemy}, 37, "s:g", true], [{18=>nil}, 18, "s:g", false], [{28=>nil}, 28, "s:g", false], [{36=>nil}, 36, "s:g", false], [{37=>nil}, 37, "s:g", false]], 28=>[[{19=>:enemy}, 19, "s:g", true], [{27=>:enemy}, 27, "s:g", true], [{29=>:enemy}, 29, "s:g", true], [{36=>:enemy}, 36, "s:g", true], [{37=>:enemy}, 37, "s:g", true], [{38=>:enemy}, 38, "s:g", true], [{19=>nil}, 19, "s:g", false], [{27=>nil}, 27, "s:g", false], [{29=>nil}, 29, "s:g", false], [{36=>nil}, 36, "s:g", false], [{37=>nil}, 37, "s:g", false], [{38=>nil}, 38, "s:g", false]], 29=>[[{20=>:enemy}, 20, "s:g", true], [{28=>:enemy}, 28, "s:g", true], [{30=>:enemy}, 30, "s:g", true], [{37=>:enemy}, 37, "s:g", true], [{38=>:enemy}, 38, "s:g", true], [{39=>:enemy}, 39, "s:g", true], [{20=>nil}, 20, "s:g", false], [{28=>nil}, 28, "s:g", false], [{30=>nil}, 30, "s:g", false], [{37=>nil}, 37, "s:g", false], [{38=>nil}, 38, "s:g", false], [{39=>nil}, 39, "s:g", false]], 30=>[[{21=>:enemy}, 21, "s:g", true], [{29=>:enemy}, 29, "s:g", true], [{31=>:enemy}, 31, "s:g", true], [{38=>:enemy}, 38, "s:g", true], [{39=>:enemy}, 39, "s:g", true], [{40=>:enemy}, 40, "s:g", true], [{21=>nil}, 21, "s:g", false], [{29=>nil}, 29, "s:g", false], [{31=>nil}, 31, "s:g", false], [{38=>nil}, 38, "s:g", false], [{39=>nil}, 39, "s:g", false], [{40=>nil}, 40, "s:g", false]], 31=>[[{22=>:enemy}, 22, "s:g", true], [{30=>:enemy}, 30, "s:g", true], [{32=>:enemy}, 32, "s:g", true], [{39=>:enemy}, 39, "s:g", true], [{40=>:enemy}, 40, "s:g", true], [{41=>:enemy}, 41, "s:g", true], [{22=>nil}, 22, "s:g", false], [{30=>nil}, 30, "s:g", false], [{32=>nil}, 32, "s:g", false], [{39=>nil}, 39, "s:g", false], [{40=>nil}, 40, "s:g", false], [{41=>nil}, 41, "s:g", false]], 32=>[[{23=>:enemy}, 23, "s:g", true], [{31=>:enemy}, 31, "s:g", true], [{33=>:enemy}, 33, "s:g", true], [{40=>:enemy}, 40, "s:g", true], [{41=>:enemy}, 41, "s:g", true], [{42=>:enemy}, 42, "s:g", true], [{23=>nil}, 23, "s:g", false], [{31=>nil}, 31, "s:g", false], [{33=>nil}, 33, "s:g", false], [{40=>nil}, 40, "s:g", false], [{41=>nil}, 41, "s:g", false], [{42=>nil}, 42, "s:g", false]], 33=>[[{24=>:enemy}, 24, "s:g", true], [{32=>:enemy}, 32, "s:g", true], [{34=>:enemy}, 34, "s:g", true], [{41=>:enemy}, 41, "s:g", true], [{42=>:enemy}, 42, "s:g", true], [{43=>:enemy}, 43, "s:g", true], [{24=>nil}, 24, "s:g", false], [{32=>nil}, 32, "s:g", false], [{34=>nil}, 34, "s:g", false], [{41=>nil}, 41, "s:g", false], [{42=>nil}, 42, "s:g", false], [{43=>nil}, 43, "s:g", false]], 34=>[[{25=>:enemy}, 25, "s:g", true], [{33=>:enemy}, 33, "s:g", true], [{35=>:enemy}, 35, "s:g", true], [{42=>:enemy}, 42, "s:g", true], [{43=>:enemy}, 43, "s:g", true], [{44=>:enemy}, 44, "s:g", true], [{25=>nil}, 25, "s:g", false], [{33=>nil}, 33, "s:g", false], [{35=>nil}, 35, "s:g", false], [{42=>nil}, 42, "s:g", false], [{43=>nil}, 43, "s:g", false], [{44=>nil}, 44, "s:g", false]], 35=>[[{26=>:enemy}, 26, "s:g", true], [{34=>:enemy}, 34, "s:g", true], [{43=>:enemy}, 43, "s:g", true], [{44=>:enemy}, 44, "s:g", true], [{26=>nil}, 26, "s:g", false], [{34=>nil}, 34, "s:g", false], [{43=>nil}, 43, "s:g", false], [{44=>nil}, 44, "s:g", false]], 36=>[[{27=>:enemy}, 27, "s:g", true], [{37=>:enemy}, 37, "s:g", true], [{45=>:enemy}, 45, "s:g", true], [{46=>:enemy}, 46, "s:g", true], [{27=>nil}, 27, "s:g", false], [{37=>nil}, 37, "s:g", false], [{45=>nil}, 45, "s:g", false], [{46=>nil}, 46, "s:g", false]], 37=>[[{28=>:enemy}, 28, "s:g", true], [{36=>:enemy}, 36, "s:g", true], [{38=>:enemy}, 38, "s:g", true], [{45=>:enemy}, 45, "s:g", true], [{46=>:enemy}, 46, "s:g", true], [{47=>:enemy}, 47, "s:g", true], [{28=>nil}, 28, "s:g", false], [{36=>nil}, 36, "s:g", false], [{38=>nil}, 38, "s:g", false], [{45=>nil}, 45, "s:g", false], [{46=>nil}, 46, "s:g", false], [{47=>nil}, 47, "s:g", false]], 38=>[[{29=>:enemy}, 29, "s:g", true], [{37=>:enemy}, 37, "s:g", true], [{39=>:enemy}, 39, "s:g", true], [{46=>:enemy}, 46, "s:g", true], [{47=>:enemy}, 47, "s:g", true], [{48=>:enemy}, 48, "s:g", true], [{29=>nil}, 29, "s:g", false], [{37=>nil}, 37, "s:g", false], [{39=>nil}, 39, "s:g", false], [{46=>nil}, 46, "s:g", false], [{47=>nil}, 47, "s:g", false], [{48=>nil}, 48, "s:g", false]], 39=>[[{30=>:enemy}, 30, "s:g", true], [{38=>:enemy}, 38, "s:g", true], [{40=>:enemy}, 40, "s:g", true], [{47=>:enemy}, 47, "s:g", true], [{48=>:enemy}, 48, "s:g", true], [{49=>:enemy}, 49, "s:g", true], [{30=>nil}, 30, "s:g", false], [{38=>nil}, 38, "s:g", false], [{40=>nil}, 40, "s:g", false], [{47=>nil}, 47, "s:g", false], [{48=>nil}, 48, "s:g", false], [{49=>nil}, 49, "s:g", false]], 40=>[[{31=>:enemy}, 31, "s:g", true], [{39=>:enemy}, 39, "s:g", true], [{41=>:enemy}, 41, "s:g", true], [{48=>:enemy}, 48, "s:g", true], [{49=>:enemy}, 49, "s:g", true], [{50=>:enemy}, 50, "s:g", true], [{31=>nil}, 31, "s:g", false], [{39=>nil}, 39, "s:g", false], [{41=>nil}, 41, "s:g", false], [{48=>nil}, 48, "s:g", false], [{49=>nil}, 49, "s:g", false], [{50=>nil}, 50, "s:g", false]], 41=>[[{32=>:enemy}, 32, "s:g", true], [{40=>:enemy}, 40, "s:g", true], [{42=>:enemy}, 42, "s:g", true], [{49=>:enemy}, 49, "s:g", true], [{50=>:enemy}, 50, "s:g", true], [{51=>:enemy}, 51, "s:g", true], [{32=>nil}, 32, "s:g", false], [{40=>nil}, 40, "s:g", false], [{42=>nil}, 42, "s:g", false], [{49=>nil}, 49, "s:g", false], [{50=>nil}, 50, "s:g", false], [{51=>nil}, 51, "s:g", false]], 42=>[[{33=>:enemy}, 33, "s:g", true], [{41=>:enemy}, 41, "s:g", true], [{43=>:enemy}, 43, "s:g", true], [{50=>:enemy}, 50, "s:g", true], [{51=>:enemy}, 51, "s:g", true], [{52=>:enemy}, 52, "s:g", true], [{33=>nil}, 33, "s:g", false], [{41=>nil}, 41, "s:g", false], [{43=>nil}, 43, "s:g", false], [{50=>nil}, 50, "s:g", false], [{51=>nil}, 51, "s:g", false], [{52=>nil}, 52, "s:g", false]], 43=>[[{34=>:enemy}, 34, "s:g", true], [{42=>:enemy}, 42, "s:g", true], [{44=>:enemy}, 44, "s:g", true], [{51=>:enemy}, 51, "s:g", true], [{52=>:enemy}, 52, "s:g", true], [{53=>:enemy}, 53, "s:g", true], [{34=>nil}, 34, "s:g", false], [{42=>nil}, 42, "s:g", false], [{44=>nil}, 44, "s:g", false], [{51=>nil}, 51, "s:g", false], [{52=>nil}, 52, "s:g", false], [{53=>nil}, 53, "s:g", false]], 44=>[[{35=>:enemy}, 35, "s:g", true], [{43=>:enemy}, 43, "s:g", true], [{52=>:enemy}, 52, "s:g", true], [{53=>:enemy}, 53, "s:g", true], [{35=>nil}, 35, "s:g", false], [{43=>nil}, 43, "s:g", false], [{52=>nil}, 52, "s:g", false], [{53=>nil}, 53, "s:g", false]], 45=>[[{36=>:enemy}, 36, "s:g", true], [{46=>:enemy}, 46, "s:g", true], [{54=>:enemy}, 54, "s:g", true], [{55=>:enemy}, 55, "s:g", true], [{36=>nil}, 36, "s:g", false], [{46=>nil}, 46, "s:g", false], [{54=>nil}, 54, "s:g", false], [{55=>nil}, 55, "s:g", false]], 46=>[[{37=>:enemy}, 37, "s:g", true], [{45=>:enemy}, 45, "s:g", true], [{47=>:enemy}, 47, "s:g", true], [{54=>:enemy}, 54, "s:g", true], [{55=>:enemy}, 55, "s:g", true], [{56=>:enemy}, 56, "s:g", true], [{37=>nil}, 37, "s:g", false], [{45=>nil}, 45, "s:g", false], [{47=>nil}, 47, "s:g", false], [{54=>nil}, 54, "s:g", false], [{55=>nil}, 55, "s:g", false], [{56=>nil}, 56, "s:g", false]], 47=>[[{38=>:enemy}, 38, "s:g", true], [{46=>:enemy}, 46, "s:g", true], [{48=>:enemy}, 48, "s:g", true], [{55=>:enemy}, 55, "s:g", true], [{56=>:enemy}, 56, "s:g", true], [{57=>:enemy}, 57, "s:g", true], [{38=>nil}, 38, "s:g", false], [{46=>nil}, 46, "s:g", false], [{48=>nil}, 48, "s:g", false], [{55=>nil}, 55, "s:g", false], [{56=>nil}, 56, "s:g", false], [{57=>nil}, 57, "s:g", false]], 48=>[[{39=>:enemy}, 39, "s:g", true], [{47=>:enemy}, 47, "s:g", true], [{49=>:enemy}, 49, "s:g", true], [{56=>:enemy}, 56, "s:g", true], [{57=>:enemy}, 57, "s:g", true], [{58=>:enemy}, 58, "s:g", true], [{39=>nil}, 39, "s:g", false], [{47=>nil}, 47, "s:g", false], [{49=>nil}, 49, "s:g", false], [{56=>nil}, 56, "s:g", false], [{57=>nil}, 57, "s:g", false], [{58=>nil}, 58, "s:g", false]], 49=>[[{40=>:enemy}, 40, "s:g", true], [{48=>:enemy}, 48, "s:g", true], [{50=>:enemy}, 50, "s:g", true], [{57=>:enemy}, 57, "s:g", true], [{58=>:enemy}, 58, "s:g", true], [{59=>:enemy}, 59, "s:g", true], [{40=>nil}, 40, "s:g", false], [{48=>nil}, 48, "s:g", false], [{50=>nil}, 50, "s:g", false], [{57=>nil}, 57, "s:g", false], [{58=>nil}, 58, "s:g", false], [{59=>nil}, 59, "s:g", false]], 50=>[[{41=>:enemy}, 41, "s:g", true], [{49=>:enemy}, 49, "s:g", true], [{51=>:enemy}, 51, "s:g", true], [{58=>:enemy}, 58, "s:g", true], [{59=>:enemy}, 59, "s:g", true], [{60=>:enemy}, 60, "s:g", true], [{41=>nil}, 41, "s:g", false], [{49=>nil}, 49, "s:g", false], [{51=>nil}, 51, "s:g", false], [{58=>nil}, 58, "s:g", false], [{59=>nil}, 59, "s:g", false], [{60=>nil}, 60, "s:g", false]], 51=>[[{42=>:enemy}, 42, "s:g", true], [{50=>:enemy}, 50, "s:g", true], [{52=>:enemy}, 52, "s:g", true], [{59=>:enemy}, 59, "s:g", true], [{60=>:enemy}, 60, "s:g", true], [{61=>:enemy}, 61, "s:g", true], [{42=>nil}, 42, "s:g", false], [{50=>nil}, 50, "s:g", false], [{52=>nil}, 52, "s:g", false], [{59=>nil}, 59, "s:g", false], [{60=>nil}, 60, "s:g", false], [{61=>nil}, 61, "s:g", false]], 52=>[[{43=>:enemy}, 43, "s:g", true], [{51=>:enemy}, 51, "s:g", true], [{53=>:enemy}, 53, "s:g", true], [{60=>:enemy}, 60, "s:g", true], [{61=>:enemy}, 61, "s:g", true], [{62=>:enemy}, 62, "s:g", true], [{43=>nil}, 43, "s:g", false], [{51=>nil}, 51, "s:g", false], [{53=>nil}, 53, "s:g", false], [{60=>nil}, 60, "s:g", false], [{61=>nil}, 61, "s:g", false], [{62=>nil}, 62, "s:g", false]], 53=>[[{44=>:enemy}, 44, "s:g", true], [{52=>:enemy}, 52, "s:g", true], [{61=>:enemy}, 61, "s:g", true], [{62=>:enemy}, 62, "s:g", true], [{44=>nil}, 44, "s:g", false], [{52=>nil}, 52, "s:g", false], [{61=>nil}, 61, "s:g", false], [{62=>nil}, 62, "s:g", false]], 54=>[[{45=>:enemy}, 45, "s:g", true], [{55=>:enemy}, 55, "s:g", true], [{63=>:enemy}, 63, "s:g", true], [{64=>:enemy}, 64, "s:g", true], [{45=>nil}, 45, "s:g", false], [{55=>nil}, 55, "s:g", false], [{63=>nil}, 63, "s:g", false], [{64=>nil}, 64, "s:g", false]], 55=>[[{46=>:enemy}, 46, "s:g", true], [{54=>:enemy}, 54, "s:g", true], [{56=>:enemy}, 56, "s:g", true], [{63=>:enemy}, 63, "s:g", true], [{64=>:enemy}, 64, "s:g", true], [{65=>:enemy}, 65, "s:g", true], [{46=>nil}, 46, "s:g", false], [{54=>nil}, 54, "s:g", false], [{56=>nil}, 56, "s:g", false], [{63=>nil}, 63, "s:g", false], [{64=>nil}, 64, "s:g", false], [{65=>nil}, 65, "s:g", false]], 56=>[[{47=>:enemy}, 47, "s:g", true], [{55=>:enemy}, 55, "s:g", true], [{57=>:enemy}, 57, "s:g", true], [{64=>:enemy}, 64, "s:g", true], [{65=>:enemy}, 65, "s:g", true], [{66=>:enemy}, 66, "s:g", true], [{47=>nil}, 47, "s:g", false], [{55=>nil}, 55, "s:g", false], [{57=>nil}, 57, "s:g", false], [{64=>nil}, 64, "s:g", false], [{65=>nil}, 65, "s:g", false], [{66=>nil}, 66, "s:g", false]], 57=>[[{48=>:enemy}, 48, "s:g", true], [{56=>:enemy}, 56, "s:g", true], [{58=>:enemy}, 58, "s:g", true], [{65=>:enemy}, 65, "s:g", true], [{66=>:enemy}, 66, "s:g", true], [{67=>:enemy}, 67, "s:g", true], [{48=>nil}, 48, "s:g", false], [{56=>nil}, 56, "s:g", false], [{58=>nil}, 58, "s:g", false], [{65=>nil}, 65, "s:g", false], [{66=>nil}, 66, "s:g", false], [{67=>nil}, 67, "s:g", false]], 58=>[[{49=>:enemy}, 49, "s:g", true], [{57=>:enemy}, 57, "s:g", true], [{59=>:enemy}, 59, "s:g", true], [{66=>:enemy}, 66, "s:g", true], [{67=>:enemy}, 67, "s:g", true], [{68=>:enemy}, 68, "s:g", true], [{49=>nil}, 49, "s:g", false], [{57=>nil}, 57, "s:g", false], [{59=>nil}, 59, "s:g", false], [{66=>nil}, 66, "s:g", false], [{67=>nil}, 67, "s:g", false], [{68=>nil}, 68, "s:g", false]], 59=>[[{50=>:enemy}, 50, "s:g", true], [{58=>:enemy}, 58, "s:g", true], [{60=>:enemy}, 60, "s:g", true], [{67=>:enemy}, 67, "s:g", true], [{68=>:enemy}, 68, "s:g", true], [{69=>:enemy}, 69, "s:g", true], [{50=>nil}, 50, "s:g", false], [{58=>nil}, 58, "s:g", false], [{60=>nil}, 60, "s:g", false], [{67=>nil}, 67, "s:g", false], [{68=>nil}, 68, "s:g", false], [{69=>nil}, 69, "s:g", false]], 60=>[[{51=>:enemy}, 51, "s:g", true], [{59=>:enemy}, 59, "s:g", true], [{61=>:enemy}, 61, "s:g", true], [{68=>:enemy}, 68, "s:g", true], [{69=>:enemy}, 69, "s:g", true], [{70=>:enemy}, 70, "s:g", true], [{51=>nil}, 51, "s:g", false], [{59=>nil}, 59, "s:g", false], [{61=>nil}, 61, "s:g", false], [{68=>nil}, 68, "s:g", false], [{69=>nil}, 69, "s:g", false], [{70=>nil}, 70, "s:g", false]], 61=>[[{52=>:enemy}, 52, "s:g", true], [{60=>:enemy}, 60, "s:g", true], [{62=>:enemy}, 62, "s:g", true], [{69=>:enemy}, 69, "s:g", true], [{70=>:enemy}, 70, "s:g", true], [{71=>:enemy}, 71, "s:g", true], [{52=>nil}, 52, "s:g", false], [{60=>nil}, 60, "s:g", false], [{62=>nil}, 62, "s:g", false], [{69=>nil}, 69, "s:g", false], [{70=>nil}, 70, "s:g", false], [{71=>nil}, 71, "s:g", false]], 62=>[[{53=>:enemy}, 53, "s:g", true], [{61=>:enemy}, 61, "s:g", true], [{70=>:enemy}, 70, "s:g", true], [{71=>:enemy}, 71, "s:g", true], [{53=>nil}, 53, "s:g", false], [{61=>nil}, 61, "s:g", false], [{70=>nil}, 70, "s:g", false], [{71=>nil}, 71, "s:g", false]], 63=>[[{54=>:enemy}, 54, "s:g", true], [{64=>:enemy}, 64, "s:g", true], [{72=>:enemy}, 72, "s:g", true], [{73=>:enemy}, 73, "s:g", true], [{54=>nil}, 54, "s:g", false], [{64=>nil}, 64, "s:g", false], [{72=>nil}, 72, "s:g", false], [{73=>nil}, 73, "s:g", false]], 64=>[[{55=>:enemy}, 55, "s:g", true], [{63=>:enemy}, 63, "s:g", true], [{65=>:enemy}, 65, "s:g", true], [{72=>:enemy}, 72, "s:g", true], [{73=>:enemy}, 73, "s:g", true], [{74=>:enemy}, 74, "s:g", true], [{55=>nil}, 55, "s:g", false], [{63=>nil}, 63, "s:g", false], [{65=>nil}, 65, "s:g", false], [{72=>nil}, 72, "s:g", false], [{73=>nil}, 73, "s:g", false], [{74=>nil}, 74, "s:g", false]], 65=>[[{56=>:enemy}, 56, "s:g", true], [{64=>:enemy}, 64, "s:g", true], [{66=>:enemy}, 66, "s:g", true], [{73=>:enemy}, 73, "s:g", true], [{74=>:enemy}, 74, "s:g", true], [{75=>:enemy}, 75, "s:g", true], [{56=>nil}, 56, "s:g", false], [{64=>nil}, 64, "s:g", false], [{66=>nil}, 66, "s:g", false], [{73=>nil}, 73, "s:g", false], [{74=>nil}, 74, "s:g", false], [{75=>nil}, 75, "s:g", false]], 66=>[[{57=>:enemy}, 57, "s:g", true], [{65=>:enemy}, 65, "s:g", true], [{67=>:enemy}, 67, "s:g", true], [{74=>:enemy}, 74, "s:g", true], [{75=>:enemy}, 75, "s:g", true], [{76=>:enemy}, 76, "s:g", true], [{57=>nil}, 57, "s:g", false], [{65=>nil}, 65, "s:g", false], [{67=>nil}, 67, "s:g", false], [{74=>nil}, 74, "s:g", false], [{75=>nil}, 75, "s:g", false], [{76=>nil}, 76, "s:g", false]], 67=>[[{58=>:enemy}, 58, "s:g", true], [{66=>:enemy}, 66, "s:g", true], [{68=>:enemy}, 68, "s:g", true], [{75=>:enemy}, 75, "s:g", true], [{76=>:enemy}, 76, "s:g", true], [{77=>:enemy}, 77, "s:g", true], [{58=>nil}, 58, "s:g", false], [{66=>nil}, 66, "s:g", false], [{68=>nil}, 68, "s:g", false], [{75=>nil}, 75, "s:g", false], [{76=>nil}, 76, "s:g", false], [{77=>nil}, 77, "s:g", false]], 68=>[[{59=>:enemy}, 59, "s:g", true], [{67=>:enemy}, 67, "s:g", true], [{69=>:enemy}, 69, "s:g", true], [{76=>:enemy}, 76, "s:g", true], [{77=>:enemy}, 77, "s:g", true], [{78=>:enemy}, 78, "s:g", true], [{59=>nil}, 59, "s:g", false], [{67=>nil}, 67, "s:g", false], [{69=>nil}, 69, "s:g", false], [{76=>nil}, 76, "s:g", false], [{77=>nil}, 77, "s:g", false], [{78=>nil}, 78, "s:g", false]], 69=>[[{60=>:enemy}, 60, "s:g", true], [{68=>:enemy}, 68, "s:g", true], [{70=>:enemy}, 70, "s:g", true], [{77=>:enemy}, 77, "s:g", true], [{78=>:enemy}, 78, "s:g", true], [{79=>:enemy}, 79, "s:g", true], [{60=>nil}, 60, "s:g", false], [{68=>nil}, 68, "s:g", false], [{70=>nil}, 70, "s:g", false], [{77=>nil}, 77, "s:g", false], [{78=>nil}, 78, "s:g", false], [{79=>nil}, 79, "s:g", false]], 70=>[[{61=>:enemy}, 61, "s:g", true], [{69=>:enemy}, 69, "s:g", true], [{71=>:enemy}, 71, "s:g", true], [{78=>:enemy}, 78, "s:g", true], [{79=>:enemy}, 79, "s:g", true], [{80=>:enemy}, 80, "s:g", true], [{61=>nil}, 61, "s:g", false], [{69=>nil}, 69, "s:g", false], [{71=>nil}, 71, "s:g", false], [{78=>nil}, 78, "s:g", false], [{79=>nil}, 79, "s:g", false], [{80=>nil}, 80, "s:g", false]], 71=>[[{62=>:enemy}, 62, "s:g", true], [{70=>:enemy}, 70, "s:g", true], [{79=>:enemy}, 79, "s:g", true], [{80=>:enemy}, 80, "s:g", true], [{62=>nil}, 62, "s:g", false], [{70=>nil}, 70, "s:g", false], [{79=>nil}, 79, "s:g", false], [{80=>nil}, 80, "s:g", false]], 72=>[[{63=>:enemy}, 63, "s:g", true], [{73=>:enemy}, 73, "s:g", true], [{63=>nil}, 63, "s:g", false], [{73=>nil}, 73, "s:g", false]], 73=>[[{64=>:enemy}, 64, "s:g", true], [{72=>:enemy}, 72, "s:g", true], [{74=>:enemy}, 74, "s:g", true], [{64=>nil}, 64, "s:g", false], [{72=>nil}, 72, "s:g", false], [{74=>nil}, 74, "s:g", false]], 74=>[[{65=>:enemy}, 65, "s:g", true], [{73=>:enemy}, 73, "s:g", true], [{75=>:enemy}, 75, "s:g", true], [{65=>nil}, 65, "s:g", false], [{73=>nil}, 73, "s:g", false], [{75=>nil}, 75, "s:g", false]], 75=>[[{66=>:enemy}, 66, "s:g", true], [{74=>:enemy}, 74, "s:g", true], [{76=>:enemy}, 76, "s:g", true], [{66=>nil}, 66, "s:g", false], [{74=>nil}, 74, "s:g", false], [{76=>nil}, 76, "s:g", false]], 76=>[[{67=>:enemy}, 67, "s:g", true], [{75=>:enemy}, 75, "s:g", true], [{77=>:enemy}, 77, "s:g", true], [{67=>nil}, 67, "s:g", false], [{75=>nil}, 75, "s:g", false], [{77=>nil}, 77, "s:g", false]], 77=>[[{68=>:enemy}, 68, "s:g", true], [{76=>:enemy}, 76, "s:g", true], [{78=>:enemy}, 78, "s:g", true], [{68=>nil}, 68, "s:g", false], [{76=>nil}, 76, "s:g", false], [{78=>nil}, 78, "s:g", false]], 78=>[[{69=>:enemy}, 69, "s:g", true], [{77=>:enemy}, 77, "s:g", true], [{79=>:enemy}, 79, "s:g", true], [{69=>nil}, 69, "s:g", false], [{77=>nil}, 77, "s:g", false], [{79=>nil}, 79, "s:g", false]], 79=>[[{70=>:enemy}, 70, "s:g", true], [{78=>:enemy}, 78, "s:g", true], [{80=>:enemy}, 80, "s:g", true], [{70=>nil}, 70, "s:g", false], [{78=>nil}, 78, "s:g", false], [{80=>nil}, 80, "s:g", false]], 80=>[[{71=>:enemy}, 71, "s:g", true], [{79=>:enemy}, 79, "s:g", true], [{71=>nil}, 71, "s:g", false], [{79=>nil}, 79, "s:g", false]], nil=>[[{0=>nil}, 0, "s:g", false], [{1=>nil}, 1, "s:g", false], [{2=>nil}, 2, "s:g", false], [{3=>nil}, 3, "s:g", false], [{4=>nil}, 4, "s:g", false], [{5=>nil}, 5, "s:g", false], [{6=>nil}, 6, "s:g", false], [{7=>nil}, 7, "s:g", false], [{8=>nil}, 8, "s:g", false], [{9=>nil}, 9, "s:g", false], [{10=>nil}, 10, "s:g", false], [{11=>nil}, 11, "s:g", false], [{12=>nil}, 12, "s:g", false], [{13=>nil}, 13, "s:g", false], [{14=>nil}, 14, "s:g", false], [{15=>nil}, 15, "s:g", false], [{16=>nil}, 16, "s:g", false], [{17=>nil}, 17, "s:g", false], [{18=>nil}, 18, "s:g", false], [{19=>nil}, 19, "s:g", false], [{20=>nil}, 20, "s:g", false], [{21=>nil}, 21, "s:g", false], [{22=>nil}, 22, "s:g", false], [{23=>nil}, 23, "s:g", false], [{24=>nil}, 24, "s:g", false], [{25=>nil}, 25, "s:g", false], [{26=>nil}, 26, "s:g", false], [{27=>nil}, 27, "s:g", false], [{28=>nil}, 28, "s:g", false], [{29=>nil}, 29, "s:g", false], [{30=>nil}, 30, "s:g", false], [{31=>nil}, 31, "s:g", false], [{32=>nil}, 32, "s:g", false], [{33=>nil}, 33, "s:g", false], [{34=>nil}, 34, "s:g", false], [{35=>nil}, 35, "s:g", false], [{36=>nil}, 36, "s:g", false], [{37=>nil}, 37, "s:g", false], [{38=>nil}, 38, "s:g", false], [{39=>nil}, 39, "s:g", false], [{40=>nil}, 40, "s:g", false], [{41=>nil}, 41, "s:g", false], [{42=>nil}, 42, "s:g", false], [{43=>nil}, 43, "s:g", false], [{44=>nil}, 44, "s:g", false], [{45=>nil}, 45, "s:g", false], [{46=>nil}, 46, "s:g", false], [{47=>nil}, 47, "s:g", false], [{48=>nil}, 48, "s:g", false], [{49=>nil}, 49, "s:g", false], [{50=>nil}, 50, "s:g", false], [{51=>nil}, 51, "s:g", false], [{52=>nil}, 52, "s:g", false], [{53=>nil}, 53, "s:g", false], [{54=>nil}, 54, "s:g", false], [{55=>nil}, 55, "s:g", false], [{56=>nil}, 56, "s:g", false], [{57=>nil}, 57, "s:g", false], [{58=>nil}, 58, "s:g", false], [{59=>nil}, 59, "s:g", false], [{60=>nil}, 60, "s:g", false], [{61=>nil}, 61, "s:g", false], [{62=>nil}, 62, "s:g", false], [{63=>nil}, 63, "s:g", false], [{64=>nil}, 64, "s:g", false], [{65=>nil}, 65, "s:g", false], [{66=>nil}, 66, "s:g", false], [{67=>nil}, 67, "s:g", false], [{68=>nil}, 68, "s:g", false], [{69=>nil}, 69, "s:g", false], [{70=>nil}, 70, "s:g", false], [{71=>nil}, 71, "s:g", false], [{72=>nil}, 72, "s:g", false], [{73=>nil}, 73, "s:g", false], [{74=>nil}, 74, "s:g", false], [{75=>nil}, 75, "s:g", false], [{76=>nil}, 76, "s:g", false], [{77=>nil}, 77, "s:g", false], [{78=>nil}, 78, "s:g", false], [{79=>nil}, 79, "s:g", false], [{80=>nil}, 80, "s:g", false]]}, "s:l"=>{0=>[[{9=>:enemy}, 9, "s:l", true], [{9=>nil}, 9, "s:l", false], [{9=>nil, 18=>:enemy}, 18, "s:l", true], [{9=>nil, 18=>nil}, 18, "s:l", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "s:l", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "s:l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "s:l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "s:l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 1=>[[{10=>:enemy}, 10, "s:l", true], [{10=>nil}, 10, "s:l", false], [{10=>nil, 19=>:enemy}, 19, "s:l", true], [{10=>nil, 19=>nil}, 19, "s:l", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "s:l", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "s:l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "s:l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "s:l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 2=>[[{11=>:enemy}, 11, "s:l", true], [{11=>nil}, 11, "s:l", false], [{11=>nil, 20=>:enemy}, 20, "s:l", true], [{11=>nil, 20=>nil}, 20, "s:l", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "s:l", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "s:l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "s:l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "s:l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 3=>[[{12=>:enemy}, 12, "s:l", true], [{12=>nil}, 12, "s:l", false], [{12=>nil, 21=>:enemy}, 21, "s:l", true], [{12=>nil, 21=>nil}, 21, "s:l", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "s:l", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "s:l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "s:l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "s:l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 4=>[[{13=>:enemy}, 13, "s:l", true], [{13=>nil}, 13, "s:l", false], [{13=>nil, 22=>:enemy}, 22, "s:l", true], [{13=>nil, 22=>nil}, 22, "s:l", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "s:l", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "s:l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "s:l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "s:l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 5=>[[{14=>:enemy}, 14, "s:l", true], [{14=>nil}, 14, "s:l", false], [{14=>nil, 23=>:enemy}, 23, "s:l", true], [{14=>nil, 23=>nil}, 23, "s:l", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "s:l", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "s:l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "s:l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "s:l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 6=>[[{15=>:enemy}, 15, "s:l", true], [{15=>nil}, 15, "s:l", false], [{15=>nil, 24=>:enemy}, 24, "s:l", true], [{15=>nil, 24=>nil}, 24, "s:l", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "s:l", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "s:l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "s:l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "s:l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 7=>[[{16=>:enemy}, 16, "s:l", true], [{16=>nil}, 16, "s:l", false], [{16=>nil, 25=>:enemy}, 25, "s:l", true], [{16=>nil, 25=>nil}, 25, "s:l", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "s:l", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "s:l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "s:l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "s:l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 8=>[[{17=>:enemy}, 17, "s:l", true], [{17=>nil}, 17, "s:l", false], [{17=>nil, 26=>:enemy}, 26, "s:l", true], [{17=>nil, 26=>nil}, 26, "s:l", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "s:l", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "s:l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "s:l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "s:l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 9=>[[{18=>:enemy}, 18, "s:l", true], [{18=>nil}, 18, "s:l", false], [{18=>nil, 27=>:enemy}, 27, "s:l", true], [{18=>nil, 27=>nil}, 27, "s:l", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "s:l", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "s:l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 10=>[[{19=>:enemy}, 19, "s:l", true], [{19=>nil}, 19, "s:l", false], [{19=>nil, 28=>:enemy}, 28, "s:l", true], [{19=>nil, 28=>nil}, 28, "s:l", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "s:l", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "s:l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 11=>[[{20=>:enemy}, 20, "s:l", true], [{20=>nil}, 20, "s:l", false], [{20=>nil, 29=>:enemy}, 29, "s:l", true], [{20=>nil, 29=>nil}, 29, "s:l", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "s:l", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "s:l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 12=>[[{21=>:enemy}, 21, "s:l", true], [{21=>nil}, 21, "s:l", false], [{21=>nil, 30=>:enemy}, 30, "s:l", true], [{21=>nil, 30=>nil}, 30, "s:l", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "s:l", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "s:l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 13=>[[{22=>:enemy}, 22, "s:l", true], [{22=>nil}, 22, "s:l", false], [{22=>nil, 31=>:enemy}, 31, "s:l", true], [{22=>nil, 31=>nil}, 31, "s:l", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "s:l", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "s:l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 14=>[[{23=>:enemy}, 23, "s:l", true], [{23=>nil}, 23, "s:l", false], [{23=>nil, 32=>:enemy}, 32, "s:l", true], [{23=>nil, 32=>nil}, 32, "s:l", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "s:l", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "s:l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 15=>[[{24=>:enemy}, 24, "s:l", true], [{24=>nil}, 24, "s:l", false], [{24=>nil, 33=>:enemy}, 33, "s:l", true], [{24=>nil, 33=>nil}, 33, "s:l", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "s:l", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "s:l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 16=>[[{25=>:enemy}, 25, "s:l", true], [{25=>nil}, 25, "s:l", false], [{25=>nil, 34=>:enemy}, 34, "s:l", true], [{25=>nil, 34=>nil}, 34, "s:l", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "s:l", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "s:l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 17=>[[{26=>:enemy}, 26, "s:l", true], [{26=>nil}, 26, "s:l", false], [{26=>nil, 35=>:enemy}, 35, "s:l", true], [{26=>nil, 35=>nil}, 35, "s:l", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "s:l", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "s:l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 18=>[[{27=>:enemy}, 27, "s:l", true], [{27=>nil}, 27, "s:l", false], [{27=>nil, 36=>:enemy}, 36, "s:l", true], [{27=>nil, 36=>nil}, 36, "s:l", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "s:l", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "s:l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 19=>[[{28=>:enemy}, 28, "s:l", true], [{28=>nil}, 28, "s:l", false], [{28=>nil, 37=>:enemy}, 37, "s:l", true], [{28=>nil, 37=>nil}, 37, "s:l", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "s:l", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "s:l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 20=>[[{29=>:enemy}, 29, "s:l", true], [{29=>nil}, 29, "s:l", false], [{29=>nil, 38=>:enemy}, 38, "s:l", true], [{29=>nil, 38=>nil}, 38, "s:l", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "s:l", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "s:l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 21=>[[{30=>:enemy}, 30, "s:l", true], [{30=>nil}, 30, "s:l", false], [{30=>nil, 39=>:enemy}, 39, "s:l", true], [{30=>nil, 39=>nil}, 39, "s:l", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "s:l", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "s:l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 22=>[[{31=>:enemy}, 31, "s:l", true], [{31=>nil}, 31, "s:l", false], [{31=>nil, 40=>:enemy}, 40, "s:l", true], [{31=>nil, 40=>nil}, 40, "s:l", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "s:l", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "s:l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 23=>[[{32=>:enemy}, 32, "s:l", true], [{32=>nil}, 32, "s:l", false], [{32=>nil, 41=>:enemy}, 41, "s:l", true], [{32=>nil, 41=>nil}, 41, "s:l", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "s:l", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "s:l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 24=>[[{33=>:enemy}, 33, "s:l", true], [{33=>nil}, 33, "s:l", false], [{33=>nil, 42=>:enemy}, 42, "s:l", true], [{33=>nil, 42=>nil}, 42, "s:l", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "s:l", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "s:l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 25=>[[{34=>:enemy}, 34, "s:l", true], [{34=>nil}, 34, "s:l", false], [{34=>nil, 43=>:enemy}, 43, "s:l", true], [{34=>nil, 43=>nil}, 43, "s:l", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "s:l", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "s:l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 26=>[[{35=>:enemy}, 35, "s:l", true], [{35=>nil}, 35, "s:l", false], [{35=>nil, 44=>:enemy}, 44, "s:l", true], [{35=>nil, 44=>nil}, 44, "s:l", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "s:l", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "s:l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 27=>[[{36=>:enemy}, 36, "s:l", true], [{36=>nil}, 36, "s:l", false], [{36=>nil, 45=>:enemy}, 45, "s:l", true], [{36=>nil, 45=>nil}, 45, "s:l", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "s:+l", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 28=>[[{37=>:enemy}, 37, "s:l", true], [{37=>nil}, 37, "s:l", false], [{37=>nil, 46=>:enemy}, 46, "s:l", true], [{37=>nil, 46=>nil}, 46, "s:l", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "s:+l", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 29=>[[{38=>:enemy}, 38, "s:l", true], [{38=>nil}, 38, "s:l", false], [{38=>nil, 47=>:enemy}, 47, "s:l", true], [{38=>nil, 47=>nil}, 47, "s:l", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "s:+l", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 30=>[[{39=>:enemy}, 39, "s:l", true], [{39=>nil}, 39, "s:l", false], [{39=>nil, 48=>:enemy}, 48, "s:l", true], [{39=>nil, 48=>nil}, 48, "s:l", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "s:+l", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 31=>[[{40=>:enemy}, 40, "s:l", true], [{40=>nil}, 40, "s:l", false], [{40=>nil, 49=>:enemy}, 49, "s:l", true], [{40=>nil, 49=>nil}, 49, "s:l", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "s:+l", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 32=>[[{41=>:enemy}, 41, "s:l", true], [{41=>nil}, 41, "s:l", false], [{41=>nil, 50=>:enemy}, 50, "s:l", true], [{41=>nil, 50=>nil}, 50, "s:l", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "s:+l", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 33=>[[{42=>:enemy}, 42, "s:l", true], [{42=>nil}, 42, "s:l", false], [{42=>nil, 51=>:enemy}, 51, "s:l", true], [{42=>nil, 51=>nil}, 51, "s:l", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "s:+l", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 34=>[[{43=>:enemy}, 43, "s:l", true], [{43=>nil}, 43, "s:l", false], [{43=>nil, 52=>:enemy}, 52, "s:l", true], [{43=>nil, 52=>nil}, 52, "s:l", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "s:+l", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 35=>[[{44=>:enemy}, 44, "s:l", true], [{44=>nil}, 44, "s:l", false], [{44=>nil, 53=>:enemy}, 53, "s:l", true], [{44=>nil, 53=>nil}, 53, "s:l", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "s:+l", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 36=>[[{45=>:enemy}, 45, "s:l", true], [{45=>nil}, 45, "s:l", false], [{45=>nil, 54=>:enemy}, 54, "s:+l", true], [{45=>nil, 54=>nil}, 54, "s:+l", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+l", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "s:+l", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 37=>[[{46=>:enemy}, 46, "s:l", true], [{46=>nil}, 46, "s:l", false], [{46=>nil, 55=>:enemy}, 55, "s:+l", true], [{46=>nil, 55=>nil}, 55, "s:+l", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+l", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "s:+l", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 38=>[[{47=>:enemy}, 47, "s:l", true], [{47=>nil}, 47, "s:l", false], [{47=>nil, 56=>:enemy}, 56, "s:+l", true], [{47=>nil, 56=>nil}, 56, "s:+l", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+l", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "s:+l", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 39=>[[{48=>:enemy}, 48, "s:l", true], [{48=>nil}, 48, "s:l", false], [{48=>nil, 57=>:enemy}, 57, "s:+l", true], [{48=>nil, 57=>nil}, 57, "s:+l", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+l", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "s:+l", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 40=>[[{49=>:enemy}, 49, "s:l", true], [{49=>nil}, 49, "s:l", false], [{49=>nil, 58=>:enemy}, 58, "s:+l", true], [{49=>nil, 58=>nil}, 58, "s:+l", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+l", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "s:+l", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 41=>[[{50=>:enemy}, 50, "s:l", true], [{50=>nil}, 50, "s:l", false], [{50=>nil, 59=>:enemy}, 59, "s:+l", true], [{50=>nil, 59=>nil}, 59, "s:+l", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+l", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "s:+l", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 42=>[[{51=>:enemy}, 51, "s:l", true], [{51=>nil}, 51, "s:l", false], [{51=>nil, 60=>:enemy}, 60, "s:+l", true], [{51=>nil, 60=>nil}, 60, "s:+l", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+l", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "s:+l", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 43=>[[{52=>:enemy}, 52, "s:l", true], [{52=>nil}, 52, "s:l", false], [{52=>nil, 61=>:enemy}, 61, "s:+l", true], [{52=>nil, 61=>nil}, 61, "s:+l", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+l", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "s:+l", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 44=>[[{53=>:enemy}, 53, "s:l", true], [{53=>nil}, 53, "s:l", false], [{53=>nil, 62=>:enemy}, 62, "s:+l", true], [{53=>nil, 62=>nil}, 62, "s:+l", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+l", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "s:+l", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 45=>[[{54=>:enemy}, 54, "s:+l", true], [{54=>nil}, 54, "s:+l", false], [{54=>nil, 63=>:enemy}, 63, "s:+l", true], [{54=>nil, 63=>nil}, 63, "s:+l", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+l", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "s:+l", false]], 46=>[[{55=>:enemy}, 55, "s:+l", true], [{55=>nil}, 55, "s:+l", false], [{55=>nil, 64=>:enemy}, 64, "s:+l", true], [{55=>nil, 64=>nil}, 64, "s:+l", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+l", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "s:+l", false]], 47=>[[{56=>:enemy}, 56, "s:+l", true], [{56=>nil}, 56, "s:+l", false], [{56=>nil, 65=>:enemy}, 65, "s:+l", true], [{56=>nil, 65=>nil}, 65, "s:+l", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+l", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "s:+l", false]], 48=>[[{57=>:enemy}, 57, "s:+l", true], [{57=>nil}, 57, "s:+l", false], [{57=>nil, 66=>:enemy}, 66, "s:+l", true], [{57=>nil, 66=>nil}, 66, "s:+l", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+l", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "s:+l", false]], 49=>[[{58=>:enemy}, 58, "s:+l", true], [{58=>nil}, 58, "s:+l", false], [{58=>nil, 67=>:enemy}, 67, "s:+l", true], [{58=>nil, 67=>nil}, 67, "s:+l", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+l", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "s:+l", false]], 50=>[[{59=>:enemy}, 59, "s:+l", true], [{59=>nil}, 59, "s:+l", false], [{59=>nil, 68=>:enemy}, 68, "s:+l", true], [{59=>nil, 68=>nil}, 68, "s:+l", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+l", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "s:+l", false]], 51=>[[{60=>:enemy}, 60, "s:+l", true], [{60=>nil}, 60, "s:+l", false], [{60=>nil, 69=>:enemy}, 69, "s:+l", true], [{60=>nil, 69=>nil}, 69, "s:+l", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+l", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "s:+l", false]], 52=>[[{61=>:enemy}, 61, "s:+l", true], [{61=>nil}, 61, "s:+l", false], [{61=>nil, 70=>:enemy}, 70, "s:+l", true], [{61=>nil, 70=>nil}, 70, "s:+l", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+l", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "s:+l", false]], 53=>[[{62=>:enemy}, 62, "s:+l", true], [{62=>nil}, 62, "s:+l", false], [{62=>nil, 71=>:enemy}, 71, "s:+l", true], [{62=>nil, 71=>nil}, 71, "s:+l", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+l", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "s:+l", false]], 54=>[[{63=>:enemy}, 63, "s:+l", true], [{63=>nil}, 63, "s:+l", false], [{63=>nil, 72=>:enemy}, 72, "s:+l", true], [{63=>nil, 72=>nil}, 72, "s:+l", false]], 55=>[[{64=>:enemy}, 64, "s:+l", true], [{64=>nil}, 64, "s:+l", false], [{64=>nil, 73=>:enemy}, 73, "s:+l", true], [{64=>nil, 73=>nil}, 73, "s:+l", false]], 56=>[[{65=>:enemy}, 65, "s:+l", true], [{65=>nil}, 65, "s:+l", false], [{65=>nil, 74=>:enemy}, 74, "s:+l", true], [{65=>nil, 74=>nil}, 74, "s:+l", false]], 57=>[[{66=>:enemy}, 66, "s:+l", true], [{66=>nil}, 66, "s:+l", false], [{66=>nil, 75=>:enemy}, 75, "s:+l", true], [{66=>nil, 75=>nil}, 75, "s:+l", false]], 58=>[[{67=>:enemy}, 67, "s:+l", true], [{67=>nil}, 67, "s:+l", false], [{67=>nil, 76=>:enemy}, 76, "s:+l", true], [{67=>nil, 76=>nil}, 76, "s:+l", false]], 59=>[[{68=>:enemy}, 68, "s:+l", true], [{68=>nil}, 68, "s:+l", false], [{68=>nil, 77=>:enemy}, 77, "s:+l", true], [{68=>nil, 77=>nil}, 77, "s:+l", false]], 60=>[[{69=>:enemy}, 69, "s:+l", true], [{69=>nil}, 69, "s:+l", false], [{69=>nil, 78=>:enemy}, 78, "s:+l", true], [{69=>nil, 78=>nil}, 78, "s:+l", false]], 61=>[[{70=>:enemy}, 70, "s:+l", true], [{70=>nil}, 70, "s:+l", false], [{70=>nil, 79=>:enemy}, 79, "s:+l", true], [{70=>nil, 79=>nil}, 79, "s:+l", false]], 62=>[[{71=>:enemy}, 71, "s:+l", true], [{71=>nil}, 71, "s:+l", false], [{71=>nil, 80=>:enemy}, 80, "s:+l", true], [{71=>nil, 80=>nil}, 80, "s:+l", false]], 63=>[[{72=>:enemy}, 72, "s:+l", true], [{72=>nil}, 72, "s:+l", false]], 64=>[[{73=>:enemy}, 73, "s:+l", true], [{73=>nil}, 73, "s:+l", false]], 65=>[[{74=>:enemy}, 74, "s:+l", true], [{74=>nil}, 74, "s:+l", false]], 66=>[[{75=>:enemy}, 75, "s:+l", true], [{75=>nil}, 75, "s:+l", false]], 67=>[[{76=>:enemy}, 76, "s:+l", true], [{76=>nil}, 76, "s:+l", false]], 68=>[[{77=>:enemy}, 77, "s:+l", true], [{77=>nil}, 77, "s:+l", false]], 69=>[[{78=>:enemy}, 78, "s:+l", true], [{78=>nil}, 78, "s:+l", false]], 70=>[[{79=>:enemy}, 79, "s:+l", true], [{79=>nil}, 79, "s:+l", false]], 71=>[[{80=>:enemy}, 80, "s:+l", true], [{80=>nil}, 80, "s:+l", false]], 72=>[], 73=>[], 74=>[], 75=>[], 76=>[], 77=>[], 78=>[], 79=>[], 80=>[], nil=>[[{0=>nil}, 0, "s:l", false], [{1=>nil}, 1, "s:l", false], [{2=>nil}, 2, "s:l", false], [{3=>nil}, 3, "s:l", false], [{4=>nil}, 4, "s:l", false], [{5=>nil}, 5, "s:l", false], [{6=>nil}, 6, "s:l", false], [{7=>nil}, 7, "s:l", false], [{8=>nil}, 8, "s:l", false], [{9=>nil}, 9, "s:l", false], [{10=>nil}, 10, "s:l", false], [{11=>nil}, 11, "s:l", false], [{12=>nil}, 12, "s:l", false], [{13=>nil}, 13, "s:l", false], [{14=>nil}, 14, "s:l", false], [{15=>nil}, 15, "s:l", false], [{16=>nil}, 16, "s:l", false], [{17=>nil}, 17, "s:l", false], [{18=>nil}, 18, "s:l", false], [{19=>nil}, 19, "s:l", false], [{20=>nil}, 20, "s:l", false], [{21=>nil}, 21, "s:l", false], [{22=>nil}, 22, "s:l", false], [{23=>nil}, 23, "s:l", false], [{24=>nil}, 24, "s:l", false], [{25=>nil}, 25, "s:l", false], [{26=>nil}, 26, "s:l", false], [{27=>nil}, 27, "s:l", false], [{28=>nil}, 28, "s:l", false], [{29=>nil}, 29, "s:l", false], [{30=>nil}, 30, "s:l", false], [{31=>nil}, 31, "s:l", false], [{32=>nil}, 32, "s:l", false], [{33=>nil}, 33, "s:l", false], [{34=>nil}, 34, "s:l", false], [{35=>nil}, 35, "s:l", false], [{36=>nil}, 36, "s:l", false], [{37=>nil}, 37, "s:l", false], [{38=>nil}, 38, "s:l", false], [{39=>nil}, 39, "s:l", false], [{40=>nil}, 40, "s:l", false], [{41=>nil}, 41, "s:l", false], [{42=>nil}, 42, "s:l", false], [{43=>nil}, 43, "s:l", false], [{44=>nil}, 44, "s:l", false], [{45=>nil}, 45, "s:l", false], [{46=>nil}, 46, "s:l", false], [{47=>nil}, 47, "s:l", false], [{48=>nil}, 48, "s:l", false], [{49=>nil}, 49, "s:l", false], [{50=>nil}, 50, "s:l", false], [{51=>nil}, 51, "s:l", false], [{52=>nil}, 52, "s:l", false], [{53=>nil}, 53, "s:l", false], [{54=>nil}, 54, "s:l", false], [{55=>nil}, 55, "s:l", false], [{56=>nil}, 56, "s:l", false], [{57=>nil}, 57, "s:l", false], [{58=>nil}, 58, "s:l", false], [{59=>nil}, 59, "s:l", false], [{60=>nil}, 60, "s:l", false], [{61=>nil}, 61, "s:l", false], [{62=>nil}, 62, "s:l", false], [{63=>nil}, 63, "s:l", false], [{64=>nil}, 64, "s:l", false], [{65=>nil}, 65, "s:l", false], [{66=>nil}, 66, "s:l", false], [{67=>nil}, 67, "s:l", false], [{68=>nil}, 68, "s:l", false], [{69=>nil}, 69, "s:l", false], [{70=>nil}, 70, "s:l", false], [{71=>nil}, 71, "s:l", false]]}, "s:n"=>{0=>[[{19=>:enemy}, 19, "s:n", true], [{19=>nil}, 19, "s:n", false]], 1=>[[{18=>:enemy}, 18, "s:n", true], [{20=>:enemy}, 20, "s:n", true], [{18=>nil}, 18, "s:n", false], [{20=>nil}, 20, "s:n", false]], 2=>[[{19=>:enemy}, 19, "s:n", true], [{21=>:enemy}, 21, "s:n", true], [{19=>nil}, 19, "s:n", false], [{21=>nil}, 21, "s:n", false]], 3=>[[{20=>:enemy}, 20, "s:n", true], [{22=>:enemy}, 22, "s:n", true], [{20=>nil}, 20, "s:n", false], [{22=>nil}, 22, "s:n", false]], 4=>[[{21=>:enemy}, 21, "s:n", true], [{23=>:enemy}, 23, "s:n", true], [{21=>nil}, 21, "s:n", false], [{23=>nil}, 23, "s:n", false]], 5=>[[{22=>:enemy}, 22, "s:n", true], [{24=>:enemy}, 24, "s:n", true], [{22=>nil}, 22, "s:n", false], [{24=>nil}, 24, "s:n", false]], 6=>[[{23=>:enemy}, 23, "s:n", true], [{25=>:enemy}, 25, "s:n", true], [{23=>nil}, 23, "s:n", false], [{25=>nil}, 25, "s:n", false]], 7=>[[{24=>:enemy}, 24, "s:n", true], [{26=>:enemy}, 26, "s:n", true], [{24=>nil}, 24, "s:n", false], [{26=>nil}, 26, "s:n", false]], 8=>[[{25=>:enemy}, 25, "s:n", true], [{25=>nil}, 25, "s:n", false]], 9=>[[{28=>:enemy}, 28, "s:n", true], [{28=>nil}, 28, "s:n", false]], 10=>[[{27=>:enemy}, 27, "s:n", true], [{29=>:enemy}, 29, "s:n", true], [{27=>nil}, 27, "s:n", false], [{29=>nil}, 29, "s:n", false]], 11=>[[{28=>:enemy}, 28, "s:n", true], [{30=>:enemy}, 30, "s:n", true], [{28=>nil}, 28, "s:n", false], [{30=>nil}, 30, "s:n", false]], 12=>[[{29=>:enemy}, 29, "s:n", true], [{31=>:enemy}, 31, "s:n", true], [{29=>nil}, 29, "s:n", false], [{31=>nil}, 31, "s:n", false]], 13=>[[{30=>:enemy}, 30, "s:n", true], [{32=>:enemy}, 32, "s:n", true], [{30=>nil}, 30, "s:n", false], [{32=>nil}, 32, "s:n", false]], 14=>[[{31=>:enemy}, 31, "s:n", true], [{33=>:enemy}, 33, "s:n", true], [{31=>nil}, 31, "s:n", false], [{33=>nil}, 33, "s:n", false]], 15=>[[{32=>:enemy}, 32, "s:n", true], [{34=>:enemy}, 34, "s:n", true], [{32=>nil}, 32, "s:n", false], [{34=>nil}, 34, "s:n", false]], 16=>[[{33=>:enemy}, 33, "s:n", true], [{35=>:enemy}, 35, "s:n", true], [{33=>nil}, 33, "s:n", false], [{35=>nil}, 35, "s:n", false]], 17=>[[{34=>:enemy}, 34, "s:n", true], [{34=>nil}, 34, "s:n", false]], 18=>[[{37=>:enemy}, 37, "s:n", true], [{37=>nil}, 37, "s:n", false]], 19=>[[{36=>:enemy}, 36, "s:n", true], [{38=>:enemy}, 38, "s:n", true], [{36=>nil}, 36, "s:n", false], [{38=>nil}, 38, "s:n", false]], 20=>[[{37=>:enemy}, 37, "s:n", true], [{39=>:enemy}, 39, "s:n", true], [{37=>nil}, 37, "s:n", false], [{39=>nil}, 39, "s:n", false]], 21=>[[{38=>:enemy}, 38, "s:n", true], [{40=>:enemy}, 40, "s:n", true], [{38=>nil}, 38, "s:n", false], [{40=>nil}, 40, "s:n", false]], 22=>[[{39=>:enemy}, 39, "s:n", true], [{41=>:enemy}, 41, "s:n", true], [{39=>nil}, 39, "s:n", false], [{41=>nil}, 41, "s:n", false]], 23=>[[{40=>:enemy}, 40, "s:n", true], [{42=>:enemy}, 42, "s:n", true], [{40=>nil}, 40, "s:n", false], [{42=>nil}, 42, "s:n", false]], 24=>[[{41=>:enemy}, 41, "s:n", true], [{43=>:enemy}, 43, "s:n", true], [{41=>nil}, 41, "s:n", false], [{43=>nil}, 43, "s:n", false]], 25=>[[{42=>:enemy}, 42, "s:n", true], [{44=>:enemy}, 44, "s:n", true], [{42=>nil}, 42, "s:n", false], [{44=>nil}, 44, "s:n", false]], 26=>[[{43=>:enemy}, 43, "s:n", true], [{43=>nil}, 43, "s:n", false]], 27=>[[{46=>:enemy}, 46, "s:n", true], [{46=>nil}, 46, "s:n", false]], 28=>[[{45=>:enemy}, 45, "s:n", true], [{47=>:enemy}, 47, "s:n", true], [{45=>nil}, 45, "s:n", false], [{47=>nil}, 47, "s:n", false]], 29=>[[{46=>:enemy}, 46, "s:n", true], [{48=>:enemy}, 48, "s:n", true], [{46=>nil}, 46, "s:n", false], [{48=>nil}, 48, "s:n", false]], 30=>[[{47=>:enemy}, 47, "s:n", true], [{49=>:enemy}, 49, "s:n", true], [{47=>nil}, 47, "s:n", false], [{49=>nil}, 49, "s:n", false]], 31=>[[{48=>:enemy}, 48, "s:n", true], [{50=>:enemy}, 50, "s:n", true], [{48=>nil}, 48, "s:n", false], [{50=>nil}, 50, "s:n", false]], 32=>[[{49=>:enemy}, 49, "s:n", true], [{51=>:enemy}, 51, "s:n", true], [{49=>nil}, 49, "s:n", false], [{51=>nil}, 51, "s:n", false]], 33=>[[{50=>:enemy}, 50, "s:n", true], [{52=>:enemy}, 52, "s:n", true], [{50=>nil}, 50, "s:n", false], [{52=>nil}, 52, "s:n", false]], 34=>[[{51=>:enemy}, 51, "s:n", true], [{53=>:enemy}, 53, "s:n", true], [{51=>nil}, 51, "s:n", false], [{53=>nil}, 53, "s:n", false]], 35=>[[{52=>:enemy}, 52, "s:n", true], [{52=>nil}, 52, "s:n", false]], 36=>[[{55=>:enemy}, 55, "s:+n", true], [{55=>nil}, 55, "s:+n", false]], 37=>[[{54=>:enemy}, 54, "s:+n", true], [{56=>:enemy}, 56, "s:+n", true], [{54=>nil}, 54, "s:+n", false], [{56=>nil}, 56, "s:+n", false]], 38=>[[{55=>:enemy}, 55, "s:+n", true], [{57=>:enemy}, 57, "s:+n", true], [{55=>nil}, 55, "s:+n", false], [{57=>nil}, 57, "s:+n", false]], 39=>[[{56=>:enemy}, 56, "s:+n", true], [{58=>:enemy}, 58, "s:+n", true], [{56=>nil}, 56, "s:+n", false], [{58=>nil}, 58, "s:+n", false]], 40=>[[{57=>:enemy}, 57, "s:+n", true], [{59=>:enemy}, 59, "s:+n", true], [{57=>nil}, 57, "s:+n", false], [{59=>nil}, 59, "s:+n", false]], 41=>[[{58=>:enemy}, 58, "s:+n", true], [{60=>:enemy}, 60, "s:+n", true], [{58=>nil}, 58, "s:+n", false], [{60=>nil}, 60, "s:+n", false]], 42=>[[{59=>:enemy}, 59, "s:+n", true], [{61=>:enemy}, 61, "s:+n", true], [{59=>nil}, 59, "s:+n", false], [{61=>nil}, 61, "s:+n", false]], 43=>[[{60=>:enemy}, 60, "s:+n", true], [{62=>:enemy}, 62, "s:+n", true], [{60=>nil}, 60, "s:+n", false], [{62=>nil}, 62, "s:+n", false]], 44=>[[{61=>:enemy}, 61, "s:+n", true], [{61=>nil}, 61, "s:+n", false]], 45=>[[{64=>:enemy}, 64, "s:+n", true], [{64=>nil}, 64, "s:+n", false]], 46=>[[{63=>:enemy}, 63, "s:+n", true], [{65=>:enemy}, 65, "s:+n", true], [{63=>nil}, 63, "s:+n", false], [{65=>nil}, 65, "s:+n", false]], 47=>[[{64=>:enemy}, 64, "s:+n", true], [{66=>:enemy}, 66, "s:+n", true], [{64=>nil}, 64, "s:+n", false], [{66=>nil}, 66, "s:+n", false]], 48=>[[{65=>:enemy}, 65, "s:+n", true], [{67=>:enemy}, 67, "s:+n", true], [{65=>nil}, 65, "s:+n", false], [{67=>nil}, 67, "s:+n", false]], 49=>[[{66=>:enemy}, 66, "s:+n", true], [{68=>:enemy}, 68, "s:+n", true], [{66=>nil}, 66, "s:+n", false], [{68=>nil}, 68, "s:+n", false]], 50=>[[{67=>:enemy}, 67, "s:+n", true], [{69=>:enemy}, 69, "s:+n", true], [{67=>nil}, 67, "s:+n", false], [{69=>nil}, 69, "s:+n", false]], 51=>[[{68=>:enemy}, 68, "s:+n", true], [{70=>:enemy}, 70, "s:+n", true], [{68=>nil}, 68, "s:+n", false], [{70=>nil}, 70, "s:+n", false]], 52=>[[{69=>:enemy}, 69, "s:+n", true], [{71=>:enemy}, 71, "s:+n", true], [{69=>nil}, 69, "s:+n", false], [{71=>nil}, 71, "s:+n", false]], 53=>[[{70=>:enemy}, 70, "s:+n", true], [{70=>nil}, 70, "s:+n", false]], 54=>[[{73=>:enemy}, 73, "s:+n", true], [{73=>nil}, 73, "s:+n", false]], 55=>[[{72=>:enemy}, 72, "s:+n", true], [{74=>:enemy}, 74, "s:+n", true], [{72=>nil}, 72, "s:+n", false], [{74=>nil}, 74, "s:+n", false]], 56=>[[{73=>:enemy}, 73, "s:+n", true], [{75=>:enemy}, 75, "s:+n", true], [{73=>nil}, 73, "s:+n", false], [{75=>nil}, 75, "s:+n", false]], 57=>[[{74=>:enemy}, 74, "s:+n", true], [{76=>:enemy}, 76, "s:+n", true], [{74=>nil}, 74, "s:+n", false], [{76=>nil}, 76, "s:+n", false]], 58=>[[{75=>:enemy}, 75, "s:+n", true], [{77=>:enemy}, 77, "s:+n", true], [{75=>nil}, 75, "s:+n", false], [{77=>nil}, 77, "s:+n", false]], 59=>[[{76=>:enemy}, 76, "s:+n", true], [{78=>:enemy}, 78, "s:+n", true], [{76=>nil}, 76, "s:+n", false], [{78=>nil}, 78, "s:+n", false]], 60=>[[{77=>:enemy}, 77, "s:+n", true], [{79=>:enemy}, 79, "s:+n", true], [{77=>nil}, 77, "s:+n", false], [{79=>nil}, 79, "s:+n", false]], 61=>[[{78=>:enemy}, 78, "s:+n", true], [{80=>:enemy}, 80, "s:+n", true], [{78=>nil}, 78, "s:+n", false], [{80=>nil}, 80, "s:+n", false]], 62=>[[{79=>:enemy}, 79, "s:+n", true], [{79=>nil}, 79, "s:+n", false]], 63=>[], 64=>[], 65=>[], 66=>[], 67=>[], 68=>[], 69=>[], 70=>[], 71=>[], 72=>[], 73=>[], 74=>[], 75=>[], 76=>[], 77=>[], 78=>[], 79=>[], 80=>[], nil=>[[{0=>nil}, 0, "s:n", false], [{1=>nil}, 1, "s:n", false], [{2=>nil}, 2, "s:n", false], [{3=>nil}, 3, "s:n", false], [{4=>nil}, 4, "s:n", false], [{5=>nil}, 5, "s:n", false], [{6=>nil}, 6, "s:n", false], [{7=>nil}, 7, "s:n", false], [{8=>nil}, 8, "s:n", false], [{9=>nil}, 9, "s:n", false], [{10=>nil}, 10, "s:n", false], [{11=>nil}, 11, "s:n", false], [{12=>nil}, 12, "s:n", false], [{13=>nil}, 13, "s:n", false], [{14=>nil}, 14, "s:n", false], [{15=>nil}, 15, "s:n", false], [{16=>nil}, 16, "s:n", false], [{17=>nil}, 17, "s:n", false], [{18=>nil}, 18, "s:n", false], [{19=>nil}, 19, "s:n", false], [{20=>nil}, 20, "s:n", false], [{21=>nil}, 21, "s:n", false], [{22=>nil}, 22, "s:n", false], [{23=>nil}, 23, "s:n", false], [{24=>nil}, 24, "s:n", false], [{25=>nil}, 25, "s:n", false], [{26=>nil}, 26, "s:n", false], [{27=>nil}, 27, "s:n", false], [{28=>nil}, 28, "s:n", false], [{29=>nil}, 29, "s:n", false], [{30=>nil}, 30, "s:n", false], [{31=>nil}, 31, "s:n", false], [{32=>nil}, 32, "s:n", false], [{33=>nil}, 33, "s:n", false], [{34=>nil}, 34, "s:n", false], [{35=>nil}, 35, "s:n", false], [{36=>nil}, 36, "s:n", false], [{37=>nil}, 37, "s:n", false], [{38=>nil}, 38, "s:n", false], [{39=>nil}, 39, "s:n", false], [{40=>nil}, 40, "s:n", false], [{41=>nil}, 41, "s:n", false], [{42=>nil}, 42, "s:n", false], [{43=>nil}, 43, "s:n", false], [{44=>nil}, 44, "s:n", false], [{45=>nil}, 45, "s:n", false], [{46=>nil}, 46, "s:n", false], [{47=>nil}, 47, "s:n", false], [{48=>nil}, 48, "s:n", false], [{49=>nil}, 49, "s:n", false], [{50=>nil}, 50, "s:n", false], [{51=>nil}, 51, "s:n", false], [{52=>nil}, 52, "s:n", false], [{53=>nil}, 53, "s:n", false], [{54=>nil}, 54, "s:n", false], [{55=>nil}, 55, "s:n", false], [{56=>nil}, 56, "s:n", false], [{57=>nil}, 57, "s:n", false], [{58=>nil}, 58, "s:n", false], [{59=>nil}, 59, "s:n", false], [{60=>nil}, 60, "s:n", false], [{61=>nil}, 61, "s:n", false], [{62=>nil}, 62, "s:n", false]]}, "s:p"=>{0=>[[{9=>:enemy}, 9, "s:p", true], [{9=>nil}, 9, "s:p", false]], 1=>[[{10=>:enemy}, 10, "s:p", true], [{10=>nil}, 10, "s:p", false]], 2=>[[{11=>:enemy}, 11, "s:p", true], [{11=>nil}, 11, "s:p", false]], 3=>[[{12=>:enemy}, 12, "s:p", true], [{12=>nil}, 12, "s:p", false]], 4=>[[{13=>:enemy}, 13, "s:p", true], [{13=>nil}, 13, "s:p", false]], 5=>[[{14=>:enemy}, 14, "s:p", true], [{14=>nil}, 14, "s:p", false]], 6=>[[{15=>:enemy}, 15, "s:p", true], [{15=>nil}, 15, "s:p", false]], 7=>[[{16=>:enemy}, 16, "s:p", true], [{16=>nil}, 16, "s:p", false]], 8=>[[{17=>:enemy}, 17, "s:p", true], [{17=>nil}, 17, "s:p", false]], 9=>[[{18=>:enemy}, 18, "s:p", true], [{18=>nil}, 18, "s:p", false]], 10=>[[{19=>:enemy}, 19, "s:p", true], [{19=>nil}, 19, "s:p", false]], 11=>[[{20=>:enemy}, 20, "s:p", true], [{20=>nil}, 20, "s:p", false]], 12=>[[{21=>:enemy}, 21, "s:p", true], [{21=>nil}, 21, "s:p", false]], 13=>[[{22=>:enemy}, 22, "s:p", true], [{22=>nil}, 22, "s:p", false]], 14=>[[{23=>:enemy}, 23, "s:p", true], [{23=>nil}, 23, "s:p", false]], 15=>[[{24=>:enemy}, 24, "s:p", true], [{24=>nil}, 24, "s:p", false]], 16=>[[{25=>:enemy}, 25, "s:p", true], [{25=>nil}, 25, "s:p", false]], 17=>[[{26=>:enemy}, 26, "s:p", true], [{26=>nil}, 26, "s:p", false]], 18=>[[{27=>:enemy}, 27, "s:p", true], [{27=>nil}, 27, "s:p", false]], 19=>[[{28=>:enemy}, 28, "s:p", true], [{28=>nil}, 28, "s:p", false]], 20=>[[{29=>:enemy}, 29, "s:p", true], [{29=>nil}, 29, "s:p", false]], 21=>[[{30=>:enemy}, 30, "s:p", true], [{30=>nil}, 30, "s:p", false]], 22=>[[{31=>:enemy}, 31, "s:p", true], [{31=>nil}, 31, "s:p", false]], 23=>[[{32=>:enemy}, 32, "s:p", true], [{32=>nil}, 32, "s:p", false]], 24=>[[{33=>:enemy}, 33, "s:p", true], [{33=>nil}, 33, "s:p", false]], 25=>[[{34=>:enemy}, 34, "s:p", true], [{34=>nil}, 34, "s:p", false]], 26=>[[{35=>:enemy}, 35, "s:p", true], [{35=>nil}, 35, "s:p", false]], 27=>[[{36=>:enemy}, 36, "s:p", true], [{36=>nil}, 36, "s:p", false]], 28=>[[{37=>:enemy}, 37, "s:p", true], [{37=>nil}, 37, "s:p", false]], 29=>[[{38=>:enemy}, 38, "s:p", true], [{38=>nil}, 38, "s:p", false]], 30=>[[{39=>:enemy}, 39, "s:p", true], [{39=>nil}, 39, "s:p", false]], 31=>[[{40=>:enemy}, 40, "s:p", true], [{40=>nil}, 40, "s:p", false]], 32=>[[{41=>:enemy}, 41, "s:p", true], [{41=>nil}, 41, "s:p", false]], 33=>[[{42=>:enemy}, 42, "s:p", true], [{42=>nil}, 42, "s:p", false]], 34=>[[{43=>:enemy}, 43, "s:p", true], [{43=>nil}, 43, "s:p", false]], 35=>[[{44=>:enemy}, 44, "s:p", true], [{44=>nil}, 44, "s:p", false]], 36=>[[{45=>:enemy}, 45, "s:p", true], [{45=>nil}, 45, "s:p", false]], 37=>[[{46=>:enemy}, 46, "s:p", true], [{46=>nil}, 46, "s:p", false]], 38=>[[{47=>:enemy}, 47, "s:p", true], [{47=>nil}, 47, "s:p", false]], 39=>[[{48=>:enemy}, 48, "s:p", true], [{48=>nil}, 48, "s:p", false]], 40=>[[{49=>:enemy}, 49, "s:p", true], [{49=>nil}, 49, "s:p", false]], 41=>[[{50=>:enemy}, 50, "s:p", true], [{50=>nil}, 50, "s:p", false]], 42=>[[{51=>:enemy}, 51, "s:p", true], [{51=>nil}, 51, "s:p", false]], 43=>[[{52=>:enemy}, 52, "s:p", true], [{52=>nil}, 52, "s:p", false]], 44=>[[{53=>:enemy}, 53, "s:p", true], [{53=>nil}, 53, "s:p", false]], 45=>[[{54=>:enemy}, 54, "s:+p", true], [{54=>nil}, 54, "s:+p", false]], 46=>[[{55=>:enemy}, 55, "s:+p", true], [{55=>nil}, 55, "s:+p", false]], 47=>[[{56=>:enemy}, 56, "s:+p", true], [{56=>nil}, 56, "s:+p", false]], 48=>[[{57=>:enemy}, 57, "s:+p", true], [{57=>nil}, 57, "s:+p", false]], 49=>[[{58=>:enemy}, 58, "s:+p", true], [{58=>nil}, 58, "s:+p", false]], 50=>[[{59=>:enemy}, 59, "s:+p", true], [{59=>nil}, 59, "s:+p", false]], 51=>[[{60=>:enemy}, 60, "s:+p", true], [{60=>nil}, 60, "s:+p", false]], 52=>[[{61=>:enemy}, 61, "s:+p", true], [{61=>nil}, 61, "s:+p", false]], 53=>[[{62=>:enemy}, 62, "s:+p", true], [{62=>nil}, 62, "s:+p", false]], 54=>[[{63=>:enemy}, 63, "s:+p", true], [{63=>nil}, 63, "s:+p", false]], 55=>[[{64=>:enemy}, 64, "s:+p", true], [{64=>nil}, 64, "s:+p", false]], 56=>[[{65=>:enemy}, 65, "s:+p", true], [{65=>nil}, 65, "s:+p", false]], 57=>[[{66=>:enemy}, 66, "s:+p", true], [{66=>nil}, 66, "s:+p", false]], 58=>[[{67=>:enemy}, 67, "s:+p", true], [{67=>nil}, 67, "s:+p", false]], 59=>[[{68=>:enemy}, 68, "s:+p", true], [{68=>nil}, 68, "s:+p", false]], 60=>[[{69=>:enemy}, 69, "s:+p", true], [{69=>nil}, 69, "s:+p", false]], 61=>[[{70=>:enemy}, 70, "s:+p", true], [{70=>nil}, 70, "s:+p", false]], 62=>[[{71=>:enemy}, 71, "s:+p", true], [{71=>nil}, 71, "s:+p", false]], 63=>[[{72=>:enemy}, 72, "s:+p", true], [{72=>nil}, 72, "s:+p", false]], 64=>[[{73=>:enemy}, 73, "s:+p", true], [{73=>nil}, 73, "s:+p", false]], 65=>[[{74=>:enemy}, 74, "s:+p", true], [{74=>nil}, 74, "s:+p", false]], 66=>[[{75=>:enemy}, 75, "s:+p", true], [{75=>nil}, 75, "s:+p", false]], 67=>[[{76=>:enemy}, 76, "s:+p", true], [{76=>nil}, 76, "s:+p", false]], 68=>[[{77=>:enemy}, 77, "s:+p", true], [{77=>nil}, 77, "s:+p", false]], 69=>[[{78=>:enemy}, 78, "s:+p", true], [{78=>nil}, 78, "s:+p", false]], 70=>[[{79=>:enemy}, 79, "s:+p", true], [{79=>nil}, 79, "s:+p", false]], 71=>[[{80=>:enemy}, 80, "s:+p", true], [{80=>nil}, 80, "s:+p", false]], 72=>[], 73=>[], 74=>[], 75=>[], 76=>[], 77=>[], 78=>[], 79=>[], 80=>[], nil=>[[{0=>nil}, 0, "s:p", false], [{1=>nil}, 1, "s:p", false], [{2=>nil}, 2, "s:p", false], [{3=>nil}, 3, "s:p", false], [{4=>nil}, 4, "s:p", false], [{5=>nil}, 5, "s:p", false], [{6=>nil}, 6, "s:p", false], [{7=>nil}, 7, "s:p", false], [{8=>nil}, 8, "s:p", false], [{9=>nil}, 9, "s:p", false], [{10=>nil}, 10, "s:p", false], [{11=>nil}, 11, "s:p", false], [{12=>nil}, 12, "s:p", false], [{13=>nil}, 13, "s:p", false], [{14=>nil}, 14, "s:p", false], [{15=>nil}, 15, "s:p", false], [{16=>nil}, 16, "s:p", false], [{17=>nil}, 17, "s:p", false], [{18=>nil}, 18, "s:p", false], [{19=>nil}, 19, "s:p", false], [{20=>nil}, 20, "s:p", false], [{21=>nil}, 21, "s:p", false], [{22=>nil}, 22, "s:p", false], [{23=>nil}, 23, "s:p", false], [{24=>nil}, 24, "s:p", false], [{25=>nil}, 25, "s:p", false], [{26=>nil}, 26, "s:p", false], [{27=>nil}, 27, "s:p", false], [{28=>nil}, 28, "s:p", false], [{29=>nil}, 29, "s:p", false], [{30=>nil}, 30, "s:p", false], [{31=>nil}, 31, "s:p", false], [{32=>nil}, 32, "s:p", false], [{33=>nil}, 33, "s:p", false], [{34=>nil}, 34, "s:p", false], [{35=>nil}, 35, "s:p", false], [{36=>nil}, 36, "s:p", false], [{37=>nil}, 37, "s:p", false], [{38=>nil}, 38, "s:p", false], [{39=>nil}, 39, "s:p", false], [{40=>nil}, 40, "s:p", false], [{41=>nil}, 41, "s:p", false], [{42=>nil}, 42, "s:p", false], [{43=>nil}, 43, "s:p", false], [{44=>nil}, 44, "s:p", false], [{45=>nil}, 45, "s:p", false], [{46=>nil}, 46, "s:p", false], [{47=>nil}, 47, "s:p", false], [{48=>nil}, 48, "s:p", false], [{49=>nil}, 49, "s:p", false], [{50=>nil}, 50, "s:p", false], [{51=>nil}, 51, "s:p", false], [{52=>nil}, 52, "s:p", false], [{53=>nil}, 53, "s:p", false], [{54=>nil}, 54, "s:p", false], [{55=>nil}, 55, "s:p", false], [{56=>nil}, 56, "s:p", false], [{57=>nil}, 57, "s:p", false], [{58=>nil}, 58, "s:p", false], [{59=>nil}, 59, "s:p", false], [{60=>nil}, 60, "s:p", false], [{61=>nil}, 61, "s:p", false], [{62=>nil}, 62, "s:p", false], [{63=>nil}, 63, "s:p", false], [{64=>nil}, 64, "s:p", false], [{65=>nil}, 65, "s:p", false], [{66=>nil}, 66, "s:p", false], [{67=>nil}, 67, "s:p", false], [{68=>nil}, 68, "s:p", false], [{69=>nil}, 69, "s:p", false], [{70=>nil}, 70, "s:p", false], [{71=>nil}, 71, "s:p", false]]}, "s:r"=>{0=>[[{1=>:enemy}, 1, "s:r", true], [{9=>:enemy}, 9, "s:r", true], [{1=>nil}, 1, "s:r", false], [{1=>nil, 2=>:enemy}, 2, "s:r", true], [{1=>nil, 2=>nil}, 2, "s:r", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "s:r", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "s:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "s:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "s:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "s:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "s:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{9=>nil}, 9, "s:r", false], [{9=>nil, 18=>:enemy}, 18, "s:r", true], [{9=>nil, 18=>nil}, 18, "s:r", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "s:r", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "s:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "s:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "s:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 1=>[[{0=>:enemy}, 0, "s:r", true], [{2=>:enemy}, 2, "s:r", true], [{10=>:enemy}, 10, "s:r", true], [{0=>nil}, 0, "s:r", false], [{2=>nil}, 2, "s:r", false], [{2=>nil, 3=>:enemy}, 3, "s:r", true], [{2=>nil, 3=>nil}, 3, "s:r", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "s:r", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "s:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "s:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "s:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{10=>nil}, 10, "s:r", false], [{10=>nil, 19=>:enemy}, 19, "s:r", true], [{10=>nil, 19=>nil}, 19, "s:r", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "s:r", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "s:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "s:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "s:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 2=>[[{1=>:enemy}, 1, "s:r", true], [{3=>:enemy}, 3, "s:r", true], [{11=>:enemy}, 11, "s:r", true], [{1=>nil}, 1, "s:r", false], [{1=>nil, 0=>:enemy}, 0, "s:r", true], [{1=>nil, 0=>nil}, 0, "s:r", false], [{3=>nil}, 3, "s:r", false], [{3=>nil, 4=>:enemy}, 4, "s:r", true], [{3=>nil, 4=>nil}, 4, "s:r", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "s:r", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "s:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "s:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "s:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{11=>nil}, 11, "s:r", false], [{11=>nil, 20=>:enemy}, 20, "s:r", true], [{11=>nil, 20=>nil}, 20, "s:r", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "s:r", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "s:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "s:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "s:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 3=>[[{2=>:enemy}, 2, "s:r", true], [{4=>:enemy}, 4, "s:r", true], [{12=>:enemy}, 12, "s:r", true], [{2=>nil}, 2, "s:r", false], [{2=>nil, 1=>:enemy}, 1, "s:r", true], [{2=>nil, 1=>nil}, 1, "s:r", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{4=>nil}, 4, "s:r", false], [{4=>nil, 5=>:enemy}, 5, "s:r", true], [{4=>nil, 5=>nil}, 5, "s:r", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "s:r", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "s:r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "s:r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "s:r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{12=>nil}, 12, "s:r", false], [{12=>nil, 21=>:enemy}, 21, "s:r", true], [{12=>nil, 21=>nil}, 21, "s:r", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "s:r", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "s:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "s:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "s:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 4=>[[{3=>:enemy}, 3, "s:r", true], [{5=>:enemy}, 5, "s:r", true], [{13=>:enemy}, 13, "s:r", true], [{3=>nil}, 3, "s:r", false], [{3=>nil, 2=>:enemy}, 2, "s:r", true], [{3=>nil, 2=>nil}, 2, "s:r", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "s:r", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "s:r", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{5=>nil}, 5, "s:r", false], [{5=>nil, 6=>:enemy}, 6, "s:r", true], [{5=>nil, 6=>nil}, 6, "s:r", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "s:r", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "s:r", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{13=>nil}, 13, "s:r", false], [{13=>nil, 22=>:enemy}, 22, "s:r", true], [{13=>nil, 22=>nil}, 22, "s:r", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "s:r", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "s:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "s:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "s:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 5=>[[{4=>:enemy}, 4, "s:r", true], [{6=>:enemy}, 6, "s:r", true], [{14=>:enemy}, 14, "s:r", true], [{4=>nil}, 4, "s:r", false], [{4=>nil, 3=>:enemy}, 3, "s:r", true], [{4=>nil, 3=>nil}, 3, "s:r", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "s:r", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "s:r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{6=>nil}, 6, "s:r", false], [{6=>nil, 7=>:enemy}, 7, "s:r", true], [{6=>nil, 7=>nil}, 7, "s:r", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "s:r", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "s:r", false], [{14=>nil}, 14, "s:r", false], [{14=>nil, 23=>:enemy}, 23, "s:r", true], [{14=>nil, 23=>nil}, 23, "s:r", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "s:r", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "s:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "s:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "s:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 6=>[[{5=>:enemy}, 5, "s:r", true], [{7=>:enemy}, 7, "s:r", true], [{15=>:enemy}, 15, "s:r", true], [{5=>nil}, 5, "s:r", false], [{5=>nil, 4=>:enemy}, 4, "s:r", true], [{5=>nil, 4=>nil}, 4, "s:r", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "s:r", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "s:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{7=>nil}, 7, "s:r", false], [{7=>nil, 8=>:enemy}, 8, "s:r", true], [{7=>nil, 8=>nil}, 8, "s:r", false], [{15=>nil}, 15, "s:r", false], [{15=>nil, 24=>:enemy}, 24, "s:r", true], [{15=>nil, 24=>nil}, 24, "s:r", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "s:r", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "s:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "s:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "s:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 7=>[[{6=>:enemy}, 6, "s:r", true], [{8=>:enemy}, 8, "s:r", true], [{16=>:enemy}, 16, "s:r", true], [{6=>nil}, 6, "s:r", false], [{6=>nil, 5=>:enemy}, 5, "s:r", true], [{6=>nil, 5=>nil}, 5, "s:r", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "s:r", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "s:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "s:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "s:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{8=>nil}, 8, "s:r", false], [{16=>nil}, 16, "s:r", false], [{16=>nil, 25=>:enemy}, 25, "s:r", true], [{16=>nil, 25=>nil}, 25, "s:r", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "s:r", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "s:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "s:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "s:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 8=>[[{7=>:enemy}, 7, "s:r", true], [{17=>:enemy}, 17, "s:r", true], [{7=>nil}, 7, "s:r", false], [{7=>nil, 6=>:enemy}, 6, "s:r", true], [{7=>nil, 6=>nil}, 6, "s:r", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "s:r", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "s:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "s:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "s:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "s:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "s:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "s:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "s:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "s:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "s:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "s:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "s:r", false], [{17=>nil}, 17, "s:r", false], [{17=>nil, 26=>:enemy}, 26, "s:r", true], [{17=>nil, 26=>nil}, 26, "s:r", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "s:r", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "s:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "s:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "s:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 9=>[[{0=>:enemy}, 0, "s:r", true], [{10=>:enemy}, 10, "s:r", true], [{18=>:enemy}, 18, "s:r", true], [{0=>nil}, 0, "s:r", false], [{10=>nil}, 10, "s:r", false], [{10=>nil, 11=>:enemy}, 11, "s:r", true], [{10=>nil, 11=>nil}, 11, "s:r", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "s:r", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "s:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "s:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "s:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "s:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "s:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{18=>nil}, 18, "s:r", false], [{18=>nil, 27=>:enemy}, 27, "s:r", true], [{18=>nil, 27=>nil}, 27, "s:r", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "s:r", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "s:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "s:r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "s:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 10=>[[{1=>:enemy}, 1, "s:r", true], [{9=>:enemy}, 9, "s:r", true], [{11=>:enemy}, 11, "s:r", true], [{19=>:enemy}, 19, "s:r", true], [{1=>nil}, 1, "s:r", false], [{9=>nil}, 9, "s:r", false], [{11=>nil}, 11, "s:r", false], [{11=>nil, 12=>:enemy}, 12, "s:r", true], [{11=>nil, 12=>nil}, 12, "s:r", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "s:r", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "s:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "s:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "s:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{19=>nil}, 19, "s:r", false], [{19=>nil, 28=>:enemy}, 28, "s:r", true], [{19=>nil, 28=>nil}, 28, "s:r", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "s:r", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "s:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "s:r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "s:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 11=>[[{2=>:enemy}, 2, "s:r", true], [{10=>:enemy}, 10, "s:r", true], [{12=>:enemy}, 12, "s:r", true], [{20=>:enemy}, 20, "s:r", true], [{2=>nil}, 2, "s:r", false], [{10=>nil}, 10, "s:r", false], [{10=>nil, 9=>:enemy}, 9, "s:r", true], [{10=>nil, 9=>nil}, 9, "s:r", false], [{12=>nil}, 12, "s:r", false], [{12=>nil, 13=>:enemy}, 13, "s:r", true], [{12=>nil, 13=>nil}, 13, "s:r", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "s:r", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "s:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "s:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "s:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{20=>nil}, 20, "s:r", false], [{20=>nil, 29=>:enemy}, 29, "s:r", true], [{20=>nil, 29=>nil}, 29, "s:r", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "s:r", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "s:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "s:r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "s:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 12=>[[{3=>:enemy}, 3, "s:r", true], [{11=>:enemy}, 11, "s:r", true], [{13=>:enemy}, 13, "s:r", true], [{21=>:enemy}, 21, "s:r", true], [{3=>nil}, 3, "s:r", false], [{11=>nil}, 11, "s:r", false], [{11=>nil, 10=>:enemy}, 10, "s:r", true], [{11=>nil, 10=>nil}, 10, "s:r", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{13=>nil}, 13, "s:r", false], [{13=>nil, 14=>:enemy}, 14, "s:r", true], [{13=>nil, 14=>nil}, 14, "s:r", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "s:r", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "s:r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "s:r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "s:r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{21=>nil}, 21, "s:r", false], [{21=>nil, 30=>:enemy}, 30, "s:r", true], [{21=>nil, 30=>nil}, 30, "s:r", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "s:r", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "s:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "s:r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "s:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 13=>[[{4=>:enemy}, 4, "s:r", true], [{12=>:enemy}, 12, "s:r", true], [{14=>:enemy}, 14, "s:r", true], [{22=>:enemy}, 22, "s:r", true], [{4=>nil}, 4, "s:r", false], [{12=>nil}, 12, "s:r", false], [{12=>nil, 11=>:enemy}, 11, "s:r", true], [{12=>nil, 11=>nil}, 11, "s:r", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "s:r", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "s:r", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{14=>nil}, 14, "s:r", false], [{14=>nil, 15=>:enemy}, 15, "s:r", true], [{14=>nil, 15=>nil}, 15, "s:r", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "s:r", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "s:r", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{22=>nil}, 22, "s:r", false], [{22=>nil, 31=>:enemy}, 31, "s:r", true], [{22=>nil, 31=>nil}, 31, "s:r", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "s:r", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "s:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "s:r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "s:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 14=>[[{5=>:enemy}, 5, "s:r", true], [{13=>:enemy}, 13, "s:r", true], [{15=>:enemy}, 15, "s:r", true], [{23=>:enemy}, 23, "s:r", true], [{5=>nil}, 5, "s:r", false], [{13=>nil}, 13, "s:r", false], [{13=>nil, 12=>:enemy}, 12, "s:r", true], [{13=>nil, 12=>nil}, 12, "s:r", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "s:r", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "s:r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{15=>nil}, 15, "s:r", false], [{15=>nil, 16=>:enemy}, 16, "s:r", true], [{15=>nil, 16=>nil}, 16, "s:r", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "s:r", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "s:r", false], [{23=>nil}, 23, "s:r", false], [{23=>nil, 32=>:enemy}, 32, "s:r", true], [{23=>nil, 32=>nil}, 32, "s:r", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "s:r", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "s:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "s:r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "s:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 15=>[[{6=>:enemy}, 6, "s:r", true], [{14=>:enemy}, 14, "s:r", true], [{16=>:enemy}, 16, "s:r", true], [{24=>:enemy}, 24, "s:r", true], [{6=>nil}, 6, "s:r", false], [{14=>nil}, 14, "s:r", false], [{14=>nil, 13=>:enemy}, 13, "s:r", true], [{14=>nil, 13=>nil}, 13, "s:r", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "s:r", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "s:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{16=>nil}, 16, "s:r", false], [{16=>nil, 17=>:enemy}, 17, "s:r", true], [{16=>nil, 17=>nil}, 17, "s:r", false], [{24=>nil}, 24, "s:r", false], [{24=>nil, 33=>:enemy}, 33, "s:r", true], [{24=>nil, 33=>nil}, 33, "s:r", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "s:r", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "s:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "s:r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "s:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 16=>[[{7=>:enemy}, 7, "s:r", true], [{15=>:enemy}, 15, "s:r", true], [{17=>:enemy}, 17, "s:r", true], [{25=>:enemy}, 25, "s:r", true], [{7=>nil}, 7, "s:r", false], [{15=>nil}, 15, "s:r", false], [{15=>nil, 14=>:enemy}, 14, "s:r", true], [{15=>nil, 14=>nil}, 14, "s:r", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "s:r", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "s:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "s:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "s:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{17=>nil}, 17, "s:r", false], [{25=>nil}, 25, "s:r", false], [{25=>nil, 34=>:enemy}, 34, "s:r", true], [{25=>nil, 34=>nil}, 34, "s:r", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "s:r", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "s:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "s:r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "s:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 17=>[[{8=>:enemy}, 8, "s:r", true], [{16=>:enemy}, 16, "s:r", true], [{26=>:enemy}, 26, "s:r", true], [{8=>nil}, 8, "s:r", false], [{16=>nil}, 16, "s:r", false], [{16=>nil, 15=>:enemy}, 15, "s:r", true], [{16=>nil, 15=>nil}, 15, "s:r", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "s:r", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "s:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "s:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "s:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "s:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "s:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "s:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "s:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "s:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "s:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "s:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "s:r", false], [{26=>nil}, 26, "s:r", false], [{26=>nil, 35=>:enemy}, 35, "s:r", true], [{26=>nil, 35=>nil}, 35, "s:r", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "s:r", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "s:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "s:r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "s:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 18=>[[{9=>:enemy}, 9, "s:r", true], [{19=>:enemy}, 19, "s:r", true], [{27=>:enemy}, 27, "s:r", true], [{9=>nil}, 9, "s:r", false], [{9=>nil, 0=>:enemy}, 0, "s:r", true], [{9=>nil, 0=>nil}, 0, "s:r", false], [{19=>nil}, 19, "s:r", false], [{19=>nil, 20=>:enemy}, 20, "s:r", true], [{19=>nil, 20=>nil}, 20, "s:r", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "s:r", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "s:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "s:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "s:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "s:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "s:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{27=>nil}, 27, "s:r", false], [{27=>nil, 36=>:enemy}, 36, "s:r", true], [{27=>nil, 36=>nil}, 36, "s:r", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "s:r", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "s:r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 19=>[[{10=>:enemy}, 10, "s:r", true], [{18=>:enemy}, 18, "s:r", true], [{20=>:enemy}, 20, "s:r", true], [{28=>:enemy}, 28, "s:r", true], [{10=>nil}, 10, "s:r", false], [{10=>nil, 1=>:enemy}, 1, "s:r", true], [{10=>nil, 1=>nil}, 1, "s:r", false], [{18=>nil}, 18, "s:r", false], [{20=>nil}, 20, "s:r", false], [{20=>nil, 21=>:enemy}, 21, "s:r", true], [{20=>nil, 21=>nil}, 21, "s:r", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "s:r", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "s:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "s:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "s:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{28=>nil}, 28, "s:r", false], [{28=>nil, 37=>:enemy}, 37, "s:r", true], [{28=>nil, 37=>nil}, 37, "s:r", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "s:r", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "s:r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 20=>[[{11=>:enemy}, 11, "s:r", true], [{19=>:enemy}, 19, "s:r", true], [{21=>:enemy}, 21, "s:r", true], [{29=>:enemy}, 29, "s:r", true], [{11=>nil}, 11, "s:r", false], [{11=>nil, 2=>:enemy}, 2, "s:r", true], [{11=>nil, 2=>nil}, 2, "s:r", false], [{19=>nil}, 19, "s:r", false], [{19=>nil, 18=>:enemy}, 18, "s:r", true], [{19=>nil, 18=>nil}, 18, "s:r", false], [{21=>nil}, 21, "s:r", false], [{21=>nil, 22=>:enemy}, 22, "s:r", true], [{21=>nil, 22=>nil}, 22, "s:r", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "s:r", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "s:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "s:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "s:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{29=>nil}, 29, "s:r", false], [{29=>nil, 38=>:enemy}, 38, "s:r", true], [{29=>nil, 38=>nil}, 38, "s:r", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "s:r", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "s:r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 21=>[[{12=>:enemy}, 12, "s:r", true], [{20=>:enemy}, 20, "s:r", true], [{22=>:enemy}, 22, "s:r", true], [{30=>:enemy}, 30, "s:r", true], [{12=>nil}, 12, "s:r", false], [{12=>nil, 3=>:enemy}, 3, "s:r", true], [{12=>nil, 3=>nil}, 3, "s:r", false], [{20=>nil}, 20, "s:r", false], [{20=>nil, 19=>:enemy}, 19, "s:r", true], [{20=>nil, 19=>nil}, 19, "s:r", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{22=>nil}, 22, "s:r", false], [{22=>nil, 23=>:enemy}, 23, "s:r", true], [{22=>nil, 23=>nil}, 23, "s:r", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "s:r", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "s:r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "s:r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "s:r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{30=>nil}, 30, "s:r", false], [{30=>nil, 39=>:enemy}, 39, "s:r", true], [{30=>nil, 39=>nil}, 39, "s:r", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "s:r", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "s:r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 22=>[[{13=>:enemy}, 13, "s:r", true], [{21=>:enemy}, 21, "s:r", true], [{23=>:enemy}, 23, "s:r", true], [{31=>:enemy}, 31, "s:r", true], [{13=>nil}, 13, "s:r", false], [{13=>nil, 4=>:enemy}, 4, "s:r", true], [{13=>nil, 4=>nil}, 4, "s:r", false], [{21=>nil}, 21, "s:r", false], [{21=>nil, 20=>:enemy}, 20, "s:r", true], [{21=>nil, 20=>nil}, 20, "s:r", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "s:r", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "s:r", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{23=>nil}, 23, "s:r", false], [{23=>nil, 24=>:enemy}, 24, "s:r", true], [{23=>nil, 24=>nil}, 24, "s:r", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "s:r", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "s:r", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{31=>nil}, 31, "s:r", false], [{31=>nil, 40=>:enemy}, 40, "s:r", true], [{31=>nil, 40=>nil}, 40, "s:r", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "s:r", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "s:r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 23=>[[{14=>:enemy}, 14, "s:r", true], [{22=>:enemy}, 22, "s:r", true], [{24=>:enemy}, 24, "s:r", true], [{32=>:enemy}, 32, "s:r", true], [{14=>nil}, 14, "s:r", false], [{14=>nil, 5=>:enemy}, 5, "s:r", true], [{14=>nil, 5=>nil}, 5, "s:r", false], [{22=>nil}, 22, "s:r", false], [{22=>nil, 21=>:enemy}, 21, "s:r", true], [{22=>nil, 21=>nil}, 21, "s:r", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "s:r", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "s:r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{24=>nil}, 24, "s:r", false], [{24=>nil, 25=>:enemy}, 25, "s:r", true], [{24=>nil, 25=>nil}, 25, "s:r", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "s:r", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "s:r", false], [{32=>nil}, 32, "s:r", false], [{32=>nil, 41=>:enemy}, 41, "s:r", true], [{32=>nil, 41=>nil}, 41, "s:r", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "s:r", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "s:r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 24=>[[{15=>:enemy}, 15, "s:r", true], [{23=>:enemy}, 23, "s:r", true], [{25=>:enemy}, 25, "s:r", true], [{33=>:enemy}, 33, "s:r", true], [{15=>nil}, 15, "s:r", false], [{15=>nil, 6=>:enemy}, 6, "s:r", true], [{15=>nil, 6=>nil}, 6, "s:r", false], [{23=>nil}, 23, "s:r", false], [{23=>nil, 22=>:enemy}, 22, "s:r", true], [{23=>nil, 22=>nil}, 22, "s:r", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "s:r", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "s:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{25=>nil}, 25, "s:r", false], [{25=>nil, 26=>:enemy}, 26, "s:r", true], [{25=>nil, 26=>nil}, 26, "s:r", false], [{33=>nil}, 33, "s:r", false], [{33=>nil, 42=>:enemy}, 42, "s:r", true], [{33=>nil, 42=>nil}, 42, "s:r", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "s:r", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "s:r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 25=>[[{16=>:enemy}, 16, "s:r", true], [{24=>:enemy}, 24, "s:r", true], [{26=>:enemy}, 26, "s:r", true], [{34=>:enemy}, 34, "s:r", true], [{16=>nil}, 16, "s:r", false], [{16=>nil, 7=>:enemy}, 7, "s:r", true], [{16=>nil, 7=>nil}, 7, "s:r", false], [{24=>nil}, 24, "s:r", false], [{24=>nil, 23=>:enemy}, 23, "s:r", true], [{24=>nil, 23=>nil}, 23, "s:r", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "s:r", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "s:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "s:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "s:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{26=>nil}, 26, "s:r", false], [{34=>nil}, 34, "s:r", false], [{34=>nil, 43=>:enemy}, 43, "s:r", true], [{34=>nil, 43=>nil}, 43, "s:r", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "s:r", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "s:r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 26=>[[{17=>:enemy}, 17, "s:r", true], [{25=>:enemy}, 25, "s:r", true], [{35=>:enemy}, 35, "s:r", true], [{17=>nil}, 17, "s:r", false], [{17=>nil, 8=>:enemy}, 8, "s:r", true], [{17=>nil, 8=>nil}, 8, "s:r", false], [{25=>nil}, 25, "s:r", false], [{25=>nil, 24=>:enemy}, 24, "s:r", true], [{25=>nil, 24=>nil}, 24, "s:r", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "s:r", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "s:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "s:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "s:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "s:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "s:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "s:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "s:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "s:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "s:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "s:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "s:r", false], [{35=>nil}, 35, "s:r", false], [{35=>nil, 44=>:enemy}, 44, "s:r", true], [{35=>nil, 44=>nil}, 44, "s:r", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "s:r", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "s:r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 27=>[[{18=>:enemy}, 18, "s:r", true], [{28=>:enemy}, 28, "s:r", true], [{36=>:enemy}, 36, "s:r", true], [{18=>nil}, 18, "s:r", false], [{18=>nil, 9=>:enemy}, 9, "s:r", true], [{18=>nil, 9=>nil}, 9, "s:r", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "s:r", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "s:r", false], [{28=>nil}, 28, "s:r", false], [{28=>nil, 29=>:enemy}, 29, "s:r", true], [{28=>nil, 29=>nil}, 29, "s:r", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "s:r", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "s:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "s:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "s:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "s:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "s:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{36=>nil}, 36, "s:r", false], [{36=>nil, 45=>:enemy}, 45, "s:r", true], [{36=>nil, 45=>nil}, 45, "s:r", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "s:+r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 28=>[[{19=>:enemy}, 19, "s:r", true], [{27=>:enemy}, 27, "s:r", true], [{29=>:enemy}, 29, "s:r", true], [{37=>:enemy}, 37, "s:r", true], [{19=>nil}, 19, "s:r", false], [{19=>nil, 10=>:enemy}, 10, "s:r", true], [{19=>nil, 10=>nil}, 10, "s:r", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "s:r", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "s:r", false], [{27=>nil}, 27, "s:r", false], [{29=>nil}, 29, "s:r", false], [{29=>nil, 30=>:enemy}, 30, "s:r", true], [{29=>nil, 30=>nil}, 30, "s:r", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "s:r", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "s:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "s:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "s:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{37=>nil}, 37, "s:r", false], [{37=>nil, 46=>:enemy}, 46, "s:r", true], [{37=>nil, 46=>nil}, 46, "s:r", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "s:+r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 29=>[[{20=>:enemy}, 20, "s:r", true], [{28=>:enemy}, 28, "s:r", true], [{30=>:enemy}, 30, "s:r", true], [{38=>:enemy}, 38, "s:r", true], [{20=>nil}, 20, "s:r", false], [{20=>nil, 11=>:enemy}, 11, "s:r", true], [{20=>nil, 11=>nil}, 11, "s:r", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "s:r", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "s:r", false], [{28=>nil}, 28, "s:r", false], [{28=>nil, 27=>:enemy}, 27, "s:r", true], [{28=>nil, 27=>nil}, 27, "s:r", false], [{30=>nil}, 30, "s:r", false], [{30=>nil, 31=>:enemy}, 31, "s:r", true], [{30=>nil, 31=>nil}, 31, "s:r", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "s:r", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "s:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "s:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "s:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{38=>nil}, 38, "s:r", false], [{38=>nil, 47=>:enemy}, 47, "s:r", true], [{38=>nil, 47=>nil}, 47, "s:r", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "s:+r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 30=>[[{21=>:enemy}, 21, "s:r", true], [{29=>:enemy}, 29, "s:r", true], [{31=>:enemy}, 31, "s:r", true], [{39=>:enemy}, 39, "s:r", true], [{21=>nil}, 21, "s:r", false], [{21=>nil, 12=>:enemy}, 12, "s:r", true], [{21=>nil, 12=>nil}, 12, "s:r", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "s:r", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "s:r", false], [{29=>nil}, 29, "s:r", false], [{29=>nil, 28=>:enemy}, 28, "s:r", true], [{29=>nil, 28=>nil}, 28, "s:r", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{31=>nil}, 31, "s:r", false], [{31=>nil, 32=>:enemy}, 32, "s:r", true], [{31=>nil, 32=>nil}, 32, "s:r", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "s:r", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "s:r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "s:r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "s:r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{39=>nil}, 39, "s:r", false], [{39=>nil, 48=>:enemy}, 48, "s:r", true], [{39=>nil, 48=>nil}, 48, "s:r", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "s:+r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 31=>[[{22=>:enemy}, 22, "s:r", true], [{30=>:enemy}, 30, "s:r", true], [{32=>:enemy}, 32, "s:r", true], [{40=>:enemy}, 40, "s:r", true], [{22=>nil}, 22, "s:r", false], [{22=>nil, 13=>:enemy}, 13, "s:r", true], [{22=>nil, 13=>nil}, 13, "s:r", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "s:r", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "s:r", false], [{30=>nil}, 30, "s:r", false], [{30=>nil, 29=>:enemy}, 29, "s:r", true], [{30=>nil, 29=>nil}, 29, "s:r", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "s:r", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "s:r", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{32=>nil}, 32, "s:r", false], [{32=>nil, 33=>:enemy}, 33, "s:r", true], [{32=>nil, 33=>nil}, 33, "s:r", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "s:r", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "s:r", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{40=>nil}, 40, "s:r", false], [{40=>nil, 49=>:enemy}, 49, "s:r", true], [{40=>nil, 49=>nil}, 49, "s:r", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "s:+r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 32=>[[{23=>:enemy}, 23, "s:r", true], [{31=>:enemy}, 31, "s:r", true], [{33=>:enemy}, 33, "s:r", true], [{41=>:enemy}, 41, "s:r", true], [{23=>nil}, 23, "s:r", false], [{23=>nil, 14=>:enemy}, 14, "s:r", true], [{23=>nil, 14=>nil}, 14, "s:r", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "s:r", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "s:r", false], [{31=>nil}, 31, "s:r", false], [{31=>nil, 30=>:enemy}, 30, "s:r", true], [{31=>nil, 30=>nil}, 30, "s:r", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "s:r", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "s:r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{33=>nil}, 33, "s:r", false], [{33=>nil, 34=>:enemy}, 34, "s:r", true], [{33=>nil, 34=>nil}, 34, "s:r", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "s:r", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "s:r", false], [{41=>nil}, 41, "s:r", false], [{41=>nil, 50=>:enemy}, 50, "s:r", true], [{41=>nil, 50=>nil}, 50, "s:r", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "s:+r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 33=>[[{24=>:enemy}, 24, "s:r", true], [{32=>:enemy}, 32, "s:r", true], [{34=>:enemy}, 34, "s:r", true], [{42=>:enemy}, 42, "s:r", true], [{24=>nil}, 24, "s:r", false], [{24=>nil, 15=>:enemy}, 15, "s:r", true], [{24=>nil, 15=>nil}, 15, "s:r", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "s:r", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "s:r", false], [{32=>nil}, 32, "s:r", false], [{32=>nil, 31=>:enemy}, 31, "s:r", true], [{32=>nil, 31=>nil}, 31, "s:r", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "s:r", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "s:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{34=>nil}, 34, "s:r", false], [{34=>nil, 35=>:enemy}, 35, "s:r", true], [{34=>nil, 35=>nil}, 35, "s:r", false], [{42=>nil}, 42, "s:r", false], [{42=>nil, 51=>:enemy}, 51, "s:r", true], [{42=>nil, 51=>nil}, 51, "s:r", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "s:+r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 34=>[[{25=>:enemy}, 25, "s:r", true], [{33=>:enemy}, 33, "s:r", true], [{35=>:enemy}, 35, "s:r", true], [{43=>:enemy}, 43, "s:r", true], [{25=>nil}, 25, "s:r", false], [{25=>nil, 16=>:enemy}, 16, "s:r", true], [{25=>nil, 16=>nil}, 16, "s:r", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "s:r", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "s:r", false], [{33=>nil}, 33, "s:r", false], [{33=>nil, 32=>:enemy}, 32, "s:r", true], [{33=>nil, 32=>nil}, 32, "s:r", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "s:r", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "s:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "s:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "s:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{35=>nil}, 35, "s:r", false], [{43=>nil}, 43, "s:r", false], [{43=>nil, 52=>:enemy}, 52, "s:r", true], [{43=>nil, 52=>nil}, 52, "s:r", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "s:+r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 35=>[[{26=>:enemy}, 26, "s:r", true], [{34=>:enemy}, 34, "s:r", true], [{44=>:enemy}, 44, "s:r", true], [{26=>nil}, 26, "s:r", false], [{26=>nil, 17=>:enemy}, 17, "s:r", true], [{26=>nil, 17=>nil}, 17, "s:r", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "s:r", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "s:r", false], [{34=>nil}, 34, "s:r", false], [{34=>nil, 33=>:enemy}, 33, "s:r", true], [{34=>nil, 33=>nil}, 33, "s:r", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "s:r", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "s:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "s:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "s:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "s:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "s:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "s:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "s:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "s:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "s:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "s:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "s:r", false], [{44=>nil}, 44, "s:r", false], [{44=>nil, 53=>:enemy}, 53, "s:r", true], [{44=>nil, 53=>nil}, 53, "s:r", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "s:+r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 36=>[[{27=>:enemy}, 27, "s:r", true], [{37=>:enemy}, 37, "s:r", true], [{45=>:enemy}, 45, "s:r", true], [{27=>nil}, 27, "s:r", false], [{27=>nil, 18=>:enemy}, 18, "s:r", true], [{27=>nil, 18=>nil}, 18, "s:r", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "s:r", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "s:r", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:r", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:r", false], [{37=>nil}, 37, "s:r", false], [{37=>nil, 38=>:enemy}, 38, "s:r", true], [{37=>nil, 38=>nil}, 38, "s:r", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "s:r", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "s:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "s:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "s:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "s:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "s:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{45=>nil}, 45, "s:r", false], [{45=>nil, 54=>:enemy}, 54, "s:+r", true], [{45=>nil, 54=>nil}, 54, "s:+r", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "s:+r", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "s:+r", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 37=>[[{28=>:enemy}, 28, "s:r", true], [{36=>:enemy}, 36, "s:r", true], [{38=>:enemy}, 38, "s:r", true], [{46=>:enemy}, 46, "s:r", true], [{28=>nil}, 28, "s:r", false], [{28=>nil, 19=>:enemy}, 19, "s:r", true], [{28=>nil, 19=>nil}, 19, "s:r", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "s:r", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "s:r", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:r", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:r", false], [{36=>nil}, 36, "s:r", false], [{38=>nil}, 38, "s:r", false], [{38=>nil, 39=>:enemy}, 39, "s:r", true], [{38=>nil, 39=>nil}, 39, "s:r", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "s:r", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "s:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "s:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "s:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{46=>nil}, 46, "s:r", false], [{46=>nil, 55=>:enemy}, 55, "s:+r", true], [{46=>nil, 55=>nil}, 55, "s:+r", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "s:+r", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "s:+r", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 38=>[[{29=>:enemy}, 29, "s:r", true], [{37=>:enemy}, 37, "s:r", true], [{39=>:enemy}, 39, "s:r", true], [{47=>:enemy}, 47, "s:r", true], [{29=>nil}, 29, "s:r", false], [{29=>nil, 20=>:enemy}, 20, "s:r", true], [{29=>nil, 20=>nil}, 20, "s:r", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "s:r", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "s:r", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:r", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:r", false], [{37=>nil}, 37, "s:r", false], [{37=>nil, 36=>:enemy}, 36, "s:r", true], [{37=>nil, 36=>nil}, 36, "s:r", false], [{39=>nil}, 39, "s:r", false], [{39=>nil, 40=>:enemy}, 40, "s:r", true], [{39=>nil, 40=>nil}, 40, "s:r", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "s:r", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "s:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "s:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "s:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{47=>nil}, 47, "s:r", false], [{47=>nil, 56=>:enemy}, 56, "s:+r", true], [{47=>nil, 56=>nil}, 56, "s:+r", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "s:+r", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "s:+r", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 39=>[[{30=>:enemy}, 30, "s:r", true], [{38=>:enemy}, 38, "s:r", true], [{40=>:enemy}, 40, "s:r", true], [{48=>:enemy}, 48, "s:r", true], [{30=>nil}, 30, "s:r", false], [{30=>nil, 21=>:enemy}, 21, "s:r", true], [{30=>nil, 21=>nil}, 21, "s:r", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "s:r", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "s:r", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:r", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:r", false], [{38=>nil}, 38, "s:r", false], [{38=>nil, 37=>:enemy}, 37, "s:r", true], [{38=>nil, 37=>nil}, 37, "s:r", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{40=>nil}, 40, "s:r", false], [{40=>nil, 41=>:enemy}, 41, "s:r", true], [{40=>nil, 41=>nil}, 41, "s:r", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "s:r", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "s:r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "s:r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "s:r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{48=>nil}, 48, "s:r", false], [{48=>nil, 57=>:enemy}, 57, "s:+r", true], [{48=>nil, 57=>nil}, 57, "s:+r", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "s:+r", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "s:+r", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 40=>[[{31=>:enemy}, 31, "s:r", true], [{39=>:enemy}, 39, "s:r", true], [{41=>:enemy}, 41, "s:r", true], [{49=>:enemy}, 49, "s:r", true], [{31=>nil}, 31, "s:r", false], [{31=>nil, 22=>:enemy}, 22, "s:r", true], [{31=>nil, 22=>nil}, 22, "s:r", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "s:r", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "s:r", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:r", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:r", false], [{39=>nil}, 39, "s:r", false], [{39=>nil, 38=>:enemy}, 38, "s:r", true], [{39=>nil, 38=>nil}, 38, "s:r", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "s:r", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "s:r", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{41=>nil}, 41, "s:r", false], [{41=>nil, 42=>:enemy}, 42, "s:r", true], [{41=>nil, 42=>nil}, 42, "s:r", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "s:r", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "s:r", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{49=>nil}, 49, "s:r", false], [{49=>nil, 58=>:enemy}, 58, "s:+r", true], [{49=>nil, 58=>nil}, 58, "s:+r", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "s:+r", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "s:+r", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 41=>[[{32=>:enemy}, 32, "s:r", true], [{40=>:enemy}, 40, "s:r", true], [{42=>:enemy}, 42, "s:r", true], [{50=>:enemy}, 50, "s:r", true], [{32=>nil}, 32, "s:r", false], [{32=>nil, 23=>:enemy}, 23, "s:r", true], [{32=>nil, 23=>nil}, 23, "s:r", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "s:r", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "s:r", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:r", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:r", false], [{40=>nil}, 40, "s:r", false], [{40=>nil, 39=>:enemy}, 39, "s:r", true], [{40=>nil, 39=>nil}, 39, "s:r", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "s:r", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "s:r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{42=>nil}, 42, "s:r", false], [{42=>nil, 43=>:enemy}, 43, "s:r", true], [{42=>nil, 43=>nil}, 43, "s:r", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "s:r", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "s:r", false], [{50=>nil}, 50, "s:r", false], [{50=>nil, 59=>:enemy}, 59, "s:+r", true], [{50=>nil, 59=>nil}, 59, "s:+r", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "s:+r", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "s:+r", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 42=>[[{33=>:enemy}, 33, "s:r", true], [{41=>:enemy}, 41, "s:r", true], [{43=>:enemy}, 43, "s:r", true], [{51=>:enemy}, 51, "s:r", true], [{33=>nil}, 33, "s:r", false], [{33=>nil, 24=>:enemy}, 24, "s:r", true], [{33=>nil, 24=>nil}, 24, "s:r", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "s:r", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "s:r", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:r", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:r", false], [{41=>nil}, 41, "s:r", false], [{41=>nil, 40=>:enemy}, 40, "s:r", true], [{41=>nil, 40=>nil}, 40, "s:r", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "s:r", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "s:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{43=>nil}, 43, "s:r", false], [{43=>nil, 44=>:enemy}, 44, "s:r", true], [{43=>nil, 44=>nil}, 44, "s:r", false], [{51=>nil}, 51, "s:r", false], [{51=>nil, 60=>:enemy}, 60, "s:+r", true], [{51=>nil, 60=>nil}, 60, "s:+r", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "s:+r", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "s:+r", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 43=>[[{34=>:enemy}, 34, "s:r", true], [{42=>:enemy}, 42, "s:r", true], [{44=>:enemy}, 44, "s:r", true], [{52=>:enemy}, 52, "s:r", true], [{34=>nil}, 34, "s:r", false], [{34=>nil, 25=>:enemy}, 25, "s:r", true], [{34=>nil, 25=>nil}, 25, "s:r", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "s:r", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "s:r", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:r", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:r", false], [{42=>nil}, 42, "s:r", false], [{42=>nil, 41=>:enemy}, 41, "s:r", true], [{42=>nil, 41=>nil}, 41, "s:r", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "s:r", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "s:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "s:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "s:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{44=>nil}, 44, "s:r", false], [{52=>nil}, 52, "s:r", false], [{52=>nil, 61=>:enemy}, 61, "s:+r", true], [{52=>nil, 61=>nil}, 61, "s:+r", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "s:+r", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "s:+r", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 44=>[[{35=>:enemy}, 35, "s:r", true], [{43=>:enemy}, 43, "s:r", true], [{53=>:enemy}, 53, "s:r", true], [{35=>nil}, 35, "s:r", false], [{35=>nil, 26=>:enemy}, 26, "s:r", true], [{35=>nil, 26=>nil}, 26, "s:r", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "s:r", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "s:r", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:r", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:r", false], [{43=>nil}, 43, "s:r", false], [{43=>nil, 42=>:enemy}, 42, "s:r", true], [{43=>nil, 42=>nil}, 42, "s:r", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "s:r", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "s:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "s:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "s:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "s:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "s:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "s:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "s:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "s:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "s:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "s:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "s:r", false], [{53=>nil}, 53, "s:r", false], [{53=>nil, 62=>:enemy}, 62, "s:+r", true], [{53=>nil, 62=>nil}, 62, "s:+r", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "s:+r", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "s:+r", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 45=>[[{36=>:enemy}, 36, "s:r", true], [{46=>:enemy}, 46, "s:r", true], [{54=>:enemy}, 54, "s:+r", true], [{36=>nil}, 36, "s:r", false], [{36=>nil, 27=>:enemy}, 27, "s:r", true], [{36=>nil, 27=>nil}, 27, "s:r", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "s:r", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "s:r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:r", false], [{46=>nil}, 46, "s:r", false], [{46=>nil, 47=>:enemy}, 47, "s:r", true], [{46=>nil, 47=>nil}, 47, "s:r", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "s:r", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "s:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "s:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "s:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "s:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "s:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{54=>nil}, 54, "s:+r", false], [{54=>nil, 63=>:enemy}, 63, "s:+r", true], [{54=>nil, 63=>nil}, 63, "s:+r", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "s:+r", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "s:+r", false]], 46=>[[{37=>:enemy}, 37, "s:r", true], [{45=>:enemy}, 45, "s:r", true], [{47=>:enemy}, 47, "s:r", true], [{55=>:enemy}, 55, "s:+r", true], [{37=>nil}, 37, "s:r", false], [{37=>nil, 28=>:enemy}, 28, "s:r", true], [{37=>nil, 28=>nil}, 28, "s:r", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "s:r", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "s:r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:r", false], [{45=>nil}, 45, "s:r", false], [{47=>nil}, 47, "s:r", false], [{47=>nil, 48=>:enemy}, 48, "s:r", true], [{47=>nil, 48=>nil}, 48, "s:r", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "s:r", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "s:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "s:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "s:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 64=>:enemy}, 64, "s:+r", true], [{55=>nil, 64=>nil}, 64, "s:+r", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "s:+r", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "s:+r", false]], 47=>[[{38=>:enemy}, 38, "s:r", true], [{46=>:enemy}, 46, "s:r", true], [{48=>:enemy}, 48, "s:r", true], [{56=>:enemy}, 56, "s:+r", true], [{38=>nil}, 38, "s:r", false], [{38=>nil, 29=>:enemy}, 29, "s:r", true], [{38=>nil, 29=>nil}, 29, "s:r", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "s:r", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "s:r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:r", false], [{46=>nil}, 46, "s:r", false], [{46=>nil, 45=>:enemy}, 45, "s:r", true], [{46=>nil, 45=>nil}, 45, "s:r", false], [{48=>nil}, 48, "s:r", false], [{48=>nil, 49=>:enemy}, 49, "s:r", true], [{48=>nil, 49=>nil}, 49, "s:r", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "s:r", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "s:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "s:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "s:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 65=>:enemy}, 65, "s:+r", true], [{56=>nil, 65=>nil}, 65, "s:+r", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "s:+r", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "s:+r", false]], 48=>[[{39=>:enemy}, 39, "s:r", true], [{47=>:enemy}, 47, "s:r", true], [{49=>:enemy}, 49, "s:r", true], [{57=>:enemy}, 57, "s:+r", true], [{39=>nil}, 39, "s:r", false], [{39=>nil, 30=>:enemy}, 30, "s:r", true], [{39=>nil, 30=>nil}, 30, "s:r", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "s:r", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "s:r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:r", false], [{47=>nil}, 47, "s:r", false], [{47=>nil, 46=>:enemy}, 46, "s:r", true], [{47=>nil, 46=>nil}, 46, "s:r", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{49=>nil}, 49, "s:r", false], [{49=>nil, 50=>:enemy}, 50, "s:r", true], [{49=>nil, 50=>nil}, 50, "s:r", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "s:r", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "s:r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "s:r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "s:r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 66=>:enemy}, 66, "s:+r", true], [{57=>nil, 66=>nil}, 66, "s:+r", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "s:+r", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "s:+r", false]], 49=>[[{40=>:enemy}, 40, "s:r", true], [{48=>:enemy}, 48, "s:r", true], [{50=>:enemy}, 50, "s:r", true], [{58=>:enemy}, 58, "s:+r", true], [{40=>nil}, 40, "s:r", false], [{40=>nil, 31=>:enemy}, 31, "s:r", true], [{40=>nil, 31=>nil}, 31, "s:r", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "s:r", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "s:r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:r", false], [{48=>nil}, 48, "s:r", false], [{48=>nil, 47=>:enemy}, 47, "s:r", true], [{48=>nil, 47=>nil}, 47, "s:r", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "s:r", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "s:r", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{50=>nil}, 50, "s:r", false], [{50=>nil, 51=>:enemy}, 51, "s:r", true], [{50=>nil, 51=>nil}, 51, "s:r", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "s:r", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "s:r", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 67=>:enemy}, 67, "s:+r", true], [{58=>nil, 67=>nil}, 67, "s:+r", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "s:+r", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "s:+r", false]], 50=>[[{41=>:enemy}, 41, "s:r", true], [{49=>:enemy}, 49, "s:r", true], [{51=>:enemy}, 51, "s:r", true], [{59=>:enemy}, 59, "s:+r", true], [{41=>nil}, 41, "s:r", false], [{41=>nil, 32=>:enemy}, 32, "s:r", true], [{41=>nil, 32=>nil}, 32, "s:r", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "s:r", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "s:r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:r", false], [{49=>nil}, 49, "s:r", false], [{49=>nil, 48=>:enemy}, 48, "s:r", true], [{49=>nil, 48=>nil}, 48, "s:r", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "s:r", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "s:r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{51=>nil}, 51, "s:r", false], [{51=>nil, 52=>:enemy}, 52, "s:r", true], [{51=>nil, 52=>nil}, 52, "s:r", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "s:r", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "s:r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 68=>:enemy}, 68, "s:+r", true], [{59=>nil, 68=>nil}, 68, "s:+r", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "s:+r", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "s:+r", false]], 51=>[[{42=>:enemy}, 42, "s:r", true], [{50=>:enemy}, 50, "s:r", true], [{52=>:enemy}, 52, "s:r", true], [{60=>:enemy}, 60, "s:+r", true], [{42=>nil}, 42, "s:r", false], [{42=>nil, 33=>:enemy}, 33, "s:r", true], [{42=>nil, 33=>nil}, 33, "s:r", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "s:r", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "s:r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:r", false], [{50=>nil}, 50, "s:r", false], [{50=>nil, 49=>:enemy}, 49, "s:r", true], [{50=>nil, 49=>nil}, 49, "s:r", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "s:r", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "s:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{52=>nil}, 52, "s:r", false], [{52=>nil, 53=>:enemy}, 53, "s:r", true], [{52=>nil, 53=>nil}, 53, "s:r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 69=>:enemy}, 69, "s:+r", true], [{60=>nil, 69=>nil}, 69, "s:+r", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "s:+r", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "s:+r", false]], 52=>[[{43=>:enemy}, 43, "s:r", true], [{51=>:enemy}, 51, "s:r", true], [{53=>:enemy}, 53, "s:r", true], [{61=>:enemy}, 61, "s:+r", true], [{43=>nil}, 43, "s:r", false], [{43=>nil, 34=>:enemy}, 34, "s:r", true], [{43=>nil, 34=>nil}, 34, "s:r", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "s:r", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "s:r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:r", false], [{51=>nil}, 51, "s:r", false], [{51=>nil, 50=>:enemy}, 50, "s:r", true], [{51=>nil, 50=>nil}, 50, "s:r", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "s:r", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "s:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "s:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "s:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{53=>nil}, 53, "s:r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 70=>:enemy}, 70, "s:+r", true], [{61=>nil, 70=>nil}, 70, "s:+r", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "s:+r", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "s:+r", false]], 53=>[[{44=>:enemy}, 44, "s:r", true], [{52=>:enemy}, 52, "s:r", true], [{62=>:enemy}, 62, "s:+r", true], [{44=>nil}, 44, "s:r", false], [{44=>nil, 35=>:enemy}, 35, "s:r", true], [{44=>nil, 35=>nil}, 35, "s:r", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "s:r", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "s:r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:r", false], [{52=>nil}, 52, "s:r", false], [{52=>nil, 51=>:enemy}, 51, "s:r", true], [{52=>nil, 51=>nil}, 51, "s:r", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "s:r", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "s:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "s:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "s:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "s:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "s:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "s:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "s:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "s:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "s:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "s:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "s:r", false], [{62=>nil}, 62, "s:+r", false], [{62=>nil, 71=>:enemy}, 71, "s:+r", true], [{62=>nil, 71=>nil}, 71, "s:+r", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "s:+r", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "s:+r", false]], 54=>[[{45=>:enemy}, 45, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{63=>:enemy}, 63, "s:+r", true], [{45=>nil}, 45, "s:+r", false], [{45=>nil, 36=>:enemy}, 36, "s:+r", true], [{45=>nil, 36=>nil}, 36, "s:+r", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 56=>:enemy}, 56, "s:+r", true], [{55=>nil, 56=>nil}, 56, "s:+r", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{63=>nil}, 63, "s:+r", false], [{63=>nil, 72=>:enemy}, 72, "s:+r", true], [{63=>nil, 72=>nil}, 72, "s:+r", false]], 55=>[[{46=>:enemy}, 46, "s:+r", true], [{54=>:enemy}, 54, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{46=>nil}, 46, "s:+r", false], [{46=>nil, 37=>:enemy}, 37, "s:+r", true], [{46=>nil, 37=>nil}, 37, "s:+r", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{54=>nil}, 54, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 57=>:enemy}, 57, "s:+r", true], [{56=>nil, 57=>nil}, 57, "s:+r", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 73=>:enemy}, 73, "s:+r", true], [{64=>nil, 73=>nil}, 73, "s:+r", false]], 56=>[[{47=>:enemy}, 47, "s:+r", true], [{55=>:enemy}, 55, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{47=>nil}, 47, "s:+r", false], [{47=>nil, 38=>:enemy}, 38, "s:+r", true], [{47=>nil, 38=>nil}, 38, "s:+r", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 54=>:enemy}, 54, "s:+r", true], [{55=>nil, 54=>nil}, 54, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 58=>:enemy}, 58, "s:+r", true], [{57=>nil, 58=>nil}, 58, "s:+r", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 74=>:enemy}, 74, "s:+r", true], [{65=>nil, 74=>nil}, 74, "s:+r", false]], 57=>[[{48=>:enemy}, 48, "s:+r", true], [{56=>:enemy}, 56, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{48=>nil}, 48, "s:+r", false], [{48=>nil, 39=>:enemy}, 39, "s:+r", true], [{48=>nil, 39=>nil}, 39, "s:+r", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 55=>:enemy}, 55, "s:+r", true], [{56=>nil, 55=>nil}, 55, "s:+r", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 59=>:enemy}, 59, "s:+r", true], [{58=>nil, 59=>nil}, 59, "s:+r", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "s:+r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 75=>:enemy}, 75, "s:+r", true], [{66=>nil, 75=>nil}, 75, "s:+r", false]], 58=>[[{49=>:enemy}, 49, "s:+r", true], [{57=>:enemy}, 57, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{49=>nil}, 49, "s:+r", false], [{49=>nil, 40=>:enemy}, 40, "s:+r", true], [{49=>nil, 40=>nil}, 40, "s:+r", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 56=>:enemy}, 56, "s:+r", true], [{57=>nil, 56=>nil}, 56, "s:+r", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 60=>:enemy}, 60, "s:+r", true], [{59=>nil, 60=>nil}, 60, "s:+r", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "s:+r", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "s:+r", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 76=>:enemy}, 76, "s:+r", true], [{67=>nil, 76=>nil}, 76, "s:+r", false]], 59=>[[{50=>:enemy}, 50, "s:+r", true], [{58=>:enemy}, 58, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{50=>nil}, 50, "s:+r", false], [{50=>nil, 41=>:enemy}, 41, "s:+r", true], [{50=>nil, 41=>nil}, 41, "s:+r", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 57=>:enemy}, 57, "s:+r", true], [{58=>nil, 57=>nil}, 57, "s:+r", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 61=>:enemy}, 61, "s:+r", true], [{60=>nil, 61=>nil}, 61, "s:+r", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "s:+r", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 77=>:enemy}, 77, "s:+r", true], [{68=>nil, 77=>nil}, 77, "s:+r", false]], 60=>[[{51=>:enemy}, 51, "s:+r", true], [{59=>:enemy}, 59, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{51=>nil}, 51, "s:+r", false], [{51=>nil, 42=>:enemy}, 42, "s:+r", true], [{51=>nil, 42=>nil}, 42, "s:+r", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 58=>:enemy}, 58, "s:+r", true], [{59=>nil, 58=>nil}, 58, "s:+r", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 62=>:enemy}, 62, "s:+r", true], [{61=>nil, 62=>nil}, 62, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 78=>:enemy}, 78, "s:+r", true], [{69=>nil, 78=>nil}, 78, "s:+r", false]], 61=>[[{52=>:enemy}, 52, "s:+r", true], [{60=>:enemy}, 60, "s:+r", true], [{62=>:enemy}, 62, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{52=>nil}, 52, "s:+r", false], [{52=>nil, 43=>:enemy}, 43, "s:+r", true], [{52=>nil, 43=>nil}, 43, "s:+r", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 59=>:enemy}, 59, "s:+r", true], [{60=>nil, 59=>nil}, 59, "s:+r", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{62=>nil}, 62, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 79=>:enemy}, 79, "s:+r", true], [{70=>nil, 79=>nil}, 79, "s:+r", false]], 62=>[[{53=>:enemy}, 53, "s:+r", true], [{61=>:enemy}, 61, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{53=>nil}, 53, "s:+r", false], [{53=>nil, 44=>:enemy}, 44, "s:+r", true], [{53=>nil, 44=>nil}, 44, "s:+r", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 60=>:enemy}, 60, "s:+r", true], [{61=>nil, 60=>nil}, 60, "s:+r", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "s:+r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "s:+r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{71=>nil, 80=>:enemy}, 80, "s:+r", true], [{71=>nil, 80=>nil}, 80, "s:+r", false]], 63=>[[{54=>:enemy}, 54, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{72=>:enemy}, 72, "s:+r", true], [{54=>nil}, 54, "s:+r", false], [{54=>nil, 45=>:enemy}, 45, "s:+r", true], [{54=>nil, 45=>nil}, 45, "s:+r", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 65=>:enemy}, 65, "s:+r", true], [{64=>nil, 65=>nil}, 65, "s:+r", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{72=>nil}, 72, "s:+r", false]], 64=>[[{55=>:enemy}, 55, "s:+r", true], [{63=>:enemy}, 63, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{55=>nil}, 55, "s:+r", false], [{55=>nil, 46=>:enemy}, 46, "s:+r", true], [{55=>nil, 46=>nil}, 46, "s:+r", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{63=>nil}, 63, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 66=>:enemy}, 66, "s:+r", true], [{65=>nil, 66=>nil}, 66, "s:+r", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{73=>nil}, 73, "s:+r", false]], 65=>[[{56=>:enemy}, 56, "s:+r", true], [{64=>:enemy}, 64, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{56=>nil}, 56, "s:+r", false], [{56=>nil, 47=>:enemy}, 47, "s:+r", true], [{56=>nil, 47=>nil}, 47, "s:+r", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 63=>:enemy}, 63, "s:+r", true], [{64=>nil, 63=>nil}, 63, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 67=>:enemy}, 67, "s:+r", true], [{66=>nil, 67=>nil}, 67, "s:+r", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{74=>nil}, 74, "s:+r", false]], 66=>[[{57=>:enemy}, 57, "s:+r", true], [{65=>:enemy}, 65, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{57=>nil}, 57, "s:+r", false], [{57=>nil, 48=>:enemy}, 48, "s:+r", true], [{57=>nil, 48=>nil}, 48, "s:+r", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 64=>:enemy}, 64, "s:+r", true], [{65=>nil, 64=>nil}, 64, "s:+r", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 68=>:enemy}, 68, "s:+r", true], [{67=>nil, 68=>nil}, 68, "s:+r", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "s:+r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{75=>nil}, 75, "s:+r", false]], 67=>[[{58=>:enemy}, 58, "s:+r", true], [{66=>:enemy}, 66, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{58=>nil}, 58, "s:+r", false], [{58=>nil, 49=>:enemy}, 49, "s:+r", true], [{58=>nil, 49=>nil}, 49, "s:+r", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 65=>:enemy}, 65, "s:+r", true], [{66=>nil, 65=>nil}, 65, "s:+r", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 69=>:enemy}, 69, "s:+r", true], [{68=>nil, 69=>nil}, 69, "s:+r", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "s:+r", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "s:+r", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{76=>nil}, 76, "s:+r", false]], 68=>[[{59=>:enemy}, 59, "s:+r", true], [{67=>:enemy}, 67, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{59=>nil}, 59, "s:+r", false], [{59=>nil, 50=>:enemy}, 50, "s:+r", true], [{59=>nil, 50=>nil}, 50, "s:+r", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 66=>:enemy}, 66, "s:+r", true], [{67=>nil, 66=>nil}, 66, "s:+r", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 70=>:enemy}, 70, "s:+r", true], [{69=>nil, 70=>nil}, 70, "s:+r", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "s:+r", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "s:+r", false], [{77=>nil}, 77, "s:+r", false]], 69=>[[{60=>:enemy}, 60, "s:+r", true], [{68=>:enemy}, 68, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{60=>nil}, 60, "s:+r", false], [{60=>nil, 51=>:enemy}, 51, "s:+r", true], [{60=>nil, 51=>nil}, 51, "s:+r", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 67=>:enemy}, 67, "s:+r", true], [{68=>nil, 67=>nil}, 67, "s:+r", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 71=>:enemy}, 71, "s:+r", true], [{70=>nil, 71=>nil}, 71, "s:+r", false], [{78=>nil}, 78, "s:+r", false]], 70=>[[{61=>:enemy}, 61, "s:+r", true], [{69=>:enemy}, 69, "s:+r", true], [{71=>:enemy}, 71, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{61=>nil}, 61, "s:+r", false], [{61=>nil, 52=>:enemy}, 52, "s:+r", true], [{61=>nil, 52=>nil}, 52, "s:+r", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 68=>:enemy}, 68, "s:+r", true], [{69=>nil, 68=>nil}, 68, "s:+r", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{71=>nil}, 71, "s:+r", false], [{79=>nil}, 79, "s:+r", false]], 71=>[[{62=>:enemy}, 62, "s:+r", true], [{70=>:enemy}, 70, "s:+r", true], [{80=>:enemy}, 80, "s:+r", true], [{62=>nil}, 62, "s:+r", false], [{62=>nil, 53=>:enemy}, 53, "s:+r", true], [{62=>nil, 53=>nil}, 53, "s:+r", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 69=>:enemy}, 69, "s:+r", true], [{70=>nil, 69=>nil}, 69, "s:+r", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "s:+r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "s:+r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "s:+r", false], [{80=>nil}, 80, "s:+r", false]], 72=>[[{63=>:enemy}, 63, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{63=>nil}, 63, "s:+r", false], [{63=>nil, 54=>:enemy}, 54, "s:+r", true], [{63=>nil, 54=>nil}, 54, "s:+r", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "s:+r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "s:+r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{73=>nil, 74=>:enemy}, 74, "s:+r", true], [{73=>nil, 74=>nil}, 74, "s:+r", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 73=>[[{64=>:enemy}, 64, "s:+r", true], [{72=>:enemy}, 72, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{64=>nil}, 64, "s:+r", false], [{64=>nil, 55=>:enemy}, 55, "s:+r", true], [{64=>nil, 55=>nil}, 55, "s:+r", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "s:+r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "s:+r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "s:+r", false], [{72=>nil}, 72, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{74=>nil, 75=>:enemy}, 75, "s:+r", true], [{74=>nil, 75=>nil}, 75, "s:+r", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 74=>[[{65=>:enemy}, 65, "s:+r", true], [{73=>:enemy}, 73, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{65=>nil}, 65, "s:+r", false], [{65=>nil, 56=>:enemy}, 56, "s:+r", true], [{65=>nil, 56=>nil}, 56, "s:+r", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "s:+r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "s:+r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "s:+r", false], [{73=>nil}, 73, "s:+r", false], [{73=>nil, 72=>:enemy}, 72, "s:+r", true], [{73=>nil, 72=>nil}, 72, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{75=>nil, 76=>:enemy}, 76, "s:+r", true], [{75=>nil, 76=>nil}, 76, "s:+r", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 75=>[[{66=>:enemy}, 66, "s:+r", true], [{74=>:enemy}, 74, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{66=>nil}, 66, "s:+r", false], [{66=>nil, 57=>:enemy}, 57, "s:+r", true], [{66=>nil, 57=>nil}, 57, "s:+r", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "s:+r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "s:+r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "s:+r", false], [{74=>nil}, 74, "s:+r", false], [{74=>nil, 73=>:enemy}, 73, "s:+r", true], [{74=>nil, 73=>nil}, 73, "s:+r", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{76=>nil, 77=>:enemy}, 77, "s:+r", true], [{76=>nil, 77=>nil}, 77, "s:+r", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "s:+r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 76=>[[{67=>:enemy}, 67, "s:+r", true], [{75=>:enemy}, 75, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{67=>nil}, 67, "s:+r", false], [{67=>nil, 58=>:enemy}, 58, "s:+r", true], [{67=>nil, 58=>nil}, 58, "s:+r", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "s:+r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "s:+r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "s:+r", false], [{75=>nil}, 75, "s:+r", false], [{75=>nil, 74=>:enemy}, 74, "s:+r", true], [{75=>nil, 74=>nil}, 74, "s:+r", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{77=>nil, 78=>:enemy}, 78, "s:+r", true], [{77=>nil, 78=>nil}, 78, "s:+r", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "s:+r", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "s:+r", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 77=>[[{68=>:enemy}, 68, "s:+r", true], [{76=>:enemy}, 76, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{68=>nil}, 68, "s:+r", false], [{68=>nil, 59=>:enemy}, 59, "s:+r", true], [{68=>nil, 59=>nil}, 59, "s:+r", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "s:+r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "s:+r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "s:+r", false], [{76=>nil}, 76, "s:+r", false], [{76=>nil, 75=>:enemy}, 75, "s:+r", true], [{76=>nil, 75=>nil}, 75, "s:+r", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{78=>nil, 79=>:enemy}, 79, "s:+r", true], [{78=>nil, 79=>nil}, 79, "s:+r", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "s:+r", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "s:+r", false]], 78=>[[{69=>:enemy}, 69, "s:+r", true], [{77=>:enemy}, 77, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{69=>nil}, 69, "s:+r", false], [{69=>nil, 60=>:enemy}, 60, "s:+r", true], [{69=>nil, 60=>nil}, 60, "s:+r", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "s:+r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "s:+r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "s:+r", false], [{77=>nil}, 77, "s:+r", false], [{77=>nil, 76=>:enemy}, 76, "s:+r", true], [{77=>nil, 76=>nil}, 76, "s:+r", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{79=>nil, 80=>:enemy}, 80, "s:+r", true], [{79=>nil, 80=>nil}, 80, "s:+r", false]], 79=>[[{70=>:enemy}, 70, "s:+r", true], [{78=>:enemy}, 78, "s:+r", true], [{80=>:enemy}, 80, "s:+r", true], [{70=>nil}, 70, "s:+r", false], [{70=>nil, 61=>:enemy}, 61, "s:+r", true], [{70=>nil, 61=>nil}, 61, "s:+r", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "s:+r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "s:+r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "s:+r", false], [{78=>nil}, 78, "s:+r", false], [{78=>nil, 77=>:enemy}, 77, "s:+r", true], [{78=>nil, 77=>nil}, 77, "s:+r", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false], [{80=>nil}, 80, "s:+r", false]], 80=>[[{71=>:enemy}, 71, "s:+r", true], [{79=>:enemy}, 79, "s:+r", true], [{71=>nil}, 71, "s:+r", false], [{71=>nil, 62=>:enemy}, 62, "s:+r", true], [{71=>nil, 62=>nil}, 62, "s:+r", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "s:+r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "s:+r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "s:+r", false], [{79=>nil}, 79, "s:+r", false], [{79=>nil, 78=>:enemy}, 78, "s:+r", true], [{79=>nil, 78=>nil}, 78, "s:+r", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "s:+r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "s:+r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "s:+r", false]], nil=>[[{0=>nil}, 0, "s:r", false], [{1=>nil}, 1, "s:r", false], [{2=>nil}, 2, "s:r", false], [{3=>nil}, 3, "s:r", false], [{4=>nil}, 4, "s:r", false], [{5=>nil}, 5, "s:r", false], [{6=>nil}, 6, "s:r", false], [{7=>nil}, 7, "s:r", false], [{8=>nil}, 8, "s:r", false], [{9=>nil}, 9, "s:r", false], [{10=>nil}, 10, "s:r", false], [{11=>nil}, 11, "s:r", false], [{12=>nil}, 12, "s:r", false], [{13=>nil}, 13, "s:r", false], [{14=>nil}, 14, "s:r", false], [{15=>nil}, 15, "s:r", false], [{16=>nil}, 16, "s:r", false], [{17=>nil}, 17, "s:r", false], [{18=>nil}, 18, "s:r", false], [{19=>nil}, 19, "s:r", false], [{20=>nil}, 20, "s:r", false], [{21=>nil}, 21, "s:r", false], [{22=>nil}, 22, "s:r", false], [{23=>nil}, 23, "s:r", false], [{24=>nil}, 24, "s:r", false], [{25=>nil}, 25, "s:r", false], [{26=>nil}, 26, "s:r", false], [{27=>nil}, 27, "s:r", false], [{28=>nil}, 28, "s:r", false], [{29=>nil}, 29, "s:r", false], [{30=>nil}, 30, "s:r", false], [{31=>nil}, 31, "s:r", false], [{32=>nil}, 32, "s:r", false], [{33=>nil}, 33, "s:r", false], [{34=>nil}, 34, "s:r", false], [{35=>nil}, 35, "s:r", false], [{36=>nil}, 36, "s:r", false], [{37=>nil}, 37, "s:r", false], [{38=>nil}, 38, "s:r", false], [{39=>nil}, 39, "s:r", false], [{40=>nil}, 40, "s:r", false], [{41=>nil}, 41, "s:r", false], [{42=>nil}, 42, "s:r", false], [{43=>nil}, 43, "s:r", false], [{44=>nil}, 44, "s:r", false], [{45=>nil}, 45, "s:r", false], [{46=>nil}, 46, "s:r", false], [{47=>nil}, 47, "s:r", false], [{48=>nil}, 48, "s:r", false], [{49=>nil}, 49, "s:r", false], [{50=>nil}, 50, "s:r", false], [{51=>nil}, 51, "s:r", false], [{52=>nil}, 52, "s:r", false], [{53=>nil}, 53, "s:r", false], [{54=>nil}, 54, "s:r", false], [{55=>nil}, 55, "s:r", false], [{56=>nil}, 56, "s:r", false], [{57=>nil}, 57, "s:r", false], [{58=>nil}, 58, "s:r", false], [{59=>nil}, 59, "s:r", false], [{60=>nil}, 60, "s:r", false], [{61=>nil}, 61, "s:r", false], [{62=>nil}, 62, "s:r", false], [{63=>nil}, 63, "s:r", false], [{64=>nil}, 64, "s:r", false], [{65=>nil}, 65, "s:r", false], [{66=>nil}, 66, "s:r", false], [{67=>nil}, 67, "s:r", false], [{68=>nil}, 68, "s:r", false], [{69=>nil}, 69, "s:r", false], [{70=>nil}, 70, "s:r", false], [{71=>nil}, 71, "s:r", false], [{72=>nil}, 72, "s:r", false], [{73=>nil}, 73, "s:r", false], [{74=>nil}, 74, "s:r", false], [{75=>nil}, 75, "s:r", false], [{76=>nil}, 76, "s:r", false], [{77=>nil}, 77, "s:r", false], [{78=>nil}, 78, "s:r", false], [{79=>nil}, 79, "s:r", false], [{80=>nil}, 80, "s:r", false]]}, "s:s"=>{0=>[[{9=>:enemy}, 9, "s:s", true], [{10=>:enemy}, 10, "s:s", true], [{9=>nil}, 9, "s:s", false], [{10=>nil}, 10, "s:s", false]], 1=>[[{9=>:enemy}, 9, "s:s", true], [{10=>:enemy}, 10, "s:s", true], [{11=>:enemy}, 11, "s:s", true], [{9=>nil}, 9, "s:s", false], [{10=>nil}, 10, "s:s", false], [{11=>nil}, 11, "s:s", false]], 2=>[[{10=>:enemy}, 10, "s:s", true], [{11=>:enemy}, 11, "s:s", true], [{12=>:enemy}, 12, "s:s", true], [{10=>nil}, 10, "s:s", false], [{11=>nil}, 11, "s:s", false], [{12=>nil}, 12, "s:s", false]], 3=>[[{11=>:enemy}, 11, "s:s", true], [{12=>:enemy}, 12, "s:s", true], [{13=>:enemy}, 13, "s:s", true], [{11=>nil}, 11, "s:s", false], [{12=>nil}, 12, "s:s", false], [{13=>nil}, 13, "s:s", false]], 4=>[[{12=>:enemy}, 12, "s:s", true], [{13=>:enemy}, 13, "s:s", true], [{14=>:enemy}, 14, "s:s", true], [{12=>nil}, 12, "s:s", false], [{13=>nil}, 13, "s:s", false], [{14=>nil}, 14, "s:s", false]], 5=>[[{13=>:enemy}, 13, "s:s", true], [{14=>:enemy}, 14, "s:s", true], [{15=>:enemy}, 15, "s:s", true], [{13=>nil}, 13, "s:s", false], [{14=>nil}, 14, "s:s", false], [{15=>nil}, 15, "s:s", false]], 6=>[[{14=>:enemy}, 14, "s:s", true], [{15=>:enemy}, 15, "s:s", true], [{16=>:enemy}, 16, "s:s", true], [{14=>nil}, 14, "s:s", false], [{15=>nil}, 15, "s:s", false], [{16=>nil}, 16, "s:s", false]], 7=>[[{15=>:enemy}, 15, "s:s", true], [{16=>:enemy}, 16, "s:s", true], [{17=>:enemy}, 17, "s:s", true], [{15=>nil}, 15, "s:s", false], [{16=>nil}, 16, "s:s", false], [{17=>nil}, 17, "s:s", false]], 8=>[[{16=>:enemy}, 16, "s:s", true], [{17=>:enemy}, 17, "s:s", true], [{16=>nil}, 16, "s:s", false], [{17=>nil}, 17, "s:s", false]], 9=>[[{1=>:enemy}, 1, "s:s", true], [{18=>:enemy}, 18, "s:s", true], [{19=>:enemy}, 19, "s:s", true], [{1=>nil}, 1, "s:s", false], [{18=>nil}, 18, "s:s", false], [{19=>nil}, 19, "s:s", false]], 10=>[[{0=>:enemy}, 0, "s:s", true], [{2=>:enemy}, 2, "s:s", true], [{18=>:enemy}, 18, "s:s", true], [{19=>:enemy}, 19, "s:s", true], [{20=>:enemy}, 20, "s:s", true], [{0=>nil}, 0, "s:s", false], [{2=>nil}, 2, "s:s", false], [{18=>nil}, 18, "s:s", false], [{19=>nil}, 19, "s:s", false], [{20=>nil}, 20, "s:s", false]], 11=>[[{1=>:enemy}, 1, "s:s", true], [{3=>:enemy}, 3, "s:s", true], [{19=>:enemy}, 19, "s:s", true], [{20=>:enemy}, 20, "s:s", true], [{21=>:enemy}, 21, "s:s", true], [{1=>nil}, 1, "s:s", false], [{3=>nil}, 3, "s:s", false], [{19=>nil}, 19, "s:s", false], [{20=>nil}, 20, "s:s", false], [{21=>nil}, 21, "s:s", false]], 12=>[[{2=>:enemy}, 2, "s:s", true], [{4=>:enemy}, 4, "s:s", true], [{20=>:enemy}, 20, "s:s", true], [{21=>:enemy}, 21, "s:s", true], [{22=>:enemy}, 22, "s:s", true], [{2=>nil}, 2, "s:s", false], [{4=>nil}, 4, "s:s", false], [{20=>nil}, 20, "s:s", false], [{21=>nil}, 21, "s:s", false], [{22=>nil}, 22, "s:s", false]], 13=>[[{3=>:enemy}, 3, "s:s", true], [{5=>:enemy}, 5, "s:s", true], [{21=>:enemy}, 21, "s:s", true], [{22=>:enemy}, 22, "s:s", true], [{23=>:enemy}, 23, "s:s", true], [{3=>nil}, 3, "s:s", false], [{5=>nil}, 5, "s:s", false], [{21=>nil}, 21, "s:s", false], [{22=>nil}, 22, "s:s", false], [{23=>nil}, 23, "s:s", false]], 14=>[[{4=>:enemy}, 4, "s:s", true], [{6=>:enemy}, 6, "s:s", true], [{22=>:enemy}, 22, "s:s", true], [{23=>:enemy}, 23, "s:s", true], [{24=>:enemy}, 24, "s:s", true], [{4=>nil}, 4, "s:s", false], [{6=>nil}, 6, "s:s", false], [{22=>nil}, 22, "s:s", false], [{23=>nil}, 23, "s:s", false], [{24=>nil}, 24, "s:s", false]], 15=>[[{5=>:enemy}, 5, "s:s", true], [{7=>:enemy}, 7, "s:s", true], [{23=>:enemy}, 23, "s:s", true], [{24=>:enemy}, 24, "s:s", true], [{25=>:enemy}, 25, "s:s", true], [{5=>nil}, 5, "s:s", false], [{7=>nil}, 7, "s:s", false], [{23=>nil}, 23, "s:s", false], [{24=>nil}, 24, "s:s", false], [{25=>nil}, 25, "s:s", false]], 16=>[[{6=>:enemy}, 6, "s:s", true], [{8=>:enemy}, 8, "s:s", true], [{24=>:enemy}, 24, "s:s", true], [{25=>:enemy}, 25, "s:s", true], [{26=>:enemy}, 26, "s:s", true], [{6=>nil}, 6, "s:s", false], [{8=>nil}, 8, "s:s", false], [{24=>nil}, 24, "s:s", false], [{25=>nil}, 25, "s:s", false], [{26=>nil}, 26, "s:s", false]], 17=>[[{7=>:enemy}, 7, "s:s", true], [{25=>:enemy}, 25, "s:s", true], [{26=>:enemy}, 26, "s:s", true], [{7=>nil}, 7, "s:s", false], [{25=>nil}, 25, "s:s", false], [{26=>nil}, 26, "s:s", false]], 18=>[[{10=>:enemy}, 10, "s:s", true], [{27=>:enemy}, 27, "s:s", true], [{28=>:enemy}, 28, "s:s", true], [{10=>nil}, 10, "s:s", false], [{27=>nil}, 27, "s:s", false], [{28=>nil}, 28, "s:s", false]], 19=>[[{9=>:enemy}, 9, "s:s", true], [{11=>:enemy}, 11, "s:s", true], [{27=>:enemy}, 27, "s:s", true], [{28=>:enemy}, 28, "s:s", true], [{29=>:enemy}, 29, "s:s", true], [{9=>nil}, 9, "s:s", false], [{11=>nil}, 11, "s:s", false], [{27=>nil}, 27, "s:s", false], [{28=>nil}, 28, "s:s", false], [{29=>nil}, 29, "s:s", false]], 20=>[[{10=>:enemy}, 10, "s:s", true], [{12=>:enemy}, 12, "s:s", true], [{28=>:enemy}, 28, "s:s", true], [{29=>:enemy}, 29, "s:s", true], [{30=>:enemy}, 30, "s:s", true], [{10=>nil}, 10, "s:s", false], [{12=>nil}, 12, "s:s", false], [{28=>nil}, 28, "s:s", false], [{29=>nil}, 29, "s:s", false], [{30=>nil}, 30, "s:s", false]], 21=>[[{11=>:enemy}, 11, "s:s", true], [{13=>:enemy}, 13, "s:s", true], [{29=>:enemy}, 29, "s:s", true], [{30=>:enemy}, 30, "s:s", true], [{31=>:enemy}, 31, "s:s", true], [{11=>nil}, 11, "s:s", false], [{13=>nil}, 13, "s:s", false], [{29=>nil}, 29, "s:s", false], [{30=>nil}, 30, "s:s", false], [{31=>nil}, 31, "s:s", false]], 22=>[[{12=>:enemy}, 12, "s:s", true], [{14=>:enemy}, 14, "s:s", true], [{30=>:enemy}, 30, "s:s", true], [{31=>:enemy}, 31, "s:s", true], [{32=>:enemy}, 32, "s:s", true], [{12=>nil}, 12, "s:s", false], [{14=>nil}, 14, "s:s", false], [{30=>nil}, 30, "s:s", false], [{31=>nil}, 31, "s:s", false], [{32=>nil}, 32, "s:s", false]], 23=>[[{13=>:enemy}, 13, "s:s", true], [{15=>:enemy}, 15, "s:s", true], [{31=>:enemy}, 31, "s:s", true], [{32=>:enemy}, 32, "s:s", true], [{33=>:enemy}, 33, "s:s", true], [{13=>nil}, 13, "s:s", false], [{15=>nil}, 15, "s:s", false], [{31=>nil}, 31, "s:s", false], [{32=>nil}, 32, "s:s", false], [{33=>nil}, 33, "s:s", false]], 24=>[[{14=>:enemy}, 14, "s:s", true], [{16=>:enemy}, 16, "s:s", true], [{32=>:enemy}, 32, "s:s", true], [{33=>:enemy}, 33, "s:s", true], [{34=>:enemy}, 34, "s:s", true], [{14=>nil}, 14, "s:s", false], [{16=>nil}, 16, "s:s", false], [{32=>nil}, 32, "s:s", false], [{33=>nil}, 33, "s:s", false], [{34=>nil}, 34, "s:s", false]], 25=>[[{15=>:enemy}, 15, "s:s", true], [{17=>:enemy}, 17, "s:s", true], [{33=>:enemy}, 33, "s:s", true], [{34=>:enemy}, 34, "s:s", true], [{35=>:enemy}, 35, "s:s", true], [{15=>nil}, 15, "s:s", false], [{17=>nil}, 17, "s:s", false], [{33=>nil}, 33, "s:s", false], [{34=>nil}, 34, "s:s", false], [{35=>nil}, 35, "s:s", false]], 26=>[[{16=>:enemy}, 16, "s:s", true], [{34=>:enemy}, 34, "s:s", true], [{35=>:enemy}, 35, "s:s", true], [{16=>nil}, 16, "s:s", false], [{34=>nil}, 34, "s:s", false], [{35=>nil}, 35, "s:s", false]], 27=>[[{19=>:enemy}, 19, "s:s", true], [{36=>:enemy}, 36, "s:s", true], [{37=>:enemy}, 37, "s:s", true], [{19=>nil}, 19, "s:s", false], [{36=>nil}, 36, "s:s", false], [{37=>nil}, 37, "s:s", false]], 28=>[[{18=>:enemy}, 18, "s:s", true], [{20=>:enemy}, 20, "s:s", true], [{36=>:enemy}, 36, "s:s", true], [{37=>:enemy}, 37, "s:s", true], [{38=>:enemy}, 38, "s:s", true], [{18=>nil}, 18, "s:s", false], [{20=>nil}, 20, "s:s", false], [{36=>nil}, 36, "s:s", false], [{37=>nil}, 37, "s:s", false], [{38=>nil}, 38, "s:s", false]], 29=>[[{19=>:enemy}, 19, "s:s", true], [{21=>:enemy}, 21, "s:s", true], [{37=>:enemy}, 37, "s:s", true], [{38=>:enemy}, 38, "s:s", true], [{39=>:enemy}, 39, "s:s", true], [{19=>nil}, 19, "s:s", false], [{21=>nil}, 21, "s:s", false], [{37=>nil}, 37, "s:s", false], [{38=>nil}, 38, "s:s", false], [{39=>nil}, 39, "s:s", false]], 30=>[[{20=>:enemy}, 20, "s:s", true], [{22=>:enemy}, 22, "s:s", true], [{38=>:enemy}, 38, "s:s", true], [{39=>:enemy}, 39, "s:s", true], [{40=>:enemy}, 40, "s:s", true], [{20=>nil}, 20, "s:s", false], [{22=>nil}, 22, "s:s", false], [{38=>nil}, 38, "s:s", false], [{39=>nil}, 39, "s:s", false], [{40=>nil}, 40, "s:s", false]], 31=>[[{21=>:enemy}, 21, "s:s", true], [{23=>:enemy}, 23, "s:s", true], [{39=>:enemy}, 39, "s:s", true], [{40=>:enemy}, 40, "s:s", true], [{41=>:enemy}, 41, "s:s", true], [{21=>nil}, 21, "s:s", false], [{23=>nil}, 23, "s:s", false], [{39=>nil}, 39, "s:s", false], [{40=>nil}, 40, "s:s", false], [{41=>nil}, 41, "s:s", false]], 32=>[[{22=>:enemy}, 22, "s:s", true], [{24=>:enemy}, 24, "s:s", true], [{40=>:enemy}, 40, "s:s", true], [{41=>:enemy}, 41, "s:s", true], [{42=>:enemy}, 42, "s:s", true], [{22=>nil}, 22, "s:s", false], [{24=>nil}, 24, "s:s", false], [{40=>nil}, 40, "s:s", false], [{41=>nil}, 41, "s:s", false], [{42=>nil}, 42, "s:s", false]], 33=>[[{23=>:enemy}, 23, "s:s", true], [{25=>:enemy}, 25, "s:s", true], [{41=>:enemy}, 41, "s:s", true], [{42=>:enemy}, 42, "s:s", true], [{43=>:enemy}, 43, "s:s", true], [{23=>nil}, 23, "s:s", false], [{25=>nil}, 25, "s:s", false], [{41=>nil}, 41, "s:s", false], [{42=>nil}, 42, "s:s", false], [{43=>nil}, 43, "s:s", false]], 34=>[[{24=>:enemy}, 24, "s:s", true], [{26=>:enemy}, 26, "s:s", true], [{42=>:enemy}, 42, "s:s", true], [{43=>:enemy}, 43, "s:s", true], [{44=>:enemy}, 44, "s:s", true], [{24=>nil}, 24, "s:s", false], [{26=>nil}, 26, "s:s", false], [{42=>nil}, 42, "s:s", false], [{43=>nil}, 43, "s:s", false], [{44=>nil}, 44, "s:s", false]], 35=>[[{25=>:enemy}, 25, "s:s", true], [{43=>:enemy}, 43, "s:s", true], [{44=>:enemy}, 44, "s:s", true], [{25=>nil}, 25, "s:s", false], [{43=>nil}, 43, "s:s", false], [{44=>nil}, 44, "s:s", false]], 36=>[[{28=>:enemy}, 28, "s:s", true], [{45=>:enemy}, 45, "s:s", true], [{46=>:enemy}, 46, "s:s", true], [{28=>nil}, 28, "s:s", false], [{45=>nil}, 45, "s:s", false], [{46=>nil}, 46, "s:s", false]], 37=>[[{27=>:enemy}, 27, "s:s", true], [{29=>:enemy}, 29, "s:s", true], [{45=>:enemy}, 45, "s:s", true], [{46=>:enemy}, 46, "s:s", true], [{47=>:enemy}, 47, "s:s", true], [{27=>nil}, 27, "s:s", false], [{29=>nil}, 29, "s:s", false], [{45=>nil}, 45, "s:s", false], [{46=>nil}, 46, "s:s", false], [{47=>nil}, 47, "s:s", false]], 38=>[[{28=>:enemy}, 28, "s:s", true], [{30=>:enemy}, 30, "s:s", true], [{46=>:enemy}, 46, "s:s", true], [{47=>:enemy}, 47, "s:s", true], [{48=>:enemy}, 48, "s:s", true], [{28=>nil}, 28, "s:s", false], [{30=>nil}, 30, "s:s", false], [{46=>nil}, 46, "s:s", false], [{47=>nil}, 47, "s:s", false], [{48=>nil}, 48, "s:s", false]], 39=>[[{29=>:enemy}, 29, "s:s", true], [{31=>:enemy}, 31, "s:s", true], [{47=>:enemy}, 47, "s:s", true], [{48=>:enemy}, 48, "s:s", true], [{49=>:enemy}, 49, "s:s", true], [{29=>nil}, 29, "s:s", false], [{31=>nil}, 31, "s:s", false], [{47=>nil}, 47, "s:s", false], [{48=>nil}, 48, "s:s", false], [{49=>nil}, 49, "s:s", false]], 40=>[[{30=>:enemy}, 30, "s:s", true], [{32=>:enemy}, 32, "s:s", true], [{48=>:enemy}, 48, "s:s", true], [{49=>:enemy}, 49, "s:s", true], [{50=>:enemy}, 50, "s:s", true], [{30=>nil}, 30, "s:s", false], [{32=>nil}, 32, "s:s", false], [{48=>nil}, 48, "s:s", false], [{49=>nil}, 49, "s:s", false], [{50=>nil}, 50, "s:s", false]], 41=>[[{31=>:enemy}, 31, "s:s", true], [{33=>:enemy}, 33, "s:s", true], [{49=>:enemy}, 49, "s:s", true], [{50=>:enemy}, 50, "s:s", true], [{51=>:enemy}, 51, "s:s", true], [{31=>nil}, 31, "s:s", false], [{33=>nil}, 33, "s:s", false], [{49=>nil}, 49, "s:s", false], [{50=>nil}, 50, "s:s", false], [{51=>nil}, 51, "s:s", false]], 42=>[[{32=>:enemy}, 32, "s:s", true], [{34=>:enemy}, 34, "s:s", true], [{50=>:enemy}, 50, "s:s", true], [{51=>:enemy}, 51, "s:s", true], [{52=>:enemy}, 52, "s:s", true], [{32=>nil}, 32, "s:s", false], [{34=>nil}, 34, "s:s", false], [{50=>nil}, 50, "s:s", false], [{51=>nil}, 51, "s:s", false], [{52=>nil}, 52, "s:s", false]], 43=>[[{33=>:enemy}, 33, "s:s", true], [{35=>:enemy}, 35, "s:s", true], [{51=>:enemy}, 51, "s:s", true], [{52=>:enemy}, 52, "s:s", true], [{53=>:enemy}, 53, "s:s", true], [{33=>nil}, 33, "s:s", false], [{35=>nil}, 35, "s:s", false], [{51=>nil}, 51, "s:s", false], [{52=>nil}, 52, "s:s", false], [{53=>nil}, 53, "s:s", false]], 44=>[[{34=>:enemy}, 34, "s:s", true], [{52=>:enemy}, 52, "s:s", true], [{53=>:enemy}, 53, "s:s", true], [{34=>nil}, 34, "s:s", false], [{52=>nil}, 52, "s:s", false], [{53=>nil}, 53, "s:s", false]], 45=>[[{37=>:enemy}, 37, "s:s", true], [{54=>:enemy}, 54, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{37=>nil}, 37, "s:s", false], [{54=>nil}, 54, "s:+s", false], [{55=>nil}, 55, "s:+s", false]], 46=>[[{36=>:enemy}, 36, "s:s", true], [{38=>:enemy}, 38, "s:s", true], [{54=>:enemy}, 54, "s:+s", true], [{55=>:enemy}, 55, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{36=>nil}, 36, "s:s", false], [{38=>nil}, 38, "s:s", false], [{54=>nil}, 54, "s:+s", false], [{55=>nil}, 55, "s:+s", false], [{56=>nil}, 56, "s:+s", false]], 47=>[[{37=>:enemy}, 37, "s:s", true], [{39=>:enemy}, 39, "s:s", true], [{55=>:enemy}, 55, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{37=>nil}, 37, "s:s", false], [{39=>nil}, 39, "s:s", false], [{55=>nil}, 55, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{57=>nil}, 57, "s:+s", false]], 48=>[[{38=>:enemy}, 38, "s:s", true], [{40=>:enemy}, 40, "s:s", true], [{56=>:enemy}, 56, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{38=>nil}, 38, "s:s", false], [{40=>nil}, 40, "s:s", false], [{56=>nil}, 56, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{58=>nil}, 58, "s:+s", false]], 49=>[[{39=>:enemy}, 39, "s:s", true], [{41=>:enemy}, 41, "s:s", true], [{57=>:enemy}, 57, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{39=>nil}, 39, "s:s", false], [{41=>nil}, 41, "s:s", false], [{57=>nil}, 57, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{59=>nil}, 59, "s:+s", false]], 50=>[[{40=>:enemy}, 40, "s:s", true], [{42=>:enemy}, 42, "s:s", true], [{58=>:enemy}, 58, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{40=>nil}, 40, "s:s", false], [{42=>nil}, 42, "s:s", false], [{58=>nil}, 58, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{60=>nil}, 60, "s:+s", false]], 51=>[[{41=>:enemy}, 41, "s:s", true], [{43=>:enemy}, 43, "s:s", true], [{59=>:enemy}, 59, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{41=>nil}, 41, "s:s", false], [{43=>nil}, 43, "s:s", false], [{59=>nil}, 59, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{61=>nil}, 61, "s:+s", false]], 52=>[[{42=>:enemy}, 42, "s:s", true], [{44=>:enemy}, 44, "s:s", true], [{60=>:enemy}, 60, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{42=>nil}, 42, "s:s", false], [{44=>nil}, 44, "s:s", false], [{60=>nil}, 60, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{62=>nil}, 62, "s:+s", false]], 53=>[[{43=>:enemy}, 43, "s:s", true], [{61=>:enemy}, 61, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{43=>nil}, 43, "s:s", false], [{61=>nil}, 61, "s:+s", false], [{62=>nil}, 62, "s:+s", false]], 54=>[[{46=>:enemy}, 46, "s:+s", true], [{63=>:enemy}, 63, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{46=>nil}, 46, "s:+s", false], [{63=>nil}, 63, "s:+s", false], [{64=>nil}, 64, "s:+s", false]], 55=>[[{45=>:enemy}, 45, "s:+s", true], [{47=>:enemy}, 47, "s:+s", true], [{63=>:enemy}, 63, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{45=>nil}, 45, "s:+s", false], [{47=>nil}, 47, "s:+s", false], [{63=>nil}, 63, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{65=>nil}, 65, "s:+s", false]], 56=>[[{46=>:enemy}, 46, "s:+s", true], [{48=>:enemy}, 48, "s:+s", true], [{64=>:enemy}, 64, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{46=>nil}, 46, "s:+s", false], [{48=>nil}, 48, "s:+s", false], [{64=>nil}, 64, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{66=>nil}, 66, "s:+s", false]], 57=>[[{47=>:enemy}, 47, "s:+s", true], [{49=>:enemy}, 49, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{47=>nil}, 47, "s:+s", false], [{49=>nil}, 49, "s:+s", false], [{65=>nil}, 65, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{67=>nil}, 67, "s:+s", false]], 58=>[[{48=>:enemy}, 48, "s:+s", true], [{50=>:enemy}, 50, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{48=>nil}, 48, "s:+s", false], [{50=>nil}, 50, "s:+s", false], [{66=>nil}, 66, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{68=>nil}, 68, "s:+s", false]], 59=>[[{49=>:enemy}, 49, "s:+s", true], [{51=>:enemy}, 51, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{49=>nil}, 49, "s:+s", false], [{51=>nil}, 51, "s:+s", false], [{67=>nil}, 67, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{69=>nil}, 69, "s:+s", false]], 60=>[[{50=>:enemy}, 50, "s:+s", true], [{52=>:enemy}, 52, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{50=>nil}, 50, "s:+s", false], [{52=>nil}, 52, "s:+s", false], [{68=>nil}, 68, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{70=>nil}, 70, "s:+s", false]], 61=>[[{51=>:enemy}, 51, "s:+s", true], [{53=>:enemy}, 53, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{51=>nil}, 51, "s:+s", false], [{53=>nil}, 53, "s:+s", false], [{69=>nil}, 69, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{71=>nil}, 71, "s:+s", false]], 62=>[[{52=>:enemy}, 52, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{52=>nil}, 52, "s:+s", false], [{70=>nil}, 70, "s:+s", false], [{71=>nil}, 71, "s:+s", false]], 63=>[[{55=>:enemy}, 55, "s:+s", true], [{72=>:enemy}, 72, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{55=>nil}, 55, "s:+s", false], [{72=>nil}, 72, "s:+s", false], [{73=>nil}, 73, "s:+s", false]], 64=>[[{54=>:enemy}, 54, "s:+s", true], [{56=>:enemy}, 56, "s:+s", true], [{72=>:enemy}, 72, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{54=>nil}, 54, "s:+s", false], [{56=>nil}, 56, "s:+s", false], [{72=>nil}, 72, "s:+s", false], [{73=>nil}, 73, "s:+s", false], [{74=>nil}, 74, "s:+s", false]], 65=>[[{55=>:enemy}, 55, "s:+s", true], [{57=>:enemy}, 57, "s:+s", true], [{73=>:enemy}, 73, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{55=>nil}, 55, "s:+s", false], [{57=>nil}, 57, "s:+s", false], [{73=>nil}, 73, "s:+s", false], [{74=>nil}, 74, "s:+s", false], [{75=>nil}, 75, "s:+s", false]], 66=>[[{56=>:enemy}, 56, "s:+s", true], [{58=>:enemy}, 58, "s:+s", true], [{74=>:enemy}, 74, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{56=>nil}, 56, "s:+s", false], [{58=>nil}, 58, "s:+s", false], [{74=>nil}, 74, "s:+s", false], [{75=>nil}, 75, "s:+s", false], [{76=>nil}, 76, "s:+s", false]], 67=>[[{57=>:enemy}, 57, "s:+s", true], [{59=>:enemy}, 59, "s:+s", true], [{75=>:enemy}, 75, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{57=>nil}, 57, "s:+s", false], [{59=>nil}, 59, "s:+s", false], [{75=>nil}, 75, "s:+s", false], [{76=>nil}, 76, "s:+s", false], [{77=>nil}, 77, "s:+s", false]], 68=>[[{58=>:enemy}, 58, "s:+s", true], [{60=>:enemy}, 60, "s:+s", true], [{76=>:enemy}, 76, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{58=>nil}, 58, "s:+s", false], [{60=>nil}, 60, "s:+s", false], [{76=>nil}, 76, "s:+s", false], [{77=>nil}, 77, "s:+s", false], [{78=>nil}, 78, "s:+s", false]], 69=>[[{59=>:enemy}, 59, "s:+s", true], [{61=>:enemy}, 61, "s:+s", true], [{77=>:enemy}, 77, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{59=>nil}, 59, "s:+s", false], [{61=>nil}, 61, "s:+s", false], [{77=>nil}, 77, "s:+s", false], [{78=>nil}, 78, "s:+s", false], [{79=>nil}, 79, "s:+s", false]], 70=>[[{60=>:enemy}, 60, "s:+s", true], [{62=>:enemy}, 62, "s:+s", true], [{78=>:enemy}, 78, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{80=>:enemy}, 80, "s:+s", true], [{60=>nil}, 60, "s:+s", false], [{62=>nil}, 62, "s:+s", false], [{78=>nil}, 78, "s:+s", false], [{79=>nil}, 79, "s:+s", false], [{80=>nil}, 80, "s:+s", false]], 71=>[[{61=>:enemy}, 61, "s:+s", true], [{79=>:enemy}, 79, "s:+s", true], [{80=>:enemy}, 80, "s:+s", true], [{61=>nil}, 61, "s:+s", false], [{79=>nil}, 79, "s:+s", false], [{80=>nil}, 80, "s:+s", false]], 72=>[[{64=>:enemy}, 64, "s:+s", true], [{64=>nil}, 64, "s:+s", false]], 73=>[[{63=>:enemy}, 63, "s:+s", true], [{65=>:enemy}, 65, "s:+s", true], [{63=>nil}, 63, "s:+s", false], [{65=>nil}, 65, "s:+s", false]], 74=>[[{64=>:enemy}, 64, "s:+s", true], [{66=>:enemy}, 66, "s:+s", true], [{64=>nil}, 64, "s:+s", false], [{66=>nil}, 66, "s:+s", false]], 75=>[[{65=>:enemy}, 65, "s:+s", true], [{67=>:enemy}, 67, "s:+s", true], [{65=>nil}, 65, "s:+s", false], [{67=>nil}, 67, "s:+s", false]], 76=>[[{66=>:enemy}, 66, "s:+s", true], [{68=>:enemy}, 68, "s:+s", true], [{66=>nil}, 66, "s:+s", false], [{68=>nil}, 68, "s:+s", false]], 77=>[[{67=>:enemy}, 67, "s:+s", true], [{69=>:enemy}, 69, "s:+s", true], [{67=>nil}, 67, "s:+s", false], [{69=>nil}, 69, "s:+s", false]], 78=>[[{68=>:enemy}, 68, "s:+s", true], [{70=>:enemy}, 70, "s:+s", true], [{68=>nil}, 68, "s:+s", false], [{70=>nil}, 70, "s:+s", false]], 79=>[[{69=>:enemy}, 69, "s:+s", true], [{71=>:enemy}, 71, "s:+s", true], [{69=>nil}, 69, "s:+s", false], [{71=>nil}, 71, "s:+s", false]], 80=>[[{70=>:enemy}, 70, "s:+s", true], [{70=>nil}, 70, "s:+s", false]], nil=>[[{0=>nil}, 0, "s:s", false], [{1=>nil}, 1, "s:s", false], [{2=>nil}, 2, "s:s", false], [{3=>nil}, 3, "s:s", false], [{4=>nil}, 4, "s:s", false], [{5=>nil}, 5, "s:s", false], [{6=>nil}, 6, "s:s", false], [{7=>nil}, 7, "s:s", false], [{8=>nil}, 8, "s:s", false], [{9=>nil}, 9, "s:s", false], [{10=>nil}, 10, "s:s", false], [{11=>nil}, 11, "s:s", false], [{12=>nil}, 12, "s:s", false], [{13=>nil}, 13, "s:s", false], [{14=>nil}, 14, "s:s", false], [{15=>nil}, 15, "s:s", false], [{16=>nil}, 16, "s:s", false], [{17=>nil}, 17, "s:s", false], [{18=>nil}, 18, "s:s", false], [{19=>nil}, 19, "s:s", false], [{20=>nil}, 20, "s:s", false], [{21=>nil}, 21, "s:s", false], [{22=>nil}, 22, "s:s", false], [{23=>nil}, 23, "s:s", false], [{24=>nil}, 24, "s:s", false], [{25=>nil}, 25, "s:s", false], [{26=>nil}, 26, "s:s", false], [{27=>nil}, 27, "s:s", false], [{28=>nil}, 28, "s:s", false], [{29=>nil}, 29, "s:s", false], [{30=>nil}, 30, "s:s", false], [{31=>nil}, 31, "s:s", false], [{32=>nil}, 32, "s:s", false], [{33=>nil}, 33, "s:s", false], [{34=>nil}, 34, "s:s", false], [{35=>nil}, 35, "s:s", false], [{36=>nil}, 36, "s:s", false], [{37=>nil}, 37, "s:s", false], [{38=>nil}, 38, "s:s", false], [{39=>nil}, 39, "s:s", false], [{40=>nil}, 40, "s:s", false], [{41=>nil}, 41, "s:s", false], [{42=>nil}, 42, "s:s", false], [{43=>nil}, 43, "s:s", false], [{44=>nil}, 44, "s:s", false], [{45=>nil}, 45, "s:s", false], [{46=>nil}, 46, "s:s", false], [{47=>nil}, 47, "s:s", false], [{48=>nil}, 48, "s:s", false], [{49=>nil}, 49, "s:s", false], [{50=>nil}, 50, "s:s", false], [{51=>nil}, 51, "s:s", false], [{52=>nil}, 52, "s:s", false], [{53=>nil}, 53, "s:s", false], [{54=>nil}, 54, "s:s", false], [{55=>nil}, 55, "s:s", false], [{56=>nil}, 56, "s:s", false], [{57=>nil}, 57, "s:s", false], [{58=>nil}, 58, "s:s", false], [{59=>nil}, 59, "s:s", false], [{60=>nil}, 60, "s:s", false], [{61=>nil}, 61, "s:s", false], [{62=>nil}, 62, "s:s", false], [{63=>nil}, 63, "s:s", false], [{64=>nil}, 64, "s:s", false], [{65=>nil}, 65, "s:s", false], [{66=>nil}, 66, "s:s", false], [{67=>nil}, 67, "s:s", false], [{68=>nil}, 68, "s:s", false], [{69=>nil}, 69, "s:s", false], [{70=>nil}, 70, "s:s", false], [{71=>nil}, 71, "s:s", false], [{72=>nil}, 72, "s:s", false], [{73=>nil}, 73, "s:s", false], [{74=>nil}, 74, "s:s", false], [{75=>nil}, 75, "s:s", false], [{76=>nil}, 76, "s:s", false], [{77=>nil}, 77, "s:s", false], [{78=>nil}, 78, "s:s", false], [{79=>nil}, 79, "s:s", false], [{80=>nil}, 80, "s:s", false]]}}
  end
end
